<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Chatgpt_Assistant
 * @subpackage Ays_Chatgpt_Assistant/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ays_Chatgpt_Assistant
 * @subpackage Ays_Chatgpt_Assistant/admin
 * @author     Ays_ChatGPT Assistant Team <info@ays-pro.com>
 */
class Chatgpt_Assistant_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * @var Chatgpt_Assistant_DB_Actions
	 */
	private $db_obj;
	private $front_settings_obj;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		global $wpdb;

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->dashboard_chat_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'dashboard_settings';
		$this->front_chat_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'front_settings';
		$this->settings_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'settings';
		$this->data_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'data';

		$this->db_obj = new Chatgpt_Assistant_DB_Actions( $this->plugin_name, $this->data_db_name );	


		// include_once(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/chatgpt-assistant-chatbox-display.php');
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Chatgpt_Assistant_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Chatgpt_Assistant_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name . '-chat-bot', plugin_dir_url(__FILE__) .  'css/chatgpt-assistant-chat-bot.css', array(), $this->version, 'all');
		
		if (false !== strpos($hook_suffix, $this->plugin_name)){		
			wp_enqueue_style( $this->plugin_name . '-select2', plugin_dir_url(__FILE__) .  'css/ays-select2.min.css', array(), $this->version, 'all');
			// wp_enqueue_style( $this->plugin_name . '-bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), $this->version, 'all');
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/chatgpt-assistant-admin.css', array(), $this->version . time(), 'all' );
			wp_enqueue_style( $this->plugin_name . '-banner', plugin_dir_url( __FILE__ ) . 'css/banner.css', array(), $this->version, 'all' );
		}
		
		if (strpos($hook_suffix, $this->plugin_name.'-settings') !== false || strpos($hook_suffix, $this->plugin_name.'-front-chat') !== false){		
			wp_enqueue_style( $this->plugin_name . '-bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), $this->version, 'all');
		}


	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Chatgpt_Assistant_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Chatgpt_Assistant_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if (false !== strpos($hook_suffix, "plugins.php")){
            wp_enqueue_script( $this->plugin_name . '-sweetalert-js', plugin_dir_url( __FILE__ ) . 'js/ays-chatgpt-assistant-sweetalert2.all.min.js', array('jquery'), $this->version, true );
            wp_enqueue_script( $this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'js/admin.js', array( 'jquery' ), $this->version, true );
            wp_localize_script( $this->plugin_name . '-admin', 'AysChatGptAdmin', array( 
            	'ajaxUrl' => admin_url( 'admin-ajax.php' )
            ) );
        }

		wp_enqueue_script( $this->plugin_name . "-popper", plugin_dir_url(__FILE__) . 'js/popper.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . "-bootstrap", plugin_dir_url(__FILE__) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, true );
        wp_enqueue_script( $this->plugin_name . '-select2js', plugin_dir_url( __FILE__ ) . 'js/ays-select2.min.js', array('jquery'), $this->version, true);
        wp_enqueue_script( $this->plugin_name . '-chat', plugin_dir_url( __FILE__ ) . 'js/chatgpt-assistant-admin-chat.js', array('jquery'), $this->version . time(), true);
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/chatgpt-assistant-admin.js', array( 'jquery' ), $this->version, true );
		wp_localize_script( $this->plugin_name . '-chat', 'AysChatGPTChatVars', array( 
			'ajaxUrl' => admin_url( 'admin-ajax.php' ),
			'selectPostType' => __( 'Select post type', $this->plugin_name ),
			'addImage'       => __( 'Add Image', $this->plugin_name ),
            'editImage'      => __( 'Edit Image', $this->plugin_name ),
            'removeImage'    => __( 'Remove Image', $this->plugin_name ),
		) );
		wp_enqueue_media();
		if ( false !== strpos( $hook_suffix, 'settings' ) ) {
			wp_enqueue_script( $this->plugin_name . '-settings', plugin_dir_url( __FILE__ ) . 'js/chatgpt-assistant-admin-settings.js', array( 'jquery' ), $this->version, true );

			wp_localize_script( $this->plugin_name . '-settings', 'aysChatGptAssistantAdminSettings', array(
				'selectUserRoles'                   => __( 'Select user roles', $this->plugin_name ),
				'delete'                            => __( 'Delete', $this->plugin_name ),
				'selectQuestionDefaultType'         => __( 'Select question default type', $this->plugin_name ),
				'yes'                               => __( 'Yes', $this->plugin_name ),
				'cancel'                            => __( 'Cancel', $this->plugin_name ),
				'somethingWentWrong'                => __( "Maybe something went wrong.", $this->plugin_name ),
				'failed'                            => __( 'Failed', $this->plugin_name ),
				'selectPage'                        => __( 'Select page', $this->plugin_name ),
				'selectPostType'                    => __( 'Select post type', $this->plugin_name ),
				'copied'                            => __( 'Copied!', $this->plugin_name),
				'clickForCopy'                      => __( 'Click to copy', $this->plugin_name),
				'selectForm'                        => __( 'Select form', $this->plugin_name),
			) );
		}
	}

	/**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    public function add_plugin_admin_menu(){
        global $wpdb;

        $menu_item = __( "ChatGPT Assistant", "ays-chatgpt-assistant" );
        $this->capability = $this->chatgpt_assistant_capabilities();

        $hook_page_view = add_menu_page(
            __( 'ChatGPT Assistant', "ays-chatgpt-assistant" ),
            $menu_item,
            $this->capability[0],
            $this->plugin_name,
            array($this, 'display_plugin_main_page'),
            CHATGPT_ASSISTANT_ADMIN_URL . '/images/icons/chatgpt-icon-menu.png',
            '6.224'
        );

		$this->db_obj = new Chatgpt_Assistant_DB_Actions( $this->plugin_name, $this->data_db_name );	
    }

	// Dashboard settings
	public function add_plugin_dashboard_chat_submenu(){
		$hook_settings = add_submenu_page( $this->plugin_name,
			__('Dashboard chat', $this->plugin_name),
			__('Dashboard chat', $this->plugin_name),
			'manage_options',
			$this->plugin_name . '-dashboard-chat',
			array($this, 'display_plugin_dashboard_chat_page')
		);
	}

	// Front settings
	public function add_plugin_front_chat_submenu(){
		$hook_settings = add_submenu_page( $this->plugin_name,
			__('Front chat', $this->plugin_name),
			__('Front chat', $this->plugin_name),
			'manage_options',
			$this->plugin_name . '-front-chat',
			array($this, 'display_plugin_front_chat_page')
		);

		$this->front_settings_obj = new ChatGPT_Assistant_Front_Chat_DB_Actions( $this->plugin_name , $this->front_chat_db_name);
	}

	public function add_plugin_general_settings_submenu(){
		$hook_settings = add_submenu_page( $this->plugin_name,
			__('Settings', $this->plugin_name),
			__('Settings', $this->plugin_name),
			'manage_options',
			$this->plugin_name . '-settings',
			array($this, 'display_plugin_settings_page')
		);		
		$this->settings_obj = new ChatGPT_Assistant_Settings_DB_Actions( $this->plugin_name , $this->settings_db_name );
		// add_action("load-$hook_settings", array($this, 'screen_option_settings'));
	}

	public function display_plugin_main_page(){
		if (isset( $_POST['ays_chatgpt_assistant_save_bttn'] )) {
			$this->db_obj->store_data();
		}
		
        include_once('partials/chatgpt-assistant-data-display.php');
    }

	public function display_plugin_dashboard_chat_page(){
		include_once('partials/dashboard-chat/chatgpt-assistant-dashboard-chat-display.php');
	}

	public function display_plugin_front_chat_page(){
		include_once('partials/front-chat/chatgpt-assistant-front-chat-display.php');
	}

	public function display_plugin_settings_page(){
		include_once('partials/settings/chatgpt-assistant-settings.php');
	}

	public function chatgpt_display_chat_icon(){
		$this->capability = $this->chatgpt_assistant_capabilities();
		if ($this->capability[1]) {
			include_once(plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/chatgpt-assistant-chatbox-display.php');
		}
    }

	public function set_global_settings(){
		$options = ($this->settings_obj->get_setting('options') === false) ? array() : json_decode($this->settings_obj->get_setting('options'), true);
		
		$this->chatbox_mode = ( isset( $options['chatbox_mode'] ) && $options['chatbox_mode'] != '' ) ? $options['chatbox_mode'] : 'light';

		// * GENERAL SETTINGS *
            // ===== Chat settings =====
			// Temprature
			$this->chatgpt_assistant_chat_temprature   = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] : '0.8';
			// Max tokens
			$this->chatgpt_assistant_max_tokens        = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens'] != '' ) ? intval($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens']) : 1500;
			// Frequency penalty
			$this->chatgpt_assistant_frequency_penalty = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] : '0.01';
			// Presence penalty
			$this->chatgpt_assistant_presence_penalty  = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] : '0.01';
			// Best of
			$this->chatgpt_assistant_best_of = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of'] != '' ) ? intval($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of']) : 1;
			// Chatbot position
			$this->chatbox_position          = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] : 'right';
		//

		// * STYLE SETTINGS *

			// Chat Widget background color
			$this->chatgpt_assistant_chatbox_background_color = isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color'] != '' ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color'] : '#ffffff';   
            $this->chatgpt_assistant_chatbox_background_color = !isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color']) && $this->chatbox_mode == 'dark' ? '#343541' : $this->chatgpt_assistant_chatbox_background_color;
			// Chatbot Response background color
			if ( !(isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color'] != '') ) {
				$this->response_bg_color = '#d3d3d3';
				if ($this->chatbox_mode == 'dark') {
					$this->response_bg_color = '#4b4d56';
				}
			} else {
				$this->response_bg_color = esc_attr($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color']);
			}
			// Chatbot User message background color
			if ( !(isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color'] != '') ) {
				$this->message_bg_color = '#4e426d';
				if ($this->chatbox_mode == 'dark') {
					$this->message_bg_color = '#343541';
				}
			} else {
				$this->message_bg_color = esc_attr($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color']);
			}
		//

		// Set Chatbot options for JS
		wp_localize_script( $this->plugin_name , 'AysChatGPTChatSettings', array( 
		    'chatTemprature' => $this->chatgpt_assistant_chat_temprature,
		    'chatMaxTokents' => $this->chatgpt_assistant_max_tokens,
		    'chatFrequencyPenalty' => $this->chatgpt_assistant_frequency_penalty,
		    'chatPresencePenalty' => $this->chatgpt_assistant_presence_penalty,
		    'chatBestOf' => $this->chatgpt_assistant_best_of,
			'chatboxPosition' => $this->chatbox_position
		) );
	}

	protected function chatgpt_assistant_capabilities(){
        global $wpdb;

        $sql = "SELECT meta_value FROM " . esc_sql( $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX ) . "settings WHERE `meta_key` = 'user_roles'";
        $result = $wpdb->get_var($sql);
        
        $capability = 'chatgpt_assistant_manage_options';
        $icon_capability = false;
        if($result !== null){
            $ays_user_roles = json_decode($result, true);
            if(is_user_logged_in()){
                $current_user = wp_get_current_user();
                $current_user_roles = $current_user->roles;
                $ishmar = 0;
                foreach($current_user_roles as $r){
                    if(in_array($r, $ays_user_roles)){
                        $ishmar++;
                    }
                }
                if($ishmar > 0){
                    $capability = "read";
					$icon_capability = true;
                }
            }
        }
        return array($capability, $icon_capability);
    }

	// ADMIN AJAX CALLS
	public function ays_chatgpt_get_post_type() {
        global $wpdb;
        $checked = isset($_REQUEST['val']) && $_REQUEST['val'] !='' ?  $_REQUEST['val']  : null;
        $search = isset($_REQUEST['q']) && $_REQUEST['q'] !='' ? sanitize_text_field( $_REQUEST['q'] ) . '%' : null;
        $pref_posts = $wpdb->prefix . "posts";

        if($search !== null){
        	$search_query = "SELECT DISTINCT( post_type ) FROM ".$pref_posts." WHERE post_type LIKE '". $search ."' ";
			$results = $wpdb->get_results($search_query);
        }

        $content_text = array(
            'results' => array()
        );

        foreach ($results as $value) {
            if ($checked !== null) {
                if (in_array($value->post_type, $checked)) {
                    continue;
                }else{
        			$p_type = get_post_types( [ 'name'=>$value->post_type ], 'objects' );
                    $content_text['results'][] = array(
                        'id' => $value->post_type,
                        'text' => $p_type[$value->post_type]->label,
                    );
                }
            }else{
                $p_type = get_post_types( [ 'name'=>$value->post_type ], 'objects' );
                $content_text['results'][] = array(
                    'id' => $value->post_type,
                    'text' => $p_type[$value->post_type]->label,
                );
            }
        }
        return $content_text;
	}

	public function ays_chatgpt_get_selected_posts() {
        $checked = isset( $_REQUEST['val'] ) && $_REQUEST['val'] !='' ? array_map( 'sanitize_text_field', $_REQUEST['val'] ) : null;
        $search = isset( $_REQUEST['q'] ) && $_REQUEST['q'] !='' ? sanitize_text_field( $_REQUEST['q'] ) : null;

        if($checked !== null){
	        $args = array(
				'post_type'   => $checked,
				'post_status' => 'publish',
				'numberposts' => -1
	        );
			if ($search !== null) {
				$args['s'] = $search;
			}

			$results = get_posts( $args );
		} else {
			$results = array();
		}

        $content_text = array(
            'results' => array()
        );

        foreach ($results as $value) {
            if ($checked !== null) {
                if (in_array($value->ID, $checked)) {
                    continue;
                }else{
                    $content_text['results'][] = array(
                        'id' => $value->ID,
                        'text' => $value->post_title,
                    );
                }
            }else{
             	$content_text['results'][] = array(
                    'id' => $value->ID,
                    'text' => $value->post_title,
                );
            }
        }
        return $content_text;
	}

	
	public function ays_chatgpt_admin_ajax(){
		global $wpdb;

		$response = array(
			"status" => false
		);

		$function = isset($_REQUEST['function']) ? sanitize_text_field( $_REQUEST['function'] ) : null;

		if($function !== null){
			$response = array();
			if( is_callable( array( $this, $function ) ) ){
				$response = $this->$function();

	            ob_end_clean();
	            $ob_get_clean = ob_get_clean();
				echo json_encode( $response );
				wp_die();
			}
        }
        ob_end_clean();
        $ob_get_clean = ob_get_clean();
		echo json_encode( $response );
		wp_die();
	}

	public function ays_chatgpt_connect(){
		$api_key      = isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_api_key']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_api_key'] != '' ? esc_attr($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_api_key']) : '';
		$method       = isset($_REQUEST['rMethod']) && $_REQUEST['rMethod'] != '' ? esc_attr($_REQUEST['rMethod']) : '';
		$request_type = isset($_REQUEST['request_type']) && $_REQUEST['request_type'] != '' ? esc_attr($_REQUEST['request_type']) : '';
		$check_openai_connection_code = false;
		$check_openai_connection = ChatGPT_assistant_Data::makeRequest($api_key, 'GET', 'models');
		$check_openai_connection_code = false;
		
		if(is_array($check_openai_connection)){
			$check_openai_connection_code = isset($check_openai_connection['openai_response_code']) && $check_openai_connection['openai_response_code'] == 200 ? true : false; 
		}
		if($check_openai_connection_code){
			$this->db_obj->store_data();
		}

		return $check_openai_connection;
	}

	public function ays_chatgpt_disconnect(){
		$id = isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_id']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_id'] != '' ? esc_attr($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_id']) : '';

		$status = $this->db_obj->update_setting($id , "" , 'api_key' , 'id');		

		return $status;
	}
	//

	public function chatgpt_assistant_general_admin_notice(){
        global $wpdb;
        if ( isset($_GET['page']) && strpos($_GET['page'], CHATGPT_ASSISTANT_NAME) !== false ){ ?>
            
             <div class="ays-notice-banner">
                <div class="navigation-bar">
                    <div id="navigation-container">
                        <a href="https://ays-pro.com/wordpress/chatgpt-assistant" class="logo-container" href="https://ays-pro.com/wordpress/chatgpt-assistant" target="_blank">
                            <img class="logo" src="<?php echo esc_url(CHATGPT_ASSISTANT_ADMIN_URL) . '/images/icons/chatgpt-icon.png'; ?>" alt="ChatGPT Assistant logo" title="ChatGPT Assistant logo"/>
						</a>
                        <ul id="menu">
                            <!-- <li class="modile-ddmenu-xss"><a class="ays-btn" href="https://ays-pro.com/wordpress/chatgpt-assistant/" target="_blank">PRO</a></li> -->
                            <!-- <li class="modile-ddmenu-xs"><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/reviews/?rate=5#new-post" target="_blank">Rate Us</a></li> -->
                            <!-- <li class="modile-ddmenu-xss"><a class="ays-btn" href="https://ays-pro.com/wordpress/chatgpt-assistant/" target="_blank"><img src="<?php echo esc_url(CHATGPT_ASSISTANT_ADMIN_URL) . '/images/icons/lightning.svg'; ?>"/>Upgrade</a></li> -->
                            <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://plugins.ays-demo.com/wordpress-chatgpt-plugin-demo/" target="_blank">DEMO</a></li>
                            <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://ays-pro.com/wordpress-chatgpt-assistant-user-manual" target="_blank">DOCUMENTATION</a></li>
                            <!-- <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">SUPPORT FORUM</a></li> -->
                            <!-- <li class="modile-ddmenu-lg take_survay"><a class="ays-btn" href="https://ays-demo.com/chatgpt-assistant-plugin-suggestion-box/" target="_blank">MAKE A SUGGESTION</a></li> -->
                            <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">CONTACT US</a></li>
                            <li class="modile-ddmenu-md">
                                <a class="toggle_ddmenu" href="javascript:void(0);"><img src="<?php echo esc_url(CHATGPT_ASSISTANT_ADMIN_URL) . '/images/icons/ellipsis.svg'; ?>"/></a>
                                <ul class="ddmenu" data-expanded="false">
                                    <li><a class="ays-btn" href="https://plugins.ays-demo.com/wordpress-chatgpt-plugin-demo/" target="_blank">DEMO</a></li>
                                    <li><a class="ays-btn" href="https://ays-pro.com/wordpress-chatgpt-assistant-user-manual" target="_blank">DOCUMENTATION</a></li>
                                    <!-- <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">SUPPORT FORUM</a></li> -->
                                    <!-- <li class="take_survay"><a class="ays-btn" href="https://ays-demo.com/chatgpt-assistant-plugin-suggestion-box/" target="_blank">MAKE A SUGGESTION</a></li> -->
                                    <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">CONTACT US</a></li>
                                </ul>
                            </li>
                            <li class="modile-ddmenu-sm">
                                <a class="toggle_ddmenu" href="javascript:void(0);"><img src="<?php echo esc_url(CHATGPT_ASSISTANT_ADMIN_URL) . '/images/icons/ellipsis.svg'; ?>"/></a>
                                <ul class="ddmenu" data-expanded="false">
                                    <!-- <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/reviews/?rate=5#new-post" target="_blank">RATE US</a></li> -->
                                    <li><a class="ays-btn" href="https://ays-demo.com/chatgpt-assistant-demo/" target="_blank">DEMO</a></li>
                                    <li><a class="ays-btn" href="https://ays-pro.com/wordpress-chatgpt-assistant-user-manual" target="_blank">DOCUMENTATION</a></li>
                                    <!-- <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">SUPPORT FORUM</a></li> -->
                                    <!-- <li class="take_survay"><a class="ays-btn" href="https://ays-demo.com/chatgpt-assistant-plugin-suggestion-box/" target="_blank">MAKE A SUGGESTION</a></li> -->
                                    <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-chatgpt-assistant/" target="_blank">CONTACT US</a></li>
                                </ul>
                            </li>
                        </ul>
                    </div>
                </div>
             </div>
		<?php }
    }

	public function add_action_links($links){
        /*
        *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
        */
        $settings_link = array(
            '<a href="' . admin_url('admin.php?page=' . $this->plugin_name) . '">' . __('Settings', "ays-chatgpt-assistant") . '</a>',
            '<a href="https://plugins.ays-demo.com/wordpress-chatgpt-plugin-demo/" target="_blank">' . __('Demo', "ays-chatgpt-assistant") . '</a>',
        );
        return array_merge($settings_link, $links);

    }

	public function deactivate_plugin_option(){
        $request_value = $_REQUEST['upgrade_plugin'];
        $upgrade_option = get_option( 'ays_chatgpt_assistant_upgrade_plugin', '' );
        if($upgrade_option === ''){
            add_option( 'ays_chatgpt_assistant_upgrade_plugin', $request_value );
        }else{
            update_option( 'ays_chatgpt_assistant_upgrade_plugin', $request_value );
        }
        return json_encode( array( 'option' => get_option( 'ays_chatgpt_assistant_upgrade_plugin', '' ) ) );
    }


}
