(function($) {
    'use strict';
    function AysChatGPTChat(element, options){
        this.el = element;
        this.$el = $(element);
        this.ajaxAction = 'ays_chart_admin_ajax';
        this.htmlClassPrefix = 'ays-chart-';
        this.htmlNamePrefix = 'ays_';
        this.dbOptions = undefined;
        this.chartSourceData = undefined;
		this.chartObj = undefined;
		this.chartOptions = null;
		this.chartData = null;
		this.chartTempData = null;

		this.chartSources = {
			'bar_chart'    : 'Bar Chart',
			'pie_chart'    : 'Pie Chart',
			'column_chart' : 'Column Chart'
		}

        this.init();

        return this;
    }

    AysChatGPTChat.prototype.init = function() {
        var _this = this;
		_this.chartSourceData = window.ChartBuilderSourceData;
        _this.setEvents();

    };

	// Set events
    AysChatGPTChat.prototype.setEvents = function(e){
		var _this = this;		
		_this.setSelect2();
        _this.$el.on('click', '.ays-chatgpt-assistant-display-type-select', function(){
            var selectedType = $(this).find("input[type=radio]").val();
            var postsBox     = _this.$el.find('.ays-chatgpt-assistant-view-place');
            if(selectedType != "all"){
                postsBox.removeClass("display_none");
            }
            else{
                postsBox.addClass("display_none");
            }
        });

        _this.$el.on('change', '#ays-chatgpt-assistant-access-for-logged-in', function(){
            if ($(this).prop("checked")) {
                _this.$el.find('.ays-chatgpt-assistant-logged-in-suboption').removeClass("display_none");
            } else {
                _this.$el.find('.ays-chatgpt-assistant-logged-in-suboption').addClass("display_none");
            }
        });

        _this.$el.on('click', '.ays-chatgpt-assistant-add-chat-icon', function (e) {
            _this.openMediaUploaderForLogoImage(e, $(this));
        });

        $(document).on('click', '.ays-chatgpt-assistant-logo-remove', function (e) {
            _this.removeSelectedImage($(this));
        });

    }

    AysChatGPTChat.prototype.removeSelectedImage = function(e) {
        var $this = e;
        $this.parents('.ays-chatgpt-assistant-image-container').find('.ays-chatgpt-assistant-image-body').fadeOut(300);
        $this.parents('.ays-chatgpt-assistant-image-container').find('.ays-chatgpt-assistant-add-chat-icon').text( AysChatGPTChatVars.addImage );
        setTimeout(function(){
            $this.parents('.ays-chatgpt-assistant-image-container').find('.ays-chatgpt-assistant-img').removeAttr('src');
            $this.parents('.ays-chatgpt-assistant-image-container').find('.ays-chatgpt-assistant-img-src').val('');
        }, 300);
    }

    AysChatGPTChat.prototype.openMediaUploaderForLogoImage = function(e, element) {
        e.preventDefault();
        var aysUploader = wp.media({
            title: 'Upload',
            button: {
                text: 'Upload'
            },
            library: {
                type: 'image'
            },
            multiple: false
        }).on('select', function () {
            var attachment = aysUploader.state().get('selection').first().toJSON();
            var answerImgCont = element.parents('.ays-chatgpt-assistant-image-container').find('.ays-chatgpt-assistant-image-body');
            var img = answerImgCont.find('img.ays-chatgpt-assistant-img');
            var hiddenInp = answerImgCont.find('input.ays-chatgpt-assistant-img-src');

            element.text( AysChatGPTChatVars.editImage );
            img.attr('src', attachment.url);
            hiddenInp.val(attachment.url);
            answerImgCont.show();
            img.removeClass('fade');
        }).open();
        return false;
    }

	AysChatGPTChat.prototype.setSelect2 = function(){
		var _this = this;
		// Select2 functionality for Post types
		var selectPostTypeBox = _this.$el.find('#ays_pb_post_types');
		var selectPostTypeData = {
            placeholder: AysChatGPTChatVars.selectPostType,
            allowClear: true,
            minimumInputLength: 3,
            multiple: true,
            ajax: {
                url: AysChatGPTChatVars.ajaxUrl,
                dataType: 'json',
                data: function (params) {
                    var checkedUsers = $(document).find('#ays_pb_post_types').val();
                    return {
                        action: 'ays_chatgpt_admin_ajax',
                        function: 'ays_chatgpt_get_post_type',
                        q: params.term,
                        val: checkedUsers,
                        page: params.page
                    };
                },
            }
        };
		selectPostTypeBox.select2(selectPostTypeData);

		// Select2 functionality for Posts
		var selectPostBox = _this.$el.find('#ays_pb_posts');
		var selectPostData = {
            allowClear: true,
            placeholder: AysChatGPTChatVars.selectPostType,
            minimumInputLength: 3,
            multiple: true,
            ajax: {
                url:  AysChatGPTChatVars.ajaxUrl,
                dataType: 'json',
                data: function (params) {
                    var checkedUsers = $(document).find('#ays_pb_post_types').val();
                    return {
                        action: 'ays_chatgpt_admin_ajax',
                        function: 'ays_chatgpt_get_selected_posts',
                        q: params.term,
                        val: checkedUsers,
                        page: params.page
                    };
                },
            }
        };
		selectPostBox.select2(selectPostData);

        _this.$el.find('#ays-chatgpt-assistant-user-roles').select2();
    }



	$.fn.AysChatGPTChatMain = function(options) {
        return this.each(function() {
            if (!$.data(this, 'AysChatGPTChatMain')) {
                $.data(this, 'AysChatGPTChatMain', new AysChatGPTChat(this, options));
            } else {
                try {
                    $(this).data('AysChatGPTChatMain').init();
                } catch (err) {
                    console.error('AysChatGPTChatMain has not initiated properly');
                }
            }
        });
    };
    $(document).find('#ays-chat-form').AysChatGPTChatMain();

})(jQuery);