<?php

if( ! class_exists( 'ChatGPT_Assistant_Front_Chat_DB_Actions' ) ){
	ob_start();

	/**
	 * Class ChatGPT_Assistant_Settings_DB_Actions
	 * Class contains functions to interact with settings database
	 *
	 * Main functionality belong to inserting, updating and deleting
	 *
	 * Hooks used in the class
	 * @hooks           @filters        ays_chatgpt_assistant_item_save_settings
	 *
	 * Database tables without prefixes
	 * @tables          settings
	 *
	 * @param           $plugin_name
	 *
	 * @since           1.0.0
	 * @package         Ays_Chatgpt_Assistant
 	 * @subpackage      Ays_Chatgpt_Assistant/includes
 	 * @author          Ays_ChatGPT Assistant Team <info@ays-pro.com>
	 */
    class ChatGPT_Assistant_Front_Chat_DB_Actions extends ChatGPT_Assistant_Main_DB_Actions {

        public function store_data(){
            if( isset( $_REQUEST["front_chat_action"] ) && wp_verify_nonce( $_REQUEST["front_chat_action"], 'front_chat_action' ) ){
                // $success = 0;
                // $name_prefix = 'ays_';
				$default_user_roles = json_encode(array(
					'administrator',
					'editor',
					'author',
					'contributor',
					'subscriber',
					'translator'
				));

				$settings = array();

				// == Sanitize in the loop all values except checkboxes, radios (only for settings array). The latter sanitize separately (out of loop) ==				
                if( isset( $_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ] ) && !empty( $_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ] )) {
					foreach($_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ] as $each_setting_key => $each_setting_value){
						if(is_array($each_setting_value)){
							$settings[$each_setting_key] = json_encode($each_setting_value);
						}
						else{
							$each_setting_value = isset($each_setting_value) && $each_setting_value != '' ? sanitize_text_field($each_setting_value) : '';
							$each_setting_key   = isset($each_setting_key) && $each_setting_key != '' ? sanitize_text_field($each_setting_key) : '';
							$settings[$each_setting_key] = $each_setting_value;
						}
                    }
                }
				
				// == Sanitize checkboxes, radios, selects here ==
				$settings['show_on_home_page'] = ( isset( $settings['show_on_home_page'] ) && $settings['show_on_home_page'] != '' ) ? sanitize_text_field($settings['show_on_home_page']) : 'off';
				$settings['except_post_types'] = ( isset( $settings['except_post_types'] ) && $settings['except_post_types'] != '' ) ? sanitize_text_field($settings['except_post_types']) : '[]';
				$settings['except_posts'] = ( isset( $settings['except_posts'] ) && $settings['except_posts'] != '' ) ? sanitize_text_field($settings['except_posts']) : '[]';
				$settings['access_for_guests'] = ( isset( $settings['access_for_guests'] ) && $settings['access_for_guests'] != '' ) ? sanitize_text_field($settings['access_for_guests']) : 'off';
				$settings['access_for_logged_in'] = ( isset( $settings['access_for_logged_in'] ) && $settings['access_for_logged_in'] != '' ) ? sanitize_text_field($settings['access_for_logged_in']) : 'off';
				$settings['user_roles'] = ( isset( $settings['user_roles'] ) && $settings['user_roles'] != '' ) ? sanitize_text_field($settings['user_roles']) : $default_user_roles;

				// Refactoring later start
				
				$post_type_for_allfeld = array();
					$all_post_types = isset($_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ]['except_post_types']) && is_array($_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ]['except_post_types']) ? array_map( 'sanitize_text_field', $_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ]['except_post_types'] ) : array();
				
					if ( isset( $_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ]['except_posts'] ) && !empty($all_post_types) ) {
						foreach ($all_post_types as $post_type) {
							$all_posts = get_posts( array(
								'numberposts' => -1,			
								'post_type'   => $post_type,
								'suppress_filters' => true,
							));
							if (!empty($all_posts)) {
								foreach ($all_posts as $posts_value) {	
									if ( in_array( $posts_value->ID, array_map( 'sanitize_text_field', $_REQUEST[ CHATGPT_ASSISTANT_NAME_PREFIX . '_settings' ]['except_posts'] ) ) ) {
									
										$not_post_type = false;
										break;
									}else{
										$not_post_type = true;
									}	        		
								}

								if ($not_post_type) {
									$post_type_for_allfeld[] = $post_type;
								}
							}else{
								$post_type_for_allfeld[] = $post_type;
							}
						}
					}else{
						$post_type_for_allfeld = $all_post_types;
					}
				$settings['all_posts'] = json_encode($post_type_for_allfeld);
				// Refactoring later end
				if( is_array( $settings ) && ! empty( $settings ) ){
					foreach ( $settings as $meta_key => $meta_value ){
						if( $this->get_setting( $meta_key , 'id' ) ) {
							$this->update_setting($meta_key, $meta_value );
						}else{
							$this->add_setting( $meta_key, $meta_value );
						}
					}
				}

                $message = "saved";
                // if($success > 0){
                    $url = admin_url('admin.php') . '?page=' . $this->plugin_name .'-front-chat' . '&status=' . $message;
                    wp_redirect( $url );
                    exit();
                // }
            }

        }
    }
}
