<?php

if( ! class_exists( 'ChatGPT_Assistant_Settings_DB_Actions' ) ){
	ob_start();

	/**
	 * Class ChatGPT_Assistant_Settings_DB_Actions
	 * Class contains functions to interact with settings database
	 *
	 * Main functionality belong to inserting, updating and deleting
	 *
	 * Hooks used in the class
	 * @hooks           @filters        ays_chatgpt_assistant_item_save_settings
	 *
	 * Database tables without prefixes
	 * @tables          settings
	 *
	 * @param           $plugin_name
	 *
	 * @since           1.0.0
	 * @package         Ays_Chatgpt_Assistant
 	 * @subpackage      Ays_Chatgpt_Assistant/includes
 	 * @author          Ays_ChatGPT Assistant Team <info@ays-pro.com>
	 */
    class ChatGPT_Assistant_Settings_DB_Actions extends ChatGPT_Assistant_Main_DB_Actions{

        public function store_data(){

            if( isset( $_REQUEST["settings_action"] ) && wp_verify_nonce( $_REQUEST["settings_action"], 'settings_action' ) ){
                $success = 0;
                
                // * GENERAL SETTINGS *
                    // ===== Chat settings =====
                    // Who will have permission to ChatGPT Assistant
                    $user_roles = (isset($_REQUEST['ays_user_roles']) && !empty($_REQUEST['ays_user_roles'])) ? array_map( 'sanitize_text_field', $_REQUEST['ays_user_roles'] ) : array('administrator');
                    // Show chat window on front end
                    $chatbox_onoff = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_onoff']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_onoff'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_onoff']) : 'off';
                    // Temprature
                    $chatgpt_assistant_chat_temprature = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chat_temprature']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chat_temprature'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chat_temprature']) : '0.8';
                    // Max tokens
                    $chatgpt_assistant_max_tokens = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_max_tokens']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_max_tokens'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_max_tokens']) : 1500;                    
                    // Frequency penalty
                    $chatgpt_assistant_frequency_penalty = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_frequency_penalty']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_frequency_penalty'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_frequency_penalty']) : '0.01';                    
                    // Presence penalty
                    $chatgpt_assistant_presence_penalty = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_presence_penalty']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_presence_penalty'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_presence_penalty']) : '0.01';
                    // Best of
                    $chatgpt_assistant_best_of = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_best_of']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_best_of'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_best_of']) : 1;
                    // Chatbot position
                    $chatbox_position = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_position']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_position'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_position']) : 'right';
                //

                // * STYLE SETTINGS *
                    // Chat Widget color
                    $chatbox_color = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_color']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_color'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_color']) : '#4ac7a5' ;
                    // Chat Widget background color
                    $chatgpt_assistant_chatbox_background_color = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_background_color']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_background_color'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_background_color']) : '#ffffff' ;
                    // Chat dark mode
                    $chatbox_mode  = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_mode']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_mode'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_chatbox_mode']) : 'light';
                    // Response background color
                    $response_bg_color = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_response_bg_color']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_response_bg_color'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_response_bg_color']) : '#d3d3d3';
                    // User message background color
                    $message_bg_color = (isset($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_message_bg_color']) && $_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_message_bg_color'] != '') ? sanitize_text_field($_REQUEST[CHATGPT_ASSISTANT_NAME_PREFIX.'_message_bg_color']) : '#4e426d';
                //

                $options = array(
                    // * GENERAL SETTINGS *
                    // User roles options
                    "user_roles_to_access" => $user_roles,
                    "chatbox_onoff"        => $chatbox_onoff,                                        
                    // Chat settings
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'   => $chatgpt_assistant_chat_temprature,
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens'        => $chatgpt_assistant_max_tokens,
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty' => $chatgpt_assistant_frequency_penalty,
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'  => $chatgpt_assistant_presence_penalty,
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of'           => $chatgpt_assistant_best_of,
					CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'          => $chatbox_position,
					// * STYLE SETTINGS *
					'chatbox_color' => $chatbox_color,
                    CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color' => $chatgpt_assistant_chatbox_background_color,
					'chatbox_mode'  => $chatbox_mode,
                    CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color' => $response_bg_color,
                    CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color'  => $message_bg_color,

                );

                $fields = array();

                $fields['user_roles'] = $user_roles;
                $fields['options'] = $options;

                foreach ($fields as $key => $value) {
                    $result = $this->update_setting( $key, json_encode( $value ) );
                    if($result){
                        $success++;
                    }
                }

                $message = "saved";
                if($success > 0){
                    $tab = "";
                    if( isset( $_REQUEST['ays_tab'] ) ){
                        $tab = "&ays_tab=". sanitize_text_field( $_REQUEST['ays_tab'] );
                    }

                    $url = admin_url('admin.php') . "?page=". $this->plugin_name ."-settings" . $tab . '&status=' . $message;
                    wp_redirect( $url );
                    exit();
                }
            }

        }
    }
}
