<?php

class ChatGPT_assistant_Data {

    public static function makeRequest($api_key, $method, $request_type, $options = []){
        $response_data = array(
            'openai_response_code' => 400,
            'openai_response_data' => array(),
        );

        $REQUEST_MAIN_URL = 'https://api.openai.com';
        $API_VERSION = 'v1';
        $COMPLETION_URL = '/completions';

        if ($api_key == '') {
            return  $response_data = array(
                'openai_response_code' => 400,
                'openai_response_data' => array(),
                'openai_response_message' => 'API KEY is not provided',
            );
        }

        if ($method == '' || $request_type == '') {
            return $response_data;
        }

        // Set options        
        if(isset($options) && !empty($options)){
            $model  = isset($options['model']) && $options['model'] != '' ? $options['model'] : 'text-davinci-003';
            $prompt = isset($options['prompt']) && $options['prompt'] != '' ? sanitize_text_field(trim($options['prompt'])) : '';
            $prompt = 'Converse as if you were an AI assistant. Answer the question as truthfully as possible. '.$prompt. '.';
            $temperature = isset($options['temperature']) && $options['temperature'] != '' ? sanitize_text_field(($options['temperature'])) : 0.7;
            $max_tokens = isset($options['max_tokens']) && $options['max_tokens'] != '' ? sanitize_text_field(($options['max_tokens'])) : 1500;
            $frequency_penalty = isset($options['frequency_penalty']) && $options['frequency_penalty'] != '' ? sanitize_text_field(($options['frequency_penalty'])) : 0.01;
            $presence_penalty  = isset($options['presence_penalty ']) && $options['presence_penalty '] != '' ? sanitize_text_field(($options['presence_penaltypresence_penalty '])) : 0.01;
            $best_of  = isset($options['best_of ']) && $options['best_of '] != '' ? sanitize_text_field(($options['best_of '])) : 1;
        }
        
        // Build Url
        $request_type = '/'.$request_type;
        $url = $REQUEST_MAIN_URL . '/' . $API_VERSION . $request_type;
        $url = esc_url($url);
        // 
        
        // Create Headers
        $headers = array(
                "Content-Type"  => "application/json",
                "Authorization" => "Bearer ".$api_key
            );
        //


        // Create request
        $request_data = array(
            "headers" => $headers,          
            "method " => $method,
        );

        if($method != 'GET'){            
            // Create Body        
            $body = array(
                "model" => $model,
                "prompt" => $prompts,
                "temperature" => $temperature,
                "max_tokens" => $max_tokens,
                "frequency_penalty" => $frequency_penalty,
                "presence_penalty" => $presence_penalty,
                "best_of" => $best_of,
            );

            $body = json_encode($body);            
            $request_data['body'] = $body;
        }
        //

        // Send request
        $api_call = wp_remote_request( $url , $request_data);
        $response_code = wp_remote_retrieve_response_code( $api_call );
        $get_data = wp_remote_retrieve_body($api_call);
        $response = json_decode($get_data , true);
        if($response_code == 200){
            if(!array_key_exists('error', $response)){
                $response_data = array(
                    'openai_response_code' => $response_code,
                    'openai_response_data' => $response,
                    'openai_response_message' => 'success',
                );
            }            
        }
        else{
            $response_error_message = isset($response['error']['message']) && $response['error']['message'] != '' ? $response['error']['message'] : '';
            $response_data = array(
                'openai_response_code' => $response_code,
                'openai_response_data' => $response,
                'openai_response_message' => $response_error_message,
            );
        }
        return $response_data;
    }

    public static function get_chatbot_styles($options){
		$styles = '<style>';
		if ($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] == 'center'){
			$styles .= '
						div.ays-assistant-chatbox div.ays-assistant-chatbox-main-container {
							left: 50%;
							transform: translateX(-50%);
						}
						div.ays-assistant-chatbox div.ays-assistant-chatbox-closed-view {
							left: 50%;
							/* transform: translateX(-50%); */
						}
			';
		}
		elseif($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] == 'left'){
			$styles .= '
						div.ays-assistant-chatbox div.ays-assistant-chatbox-main-container {
							left: 0;
							right: unset;
						}
						div.ays-assistant-chatbox div.ays-assistant-chatbox-closed-view {
							left: 20px;
							right: unset;
						}
			';
		}
		else{
			$styles .= '
						div.ays-assistant-chatbox div.ays-assistant-chatbox-main-container {
							right: 0;
						}
						div.ays-assistant-chatbox div.ays-assistant-chatbox-closed-view {
							right: 20px;
						}
			';
		}
			$styles .= '
						div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-header-row,
						div.ays-assistant-chatbox-main-container button.ays-assistant-chatbox-send-button {
							background-color: '.$options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_color'].';
						}
						div.ays-assistant-chatbox-main-container button.ays-assistant-chatbox-send-button:disabled {
							background-color: '.$options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_color'].'2b;
						}
						.ays-assistant-chatbox[colmode] div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-main-chat-box {
							background-color: '.$options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color'].';
						}
						div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-ai-message-box,
						div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-loading-box {
							background-color: '.$options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color'].';
						}
						div.ays-assistant-chatbox-main-container div.ays-assistant-chatbox-messages-box div.ays-assistant-chatbox-user-message-box {
							background-color: '.$options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color'].';
						}
			';

		$styles .= '</style>';
						
		return $styles;
	}

}
