<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Chatgpt_Assistant
 * @subpackage Ays_Chatgpt_Assistant/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ays_Chatgpt_Assistant
 * @subpackage Ays_Chatgpt_Assistant/public
 * @author     Ays_ChatGPT Assistant Team <info@ays-pro.com>
 */
class Chatgpt_Assistant_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		global $wpdb;
		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->dashboard_chat_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'dashboard_settings';
		$this->front_chat_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'front_settings';
		$this->settings_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'settings';
		$this->data_db_name = $wpdb->prefix . CHATGPT_ASSISTANT_DB_PREFIX . 'data';

		add_shortcode( 'chatgpt_assistant', array($this, 'ays_generate_chatbox') );
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Chatgpt_Assistant_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Chatgpt_Assistant_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/chatgpt-assistant-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Chatgpt_Assistant_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Chatgpt_Assistant_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/chatgpt-assistant-public.js', array( 'jquery' ), $this->version, true );

	}

	public function ays_chatgpt_shortcodes_show_all () {
		echo do_shortcode('[chatgpt_assistant]');
	}

	public function ays_generate_chatbox () {
		global $wpdb;		
		// Set main DB objects
		$this->set_db_objects();
		// Set main settings
		$this->set_global_main_settings_options();
		// Set front settings
		$this->set_global_front_settings_options();

		// * LIMITATIONS *
		$show_chat = array();
			// Displaying Limitation
			$show_chat[] = $this->check_chatbot_display_limitations();
			// Users/Guests Limitation
			$show_chat[] = $this->check_chatbot_user_limitations();
			// $limitations = false;
			$this->check_limitations($show_chat);
		//
		return $this->show_chatgpt_assistant();
		 
	}
	
	public function set_db_objects(){
		$this->db_obj = new Chatgpt_Assistant_DB_Actions( $this->plugin_name , $this->data_db_name);
		$this->settings_obj = new ChatGPT_Assistant_Settings_DB_Actions( $this->plugin_name , $this->settings_db_name);
		$this->front_settings_obj = new ChatGPT_Assistant_Front_Chat_DB_Actions( $this->plugin_name , $this->front_chat_db_name );
	}

	// Get and set main db settings (API key, ...)
	public function set_global_main_settings_options(){
		$data = $this->db_obj->get_data();
		$this->api_key = isset( $data['api_key'] ) && $data['api_key'] != '' ? esc_attr( $data['api_key'] ) : '';
	}

	// Get and set front settings
	public function set_global_front_settings_options(){

		$default_user_roles = array(
			'administrator',
			'editor',
			'author',
			'contributor',
			'subscriber',
			'translator'
		);

		$front_chat_options = (empty($this->front_settings_obj->get_all_data())) ? array() : $this->front_settings_obj->get_all_data();

		$this->show_all     = isset($front_chat_options['chatgpt_assistant_display_chat_on_page']) && $front_chat_options['chatgpt_assistant_display_chat_on_page'] != "" ? $front_chat_options['chatgpt_assistant_display_chat_on_page'] : 'all';

		$this->access_for_guests    = isset($front_chat_options['chatgpt_assistant_access_for_guests']) && $front_chat_options['chatgpt_assistant_access_for_guests'] != "" ? $front_chat_options['chatgpt_assistant_access_for_guests'] : 'on';
		$this->access_for_logged_in = isset($front_chat_options['chatgpt_assistant_access_for_logged_in']) && $front_chat_options['chatgpt_assistant_access_for_logged_in'] != "" ? $front_chat_options['chatgpt_assistant_access_for_logged_in'] : 'on';
		
		$this->user_roles = isset($front_chat_options['chatgpt_assistant_user_roles']) && $front_chat_options['chatgpt_assistant_user_roles'] != "" ? json_decode($front_chat_options['chatgpt_assistant_user_roles']) : $default_user_roles;

		$this->chat_icon  = isset($front_chat_options['chatgpt_assistant_chat_icon']) && $front_chat_options['chatgpt_assistant_chat_icon'] != "" ? esc_attr($front_chat_options['chatgpt_assistant_chat_icon']) : esc_attr(CHATGPT_ASSISTANT_ADMIN_URL) . "/images/icons/chatgpt-icon.png";

		$this->except_posts = isset($front_chat_options['chatgpt_assistant_except_posts']) && !empty($front_chat_options['chatgpt_assistant_except_posts']) ? json_decode($front_chat_options['chatgpt_assistant_except_posts'], true) : array();

		$this->except_post_types = isset($front_chat_options['chatgpt_assistant_except_post_types']) && !empty($front_chat_options['chatgpt_assistant_except_post_types']) ? json_decode($front_chat_options['chatgpt_assistant_except_post_types'] , true) : array();	
		
		$this->except_all_post_types = ( isset( $front_chat_options['chatgpt_assistant_all_posts'] ) && $front_chat_options['chatgpt_assistant_all_posts'] != '' ) ? json_decode($front_chat_options['chatgpt_assistant_all_posts'], true) : array();

		$this->show_on_home_page     = ( isset($front_chat_options['chatgpt_assistant_show_on_home_page']) && $front_chat_options['chatgpt_assistant_show_on_home_page'] == 'on' ) ? true : false;

	}

	// Get and set global settings
	public function set_global_settings_options(){
		$options = ($this->settings_obj->get_setting('options') === false) ? array() : json_decode($this->settings_obj->get_setting('options'), true);
		
		$this->chatbox_color = (isset($options['chatbox_color']) && $options['chatbox_color'] != '' ) ? $options['chatbox_color'] : '#4e426d';
		$this->chatbox_mode  = ( isset( $options['chatbox_mode'] ) && $options['chatbox_mode'] != '' ) ? $options['chatbox_mode'] : 'light';
		$this->chatbox_onoff = ( isset( $options['chatbox_onoff'] ) && $options['chatbox_onoff'] != '' ) ? $options['chatbox_onoff'] : 'off';

		// * GENERAL SETTINGS *
            // ===== Chat settings =====
			// Temprature
			$this->chatgpt_assistant_chat_temprature   = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chat_temprature'] : '0.8';
			// Max tokens
			$this->chatgpt_assistant_max_tokens        = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens'] != '' ) ? intval($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'max_tokens']) : 1500;
			// Frequency penalty
			$this->chatgpt_assistant_frequency_penalty = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'frequency_penalty'] : '0.01';
			// Presence penalty
			$this->chatgpt_assistant_presence_penalty  = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'presence_penalty'] : '0.01';
			// Best of
			$this->chatgpt_assistant_best_of = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of'] != '' ) ? intval($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'best_of']) : 1;
			// Chatbot position
			$this->chatbox_position          = ( isset( $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] ) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] != '' ) ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position'] : 'right';
		//

		// * STYLE SETTINGS *

			// Chat Widget background color
			$this->chatgpt_assistant_chatbox_background_color = isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color'] != '' ? $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color'] : '#ffffff';   
            $this->chatgpt_assistant_chatbox_background_color = !isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color']) && $this->chatbox_mode == 'dark' ? '#343541' : $this->chatgpt_assistant_chatbox_background_color;
			// Chatbot Response background color
			if ( !(isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color'] != '') ) {
				$this->response_bg_color = '#d3d3d3';
				if ($this->chatbox_mode == 'dark') {
					$this->response_bg_color = '#4b4d56';
				}
			} else {
				$this->response_bg_color = esc_attr($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color']);
			}
			// Chatbot User message background color
			if ( !(isset($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color']) && $options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color'] != '') ) {
				$this->message_bg_color = '#4e426d';
				if ($this->chatbox_mode == 'dark') {
					$this->message_bg_color = '#343541';
				}
			} else {
				$this->message_bg_color = esc_attr($options[CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color']);
			}
		//

		// Set global styles for chatbot
			$this->chatbot_global_styles = array(
				CHATGPT_ASSISTANT_OPTIONS_PREFIX.'position' => $this->chatbox_position,
				CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_color' => $this->chatbox_color,
				CHATGPT_ASSISTANT_OPTIONS_PREFIX.'chatbox_background_color' => $this->chatgpt_assistant_chatbox_background_color,
				CHATGPT_ASSISTANT_OPTIONS_PREFIX.'response_bg_color' => $this->response_bg_color,
				CHATGPT_ASSISTANT_OPTIONS_PREFIX.'message_bg_color' => $this->message_bg_color,
		);

		// Set Chatbot options for JS
		wp_localize_script( $this->plugin_name , 'AysChatGPTChatSettings', array( 
		    'chatTemprature' => $this->chatgpt_assistant_chat_temprature,
		    'chatMaxTokents' => $this->chatgpt_assistant_max_tokens,
		    'chatFrequencyPenalty' => $this->chatgpt_assistant_frequency_penalty,
		    'chatPresencePenalty' => $this->chatgpt_assistant_presence_penalty,
		    'chatBestOf' => $this->chatgpt_assistant_best_of,
			'chatboxPosition' => $this->chatbox_position
		) );
	}

	// * LIMITATIONS *
	// Check displaying (home, page, post, ...) limitations
	public function check_chatbot_display_limitations(){
		$check_displaying = false;
		$show = array('selected');
		if($this->show_all != 'all'){
			$post_id = get_the_ID();
			if($post_id != false){
				$post = get_post( $post_id );
				$this_post_title = strval( $post->ID );

				$postType = $post->post_type;
				
				if ( is_front_page() ) {
					$check_displaying = $this->show_on_home_page;
					return $check_displaying;
				}

				if( in_array( $post_id . "", $this->except_posts ) ){
					if( in_array( $this->show_all, $show ) ){
						$check_displaying = true;
					}else{
						$check_displaying = false;
					}					
				}elseif( !in_array( $this_post_title, $this->except_posts ) && in_array( $postType, $this->except_all_post_types ) ) {					
					if( in_array( $this->show_all, $show ) ){
						$check_displaying = true;
					}else{
						$check_displaying = false;
					}
					
				}
				else{
					if( in_array( $this->show_all, $show ) ){
						$check_displaying = false;
					}else{
						$check_displaying = true;
					}
				
				}
				return $check_displaying;
			}
		}else{
			return true;
		}
	
	}
	// Check user/guest limitations
	public function check_chatbot_user_limitations(){
		$check_displaying = true;
		if (is_user_logged_in()) {
			if ($this->access_for_logged_in === "on") {
				$roles = (array)wp_get_current_user()->roles;
				if (count(array_intersect($roles, $this->user_roles)) >= 1) {
					$check_displaying = true;
				} else {
					$check_displaying = false;
				}
			} else {
				$check_displaying = false;
			}
		} else {
			if ($this->access_for_guests === "on") {
				$check_displaying = true;
			} else {
				$check_displaying = false;
			}
		}
		return $check_displaying;
	}
	// Check limitations
	public function check_limitations($limit_data){
		$this->limitations = false;
		if(array_sum($limit_data) == count($limit_data)){
			$this->limitations = true;
		}
	}
	//

	// Show Main Chatbot
	public function show_chatgpt_assistant(){
		if (isset($this->api_key) && $this->api_key != '' && $this->limitations) :
			$this->set_global_settings_options();
			if ($this->chatbox_onoff == 'on') :

				ob_start();
				?>
				<div class="ays-assistant-chatbox" style="display: none;" colmode="<?php echo esc_attr($this->chatbox_mode); ?>">
					<div class="ays-assistant-chatbox-closed-view"> <!-- closed logo -->
						<div class="ays-assistant-closed-icon-container">
							<img class="ays-assistant-chatbox-logo-image" src="<?php echo esc_attr($this->chat_icon) ?>" alt="ChatGPT icon">
						</div>
					</div>
					<div class="ays-assistant-chatbox-maximized-bg" style="display: none;"></div>
					<div class="ays-assistant-chatbox-main-container" style="display: none;">
						<div class="ays-assistant-chatbox-main-chat-box">
							<div class="ays-assistant-chatbox-header-row"> <!-- header row -->
								<!-- <p class="ays-assistant-chatbox-header-text">ChatGPT Assistant</p> -->
								<div class="ays-assistant-header-row-logo-row">
									<div class="ays-assistant-header-row-logo">
										<img class="ays-assistant-header-row-logo-image" src="<?php echo esc_attr($this->chat_icon) ?>" alt="ChatGPT icon">
									</div>
									<p class="ays-assistant-chatbox-header-text"><?php echo __( "AI Assistant", "ays-chatgpt-assistant" ); ?></p>
								</div>
								<div class="ays-assistant-chatbox-logo">
									<img src="<?php echo esc_attr(CHATGPT_ASSISTANT_ADMIN_URL) ?>/images/icons/maximize.svg" alt="Maximize" class="ays-assistant-chatbox-resize-bttn">
									<img src="<?php echo esc_attr(CHATGPT_ASSISTANT_ADMIN_URL) ?>/images/icons/close-button.svg" alt="Close" class="ays-assistant-chatbox-close-bttn">
								</div>
							</div>
							<div class="ays-assistant-chatbox-messages-box"> <!-- messages container -->
								<div class="ays-assistant-chatbox-loading-box" style="display: none;"> <!-- loader -->
									<div class="ays-assistant-chatbox-loader-ball-2">
										<div></div>
										<div></div>
										<div></div>
									</div>
								</div>
							</div>
							<div class="ays-assistant-chatbox-input-box"> <!-- prompt part -->
								<input type="hidden" class="ays-assistant-chatbox-apikey" name="ays_assistant_chatbox_apikey" value="<?php echo esc_attr($this->api_key); ?>">
								<input class="ays-assistant-chatbox-prompt-input" type="text" name="ays_assistant_chatbox_prompt" id="ays-assistant-chatbox-prompt" placeholder="Enter your message">
								<button class="ays-assistant-chatbox-send-button" disabled>
									<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512" fill="#f8f8f8" width="18" height="18">
										<path d="M498.1 5.6c10.1 7 15.4 19.1 13.5 31.2l-64 416c-1.5 9.7-7.4 18.2-16 23s-18.9 5.4-28 1.6L284 427.7l-68.5 74.1c-8.9 9.7-22.9 12.9-35.2 8.1S160 493.2 160 480V396.4c0-4 1.5-7.8 4.2-10.7L331.8 202.8c5.8-6.3 5.6-16-.4-22s-15.7-6.4-22-.7L106 360.8 17.7 316.6C7.1 311.3 .3 300.7 0 288.9s5.9-22.8 16.1-28.7l448-256c10.7-6.1 23.9-5.5 34 1.4z"/>
									</svg>
								</button>
							</div>
						</div>
					</div>
				</div>
				<?php echo ChatGPT_assistant_Data::get_chatbot_styles($this->chatbot_global_styles); ?>
				<?php
			endif;
		endif;

		$content = ob_get_clean();

		return $content;
	}

}
