<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Advanced_Display_Quizzes
 * @subpackage Quiz_Maker_Advanced_Display_Quizzes/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Advanced_Display_Quizzes
 * @subpackage Quiz_Maker_Advanced_Display_Quizzes/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Advanced_Display_Quizzes_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Advanced_Display_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Advanced_Display_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


		wp_enqueue_style( $this->plugin_name, AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_ADMIN_URL . '/css/quiz-maker-advanced-display-quizzes-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Advanced_Display_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Advanced_Display_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


		wp_enqueue_script( $this->plugin_name, AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_ADMIN_URL . '/js/quiz-maker-advanced-display-quizzes-admin.js', array( 'jquery' ), $this->version, false );

	}

	// Shortcode quiz page action hook -> do_action in quizz code
    public function ays_qm_settings_page_advanced_display_quizzes_content($args){

        $shortcodes_contents = apply_filters( 'ays_qm_settings_page_advanced_display_quizzes_contents', array(), $args );
        $shortcodes = array();

        foreach ($shortcodes_contents as $key => $shortcodes_content) {
            $content = '<fieldset>';
            if(isset($shortcodes_content['title'])){
                $content .= '<legend>';
                if(isset($shortcodes_content['icon'])){
                    $content .= '<strong style="font-size:30px;">'. $shortcodes_content['icon'] .'</strong>';
                }
                $content .= '<h5 style="margin: 0 4px;">'. $shortcodes_content['title'] .'</h5></legend>';
            }
            $content .= $shortcodes_content['content'];

            $content .= '</fieldset>';

            $shortcodes[] = $content;
        }

        echo implode('<hr/>', $shortcodes);
    }

    /*
    ==========================================
        Quizzes table shortcode | Start
    ==========================================
    */

    public function ays_quiz_settings_page_adq_table_content( $shortcodes, $args ){

    	$icon  = '[ ]';
        $title = __( 'Quizzes URLs: Table View', $this->plugin_name );

        $shortcode_str_1 = esc_attr( '[ays_quiz_display_all_quizzes_table orderby="ASC/DESC/random"] ' );

        $shortcode_str_2 = esc_attr( '[ays_quiz_display_quizzes_by_category_table display="all" id="N" orderby="DESC"] ' );

        $content = array();

		/////////////////// shortcode first ///////////

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_display_all_quizzes_table">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("It is designed for the results of all quizzes.Copy the shortcode and paste it into your desired page/post to display the URLs of all quizzes in a table on the front end. The table will include the Quiz Title, Pass/Fail Status, Score, and Date columns.
							*Note: You must insert each Quiz URL into the Quiz Display Page URL option (Settings tab) of the given quiz so that the shortcode can work for you.
							Also, please note, that the shortcode will work for only logged-in users. The text 'You must log in to see your results' will be displayed for guests. The ordering is set as DESC by default.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_display_all_quizzes_table" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str_1 .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';
						      
	            		$content[] = "<li>";
	            		$content[] = sprintf(
							                    __( '%s orderby %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: orderby="DESC".', $this->plugin_name ),
							                    '<b>',
							                    '</b>'
							                );	
	            		$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
	            		$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s ASC %s', $this->plugin_name ) . ' - ' . __( 'The earliest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (oldest to newest).', $this->plugin_name ),
											'<b>',
											'</b>'
										);	
	            		$content[] = "</li>";	
	            		$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s DESC %s', $this->plugin_name ) . ' - ' . __( 'The latest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (newest to oldest).', $this->plugin_name ),
											'<b>',
											'</b>'
										);;	
	            		$content[] = "</li>";
						$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s random %s', $this->plugin_name ) . ' - ' . __( 'The quizzes will be displayed in random order every time the users refresh the page.', $this->plugin_name ),
											'<b>',
											'</b>'
										);;	
	            		$content[] = "</li>";
	            		$content[] = " </ul>";	
	            		$content[] = "</li>";	
						////////

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';
            $content[] = '</div>';
        $content[] = '</div>';
		
		/////////////////// shortcode second ///////////

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_display_quizzes_by_category_table">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and paste it into your desired page/post to display the URLs of all quizzes of all categories/your desired category in a table on the front end.
							The table will include the Quiz Title, Pass/Fail Status, Score, and Date columns.
							*Note: You must insert each Quiz URL into the Quiz Display Page URL option (Settings tab) of the given quiz so that the shortcode can work for you.
							Also, please note, that the shortcode will work for only logged-in users. The text 'You must log in to see your results' will be displayed for guests. The ordering is set as DESC by default.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_display_quizzes_by_category_table" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str_2 .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
				
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

						//////
						$content[] = "<li>";
							$content[] = sprintf(
								__( '%s ID %s', $this->plugin_name ) . ' - ' . __( 'Select the IDs. Example: id="20,24".', $this->plugin_name ),
								'<b>',
								'</b>'
							);
						$content[] = "</li>";
						$content[] = "<li>";
							$content[] = sprintf(
													__( '%s display %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: display="all".', $this->plugin_name ),
													'<b>',
													'</b>'
												);	
							$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s all %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as All, it will show all quizzes.', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
	            				$content[] = "</li>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s quiz_category %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as Category, it will show all quizzes assigned to the given categories. Please enter the IDs of the given categories.', $this->plugin_name ),
												'<b>',
												'</b>'
											);
								$content[] = "</li>";
								
							$content[] = " </ul>";

						$content[] = "</li>";
						$content[] = "<li>";
								$content[] = sprintf(
															__( '%s Orderby %s', $this->plugin_name ) . ' - ' . __( 'Choose the way of ordering the quizzes. Example: orderby="ASC".', $this->plugin_name ),
															'<b>',
															'</b>'
														);
								$content[] = "<ul class='ays-quiz-general-settings-ul'>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s ASC %s', $this->plugin_name ) . ' - ' . __( 'The earliest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (oldest to newest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);	
								$content[] = "</li>";	
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s DESC  %s', $this->plugin_name ) . ' - ' . __( 'The latest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (newest to oldest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s random   %s', $this->plugin_name ) . ' - ' . __( 'The quizzes will be displayed in random order every time the users refresh the page.', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
							$content[] = " </ul>";
						$content[] = "</li>";

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content = implode( '', $content );

        $shortcodes['quizzes_in_table'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}
	/*
    ==========================================
        Quizzes table shortcode | End
    ==========================================
    */

	/*
    ==========================================
        Quizzes list shortcode | Start
    ==========================================
    */
	public function ays_quiz_settings_page_adq_list_content( $shortcodes, $args ){

    	$icon  = '[ ]';
        $title = __( 'Quizzes URLs: List View', $this->plugin_name );

        $shortcode_str_1 = esc_attr( '[ays_quiz_display_all_quizzes_list orderby="ASC/DESC/random"] ' );

        $shortcode_str_2 = esc_attr( '[ays_quiz_display_quizzes_by_category_list display="all" id="N" orderby="DESC" layout="list"] ' );

        $content = array();

		/////////////////// shortcode first ///////////

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_display_all_quizzes_table">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and paste it into your desired page/post to display the URLs of all quizzes in a list on the front end. The lists will include the Quiz Names.
							*Note: You must insert each Quiz URL into the Quiz Display Page URL option (Settings tab) of the given quiz so that the shortcode can work for you.
							The ordering is set as DESC by default.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_display_all_quizzes_table" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str_1 .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

	            		
						//////
						      
	            		$content[] = "<li>";
	            		$content[] = sprintf(
							                    __( '%s orderby %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: orderby="DESC".', $this->plugin_name ),
							                    '<b>',
							                    '</b>'
							                );	
	            		$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
	            		$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s ASC %s', $this->plugin_name ) . ' - ' . __( 'The earliest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (oldest to newest).', $this->plugin_name ),
											'<b>',
											'</b>'
										);	
	            		$content[] = "</li>";	
	            		$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s DESC %s', $this->plugin_name ) . ' - ' . __( 'The latest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (newest to oldest).', $this->plugin_name ),
											'<b>',
											'</b>'
										);;	
	            		$content[] = "</li>";
						$content[] = "<li>";	
	            		$content[] = sprintf(
											__( '%s random %s', $this->plugin_name ) . ' - ' . __( 'The quizzes will be displayed in random order every time the users refresh the page.', $this->plugin_name ),
											'<b>',
											'</b>'
										);;	
	            		$content[] = "</li>";
	            		$content[] = " </ul>";	
	            		$content[] = "</li>";	
						////////

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';
		
		/////////////////// shortcode second ///////////

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_display_quizzes_by_category_table">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and paste it into your desired page/post to display the URLs of all quizzes of all categories/your desired category in a list on the front end.
							The lists will include the Quiz Names.
							*Note: You must insert each Quiz URL into the Quiz Display Page URL option (Settings tab) of the given quiz so that the shortcode can work for you.
							The ordering is set as DESC by default.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_display_quizzes_by_category_table" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str_2 .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
				
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

						//////
						$content[] = "<li>";
							$content[] = sprintf(
												__( '%s ID %s', $this->plugin_name ) . ' - ' . __( 'Select the IDs. Example: id="20,24".', $this->plugin_name ),
												'<b>',
												'</b>'
											);
						$content[] = "</li>";
						$content[] = "<li>";
							$content[] = sprintf(
												__( '%s display %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: display="all".', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
							$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s all %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as All, it will show all quizzes.', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
	            				$content[] = "</li>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s quiz_category %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as Category, it will show all quizzes assigned to the given categories. Please enter the IDs of the given categories.', $this->plugin_name ),
												'<b>',
												'</b>'
											);
								$content[] = "</li>";
								
							$content[] = " </ul>";

						$content[] = "</li>";
						$content[] = "<li>";
								$content[] = sprintf(
														__( '%s Orderby %s', $this->plugin_name ) . ' - ' . __( 'Choose the way of ordering the quizzes. Example: orderby="ASC".', $this->plugin_name ),
														'<b>',
														'</b>'
													);
								$content[] = "<ul class='ays-quiz-general-settings-ul'>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s ASC %s', $this->plugin_name ) . ' - ' . __( 'The earliest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (oldest to newest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);	
								$content[] = "</li>";	
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s DESC  %s', $this->plugin_name ) . ' - ' . __( 'The latest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (newest to oldest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s random   %s', $this->plugin_name ) . ' - ' . __( 'The quizzes will be displayed in random order every time the users refresh the page.', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
							$content[] = " </ul>";
						$content[] = "</li>";

						////////
	            		$content[] = "<li>";
							$content[] = sprintf(
												__( '%s layout %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: layout="grid".', $this->plugin_name ),
												'<b>',
												'</b>'
											);

							$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
							$content[] = "<li>";	
							$content[] = sprintf(
												__( '%s List %s', $this->plugin_name ) . ' - ' . __( 'Choose the design of the layout as list', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
							$content[] = "</li>";	
							$content[] = "<li>";	
							$content[] = sprintf(
												__( '%s Grid %s', $this->plugin_name ) . ' - ' . __( 'Choose the design of the layout as grid', $this->plugin_name ),
												'<b>',
												'</b>'
											);;	
							$content[] = "</li>";
							
	            			$content[] = " </ul>";	
	            		$content[] = "</li>";	
						////////
	            		

	            		
	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content = implode( '', $content );

        $shortcodes['quizzes_in_list'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}
	/*
    ==========================================
        Quizzes list shortcode | End
    ==========================================
    */

	/*
    ==========================================
        Quizzes with images shortcode | Start
    ==========================================
    */
	public function ays_quiz_settings_page_adq_poster_content( $shortcodes, $args ){

    	$icon  = '[ ]';
        $title = __( 'Quizzes URLs: Image View', $this->plugin_name );

        $shortcode_str_1 = esc_attr( '[ays_quiz_display_quizzes_with_image display="all" id="N" orderby="DESC" layout="grid"] ' );


        $content = array();

		/////////////////// shortcode first ///////////

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_display_all_quizzes_table">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and paste it into your desired page/post to display the URLs of all quizzes of all categories/your desired category in a list on the front end.
							By inserting the shortcode on the front end, the Quiz Image with the Quiz Title will be displayed for the users.
							*Note: You must insert each Quiz URL into the Quiz Display Page URL option (Settings tab) of the given quiz so that the shortcode can work for you.
							The ordering is set as DESC by default.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_display_all_quizzes_table" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str_1 .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';
				
	            $content[] = '<blockquote>';
				
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

						//////
						$content[] = "<li>";
							$content[] = sprintf(
								__( '%s ID %s', $this->plugin_name ) . ' - ' . __( 'Select the IDs. Example: id="20,24".', $this->plugin_name ),
								'<b>',
								'</b>'
							);
						$content[] = "</li>";
						$content[] = "<li>";
							$content[] = sprintf(
												__( '%s display %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: display="all".', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
							$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s all %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as All, it will show all quizzes.', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
	            				$content[] = "</li>";	
	            				$content[] = "<li>";	
								$content[] = sprintf(
												__( '%s quiz_category_id(s) %s', $this->plugin_name ) . ' - ' . __( 'If you set the method as Category, it will show all quizzes assigned to the given categories. Please enter the IDs of the given categories.', $this->plugin_name ),
												'<b>',
												'</b>'
											);
								$content[] = "</li>";
								
							$content[] = " </ul>";

						$content[] = "</li>";
						$content[] = "<li>";
								$content[] = sprintf(
													__( '%s Orderby %s', $this->plugin_name ) . ' - ' . __( 'Choose the way of ordering the quizzes. Example: orderby="ASC".', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "<ul class='ays-quiz-general-settings-ul'>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s ASC %s', $this->plugin_name ) . ' - ' . __( 'The earliest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (oldest to newest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);	
								$content[] = "</li>";	
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s DESC  %s', $this->plugin_name ) . ' - ' . __( 'The latest created quizzes will appear at top of the list. The order will be classified based on the quiz ID (newest to oldest).', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
								$content[] = "<li>";	
								$content[] = sprintf(
													__( '%s random   %s', $this->plugin_name ) . ' - ' . __( 'The quizzes will be displayed in random order every time the users refresh the page.', $this->plugin_name ),
													'<b>',
													'</b>'
												);
								$content[] = "</li>";
							$content[] = " </ul>";
						$content[] = "</li>";

						////////
	            		$content[] = "<li>";
							$content[] = sprintf(
													__( '%s layout %s', $this->plugin_name ) . ' - ' . __( 'Choose the method of filtering. Example: layout="grid".', $this->plugin_name ),
													'<b>',
													'</b>'
												);

							$content[] = "<ul class='ays-quiz-general-settings-ul'>";	
							$content[] = "<li>";	
							$content[] = sprintf(
												__( '%s List %s', $this->plugin_name ) . ' - ' . __( 'Choose the design of the layout as list', $this->plugin_name ),
												'<b>',
												'</b>'
											);	
							$content[] = "</li>";	
							$content[] = "<li>";	
							$content[] = sprintf(
												__( '%s Grid %s', $this->plugin_name ) . ' - ' . __( 'Choose the design of the layout as grid', $this->plugin_name ),
												'<b>',
												'</b>'
											);;	
							$content[] = "</li>";
							
	            			$content[] = " </ul>";	
	            		$content[] = "</li>";	
						////////
	            		

	            		
	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';
            $content[] = '</div>';
        $content[] = '</div>';
		
        $content = implode( '', $content );

        $shortcodes['quizzes_in_poster'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}
	/*
    ==========================================
        Quizzes with images shortcode | End
    ==========================================
    */
}
