<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Advanced_Display_Quizzes
 * @subpackage Quiz_Maker_Advanced_Display_Quizzes/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Advanced_Display_Quizzes
 * @subpackage Quiz_Maker_Advanced_Display_Quizzes/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Advanced_Display_Quizzes_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Advanced_Display_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Advanced_Display_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name . '-adq-quiz-dataTable', AYS_QUIZ_PUBLIC_URL . '/css/quiz-maker-dataTables.min.css', array(), $this->version, 'all' );
		wp_enqueue_style($this->plugin_name . '-sweetalert-css', AYS_QUIZ_PUBLIC_URL . '/css/quiz-maker-sweetalert2.min.css', array(), $this->version, 'all' ); 

		wp_enqueue_style( $this->plugin_name, AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/css/quiz-maker-advanced-display-quizzes-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Advanced_Display_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Advanced_Display_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name . '-adq-quiz-dataTable', AYS_QUIZ_PUBLIC_URL . '/js/quiz-maker-datatable.min.js', array('jquery'), $this->version, true);
        wp_enqueue_script( $this->plugin_name . '-sweetalert-js', AYS_QUIZ_PUBLIC_URL . '/js/quiz-maker-sweetalert2.all.min.js', array('jquery'), $this->version, true );

		wp_enqueue_script( $this->plugin_name, AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/js/quiz-maker-advanced-display-quizzes-public.js', array( 'jquery' ), $this->version, false );

	}

}
