<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Advancesd_Display_List_by_Cat_shortcode
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-advanced-display-';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_quiz_display_quizzes_by_category_list', array($this, 'ays_generate_display_quizzes_by_category_list')); // funkciayi verjin masy poxel dnel shortcodi anunov
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style( $this->plugin_name . '-adq-list-by-cats', AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/css/quiz-maker-adq-display-list-by-category-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
          */
        
    }
    
    public function get_quizes_info( $order = "DESC"){
        global $wpdb;
        $shuffle = false;

        $quizzes_table  = esc_sql( $wpdb->prefix . "aysquiz_quizes" );

        $user_id = get_current_user_id();

        if($user_id < 1){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }

        $sql = "SELECT id , quiz_category_id as cat_id, title, quiz_url, options
        FROM $quizzes_table WHERE `published` = 1
        ORDER BY id $order";

        $results = $wpdb->get_results($sql, "ARRAY_A");

        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;

    }


    public function get_quiz_categories( $order = "DESC", $display = "all", $ids = ""){
        global $wpdb;
        $shuffle = false;

        $quizes_categories_table  = esc_sql( $wpdb->prefix . "aysquiz_quizcategories" );

        $user_id = get_current_user_id();

        if($user_id < 1 ){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }

        if ($display == "quiz_category" && is_array($ids) && !empty($ids)){
            foreach($ids as $k => $id){
                $id_pre_check = esc_sql(intval($id));
                if($id_pre_check > 0){
                    $ids[$k] = esc_sql(intval($id));
                }
                else{
                    unset($ids[$k]);
                }
            }
            $ids = array_values($ids);
            $sql = "SELECT `id` , `title` , `description`
            FROM $quizes_categories_table
            WHERE id IN (" . implode(',', $ids) . ") AND `published` = 1
            ORDER BY id $order";
        }
        else{
            $sql = "SELECT `id` , `title` , `description`
            FROM $quizes_categories_table WHERE `published` = 1
            ORDER BY id $order";
        }

        $results = $wpdb->get_results($sql, "ARRAY_A");
        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;

    }

    public function ays_prepare_quiz_datas( $attr ){
        $order = "DESC";
        $display = "all";
        $ids = array();
        if (isset($attr['orderby'])){
            $order = strtoupper($attr['orderby']);
        }
        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if (isset($attr['display'])){
            $display = $attr['display'];
        }
        if (isset($attr['id'])){
            $ids = explode(',',$attr['id']);
        }

        $quiz_infos = $this->get_quizes_info( $order );
        $quiz_categories = $this->get_quiz_categories( $order, $display ,$ids);
        $processed_quiz_infos = array();
        $category_ids = array();
        foreach($quiz_categories AS $k => $cat_value){
            $cat_title = isset($cat_value['title']) ? $cat_value['title'] : "";
            $processed_quiz_infos[$cat_value['id']] = array( array('cat_title' => $cat_title));
            $category_ids[] = $cat_value['id'];
        }
        foreach($quiz_infos AS $key => $val){
            if(in_array($val['cat_id'],$category_ids)){
                $processed_quiz_infos[$val['cat_id']][] = $val;
            }
        }
        return $processed_quiz_infos;
    }

    public function ays_generate_table_html( $table_data , $layout = "list"){
        $res_empty_class = "";
        
        $options = (Quiz_Maker_Settings_Actions::ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( Quiz_Maker_Settings_Actions::ays_get_setting('options') ), true);
        $quizzes_title_length = (isset($options['quizzes_title_length']) && intval($options['quizzes_title_length']) != 0) ? absint(intval($options['quizzes_title_length'])) : 5;
        if($quizzes_title_length == 0){
            $quizzes_title_length = 5;
        }

        $class_layout_style = "ays-list-layout";
        if (strtolower($layout) == 'grid'){
            $class_layout_style = "ays-grid-layout";
        }
        $html = "";
        $html .= "<div class='ays-quizzes-list-container " . $class_layout_style . "'>";
        $category_title = "";
        
        foreach($table_data as $key => $value){
            
            $flag = true;
            if(isset($value) && isset($value[0]['cat_title']) && $value[0]['cat_title'] != ""){
                $category_title = esc_html($value[0]['cat_title']);
            }
            foreach($value as $cat_id => $values_by_cat){
                if(isset($values_by_cat['cat_title'])){ // first array contains only cat title
                    continue;
                }
                if($flag){
                    $html .= "<div class='ays-quizzes-list-ul-container'>";
                    $html .= "<div class='ays-quizzes-padding-div'>";

                    if($category_title != ""){
                        $html .= "<p class='ays-quizzes-list-cat-title'>" . $category_title . "</p>";
                    }
                    $html .= "<ul class='ays-quizzes-list-ul ays-word-break'>";
                    $flag = false;
                }
                if(isset($values_by_cat['title'])){
                    $title = wp_trim_words( $values_by_cat['title'], $quizzes_title_length);
                    if(isset($values_by_cat['quiz_url']) && $values_by_cat['quiz_url'] != ""){
                        $html .= "<li><a href='" . filter_var(esc_html($values_by_cat['quiz_url']), FILTER_SANITIZE_URL) . "'>" . esc_html($title) . "</a></li>";
                    }
                    else{
                        $html .= "<li>" . esc_html($title) . "</li>";
                    }
                }
            }
            // if($flag){
            //     if($category_title != ""){
            //         $empty_cat_html = "<div class='ays-quizzes-list-ul-container'> 
            //             <div class='ays-quizzes-padding-div'>
            //                     <p class='ays-quizzes-list-cat-title'>" . $category_title . "</p>
            //             </div>
            //         </div>";
            //         $html .= $empty_cat_html;
            //     }  
            // }
            // else{
            //     $html .= "</ul>";
            //     $html .= "</div>"; 
            //     $html .= "</div>"; 
            // }
            if(!$flag){
                $html .= "</ul>";
                $html .= "</div>"; 
                $html .= "</div>"; 
            }
            $category_title = "";

        }
        $html .= "</div>"; 
        return $html;
    }
    public function ays_generate_display_quizzes_by_category_list( $attr ){
        $layout = isset($attr['layout']) && strtolower($attr['layout']) == 'grid' ? "grid" : "list";
        $this->unique_id = uniqid();
        // if(! is_user_logged_in()){
        //     return "<p style='text-align: center;font-style:italic;'>" . __( "You must log in to see your results.", $this->plugin_name ) . "</p>";
        // }
        $this->enqueue_styles();
        $this->enqueue_scripts();
        $table_data = $this->ays_prepare_quiz_datas($attr);//attr for orderby
        $table_html = $this->ays_generate_table_html($table_data,$layout);

        return $table_html;
    }
}