<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Advancesd_Display_Table_shortcode
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-advanced-display-';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_quiz_display_all_quizzes_table', array($this, 'ays_generate_all_quizzes_table')); // funkciayi verjin masy poxel dnel shortcodi anunov
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

         
        wp_enqueue_style( $this->plugin_name . '-adq-quiz-dataTable', AYS_QUIZ_PUBLIC_URL . '/css/quiz-maker-dataTables.min.css', array(), $this->version, 'all' );
		wp_enqueue_style($this->plugin_name . '-sweetalert-css', AYS_QUIZ_PUBLIC_URL . '/css/quiz-maker-sweetalert2.min.css', array(), $this->version, 'all' );

        wp_enqueue_style( $this->plugin_name . "-all-in-table", AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/css/quiz-maker-adq-all-in-table-public.css', array(), $this->version, 'all' );
        wp_enqueue_style( $this->plugin_name, AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/css/quiz-maker-advanced-display-quizzes-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
          */
        wp_enqueue_script( $this->plugin_name . '-adq-quiz-dataTable', AYS_QUIZ_PUBLIC_URL . '/js/quiz-maker-datatable.min.js', array('jquery'), $this->version, true);
        wp_enqueue_script( $this->plugin_name . '-sweetalert-js', AYS_QUIZ_PUBLIC_URL . '/js/quiz-maker-sweetalert2.all.min.js', array('jquery'), $this->version, true );

        wp_enqueue_script( $this->plugin_name . '-all-results-public', AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/js/all-in-table/all-in-table-public.js', array('jquery'), $this->version, true);
         wp_localize_script( $this->plugin_name . '-adq-quiz-dataTable', 'quizAdqLangDataTableObj', array(
             "sEmptyTable"           => __( "No data available in table", $this->plugin_name ),
             "sInfo"                 => __( "Showing _START_ to _END_ of _TOTAL_ entries", $this->plugin_name ),
             "sInfoEmpty"            => __( "Showing 0 to 0 of 0 entries", $this->plugin_name ),
             "sInfoFiltered"         => __( "(filtered from _MAX_ total entries)", $this->plugin_name ),
             // "sInfoPostFix":          => __( "", $this->plugin_name ),
             // "sInfoThousands":        => __( ",", $this->plugin_name ),
             "sLengthMenu"           => __( "Show _MENU_ entries", $this->plugin_name ),
             "sLoadingRecords"       => __( "Loading...", $this->plugin_name ),
             "sProcessing"           => __( "Processing...", $this->plugin_name ),
             "sSearch"               => __( "Search:", $this->plugin_name ),
             // "sUrl":                  => __( "", $this->plugin_name ),
             "sZeroRecords"          => __( "No matching records found", $this->plugin_name ),
             "sFirst"                => __( "First", $this->plugin_name ),
             "sLast"                 => __( "Last", $this->plugin_name ),
             "sNext"                 => __( "Next", $this->plugin_name ),
             "sPrevious"             => __( "Previous", $this->plugin_name ),
             "sSortAscending"        => __( ": activate to sort column ascending", $this->plugin_name ),
             "sSortDescending"       => __( ": activate to sort column descending", $this->plugin_name ),
         ) );
    }

    public function get_user_reports_info_all( $order = "DESC"){
        global $wpdb;
        $shuffle = false;

        $reports_table = esc_sql( $wpdb->prefix . "aysquiz_reports" );

        $user_id = get_current_user_id();

        if($user_id < 1){
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }
        
        $sql = "SELECT t1.quiz_id, t1.id, t1.user_id, CAST(t1.score as DECIMAL(10,2)) as max_score, t1.points, t1.end_date from $reports_table t1
                inner join
            (
                select quiz_id, user_id, max(CAST(score as DECIMAL(10,2))) as max_score
                from $reports_table
                WHERE user_id = $user_id
                group by quiz_id
            ) tmp
                on t1.quiz_id = tmp.quiz_id
                and CAST(t1.score as DECIMAL(10,2)) = CAST(tmp.max_score as DECIMAL(10,2))
                and t1.user_id = $user_id";

        $results = $wpdb->get_results($sql, "ARRAY_A");

        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }

        return $results;

    }
    
    public function get_quizes_info( $order = "DESC"){
        global $wpdb;
        $shuffle = false;

        $quizzes_table  = esc_sql( $wpdb->prefix . "aysquiz_quizes" );

        $user_id = get_current_user_id();

        if($user_id < 1){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }

        $sql = "SELECT id , title, quiz_category_id as cat_id, quiz_image, quiz_url, options
        FROM $quizzes_table WHERE `published` = 1
        ORDER BY id $order";

        $results = $wpdb->get_results($sql, "ARRAY_A");

        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;

    }

    public function get_quiz_categories( $order = "DESC"){
        global $wpdb;
        $shuffle = false;

        $quizes_categories_table  = esc_sql( $wpdb->prefix . "aysquiz_quizcategories" );

        $user_id = get_current_user_id();

        if($user_id < 1 ){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }
        $sql = "SELECT id , title
        FROM $quizes_categories_table WHERE `published` = 1
        ORDER BY id $order";

        $results = $wpdb->get_results($sql, "ARRAY_A");
        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;

    }

    public function ays_prepare_quiz_datas( $attr ){
        $order = "DESC";

        if (isset($attr['orderby'])){
            $order = strtoupper($attr['orderby']);
        }
        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }

        $quiz_infos = $this->get_quizes_info( $order );
        $reports = $this->get_user_reports_info_all( $order );
        $quiz_categories = $this->get_quiz_categories( $order );
        $processed_quiz_infos = array();
        foreach($quiz_infos AS $key => $val){
            $val['max_score'] = '';
            $val['end_date'] = '';
            $val['cat_title'] = '';
            $val['user_id'] = '';
            $val['pass_score'] = '';
            $val['points'] = '';
            $val['quiz_pass_score_type'] = '';
            foreach($reports as $r_key => $r_val){
                if ($val['id'] ==  $r_val['quiz_id']){
                    $val['max_score'] = $r_val['max_score'];
                    $val['end_date'] = $r_val['end_date'];
                    $val['user_id'] = $r_val['user_id'];
                    $val['points'] = $r_val['points'];
                    $options = json_decode($val['options'],true);
                    $val['pass_score'] = isset($options['pass_score']) ? $options['pass_score'] : "-";
                    $val['quiz_pass_score_type'] = isset($options['quiz_pass_score_type']) ? $options['quiz_pass_score_type'] : "-";
                    break;
                }
            }
            foreach($quiz_categories as $cat_key => $cat_val){
                if($val['cat_id'] ==  $cat_val['id']){
                    $val['cat_title'] = $cat_val['title'];
                    $processed_quiz_infos[] = $val;
                    break;
                }
            }
        }
        return $processed_quiz_infos;
    }

    public function ays_generate_table_html( $table_data ){
        $res_empty_class = "";
        $options = (Quiz_Maker_Settings_Actions::ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( Quiz_Maker_Settings_Actions::ays_get_setting('options') ), true);
        $quizzes_title_length = (isset($options['quizzes_title_length']) && intval($options['quizzes_title_length']) != 0) ? absint(intval($options['quizzes_title_length'])) : 5;
        if($quizzes_title_length == 0){
            $quizzes_title_length = 5;
        }

        $columns = array(
            'quiz_name' => "<th style='width:20%;'>" . __( "Quiz Name", $this->plugin_name ) . "</th>",
            'success' => "<th style='width:20%;'>" . __( "Pass/Fail", $this->plugin_name ) . "</th>",
            'score' => "<th style='width:20%;'>" . __( "Score", $this->plugin_name ) . "</th>",
            'points' => "<th style='width:20%;'>" . __( "Points", $this->plugin_name ) . "</th>",
            'date' => "<th style='width:20%;'>" . __( "Date", $this->plugin_name ) . "</th>",
        );

        
        if(is_null($table_data) || empty($table_data))
            $res_empty_class = "ays-all-quizzes-table-is-empty";
        
        $html = "<div class='ays-all-quizzes-table-container ". $res_empty_class ."'>
        <table id='ays-all-quizzes-table".$this->unique_id."' class='ays-all-quizzes-table-generic'>
            <thead>";
        $html .= "<tr>";
        foreach($columns as $key => $value){
            $html .= $value;
        }
        $html .= "</tr></thead>";

        $html .= "<tbody>";
        $data_order_index = 0;

        $date_format = get_option( 'date_format' );
        $time_format = get_option( 'time_format' );
        $full_format = $date_format . " " . $time_format;

        if ($res_empty_class == ""){
            foreach($table_data as $index => $value){
                $class_no_sort = "";
                $pass_score_failed = true;
                if (isset($value['quiz_pass_score_type']) && $value['quiz_pass_score_type'] == 'percentage' && ($value['pass_score'] == "-" || floatval($value['pass_score']) <= floatval($value['max_score']))){
                    $pass_score_failed = false;
                }
                else if (isset($value['quiz_pass_score_type']) && $value['quiz_pass_score_type'] == 'point' && ($value['pass_score'] == "-" || floatval($value['pass_score']) <= floatval($value['points']))){
                    $pass_score_failed = false;
                }

                //// quiz_name
                $title = "";
                if(isset($value['title'])){
                    $title = wp_trim_words( $value['title'], $quizzes_title_length);
                }

                if(isset($value['title']) && $value['title'] != "" && isset($value['quiz_url']) && $value['quiz_url'] != ""){
                    $columns['quiz_name'] = "<td data-order='" . $data_order_index ."'><a href='" . filter_var(esc_html($value['quiz_url']), FILTER_SANITIZE_URL) . "' target='_blank'>" . esc_html($title) . "</a></td>";
                }
                else if(isset($value['quiz_url']) && $value['quiz_url'] != ""){
                    $columns['quiz_name'] = "<td ><a href='" . filter_var(esc_html($value['quiz_url']), FILTER_SANITIZE_URL) . "' target='_blank'> - </a></td>";

                }
                else if(isset($value['title']) && $value['title'] != ""){
                    $columns['quiz_name'] = "<td data-order='" . $data_order_index ."'>" . esc_html($title) . "</td>";
                }
                else{
                    $columns['quiz_name'] = "<td> - </td>";
                }

                //// pass_score 
                if (!isset($value['pass_score']) || $value['pass_score'] == ""){
                    $columns['success'] = "<td > - </td>";
                    // $class_no_sort = "no_sort";
                }
                else if ($pass_score_failed){
                    $columns['success'] = "<td data-order='0' ><div class='centered_by_flex '> <img class='wrong_check_icon'src='" . AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . "/images/marks/wrong.png" . "'> </div> </td>";
                }
                else{
                    $columns['success'] = "<td data-order='1' > <div class='centered_by_flex'> <img class='right_check_icon'src='" . AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . "/images/marks/correct.png" . "'> </div></td>";
                }
                //// max_score
                if(isset($value['max_score']) && $value['max_score'] != ""){
                    $columns['score'] = "<td data-order='" . floatval(esc_html($value['max_score'])) . "'>" . floatval(esc_html($value['max_score'])) . "% </td>";
                }
                else{
                    $columns['score'] = "<td data-order='0'> - </td>";
                }
                // points
                if(isset($value['points']) && $value['points'] != ""){
                    $columns['points'] = "<td data-order='" . floatval(esc_html($value['points'])) . "'>" . floatval(esc_html($value['points'])) . "</td>";
                }
                else{
                    $columns['points'] = "<td data-order='0'> - </td>";
                }

                //// end_date
                if(isset($value['end_date']) && $value['end_date'] != ""){
                    $columns['date'] = "<td data-order='" . strtotime($value['end_date']) ."'>" . date($full_format, strtotime($value['end_date'])) . "</td>";///ordery
                }
                else{
                    $columns['date'] = "<td > - </td>";
                }
                $html .= "<tr class='" . $class_no_sort . "' >";
                    $html .= implode($columns);
                $html .= "</tr>";
                $data_order_index++;
            }
        }
        $html .= "</tbody>";
        $html .= "</table>";
        $html .= "<hr class='ays_quiz_adq_seperator'>";
        $html .= "</div>";
        return $html;
    }
    public function ays_generate_all_quizzes_table( $attr ){
        $this->unique_id = uniqid();
        if(! is_user_logged_in()){
            return "<p style='text-align: center;font-style:italic;'>" . __( "You must log in to see your results.", $this->plugin_name ) . "</p>";
        }
        $this->enqueue_styles();
        $this->enqueue_scripts();
        $table_data = $this->ays_prepare_quiz_datas($attr);//attr for orderby
        $table_html = $this->ays_generate_table_html($table_data);

        return $table_html;
    }
}