<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Advancesd_Display_with_Images_shortcode
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-advanced-display-';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        // [ays_quiz_display_quizzes_with_image by="quiz/category" display="all/quiz_category_id(s)" orderby="ASC/DESC/random" layout="list/grid"] 
        add_shortcode('ays_quiz_display_quizzes_with_image', array($this, 'ays_generate_quizzes_with_image')); // funkciayi verjin masy poxel dnel shortcodi anunov
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style( $this->plugin_name . "-with-images", AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . '/css/quiz-maker-adq-with-images-public.css', array(), $this->version, 'all' );

         
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
          */
        
    }
    
    public function get_quizes_info( $order = "DESC"){
        global $wpdb;
        $shuffle = false;

        $quizzes_table  = esc_sql( $wpdb->prefix . "aysquiz_quizes" );

        $user_id = get_current_user_id();

        if($user_id < 1){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }

        $sql = "SELECT id , title, quiz_image, quiz_category_id as cat_id, quiz_url, options
        FROM $quizzes_table WHERE `published` = 1
        ORDER BY id $order";

        $results = $wpdb->get_results($sql, "ARRAY_A");

        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;

    }

    public function get_quiz_categories( $order = "DESC", $display = "all", $ids = ""){
        global $wpdb;
        $shuffle = false;

        $quizes_categories_table  = esc_sql( $wpdb->prefix . "aysquiz_quizcategories" );

        $user_id = get_current_user_id();

        if($user_id < 1 ){ 
            return array();
        }

        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if ($order == "RANDOM"){
            $order = "DESC";
            $shuffle = true;
        }

        if ($display == "quiz_category_id(s)" && is_array($ids) && !empty($ids)){
            foreach($ids as $k => $id){
                $id_pre_check = esc_sql(intval($id));
                if($id_pre_check > 0){
                    $ids[$k] = esc_sql(intval($id));
                }
                else{
                    unset($ids[$k]);
                }
            }
            $ids = array_values($ids);
            $sql = "SELECT `id` , `title` , `description`
            FROM $quizes_categories_table
            WHERE id IN (" . implode(',', $ids) . ") AND `published` = 1
            ORDER BY id $order";
        }
        else{
            $sql = "SELECT `id` , `title` , `description`
            FROM $quizes_categories_table WHERE `published` = 1
            ORDER BY id $order";
        }

        $results = $wpdb->get_results($sql, "ARRAY_A");
        if ($shuffle){
            if (!shuffle($results)){
                return array();
            }
        }
        return $results;
    }

    public function get_published_cat_ids($order = "DESC", $display = "all", $ids = ""){
        $published_categories = $this->get_quiz_categories($order,$display,$ids);
        $ids = array();
        foreach($published_categories as $key => $value){
            $ids[] = $value['id'];
        }
        return $ids;
    }

    public function ays_prepare_quiz_datas( $attr ){
        $order = "DESC";
        $display = "all";
        $ids = array();

        if (isset($attr['orderby'])){
            $order = strtoupper($attr['orderby']);
        }
        if($order != "DESC" && $order != "ASC" && $order != "RANDOM" ){
            $order = "DESC";
        }
        if (isset($attr['display'])){
            $display = $attr['display'];
        }
        if (isset($attr['id'])){
            $ids = explode(',',$attr['id']);
        }
        $quiz_infos = $this->get_quizes_info( $order );
        $published_category_ids = $this->get_published_cat_ids($order,$display,$ids);
        foreach($quiz_infos as $key => $value){
            if(!in_array($value['cat_id'], $published_category_ids)){
                unset($quiz_infos[$key]);
            }
        }
        $quiz_infos = array_values($quiz_infos);
        return $quiz_infos;
    }

    public function ays_generate_table_html( $table_data , $layout = 'grid'){
        $res_empty_class = "";
        //Quizzes title length
        $options = (Quiz_Maker_Settings_Actions::ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( Quiz_Maker_Settings_Actions::ays_get_setting('options') ), true);
        $quizzes_title_length = (isset($options['quizzes_title_length']) && intval($options['quizzes_title_length']) != 0) ? absint(intval($options['quizzes_title_length'])) : 5;
        if($quizzes_title_length == 0){
            $quizzes_title_length = 5;
        }

        $class_layout_style = "ays-quizzes-with-images-grid-style";
        if (strtolower($layout) == 'list'){
            $class_layout_style = "ays-quizzes-with-images-list-style";
        }
        $html = "";
        $html .= "<div class='ays-quizzes-with-images-container " . $class_layout_style ."'>";
        foreach($table_data as $key => $value){
            $html .= "<div class='ays-quizzes-with-images-item'>";
                $html .= "<div class='ays-quizzes-with-images-image'>";
                    if(isset($value['quiz_image']) && $value['quiz_image'] != ""){
                        $html .= "<img alt='quiz image' src='" . filter_var(esc_html($value['quiz_image']), FILTER_SANITIZE_URL) . "'>";
                    }
                    else{
                        $html .= "<img class='ays-adq-default-logo' alt='quiz image' src='" . filter_var(esc_html(AYS_QUIZ_MAKER_ADD_ON_ADVANCED_DISPLAY_QUIZZES_PUBLIC_URL . "/images/default_logo/default_logo.svg")) . "'>";
                        //default
                    }
                $html .= "</div>"; 

                    $html .= "<div class='ays-quizzes-with-images-title'>";
                        if(isset($value['title'])){
                            $title = wp_trim_words( $value['title'], $quizzes_title_length);
                            if(isset($value['quiz_url']) && $value['quiz_url'] != ""){
                                $html .= "<p><a href='" . filter_var(esc_html($value['quiz_url']), FILTER_SANITIZE_URL) . "'>" . esc_html($title) . "</a></p>";
                            }
                            else{
                                $html .= "<p>" . esc_html($title) . "</p>";
                            }
                        }
                    $html .= "</div>"; 

            $html .= "</div>"; 
        }
        $html .= "</div>"; 
        return $html;
    }
    public function ays_generate_quizzes_with_image( $attr ){
        $this->unique_id = uniqid();
        $layout = isset($attr['layout']) && strtolower($attr['layout']) == 'list' ? "list" : "grid";

        // if(! is_user_logged_in()){
        //     return "<p style='text-align: center;font-style:italic;'>" . __( "You must log in to see your results.", $this->plugin_name ) . "</p>";
        // }
        $this->enqueue_styles();
        $this->enqueue_scripts();
        $table_data = $this->ays_prepare_quiz_datas($attr);
        $table_html = $this->ays_generate_table_html($table_data,$layout);

        return $table_html;
    }
}