<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Category_Selective
 * @subpackage Quiz_Maker_Category_Selective/public
 */


/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Category_Selective
 * @subpackage Quiz_Maker_Category_Selective/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Category_Selective_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-category-selective-public.js', array( 'jquery' ), $this->version, false );

		wp_localize_script( $this->plugin_name, 'quiz_maker_category_selective_ajax_public', array(
            'ajax_url' 			 => admin_url('admin-ajax.php'),
        ));

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-category-selective-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Get start page content
	 *
	 * @param $quiz_id
	 *
	 * @return mixed
	 */
	public function get_start_page( $content, $quiz_data ){
		$this->enqueue_scripts();
		$this->enqueue_styles();

		$cat_arr = $this->get_question_categories( $quiz_data );
		$content = $this->get_start_page_html( $cat_arr, $quiz_data );

		return $content;
	}

	/**
	 * Get question categories for the given quiz
	 *
	 * @param $quiz_id
	 *
	 * @return mixed
	 */
	public function get_question_categories( $quiz_data ) {
		global $wpdb;

        if (!isset($quiz_data['quiz_id']) || $quiz_data['quiz_id'] <= 0) {
            return array();
        }

		$sql = "SELECT question_ids FROM {$wpdb->prefix}aysquiz_quizes WHERE id={$quiz_data['quiz_id']}";
		$q_ids = $wpdb->get_var($sql);

        $sql = "SELECT c.id, c.title, COUNT(c.id) AS max_q
                FROM {$wpdb->prefix}aysquiz_categories c
                JOIN {$wpdb->prefix}aysquiz_questions q
                ON c.id = q.category_id
                WHERE q.id IN ({$q_ids})
				GROUP BY c.id";

        $result = $wpdb->get_results($sql, 'ARRAY_A');

        return $result;
	}
	
	/**
	 * Get question categories for the given quiz
	 *
	 * @param $quiz_id
	 *
	 * @return mixed
	 */
	public function get_questions( $question_ids, $quiz_id ) {
		global $wpdb;

		$data = isset($_COOKIE['ays_quiz_selected_categories-'.$quiz_id]) ? stripslashes($_COOKIE['ays_quiz_selected_categories-'.$quiz_id]) : "";
		$data = $data != "" ? json_decode($data, true) : array();

        if (!isset($quiz_id) || $quiz_id <= 0) {
            return array();
        }

		$question_arr = array();
		foreach ($data as $cat_id => $count) {
			$sql = "SELECT id FROM `{$wpdb->prefix}aysquiz_questions` WHERE category_id = " . intval($cat_id) . " ORDER BY RAND() LIMIT " . intval($count) . "";
			$q_ids = $wpdb->get_results($sql, "ARRAY_N");
			foreach ($q_ids as $key => $value) {
				array_push($question_arr, $value[0]);
			}
		}

        return $question_arr;
	}

	/**
	 * Get restart button content
	 *
	 * @param $quiz_id
	 *
	 * @return mixed
	 */
	public function get_restart_button( $content, $quiz_id ){
		$this->enqueue_scripts();
		$this->enqueue_styles();

		$content = "";
		ob_start();
	    ?>

		<div class="ays-quiz-category-selective-main-container">
			<div class="ays-quiz-category-selective-container" style="text-align:center;">
				<button data-quiz-id="<?php echo absint($quiz_id); ?>" class="ays-quiz-category-selective-restart-bttn"><?php echo __("Reset", $this->plugin_name); ?></button>
			</div>
		</div>

		<?php
        $content = ob_get_clean();

		return $content;
	}
	
	/**
	 * Get start page html part
	 *
	 * @param $cat_arr
	 *
	 * @return string
	 */
	public function get_start_page_html( $res, $quiz_data ) {
		$html = "";

		$cat_arr = array();
		$max_q_count = array();
        foreach($res as $res){
            $cat_arr[$res['id']] = $res['title'];
            $max_q_count[$res['id']] = $res['max_q'];
        }

		ob_start();
	    ?>

		<form method="post" class="ays-quiz-category-selective-category-form">
			<div class="ays-quiz-category-selective-main-container">
				<div class="ays-quiz-category-selective-header-container">
					<h3 class="ays-quiz-category-selective-header-text">
						<?php echo __($quiz_data['title'], $this->plugin_name); ?>
					</h3>
				</div>
				<div class="ays-quiz-category-selective-container">
					<?php
					$i = 0;
					foreach($cat_arr as $cid => $val):
					?>
					<div class="ays-quiz-category-selective-category-container">
						<div class="ays-quiz-category-selective-title-container">
							<label for="ays-cat-count-<?php echo $cid; ?>">
								<?php echo $val; ?>
							</label>
						</div>
						<div class="ays-quiz-category-selective-count-container">
							<input type="number" min="0" max="<?php echo $max_q_count[$cid] ?>" name="ays_quiz_category_selective_cat_count[<?php echo $cid; ?>]" id="ays-cat-count-<?php echo $cid; ?>" class="ays-quiz-category-selective-text-input" placeholder="<?php echo __("Maximum count of questions is ", $this->plugin_name) . $max_q_count[$cid]; ?>">
						</div>
					</div>
					<?php
						$i++;
					?>
					<?php endforeach; ?>
				</div>
				<div class="ays-quiz-category-selective-submit-container">
					<button type="button" data-quiz-id="<?php echo $quiz_data['quiz_id']; ?>" class="ays-quiz-category-selective-submit-bttn"><?php echo __("Start", $this->plugin_name); ?></button>
				</div>
			</div>
		</form>

		<?php
        $html = ob_get_clean();

        return $html;
	}
	
	public function ays_quiz_cat_delete_cookie_data () {
		if(isset($_REQUEST['action']) && $_REQUEST['action'] == 'ays_quiz_cat_delete_cookie_data'){
            $quiz_id = (isset($_REQUEST['quiz_id']) && $_REQUEST['quiz_id'] != '') ? absint( sanitize_text_field($_REQUEST['quiz_id']) ) : null;
			
			setcookie('ays_quiz_selected_categories-'.$quiz_id, '', time() - 86401, '/');
			unset($_COOKIE['ays_quiz_selected_categories-'.$quiz_id]);

			ob_end_clean();
            $ob_get_clean = ob_get_clean();
            echo json_encode(array(
                'status' => true,
            ));
            wp_die();
		} else {
			ob_end_clean();
            $ob_get_clean = ob_get_clean();
            echo json_encode(array(
                'status' => false,
            ));
            wp_die();
		}
	}
	
	public function ays_quiz_cat_set_cookie_data () {
		if(isset($_REQUEST['action']) && $_REQUEST['action'] == 'ays_quiz_cat_set_cookie_data'){
            $quiz_id = (isset($_REQUEST['quiz_id']) && $_REQUEST['quiz_id'] != '') ? absint( sanitize_text_field($_REQUEST['quiz_id']) ) : null;
            $data = (isset($_REQUEST['formData']) && $_REQUEST['formData'] != '') ? json_encode($_REQUEST['formData']) : "";

			if (!setcookie('ays_quiz_selected_categories-'.$quiz_id, $data, time() + 3600, '/')) {
				echo json_encode(array(
					'status' => false,
				));
				wp_die();
			}

			ob_end_clean();
            $ob_get_clean = ob_get_clean();
            echo json_encode(array(
                'status' => true,
            ));
            wp_die();
		} else {
			ob_end_clean();
            $ob_get_clean = ob_get_clean();
            echo json_encode(array(
                'status' => false,
            ));
            wp_die();
		}
	}

}
