<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Chained_Quizzes_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

    private $chained_quizzes_obj;
    private $capability;
    private $current_user_can_edit;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Chained_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Chained_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (false === strpos($hook_suffix, $this->plugin_name)){
            return;
        }
        
		wp_enqueue_style( $this->plugin_name . '-select2',  plugin_dir_url( __FILE__ ) .  'css/quiz-maker-select2.min.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-chained-quizzes-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Chained_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Chained_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (false === strpos($hook_suffix, $this->plugin_name)){
            return;
        }

		wp_enqueue_script( $this->plugin_name . '-select2js', plugin_dir_url( __FILE__ ) . 'js/quiz-maker-select2.min.js', array('jquery'), $this->version, true);
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-chained-quizzes-admin.js', array( 'jquery' ), $this->version, false );

	}


    public function add_plugin_chained_quizzes_submenu(){
		$this->capability = $this->quiz_maker_chained_quizzes_capabilities();
		$this->current_user_can_edit = self::quiz_maker_chained_quizzes_capabilities_for_editing();
		
        $hook_chained_quizzes = add_submenu_page(
            PARENT_QUIZ_MAKER_NAME,
            __('Chained Quizzes', $this->plugin_name),
            __('Chained Quizzes', $this->plugin_name),
            $this->capability,
            PARENT_QUIZ_MAKER_NAME . '-chained-quizzes',
            array($this, 'display_plugin_chained_quizzes_page')
        );

        add_action("load-$hook_chained_quizzes", array($this, 'screen_option_chained_quizzes'));
    }

    public static function set_screen($status, $option, $value){
        return $value;
    }

    public function display_plugin_chained_quizzes_page(){
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
            case 'add':
                include_once('partials/chained_quizzes/actions/quiz-maker-chained-quizzes-actions.php');
                break;
            case 'edit':
                include_once('partials/chained_quizzes/actions/quiz-maker-chained-quizzes-actions.php');
                break;
            default:
                include_once('partials/chained_quizzes/quiz-maker-chained-quizzes-display.php');
        }
    }

    public function screen_option_chained_quizzes(){
        $option = 'per_page';
        $args = array(
            'label' => __('Chained Quizzes', $this->plugin_name),
            'default' => 20,
            'option' => 'chained_quizzes_per_page'
        );

        if( ! ( isset( $_GET['action'] ) && ( $_GET['action'] == 'add' || $_GET['action'] == 'edit' ) ) ){
            add_screen_option($option, $args);
        }

        $this->chained_quizzes_obj = new Chained_Quizzes_List_Table($this->plugin_name);
    }    

    protected function quiz_maker_chained_quizzes_capabilities(){
        global $wpdb;

        $settings_table = esc_sql( $wpdb->prefix . QUIZ_MAKER_CHAINED_QUIZZES_DB_PREFIX . 'settings' );

        $sql = "SELECT meta_value FROM {$settings_table} WHERE `meta_key` = 'user_roles'";
        $result = $wpdb->get_var($sql);
        
        $capability = 'ays_quiz_manage_options';
        if($result !== null){
            $ays_user_roles = json_decode($result, true);
            if(is_user_logged_in()){
                $current_user = wp_get_current_user();
                $current_user_roles = $current_user->roles;
                $ishmar = 0;
                foreach($current_user_roles as $r){
                    if(in_array($r, $ays_user_roles)){
                        $ishmar++;
                    }
                }
                if($ishmar > 0){
                    $capability = "read";
                }
            }
        }
        return $capability;
    }

    public static function quiz_maker_chained_quizzes_capabilities_for_editing(){
        global $wpdb;

        $settings_table = esc_sql( $wpdb->prefix . QUIZ_MAKER_CHAINED_QUIZZES_DB_PREFIX . 'settings' );

        $sql = "SELECT meta_value FROM {$settings_table} WHERE `meta_key` = 'options'";
        $result = $wpdb->get_var($sql);

        $capability = false;
        if($result !== null){
            $options = json_decode($result, true);

            // User roles to change quiz
            $ays_user_roles = (isset($options['user_roles_to_change_quiz']) && !empty( $options['user_roles_to_change_quiz'] ) ) ? $options['user_roles_to_change_quiz'] : array('administrator');
            if(is_user_logged_in()){
                $current_user = wp_get_current_user();
                $current_user_roles = $current_user->roles;
                $ishmar = 0;
                foreach($current_user_roles as $r){
                    if(in_array($r, $ays_user_roles)){
                        $ishmar++;
                    }
                }
                if($ishmar > 0){
                    $capability = true;
                }
            }
        }
        return $capability;
    }


}
