<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/includes
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @since      1.0.0
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/includes
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Chained_Quizzes_Data {

    public static function get_quiz_validated_data_from_array( $chained_quiz, $attr ){
        global $wpdb;

        // Array for quiz validated options
        $settings = array();
        
        // ID
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
        $settings['id'] = $id;

        // Quiz options
        $options = array();
        $quiz_options = array();

        if( isset( $chained_quiz['options'] ) && $chained_quiz['options'] != '' ){
            $options = json_decode( $chained_quiz['options'], true );
        }


        $settings[ 'options' ]   = $options;
        // $settings[ 'q_options' ] = $quiz_options;

        $options[ 'chained_quizzes_print_report' ] = isset( $options['chained_quizzes_print_report' ] ) ? $options['chained_quizzes_print_report' ] : 'off';
        $settings[ 'chained_quizzes_print_report' ] = (isset( $options['chained_quizzes_print_report' ] ) && $options['chained_quizzes_print_report' ] == 'on') ? true : false;

        // Enable retake button
        $options[ 'chained_quizzes_print_enable_retake_button' ] = isset( $options['chained_quizzes_print_enable_retake_button' ] ) ? $options['chained_quizzes_print_enable_retake_button' ] : 'off';
        $settings[ 'chained_quizzes_print_enable_retake_button' ] = (isset( $options['chained_quizzes_print_enable_retake_button' ] ) && $options['chained_quizzes_print_enable_retake_button' ] == 'on') ? true : false;

        // Enable the Chained Quiz completion based on the pass score
        $options[ 'chained_quizzes_enable_completion_pass_score' ] = isset( $options['chained_quizzes_enable_completion_pass_score' ] ) ? $options['chained_quizzes_enable_completion_pass_score' ] : 'off';
        $settings[ 'chained_quizzes_enable_completion_pass_score' ] = (isset( $options['chained_quizzes_enable_completion_pass_score' ] ) && $options['chained_quizzes_enable_completion_pass_score' ] == 'on') ? true : false;

        // Access for guests
        $options[ 'chained_quizzes_guest_access' ] = isset( $options['chained_quizzes_guest_access' ] ) ? $options['chained_quizzes_guest_access' ] : 'off';
        $settings[ 'chained_quizzes_guest_access' ] = (isset( $options['chained_quizzes_guest_access' ] ) && $options['chained_quizzes_guest_access' ] == 'on') ? true : false;

        // Calculate the report type
        $options['calculate_report_type'] = ! isset($options['calculate_report_type']) ? 'take_quiz' : $options['calculate_report_type'];
        $settings['calculate_report_type'] = (isset($options['calculate_report_type']) && $options['calculate_report_type'] != "") ? $options['calculate_report_type'] : 'take_quiz';
      
   
        $settings['title'] = (isset( $chained_quiz[ 'title' ] ) && $chained_quiz[ 'title' ] != '') ? sanitize_text_field( $chained_quiz[ 'title' ] ) : '';

    
        $settings[ 'quiz_ids' ] = isset( $chained_quiz[ 'quiz_ids' ] ) && $chained_quiz[ 'quiz_ids' ] != '' ?  array_unique(explode(',', $chained_quiz[ 'quiz_ids' ])) : array();

        $settings['status'] = (isset( $chained_quiz[ 'published' ] ) && $chained_quiz[ 'published' ] == '1') ? true : false;



        return $settings;
    }

    public static function get_chained_quiz_by_id( $id ){
        global $wpdb;
        $chained_quizzes_table    = esc_sql( $wpdb->prefix . QUIZ_MAKER_CHAINED_QUIZZES_DB_PREFIX . "chainedquizzes" );

        if ( is_null( $id ) || empty( $id ) ) {
            return null;
        }

        $sql = "SELECT *
                FROM {$chained_quizzes_table}
                WHERE id = {$id}";


        $chained_quiz = $wpdb->get_row( $sql, "ARRAY_A" );

        return $chained_quiz;
    }

    public static function get_user_reports_info( $quiz_id ){
        global $wpdb;

        $current_user = wp_get_current_user();
        $id = $current_user->ID;

        $user_query = "";
        if (get_current_user_id() > 0) {
            $id_row = 'user_id';
            $user_id = $id;
        } else {
            $id_row = 'unique_id';
            $user_id = isset($_COOKIE['ays_chained_quiz_guest_id']) ? $_COOKIE['ays_chained_quiz_guest_id'] : '' ;
            $user_query = " AND user_id = 0";
        }

        if ( empty($quiz_id) || is_null($quiz_id) ) {
            return null;
        }

        
        $reports_table = $wpdb->prefix . "aysquiz_reports";
        $sql = "SELECT count(*)
                FROM $reports_table
                WHERE quiz_id = ". $quiz_id ." AND " . $id_row . " = '" . $user_id . "'" . $user_query . "
                ORDER BY id DESC";
        $results = $wpdb->get_var($sql);

        return $results;

    }  

    public static function get_quizzes_reports( $quiz_id ){
        global $wpdb;

        $current_user = wp_get_current_user();
        $id = $current_user->ID;

        $user_query = "";
        if (get_current_user_id() > 0) {
            $id_row = 'user_id';
            $user_id = $id;
        } else {
            $id_row = 'unique_id';
            $user_id = isset($_COOKIE['ays_chained_quiz_guest_id']) ? $_COOKIE['ays_chained_quiz_guest_id'] : '' ;
            $user_query = " AND user_id = 0";
        }

        if ( empty($quiz_id) || is_null($quiz_id) ) {
            return null;
        }

        $quizzes_table = $wpdb->prefix . "aysquiz_quizes";
        $reports_table = $wpdb->prefix . "aysquiz_reports";
        $sql = "SELECT q.title,r.score,r.end_date,r.options
                FROM $reports_table as r
                LEFT JOIN $quizzes_table AS q
                    ON q.id = r.quiz_id
                WHERE r.quiz_id = ". $quiz_id ." AND r." . $id_row . " = '" . $user_id . "'" . $user_query . "
                ORDER BY r.id DESC";
        $results = $wpdb->get_row($sql,'ARRAY_A');

        return $results;
    }

    public static function delete_quizzes_reports( $quiz_id ){
        global $wpdb;

        $current_user = wp_get_current_user();
        $id = $current_user->ID;

        $user_query = "";
        if (get_current_user_id() > 0) {
            $id_row = 'user_id';
            $user_id = $id;
        } else {
            $id_row = 'unique_id';
            $user_id = isset($_COOKIE['ays_chained_quiz_guest_id']) ? $_COOKIE['ays_chained_quiz_guest_id'] : '' ;
            $user_query = " AND user_id = 0";
        }

        if ( empty($quiz_id) || is_null($quiz_id) ) {
            return null;
        }

        $quizzes_table = $wpdb->prefix . "aysquiz_quizes";
        $reports_table = $wpdb->prefix . "aysquiz_reports";
        $sql = "DELETE FROM $reports_table
                WHERE quiz_id = ". $quiz_id ." AND " . $id_row . " = '" . $user_id . "'" . $user_query;

        $results = $wpdb->get_row($sql,'ARRAY_A');

        return $results;
    }

    public static function get_quiz_by_id($id){
        global $wpdb;

        $sql = "SELECT *
                FROM {$wpdb->prefix}aysquiz_quizes
                WHERE id=" . $id;

        $quiz = $wpdb->get_row($sql, 'ARRAY_A');

        return $quiz;
    }

    public static function ays_autoembed( $content ) {
        global $wp_embed;
        $content = stripslashes( wpautop( $content ) );
        $content = $wp_embed->autoembed( $content );
        if ( strpos( $content, '[embed]' ) !== false ) {
            $content = $wp_embed->run_shortcode( $content );
        }
        $content = do_shortcode( $content );
        return $content;
    }

}
