<?php
class Chained_Quizzes_List_Table extends WP_List_Table{
    private $plugin_name;
    /** Class constructor */
    public function __construct($plugin_name) {
        $this->plugin_name = $plugin_name;
        parent::__construct( array(
            'singular' => __( 'Chained Quiz', $this->plugin_name ), //singular name of the listed records
            'plural'   => __( 'Chained Quizzes', $this->plugin_name ), //plural name of the listed records
            'ajax'     => false //does this table support ajax?
        ) );
        add_action( 'admin_notices', array( $this, 'quiz_chained_quizzes_notices' ) );
    }

    
    protected function get_views() {
        $published_count = $this->published_chained_quizzes_count();
        $unpublished_count = $this->unpublished_chained_quizzes_count();
        $all_count = $this->all_record_count();
        $selected_all = "";
        $selected_0 = "";
        $selected_1 = "";
        if(isset($_GET['fstatus'])){
            switch($_GET['fstatus']){
                case "0":
                    $selected_0 = " style='font-weight:bold;' ";
                    break;
                case "1":
                    $selected_1 = " style='font-weight:bold;' ";
                    break;
                default:
                    $selected_all = " style='font-weight:bold;' ";
                    break;
            }
        }else{
            $selected_all = " style='font-weight:bold;' ";
        }
        $status_links = array(
            "all" => "<a ".$selected_all." href='?page=".esc_attr( $_REQUEST['page'] )."'>". __( 'All', $this->plugin_name )." (".$all_count.")</a>",
            "published" => "<a ".$selected_1." href='?page=".esc_attr( $_REQUEST['page'] )."&fstatus=1'>". __( 'Published', $this->plugin_name )." (".$published_count.")</a>",
            "unpublished"   => "<a ".$selected_0." href='?page=".esc_attr( $_REQUEST['page'] )."&fstatus=0'>". __( 'Unpublished', $this->plugin_name )." (".$unpublished_count.")</a>"
        );
        return $status_links;
    }
    
    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_chained_quizzes( $per_page = 20, $page_number = 1 ) {

        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}aysquiz_chainedquizzes";

        if ( ! empty( $_REQUEST['orderby'] ) ) {
            $order_by  = ( isset( $_REQUEST['orderby'] ) && sanitize_text_field( $_REQUEST['orderby'] ) != '' ) ? sanitize_text_field( $_REQUEST['orderby'] ) : 'id';
            $order_by .= ( ! empty( $_REQUEST['order'] ) && strtolower( $_REQUEST['order'] ) == 'asc' ) ? ' ASC' : ' DESC';

            $sql_orderby = sanitize_sql_orderby($order_by);

            if ( $sql_orderby ) {
                $sql .= ' ORDER BY ' . $sql_orderby;
            } else {
                $sql .= ' ORDER BY id DESC';
            }
        }else{
            $sql .= ' ORDER BY id DESC';
        }

        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;


        $result = $wpdb->get_results( $sql, 'ARRAY_A' );

        return $result;
    }

    public function get_quizzes(){
        global $wpdb;

        $sql = "SELECT * FROM " . $wpdb->prefix . QUIZ_MAKER_CHAINED_QUIZZES_DB_PREFIX . "quizes WHERE `published` = 1 ORDER BY id DESC";

        $result = $wpdb->get_results($sql, 'ARRAY_A');

        return $result;
    }


    public function add_edit_chained_quiz( $data ){
        global $wpdb;
        $chained_quizzes_table = $wpdb->prefix . 'aysquiz_chainedquizzes';
        $ays_change_type = (isset($data['ays_change_type']))?$data['ays_change_type']:'';

        if( isset($data["chained_quiz_action"]) && wp_verify_nonce( $data["chained_quiz_action"],'chained_quiz_action' ) ){
            
            $id         = absint( intval( $data['id'] ) );
            $title      = stripslashes(sanitize_text_field($data['ays-chained-quiz-title'] ));
            $quiz_ids   = isset($data['ays_chained_quiz_added_quizzes'] ) && !empty($data['ays_chained_quiz_added_quizzes']) ? $data['ays_chained_quiz_added_quizzes'] : array();
            $publish    = absint( intval( $data['ays_chaind_quiz_publish'] ) );

            // Print report
            $chained_quizzes_print_report = (isset( $data['ays_chained_quizzes_print_report'] ) && $data['ays_chained_quizzes_print_report'] == 'on') ? 'on' : 'off';

            // Enable retake button
            $chained_quizzes_print_enable_retake_button = (isset( $data['ays_chained_quizzes_print_enable_retake_button'] ) && $data['ays_chained_quizzes_print_enable_retake_button'] == 'on') ? 'on' : 'off';
            
            // Guest access
            $chained_quizzes_guest_access = (isset( $data['ays_chained_quizzes_guest_access'] ) && $data['ays_chained_quizzes_guest_access'] == 'on') ? 'on' : 'off';

            // Calculate the report type
            $calculate_report_type = isset($data['ays_chained_calculate_report_type']) && $data['ays_chained_calculate_report_type'] != '' ? sanitize_text_field($data['ays_chained_calculate_report_type']) : 'take_quiz';

            // Enable the Chained Quiz completion based on the pass score
            $chained_quizzes_enable_completion_pass_score = (isset( $data['ays_chained_quizzes_enable_completion_pass_score'] ) && $data['ays_chained_quizzes_enable_completion_pass_score'] == 'on') ? 'on' : 'off';

            // Options
            $options = array(
                "chained_quizzes_print_report"                      => $chained_quizzes_print_report,
                "chained_quizzes_guest_access"                      => $chained_quizzes_guest_access,
                "calculate_report_type"                             => $calculate_report_type,
                "chained_quizzes_print_enable_retake_button"        => $chained_quizzes_print_enable_retake_button,
                "chained_quizzes_enable_completion_pass_score"      => $chained_quizzes_enable_completion_pass_score,
            );

            foreach ($quiz_ids as $key => $value) {
                if($value == 0 ){
                    unset($quiz_ids[$key]);
                }
            }

            $quiz_ids = implode(',', $quiz_ids);

            $message = '';
            if( $id == 0 ){
                $result = $wpdb->insert(
                    $chained_quizzes_table,
                    array(
                        'title'          => $title,
                        'quiz_ids'       => $quiz_ids,
                        'published'      => $publish,
                        'options'        => json_encode( $options )
                    ),
                    array( '%s', '%s', '%d', '%s' )
                );
                $message = 'created';
            }else{
                $result = $wpdb->update(
                    $chained_quizzes_table,
                    array(
                        'title'          => $title,
                        'quiz_ids'       => $quiz_ids,
                        'published'      => $publish,
                        'options'        => json_encode( $options )
                    ),
                    array( 'id' => $id ),
                    array( '%s', '%s', '%d', '%s' ),
                    array( '%d' )
                );
                $message = 'updated';
            }

            if( $result >= 0  ) {
                if($ays_change_type != ''){
                    $url = esc_url_raw( remove_query_arg(false) ) . '&status=' . $message;
                    wp_redirect( $url );
                }else{
                    $url = esc_url_raw( remove_query_arg( array( 'action', 'question' ) ) ) . '&status=' . $message;
                    wp_redirect( $url );
                }
            }
        }
    }

    /**
     * Delete a customer record.
     *
     * @param int $id customer ID
     */
    public static function delete_chained_quizzes( $id ) {
        global $wpdb;
        $wpdb->delete(
            "{$wpdb->prefix}aysquiz_chainedquizzes",
            array( 'id' => $id ),
            array( '%d' )
        );
    }


    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}aysquiz_chainedquizzes";

        return $wpdb->get_var( $sql );
    }


    public static function all_record_count() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}aysquiz_chainedquizzes";

        return $wpdb->get_var( $sql );
    }

    public static function published_chained_quizzes_count() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}aysquiz_chainedquizzes WHERE published=1";

        return $wpdb->get_var( $sql );
    }
    
    public static function unpublished_chained_quizzes_count() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}aysquiz_chainedquizzes WHERE published=0";

        return $wpdb->get_var( $sql );
    }

    /** Text displayed when no customer data is available */
    public function no_items() {
        echo __( 'There are no chained quizzes yet.', $this->plugin_name );
    }


    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default( $item, $column_name ) {
        switch ( $column_name ) {
            case 'title':
            case 'shortcode':
            case 'published':
            case 'id':
                return $item[ $column_name ];
                break;
            default:
                return print_r( $item, true ); //Show the whole array for troubleshooting purposes
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb( $item ) {
        return sprintf(
            '<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['id']
        );
    }


    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_title( $item ) {
        $delete_nonce = wp_create_nonce( $this->plugin_name . '-delete-chained-quiz' );

        $title = sprintf( '<a href="?page=%s&action=%s&chained_quiz=%d"><strong>' . $item['title'] . '</strong></a>', esc_attr( $_REQUEST['page'] ), 'edit', absint( $item['id'] ) );

        $actions = array(
            'edit' => sprintf( '<a href="?page=%s&action=%s&chained_quiz=%d">'. __('Edit', $this->plugin_name) .'</a>', esc_attr( $_REQUEST['page'] ), 'edit', absint( $item['id'] ) ),
        );
        
        $actions['delete'] = sprintf( '<a class="ays_confirm_del" data-message="%s" href="?page=%s&action=%s&chained_quiz=%s&_wpnonce=%s">'. __('Delete', $this->plugin_name) .'</a>', $item['title'], esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['id'] ), $delete_nonce );        

        return $title . $this->row_actions( $actions );
    }

    function column_published( $item ) {
        switch( $item['published'] ) {
            case "1":
                return '<span class="ays-publish-status"><i class="ays_fa ays_fa_check_square_o" aria-hidden="true"></i>'. __('Published',$this->plugin_name) . '</span>';
                break;
            case "0":
                return '<span class="ays-publish-status"><i class="ays_fa ays_fa_square_o" aria-hidden="true"></i>'. __('Unublished',$this->plugin_name) . '</span>';
                break;
        }
    }

    function column_shortcode( $item ) {
        $shortcode = htmlentities('[ays_quiz_chain id="'.$item["id"].'"]');
        return '<input type="text" onClick="this.setSelectionRange(0, this.value.length)" readonly value="'.$shortcode.'" />';
    }


    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns() {
        $columns = array(
            'cb'            => '<input type="checkbox" />',
            'title'         => __( 'Title', $this->plugin_name ),
            'shortcode'     => __( 'Shortcode', $this->plugin_name ),
            'published'     => __( 'Publish', $this->plugin_name ),
            'id'            => __( 'ID', $this->plugin_name ),
        );

        if( isset( $_GET['action'] ) && ( $_GET['action'] == 'add' || $_GET['action'] == 'edit' ) ){
            return array();
        }

        return $columns;
    }


    /**
     * Columns to make sortable.
     *
     * @return array
     */
    public function get_sortable_columns() {
        $sortable_columns = array(
            'title'         => array( 'title', true ),
            'id'           => array( 'id', true ),
        );

        return $sortable_columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions() {
        $actions = array(
            'bulk-delete' => __('Delete', $this->plugin_name)
        );

        return $actions;
    }


    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items() {

        $this->_column_headers = $this->get_column_info();

        /** Process bulk action */
        $this->process_bulk_action();

        $per_page     = $this->get_items_per_page( 'chained_quizzes_per_page', 20 );
        $current_page = $this->get_pagenum();
        $total_items  = self::record_count();

        $this->set_pagination_args( array(
            'total_items' => $total_items, //WE have to calculate the total number of items
            'per_page'    => $per_page //WE have to determine how many items to show on a page
        ) );

        $this->items = self::get_chained_quizzes( $per_page, $current_page );
    }
    public function get_chained_quiz_by_id($chained_quiz_id){
        global $wpdb;
        $sql = "SELECT * FROM {$wpdb->prefix}aysquiz_chainedquizzes where `id`=".absint( intval( $chained_quiz_id ) );
        $result = $wpdb->get_row($sql,'ARRAY_A');
        return $result;
    }

    public function process_bulk_action() {

        //Detect when a bulk action is being triggered...
        if ( 'delete' === $this->current_action() ) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr( $_REQUEST['_wpnonce'] );

            if ( ! wp_verify_nonce( $nonce, $this->plugin_name . '-delete-chained-quiz' ) ) {
                die( 'Go get a life script kiddies' );
            }
            else {
                self::delete_chained_quizzes( absint( $_GET['chained_quiz'] ) );

                // esc_url_raw() is used to prevent converting ampersand in url to "#038;"
                // add_query_arg() return the current url

                $url = esc_url_raw( remove_query_arg( array('action', 'chained_quiz', '_wpnonce') ) ) . '&status=deleted';
                wp_redirect( $url );
            }

        }

        // If the delete bulk action is triggered
        if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' ) || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' ) ) {

            $delete_ids = ( isset( $_POST['bulk-delete'] ) && ! empty( $_POST['bulk-delete'] ) ) ? esc_sql( $_POST['bulk-delete'] ) : array();

            // loop over the array of record IDs and delete them
            foreach ( $delete_ids as $id ) {
                self::delete_chained_quizzes( $id );

            }

            // esc_url_raw() is used to prevent converting ampersand in url to "#038;"
            // add_query_arg() return the current url
            $url = esc_url_raw( remove_query_arg( array('action', 'chained_quiz', '_wpnonce') ) ) . '&status=deleted';
            wp_redirect( $url );
        }
    }



    public function chained_quiz_notices(){
        $status = (isset($_REQUEST['status'])) ? sanitize_text_field( $_REQUEST['status'] ) : '';

        if ( empty( $status ) )
            return;

        if ( 'created' == $status )
            $updated_message = esc_html( __( 'Chained Quiz created.', $this->plugin_name ) );
        elseif ( 'updated' == $status )
            $updated_message = esc_html( __( 'Chained Quiz saved.', $this->plugin_name ) );
        elseif ( 'deleted' == $status )
            $updated_message = esc_html( __( 'Chained Quiz deleted.', $this->plugin_name ) );

        if ( empty( $updated_message ) )
            return;

        ?>
        <div class="notice notice-success is-dismissible">
            <p> <?php echo $updated_message; ?> </p>
        </div>
        <?php
    }
}
