<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Chained_Quizzes
 * @subpackage Quiz_Maker_Chained_Quizzes/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Chained_Quizzes_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Quiz maker options array.
	 *
	 * @since    1.0.5
	 * @access   private
	 * @var      array    $options    Quiz maker options array.
	 */
	private $options;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->options = array();

		add_shortcode('ays_quiz_chain', array($this, 'ays_generate_quiz_chained_quizzes_method'));
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Chained_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Chained_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-chained-quizzes-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Chained_Quizzes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Chained_Quizzes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-chained-quizzes-public.js', array( 'jquery' ), $this->version, false );

		wp_localize_script( $this->plugin_name, 'quiz_maker_chained_quiz_ajax_public', array(
            'ajax_url' 			 => admin_url('admin-ajax.php'),
            'areYouSureButton'   => __( "Are you sure you want to retake quizzes? \nNote: By confirming this option, the previous results of the quizzes will be deleted.", $this->plugin_name),
        ));

	}

	public function ays_generate_quiz_chained_quizzes_method( $attr ){

        $id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;

        if (is_null($id) || $id == 0 ) {
            return '';
        }
        $this->enqueue_styles();
        $this->enqueue_scripts();

		$chained_quiz = Quiz_Maker_Chained_Quizzes_Data::get_chained_quiz_by_id( $id );
		$this->options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_validated_data_from_array( $chained_quiz, $attr );

        if(!is_user_logged_in() && !$this->options[ 'chained_quizzes_guest_access' ]) {
        	$logged_users_message =  __('You must log in to pass this chained quiz.', $this->plugin_name);
        }else{
        	$logged_users_message = null;
        }

        if($logged_users_message !== null){
            $user_massage = '<div class="logged_in_message">' .  Quiz_Maker_Data::ays_autoembed( $logged_users_message ) . '</div>';
        }else{
            $user_massage = null;
        }

        if($user_massage !== null && !is_user_logged_in()){
            $content = $user_massage;
        }else{
        	$content = $this->ays_chained_quizzes_shortcode_content($id, $attr);
        }

        return str_replace( array( "\r\n", "\n", "\r" ), "\n", $content );  
    }

    public function ays_chained_quizzes_shortcode_content( $id, $attr ){
        $content = array();
        
        $chained_quiz = Quiz_Maker_Chained_Quizzes_Data::get_chained_quiz_by_id( $id );

        if( is_null( $chained_quiz ) || empty( $chained_quiz ) ){
            return '';
        }

        $this->options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_validated_data_from_array( $chained_quiz, $attr );

        if ( ! $this->options[ 'status' ]) {
            return '';
        }

        $chained_quiz_status = $this->options[ 'status' ];
        $quiz_ids = $this->options[ 'quiz_ids' ];

        if( $chained_quiz_status ){
        	$finished_quiz_ids = array();

        	$first_quiz_id = isset($quiz_ids[0]) && intval($quiz_ids[0]) > 0 ? intval($quiz_ids[0]) : 0;

        	foreach ($quiz_ids as $key => $quiz_id) {
        		
        		$quizzes_report = Quiz_Maker_Chained_Quizzes_Data::get_quizzes_reports($quiz_id);
        		$quiz_options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_by_id($quiz_id);
	            $quizzes_report_options = (isset( $quizzes_report['options'] ) && $quizzes_report['options'] != "") ? json_decode($quizzes_report['options']) : array();
	            if( is_array( $quizzes_report_options ) ){
	                $quizzes_report_options = (object) $quizzes_report_options;
	            }

	            $quizzes_options = json_decode($quiz_options['options']);
	            if( is_array( $quizzes_options ) ){
	                $quizzes_options = (object) $quizzes_options;
	            }


	            $chained_quiz_id = isset($quizzes_report_options->chained_quiz_id) && $quizzes_report_options->chained_quiz_id !== null ? $quizzes_report_options->chained_quiz_id : null;

	            $quiz_pass_score = isset($quizzes_options->pass_score) && $quizzes_options->pass_score != '' ? $quizzes_options->pass_score : 0;

	            if($chained_quiz_id === null && !empty($quizzes_report) ){
	            	if($this->options[ 'calculate_report_type' ] == 'pass_quiz' ){
	                    if( isset($quizzes_report['score']) && $quizzes_report['score'] !== null && $quiz_pass_score <= $quizzes_report['score'] ){
	                        $finished_quiz_ids[] = intval($quiz_id);
	                    }
	                } else {
	                    $finished_quiz_ids[] = intval($quiz_id);
	                }
	            }
	            elseif(isset($quizzes_report['score']) && $quizzes_report['score'] !== null && $quiz_pass_score <= $quizzes_report['score'] && $this->options[ 'calculate_report_type' ] == 'pass_quiz'){
	            	$finished_quiz_ids[] = intval($quiz_id);
	            }
        	}


        	$quiz_diff_ids = array_diff($quiz_ids,$finished_quiz_ids);
        	$quiz_diff_ids = array_values($quiz_diff_ids);

        	foreach ($quiz_diff_ids as $key => $quiz_id) {
        		$user_result_info = Quiz_Maker_Chained_Quizzes_Data::get_user_reports_info($quiz_id);
        		$quizzes_report = Quiz_Maker_Chained_Quizzes_Data::get_quizzes_reports($quiz_id);
        		$quiz_options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_by_id($quiz_id);
	            $options = json_decode($quiz_options['options']);
	            if( is_array( $options ) ){
	                $options = (object) $options;
	            }

            	$first_chained_quiz_class = '';
	            if( intval($quiz_id) == $first_quiz_id ){
	            	$first_chained_quiz_class = 'ays_quiz_first_chained_quiz';
	            }

	            //Pass score count
	            $pass_score_count = (isset($options->pass_score) && $options->pass_score != '') ? absint(intval($options->pass_score)) : 0;


        		if( $key == count($quiz_diff_ids) - 1 ){
        			$quiz_shortcode = '[ays_quiz id="'. $quiz_id .'" chain="'.$id.'" report="on"]';
        		}else{
        			$quiz_shortcode = '[ays_quiz id="'. $quiz_id .'" chain="'.$id.'"]';

        		}
        		
        		if(intval($user_result_info) == 0){

                    $content[] = '<div class="ays_quiz_chained_quiz_container" id="'. $first_chained_quiz_class .'">';
                        $content[] = do_shortcode( $quiz_shortcode );
                    $content[] = '</div>';       

            		$content = implode( '', $content );
        			return $content;
        			
        		}elseif( $this->options[ 'calculate_report_type' ] == 'pass_quiz' ){

        			if($this->options[ 'chained_quizzes_enable_completion_pass_score' ]){
        				if($quizzes_report['score'] < $pass_score_count){
    						break;
        				}
        			} elseif($quizzes_report['score'] < $pass_score_count){
		                    $content[] = '<div class="ays_quiz_chained_quiz_container" id="'. $first_chained_quiz_class .'">';
		                        $content[] = do_shortcode( $quiz_shortcode );
		                    $content[] = '</div>';
		                    $content = implode( '', $content );
    						return $content;
        			}
        		}
        	}

			$quiz_ids = array_unique($quiz_ids);

			$cookie_name = 'ays_quiz_chained_quiz_information_form_data';
			if( isset($_COOKIE[$cookie_name]) ){
				unset($_COOKIE[$cookie_name]);
	            $cookie_expiration =  current_time('timestamp') - 1;
	            setcookie($cookie_name, "", $cookie_expiration, '/');
			}

			if( $this->options[ 'chained_quizzes_print_report' ]){
				$content[] = '<div class="ays_quiz_chained_quiz_container">';
                    $content[] = '<div class="ays_quiz_chained_quiz_table_main">';
                    $content[] = '<h2>'.__("Results", $this->plugin_name).'</h2>';
                    	$content[] = '<table>';
	                    	$content[] = '<thead>';
	                    	$content[] = '<tr>';
	                    		$content[] = '<th>'.__("Quiz Title", $this->plugin_name).'</th>';
	                    		$content[] = '<th>'.__("Quiz Score", $this->plugin_name).'</th>';
	                    		$content[] = '<th>'.__("Date", $this->plugin_name).'</th>';
	                    	$content[] = '</tr>';
	                    	$content[] = '</thead>';
	                    	$content[] = '<tbody>';
	                    		foreach ($quiz_ids as $key => $quiz_id) {
        							$quizzes_report = Quiz_Maker_Chained_Quizzes_Data::get_quizzes_reports($quiz_id);

        							if( isset($quizzes_report) && !empty($quizzes_report) ){
	        							$options = json_decode($quizzes_report['options']);

							            if( is_array( $options ) ){
							                $options = (object) $options;
							            }

							            $title = isset($quizzes_report['title']) && $quizzes_report['title'] != '' ? esc_attr($quizzes_report['title']) : '';
							            $score = isset($quizzes_report['score']) && $quizzes_report['score'] != '' ? esc_attr($quizzes_report['score']) . '%' : '';
							            $end_date = isset($quizzes_report['end_date']) && $quizzes_report['end_date'] != '' ? esc_attr($quizzes_report['end_date']) : '';

							            if( !isset($options->chained_quiz_id) || $options->chained_quiz_id == '' ){
							            	continue;
							            }
        							} else {
        								$quiz_options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_by_id($quiz_id);
        								$title = isset($quiz_options['title']) && $quiz_options['title'] != "" ? sanitize_text_field($quiz_options['title']) : "-";
        								$score = "-";
        								$end_date = "-";
        							}

        							$content[] = '<tr>';
        								$content[] = '<td>';
        									$content[] = $title;
        								$content[] = '</td>';	
        								$content[] = '<td>';
        									$content[] = $score;
        								$content[] = '</td>';        								
        								$content[] = '<td>';
        									$content[] = $end_date;
        								$content[] = '</td>';
	                    			$content[] = '</tr>';
	                    			
	                    		}

	                    	$content[] = '</tbody>';


                    	$content[] = '</table>';

						if ( $this->options[ 'chained_quizzes_print_enable_retake_button' ] ) {
		                	$content[] = '<div class="ays_quiz_chained_quiz_button_main">';
		                		$content[] = '<button class="ays_quiz_chained_quiz_button" id="ays_quiz_chained_quiz_button" data-id="'. $id .'">'. __("Retake Quizzes", $this->plugin_name) .'</button>';
                   			$content[] = '</div>';
		                }

                    $content[] = '</div>';
                $content[] = '</div>';

               	$content = implode( '', $content );

   				return $content;
			}else {
				$message = __('Congratulations! You have passed all the quizzes.', $this->plugin_name);
				$content = '<div class="logged_in_message">' .  Quiz_Maker_Data::ays_autoembed( $message ) . '</div>'; 
				return $content;
    		}
        }

 		return '';
			
    }

	public function ays_chained_quiz_retake_button(){
        if(isset($_REQUEST['action']) && $_REQUEST['action'] == 'ays_chained_quiz_retake_button'){

            $content = array();
            $attr = array();
            $id = (isset($_REQUEST['id']) && $_REQUEST['id'] != '') ? absint( sanitize_text_field($_REQUEST['id']) ) : null;
        	$attr['id'] = $id;
	        $chained_quiz = Quiz_Maker_Chained_Quizzes_Data::get_chained_quiz_by_id( $id );

	        if( is_null( $chained_quiz ) || empty( $chained_quiz ) ){
	            ob_end_clean();
            	$ob_get_clean = ob_get_clean();
	            $response_text = __( "Something went wrong", $this->plugin_name );
	            echo json_encode(array(
	                'status' => false,
	                'message' => $response_text,
	            ));
	            wp_die();
	        }

	        $options = Quiz_Maker_Chained_Quizzes_Data::get_quiz_validated_data_from_array( $chained_quiz, $attr );

	        if ( ! $options[ 'status' ]) {
	            ob_end_clean();
            	$ob_get_clean = ob_get_clean();
	            $response_text = __( "Something went wrong", $this->plugin_name );
	            echo json_encode(array(
	                'status' => false,
	                'message' => $response_text,
	            ));
	            wp_die();
	        }

	        $chained_quiz_status = $options[ 'status' ];
	        $quiz_ids = $options[ 'quiz_ids' ];

	        if( $chained_quiz_status ){
	        	foreach ($quiz_ids as $key => $quiz_id) {
	        		$quizzes_report = Quiz_Maker_Chained_Quizzes_Data::delete_quizzes_reports($quiz_id);
	        	}

	        	ob_end_clean();
            	$ob_get_clean = ob_get_clean();
	            echo json_encode(array(
	                'status' => true,
	            ));
	            wp_die();

	        }

            ob_end_clean();
        	$ob_get_clean = ob_get_clean();
            $response_text = __( "Something went wrong", $this->plugin_name );
            echo json_encode(array(
                'status' => false,
                'message' => $response_text,
            ));
            wp_die();
        }else{
            ob_end_clean();
            $ob_get_clean = ob_get_clean();
            $response_text = __( "Something went wrong", $this->plugin_name );
            echo json_encode(array(
                'status' => false,
                'message' => $response_text,
            ));
            wp_die();
        }
    }

}
