<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_ChatGPT_Question_Builder
 * @subpackage Quiz_Maker_ChatGPT_Question_Builder/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_ChatGPT_Question_Builder
 * @subpackage Quiz_Maker_ChatGPT_Question_Builder/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_AI_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_AI_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_AI_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-ai-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_AI_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_AI_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-ai-admin.js', array( 'jquery' ), $this->version, false );
		wp_localize_script( $this->plugin_name, 'ays_quiz_ai_addon_questions', array(
			'ajax_url' => admin_url('admin-ajax.php'),
		) );
	}

	public function ays_ai_settings_page_content( $integrations, $args ){

		// AI Settings
		$actions    = Quiz_Maker_AI_Data::ays_get_setting('ai');
		$ai_res 	= ($actions === false) ? json_encode(array()) : $actions;
		$ai     	= json_decode($ai_res, true);

		$quiz_ai_account_id = isset($ai['api_key']) && $ai['api_key'] != "" ? esc_attr($ai['api_key']) : '';

        $icon  = QUIZ_MAKER_AI_ADMIN_URL . '/images/ai-icon.png';
        $title = __( 'ChatGPT Question Builder', $this->plugin_name );

		$content = '';
		$content .= '<div class="form-group row">
						<div class="col-sm-3">
							<button id="chatGPTInstructionsPopOver" type="button" class="btn btn-info" data-original-title="ChatGPT Integration Setup Instructions">
								'. __('Instructions', $this->plugin_name) .'
							</button>
							<div class="d-none" id="chatGPTInstructions">
								<ol>
									<li>
									  ' . __('Sign up <a href="https://platform.openai.com/signup" target="_blank">here</a>. You can use your Google or Microsoft account to sign up if you don`t want 
								      to create using an email/password combination. You may need a valid mobile number to verify your account.', $this->plugin_name) . '
									</li>
									<li>
									' . __('Now, visit your <a href="https://platform.openai.com/account/api-keys" target="_blank">OpenAI key page</a>.', $this->plugin_name) . '
									</li>
									<li>' . __('Create a new key by clicking the "Create new secret key" button.', $this->plugin_name) . '</li>
									<li>' . __('Copy the key and paste it here', $this->plugin_name) . '</li>
									<li>' . __('Save changes.', $this->plugin_name) . '</li>
								</ol>
							</div>
						</div>
					</div>
					<div class="form-group row">
						<div class="col-sm-12">
							<div class="form-group row">
								<div class="col-sm-3">
									<label for="ays_quiz_ai_client_secret">'. __('API Key', $this->plugin_name) .'</label>
								</div>
								<div class="col-sm-9">
									<input type="text" class="ays-text-input" id="ays_quiz_ai_client_secret" name="ays_quiz_ai_client_secret" value="'. $quiz_ai_account_id .'" >
								</div>
							</div>
						</div>
					</div>';

        $integrations['ai'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $integrations;
    }

	// AI Settings integration in General settings page data saver
	public function ays_settings_page_ai_save( $fields, $data ){
		$quiz_ai_client_secret = isset($data['ays_quiz_ai_client_secret']) && $data['ays_quiz_ai_client_secret'] != "" ? sanitize_text_field($data['ays_quiz_ai_client_secret']) : '';
		$ai_options = array(
			"api_key" => $quiz_ai_client_secret,
		);
		
		$fields['ai'] = json_encode($ai_options);

		return $fields;
	}

	public function quiz_maker_ai_append_icon_to_main_page() {		
		$icon = '<button class="ays-quiz-ai-addon-icon"></button>';

		echo "<script>
				jQuery(document).ready(function() {
					jQuery('.wrap.ays_questions_list_table .question-action-butons').prepend('" . $icon . "');
				});
			 </script>";
	}

	public function quiz_maker_ai_append_modal_window_to_main_page() {

		$ai_data    = Quiz_Maker_AI_Data::ays_get_setting('ai');
		$ai_res 	= ($ai_data === false) ? json_encode(array()) : $ai_data;
		$key_data     	= json_decode($ai_res, true);

		$api_key = isset($key_data['api_key']) && $key_data['api_key'] != "" ? esc_attr($key_data['api_key']) : '';

		$modal = '<div id="ays-ai-addon-modal" class="ays-quiz-ai-addon-modal-window">
            		<div class="ays-quiz-ai-addon-modal-content">
                		<span class="close ays-quiz-ai-addon-close">X</span>
						<div class="form-group row">
							<div class="col-sm-4">
								<label for="ays_ai_addon_question_theme">
								' . __( "Questions Theme", $this->plugin_name ) . '
								</label>
							</div>
							<div class="col-sm-8">
								<input type="text" id="ays_ai_addon_question_theme" class="ays-text-input" placeholder="Theme" value="Geographic">
							</div>
						</div>
						<div class="form-group row">
							<div class="col-sm-4">
								<label for="ays_ai_addon_questions_count">
								' . __( "Questions Count", $this->plugin_name ) . '
								</label>
							</div>
							<div class="col-sm-8">
								<input type="number" id="ays_ai_addon_questions_count" class="ays-text-input" min="0" max="30" value="3">
								<p style="font-size: 14; font-style: italic; color: #9e9e9e;">Maximum value of questions is 30.</p>
							</div>
						</div>
						<div class="form-group row">
							<div class="col-sm-4">
								<label for="ays_ai_addon_answers_count">
								' . __( "Answers Count", $this->plugin_name ) . '
								</label>
							</div>
							<div class="col-sm-8">
								<input type="number" id="ays_ai_addon_answers_count" class="ays-text-input" min="0" max="6" value="3">
								<p style="font-size: 14; font-style: italic; color: #9e9e9e;">Maximum value of answers is 6.</p>
							</div>
						</div>
						<input type="hidden" class="ays-quiz-ai-addon-api-key" value = "' . $api_key . '">
						<div class="ays-quiz-ai-generate-button-box">
							<button class="ays-quiz-ai-generate-quiz">Generate</button>
						</div>
						<div class="ays-quiz-preloader" style="top:0">
							<img class="loader" src="' . QUIZ_MAKER_AI_ADMIN_URL . '/images/loaders/tail-spin.svg">
							<span>Please wait</span>
						</div>
            		</div>
        		</div>';

		$modalWindow = preg_replace('/\s+/', ' ', $modal);

		echo "<script>
				jQuery(document).ready(function() {
					jQuery('.wrap.ays_questions_list_table').prepend('" . $modalWindow . "');
				});
			</script>";
	}

    public function ays_ai_generated_questions_import( $import_file ){
		global $wpdb;

		$questions_table = $wpdb->prefix . "aysquiz_questions";
		$answers_table   = $wpdb->prefix . "aysquiz_answers";

		$questions = ($_POST['questions']);

		$user_id = get_current_user_id();
		$user    = get_userdata($user_id);
		$author  = array(
			'id'   => $user->ID,
			'name' => $user->data->display_name
		);
		
        $question_category_table = $wpdb->prefix . "aysquiz_categories";
        $categories_r = $wpdb->get_results("SELECT id, title FROM ".$question_category_table, 'ARRAY_A');
        $for_import = array();
        $categories = array();
        foreach($categories_r as $cat){
            $categories[$cat['id']] = strtolower($cat['title']);
        }

        $question_tags_table = $wpdb->prefix . "aysquiz_question_tags";
        $tags_r = $wpdb->get_results("SELECT id, title FROM ". $question_tags_table ." WHERE status='published'", 'ARRAY_A');
        $tags = array();
        foreach($tags_r as $tag){
            $tags[$tag['id']] = strtolower($tag['title']);
        }

		foreach ( $questions as &$question ) {
			$questions_options = array();

			$options = array(
				'author'                                => $author,
				'bg_image'                              => '',
				'use_html'                              => 'off',
				'enable_question_text_max_length'       => 'off',
				'question_text_max_length'              => '',
				'question_limit_text_type'              => '',
				'question_enable_text_message'          => 'off',
				'enable_question_number_max_length'     => 'off',
				'question_number_max_length'            => '',
				'quiz_hide_question_text'               => 'off',
				'enable_max_selection_number'           => 'off',
				'max_selection_number'                  => '',
				'quiz_question_note_message'            => '',
				'enable_case_sensitive_text'            => 'off',
				'enable_min_selection_number'           => 'off',
				'min_selection_number'                  => '',
				'enable_question_number_min_length'     => 'off',
				'question_number_min_length'            => '',
				'enable_question_number_error_message'  => 'off',
				'question_number_error_message'         => '',
				'quiz_enable_question_stripslashes'     => 'off',
			);

			$category_id = 1;
			$tag_ids = '';
			$db_question_id = '';
			$question_content = htmlspecialchars_decode($question['question'], ENT_HTML5);
			$question_content = $this->convertFromCP1252( $question_content );

			$question_title = '';
			$question_hint = '';
			$type = 'radio';
			$published = 1;
			$wrong_answer_text = '';
			$right_answer_text = '';
			$explanation = '';
			$user_explanation = 'off';
			$not_influence_to_score = 'off';
			$question_weight = 1;
			$create_date = current_time( 'mysql' );
			if(isset($question['answers'])){
				$answers_get = $question['answers'];
			}else{
				$answers_get = array();
			}
			$attach_url = '';

			$answers = array();
			foreach($answers_get as $key => $answer){

				$answer_id = "";

				$answer_content = (isset($answer['answer']) && $answer['answer'] != '') ? htmlspecialchars_decode($answer['answer'], ENT_HTML5) : '';
				$answer_content = $this->convertFromCP1252( $answer_content );

				$image = '';
				$correct = (isset($answer['correct']) && $answer['correct'] != '') ? intval($answer['correct']) : 0;
				$ordering = $key + 1;
				$weight = 1;

				$placeholder = '';
				$keyword = "A";

				$answers[] = array(
					'id'            => $answer_id,
					'answer'        => $answer_content,
					'image'         => $image,
					'correct'       => $correct,
					'ordering'      => $ordering,
					'weight'        => $weight,
					'placeholder'   => $placeholder,
					'keyword'       => $keyword,
				);
			}

			$for_import[] = array(
				'id'                        => $db_question_id,
				'category_id'               => $category_id,
				'tag_id'                    => $tag_ids,
				'question'                  => $question_content,
				'question_title'            => $question_title,
				'question_image'            => $attach_url,
				'question_hint'             => $question_hint,
				'type'                      => $type,
				'published'                 => $published,
				'wrong_answer_text'         => $wrong_answer_text,
				'right_answer_text'         => $right_answer_text,
				'explanation'               => $explanation,
				'user_explanation'          => $user_explanation,
				'not_influence_to_score'    => $not_influence_to_score,
				'weight'                    => $question_weight,
				'create_date'               => $create_date,
				'options'                   => $options,
				'answers'                   => $answers,
			);
		}

		$imported = 0;
        $failed = 0;

        foreach($for_import as $key => $question){

            $db_question_fields = array(
                'category_id'               => $question['category_id'],
                'tag_id'                    => $question['tag_id'],
                'question'                  => $question['question'],
                'question_title'            => $question['question_title'],
                'question_image'            => $question['question_image'],
                'question_hint'             => $question['question_hint'],
                'type'                      => $question['type'],
                'published'                 => $question['published'],
                'wrong_answer_text'         => $question['wrong_answer_text'],
                'right_answer_text'         => $question['right_answer_text'],
                'explanation'               => $question['explanation'],
                'user_explanation'          => $question['user_explanation'],
                'not_influence_to_score'    => $question['not_influence_to_score'],
                'weight'                    => $question['weight'],
                'create_date'               => $question['create_date'],
                'author_id'                 => $author['id'],
                'options'                   => json_encode($question['options']),
            );

            $db_question_fields_types = array(
                '%d', //category_id
                '%s', //tag_id
                '%s', //question
                '%s', //question_title
                '%s', //question_image
                '%s', //hint
                '%s', //type
                '%d', //published
                '%s', //wrong answer text
                '%s', //right answer text
                '%s', //explanation
                '%s', //user_explanation
                '%s', //not_influence_to_score
                '%f', //weight
                '%s', //create_date
                '%d', //author
                '%s', //options
            );

			$db_question_id = "";
			$quest_res = $wpdb->insert(
				$questions_table,
				$db_question_fields,
				$db_question_fields_types
			);
			$question_id = $wpdb->insert_id;

            $ordering = 1;
            $answer_res_success = 0;
            $answer_res_fail = 0;
            foreach ( $question['answers'] as &$answer ) {

                $db_answer_fields = array(
                    'question_id'   => $question_id,
                    'answer'        => $answer['answer'],
                    'image'         => $answer['image'],
                    'correct'       => $answer['correct'],
                    'ordering'      => $answer['ordering'],
                    'weight'        => $answer['weight'],
                    'placeholder'   => $answer['placeholder'],
                    'keyword'       => $answer['keyword'],
                );

                $db_answer_fields_types = array(
                    '%d', // question_id
                    '%s', // answer
                    '%s', // image
                    '%d', // correct
                    '%d', // ordering
                    '%f', // weight
                    '%s', // placeholder
                    '%s', // keyword
                );

				$db_answer_id = "";

				$result = $wpdb->insert(
					$answers_table,
					$db_answer_fields,
					$db_answer_fields_types
				);

                if($result === false){
                    $answer_res_fail++;
                }
                if($result >= 0){
                    $answer_res_success++;
                }
            }

            if($quest_res === false){
                $failed++;
            }
            if($quest_res >= 0 && $answer_res_success > 0){
                $imported++;
            }else{
                $failed++;
            }

        }
	}

	public static function convertFromCP1252( $string ) {
        $search = array(
            // '&',
            // '<',
            // '>',
            // '"',
            '×',
            '·',
            chr(212),
            chr(213),
            chr(210),
            chr(211),
            chr(209),
            chr(208),
            chr(201),
            chr(145),
            chr(146),
            chr(147),
            chr(148),
            chr(151),
            chr(150),
            chr(133),
            '′',
            chr(194),
        );
         $replace = array(
            // '&amp;',
            // '&lt;',
            // '&gt;',
            // '&quot;',
            '&#215;',
            '&#183;',
            '&#8216;',
            '&#8217;',
            '&#8220;',
            '&#8221;',
            '&#8211;',
            '&#8212;',
            '&#8230;',
            '&#8216;',
            '&#8217;',
            '&#8220;',
            '&#8221;',
            '&#8211;',
            '&#8212;',
            '&#8230;',
            '&#8242;',
            ''
        );
        // return str_replace($search, $replace, $string);
        $string = preg_replace('/_x([0-9a-fA-F]{4})_/', '&#x$1;', $string);
        return $string;
    }

}