(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	$(document).ready(function() {

		$(document).on("click" , '.ays-quiz-ai-addon-icon', openAIModalWindow);
		$(document).on("click" , 'span.close', closeAIMoadlWindow);
		$(document).on("click", '#ays-ai-addon-modal', function(e) {
			if ($(e.target).is('#ays-ai-addon-modal') && $(".ays-quiz-preloader:visible").length == 0) {
				closeAIMoadlWindow();
			}
		});
		$(document).on("keydown", (event) => {
			if (event.key === 'Escape') {
				if($("#ays-ai-addon-modal:visible").length != 0 && $(".ays-quiz-preloader:visible").length == 0) {
					closeAIMoadlWindow();
				}
			}
		});
		$(document).on("click" , '.ays-quiz-ai-generate-quiz', importQuestions);

		function openAIModalWindow() {
			var modal = $(".ays-quiz-ai-addon-modal-window");
			modal.addClass("show");
		}

		function closeAIMoadlWindow() {
			var modal = $(".ays-quiz-ai-addon-modal-window");
			modal.removeClass("show");
		}

		function showPreloader() {
			$(document).find('div.ays-quiz-preloader').css('display', 'flex');
			$(document).find('div.ays-quiz-preloader').addClass('ays_quiz_ai_modal_overlay');
		}

		function hidePreloader() {
			$(document).find('div.ays-quiz-preloader').css('display', 'none');
			$(document).find('div.ays-quiz-preloader').removeClass('ays_quiz_ai_modal_overlay');
		}

		function createPrompt() {
			var questionTheme = ($("#ays_ai_addon_question_theme").val() != '') ? $("#ays_ai_addon_question_theme").val() : "IQ Test";
			var questionsCount = ($("#ays_ai_addon_questions_count").val() != '' ) ? $("#ays_ai_addon_questions_count").val() : 3;
			var answersCount = ($("#ays_ai_addon_answers_count").val() != '') ? $("#ays_ai_addon_answers_count").val() : 3;

			var prompt = `Generate a JSON response without line breaks. Example - {"theme": "Some theme","questions": [{"q_title":"some question","options":["answer1","answer2","answer3"],"correct_answer":"index of correct answer in array"},]} -  which contains exactly ${questionsCount} questions, exactly ${answersCount} answers one of which is correct and a theme is ${questionTheme}`;

			return prompt;
		}

		function importQuestions() {
			showPreloader();
			
			var url = "https://api.openai.com/v1/completions";
			var key = $(".ays-quiz-ai-addon-api-key").val();
			if(key == ''){
				swal.fire({
					type: 'error',
					text: "Oops! It looks like you haven't set up your API Key yet. Please go to the 'Settings -> Integrations' tab and enter your API Key to continue."
				});
				hidePreloader();
				return false;
			}

			generateQuestions(url, key)
			.then(data => {
				console.log(data.choices[0].text);
				var importFile = convertToImportFile(JSON.parse(data.choices[0].text));
				addQuestions(importFile);
			});
		}

		function generateQuestions (url, key, tries = 0) {
			return fetch(url, {
					method:"POST",
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${key}`
                    },
                    body: JSON.stringify({
                        model: "text-davinci-003",
                        prompt: createPrompt(),
                        max_tokens: 4022,
                        temperature: 0.8
                    })
                })
                .then(response => response.json())
				.then(response => {
					if (response.error && response.error.message) {
						throw new Error(response.error.message);
                    }
					return response;
				})
                .catch(error => {
                    if (tries < 3) {
                          return generateQuestions(url, key, tries + 1);
                    } else {
						swal.fire({
							type: 'error',
							text: error.message
						});
						hidePreloader();
						return false;
                    }
                });
        }

		function convertToImportFile(data) {
			var importFile = [];
			var questions = data.questions;

			for(var i = 0; i < questions.length; i++) {
				var answers = questions[i].options;
				var answersPerQuestion = [];

				for(var j = 0; j < answers.length; j++) {
					var correct = (j == questions[i].correct_answer) ? 1 : 0;

					var answer = {
						"answer":answers[j],
						"correct":correct,
						"ordering":j + 1,
					}
					answersPerQuestion.push(answer);
				}

				var question = {
					"question":questions[i].q_title,
					"answers" : answersPerQuestion
				}

				importFile.push(question);
			}
			return importFile;
		}

		function addQuestions(data) {
			$.ajax({
				url: ays_quiz_ai_addon_questions.ajax_url,
				method: 'post',
				data: {
					action: 'ays_ai_generated_questions_import',
					questions: data
				},
				success: function (response) {
					hidePreloader();

					$(document).find('#ays-ai-addon-modal .ays-quiz-ai-addon-modal-content').addClass('animated bounceOutRight');
					$(document).find('#ays-ai-addon-modal').modal('hide');

					swal({
						title: '<strong>Great Job!</strong>',
						type: 'success',
						html: '<p>Questions was created successfully</p>',
						showCloseButton: true,
						focusConfirm: false,
						confirmButtonText: '<i class="ays_fa ays_fa_thumbs_up"></i> Great!',
						confirmButtonAriaLabel: quizLangObj.thumbsUpGreat,
						onAfterClose: function() {
							$(document).find('#ays-ai-addon-modal').removeClass('animated bounceOutRight');
							$(document).find('#ays-ai-addon-modal').css('display', 'none');
							window.location.href = "admin.php?page=quiz-maker-questions";
						}
					});
					var modalQuestion = $('.ays_modal_element.ays_modal_question');
					modalQuestion.each(function(){
						if($('.ays_modal_element.ays_modal_question').length !== 1){
							$(this).remove();
						}
					});
				},
			})
		}

	});

})( jQuery );