<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Conditional_Logic_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-conditional-logic-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_editor();
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-conditional-logic-admin.js', array( 'jquery' ), $this->version, true );

	}

	public function add_plugin_conditional_results(){
    	
        $hook_quiz_maker_conditional_results = add_submenu_page(
            PARENT_QUIZ_MAKER_NAME,
            __('Conditional Results', $this->plugin_name),
            __('Conditional Results', $this->plugin_name),
            'manage_options',
            PARENT_QUIZ_MAKER_NAME . "-conditional-results",
            array($this, 'display_add_on_page')
		);
		add_action("load-$hook_quiz_maker_conditional_results", array($this, 'screen_option_conditional_results'));
	}
	
	public function screen_option_conditional_results(){
        $option = 'per_page';
        $args = array(
            'label' => __('Conditional Results', $this->plugin_name),
            'default' => 20,
            'option' => 'conditional_results_per_page'
        );

		if(!( isset( $_GET['action'] ) && $_GET['action'] == 'edit')){
            add_screen_option($option, $args);
        }
		
		$this->quizes_obj = new Quiz_Conditions_List_Table(PARENT_QUIZ_MAKER_NAME);
    }

    public function display_add_on_page(){ 
		$action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';
		if($action == 'edit'){
			include_once('partials/quiz-maker-conditional-logic-actions.php');
		}
		else{
			include_once('partials/quiz-maker-conditional-logic-admin-display.php');
		}
    }

}
