<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Conditional_Logic_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-conditional-logic-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-conditional-logic-public.js', array( 'jquery' ), $this->version, false );

	}

	public function ays_quiz_detect_condition($conditions, $answered_questions) {
		$collected_conditions_all = array();
		foreach($conditions as $condition_id => $condition_value){
			$collected_questions  = array();
			$collected_conditions = array();
			$condition_questions  = isset($condition_value['condition_question_add']) && !empty($condition_value['condition_question_add']) ? $condition_value['condition_question_add'] : array();
			foreach($condition_questions as $cond_question_id => $cond_question_value){
				$cond_question_id      = isset($cond_question_value['question_id']) && $cond_question_value['question_id'] != "" ? $cond_question_value['question_id'] : "";  
				$cond_question_type    = isset($cond_question_value['type']) && $cond_question_value['type'] != "" ? $cond_question_value['type'] : "";  
				$cond_question_answer  = isset($cond_question_value['answer']) && $cond_question_value['answer'] != "" ? $cond_question_value['answer'] : "";  
				$cond_plus_condition   = isset($cond_question_value['plus_condition']) && $cond_question_value['plus_condition'] != "" ? $cond_question_value['plus_condition'] : "";  
				$cond_question_equality = isset($cond_question_value['equality']) && $cond_question_value['equality'] != "" ? $cond_question_value['equality'] : "==";
				
				if($cond_plus_condition == 'and'){
					$cond_plus_condition_ready = "&&";
				}elseif($cond_plus_condition == 'or'){
					$cond_plus_condition_ready = "||";
				}else{
					$cond_plus_condition_ready = "";
				}
				
				if(array_key_exists("ays-question-".$cond_question_id , $answered_questions)){
					$if_condition = false;
					if(isset($answered_questions["ays-question-".$cond_question_id])){
						
						if(is_array($answered_questions["ays-question-".$cond_question_id])){
							if(in_array($cond_question_answer, $answered_questions["ays-question-".$cond_question_id])){
								$if_condition = true;
							}
						}else{
							if( $answered_questions["ays-question-".$cond_question_id] != '' ){
								if($cond_question_type == 'number'){
										$if_condition = $this->ays_quiz_check_equality(intval($cond_question_answer), intval($answered_questions["ays-question-".$cond_question_id]), $cond_question_equality);
									}
								else{
									$if_condition = $this->ays_quiz_check_equality($cond_question_answer, $answered_questions["ays-question-".$cond_question_id], $cond_question_equality);
								}
							}
						}
					}


					if($if_condition){
						$collected_questions[] = 1;
					}else{
						$collected_questions[] = 0;
					}
					$collected_questions[] = $cond_plus_condition_ready;
				}
				else{
					$collected_questions[] = 0;
					$collected_questions[] = $cond_plus_condition_ready;
				}
			}
			$if_condition_str   = implode("" , $collected_questions);
			$if_condition_ready = 0;
			try{
				$if_condition_ready = eval("return $if_condition_str;");
			}catch(Throwable $e){
				var_dump( "Captured Throwable: " . $e->getMessage());
			}

			if($if_condition_ready == 1){
				$if_condition_ready = true;
			}elseif($if_condition_ready == 0){
				$if_condition_ready = false;
			}
			$collected_conditions_all[$condition_id] = $if_condition_ready;
		}

		$true_conditions_count = false;
		if(array_sum($collected_conditions_all) > 1){
			$true_conditions_count = array_sum($collected_conditions_all);
		}

		$condition_messages = $this->ays_get_condition_messages($conditions, $collected_conditions_all);
		return $condition_messages;
	}

	public function ays_quiz_check_equality( $condition_answer, $answered_answer, $sign = "==" ){
        switch($sign){
            case "==":
                if($answered_answer == $condition_answer){
                    return true;
                }
            break;
            case "!=":
                if($answered_answer != $condition_answer){
                    return true;
                }
            break;
            case "<":
                if($answered_answer < $condition_answer){
                    return true;
                }
            break;
            case "<=":
                if($answered_answer <= $condition_answer){
                    return true;
                }
            break;
            case ">":
                if($answered_answer > $condition_answer){
                    return true;
                }
            break;
            case ">=":
                if($answered_answer >= $condition_answer){
                    return true;
                }
            break;
            case "contains":
                if( strpos($answered_answer, $condition_answer) !== false ){
                    return true;
                }
            break;
            case "not_contain":
                if( strpos( $answered_answer, $condition_answer ) === false ){
                    return true;
                }
            break;
            default:
                if($condition_answer == $answered_answer){
                    return true;
                }
            break;
        }
        return false;
    }

	public function ays_get_condition_messages( $conditions, $collected_conditions ){
		$cond_page_message    = "";
		$cond_email_message   = ".";
		$cond_email_file      = "";
		$cond_redirect_delay  = "";
		$cond_redirect_url    = "";
		$cond_timer_countdown = "";
		$conditions_data      = array();
		foreach($collected_conditions as $cond_all_key => $cond_all_value){
			if($cond_all_value){
				if(array_key_exists($cond_all_key , $conditions)){
					if(isset($conditions[$cond_all_key]['messages'])){
						if(isset($conditions[$cond_all_key]['messages']['page'])){
							$cond_page_message = isset($conditions[$cond_all_key]['messages']['page']['message']) && $conditions[$cond_all_key]['messages']['page']['message'] != "" ? $conditions[$cond_all_key]['messages']['page']['message'] : "";
						}
						if(isset($conditions[$cond_all_key]['messages']['email'])){
							$cond_email_message = isset($conditions[$cond_all_key]['messages']['email']['message']) && $conditions[$cond_all_key]['messages']['email']['message'] != "" ? $conditions[$cond_all_key]['messages']['email']['message'] : ".";
							$cond_email_file    = isset($conditions[$cond_all_key]['messages']['email']['file']) && $conditions[$cond_all_key]['messages']['email']['file'] != "" ? $conditions[$cond_all_key]['messages']['email']['file'] : "";
							$cond_email_file_id = isset($conditions[$cond_all_key]['messages']['email']['file_id']) && $conditions[$cond_all_key]['messages']['email']['file_id'] != "" ? $conditions[$cond_all_key]['messages']['email']['file_id'] : "";
						}
						if(isset($conditions[$cond_all_key]['messages']['redirect'])){
							$cond_redirect_delay  = isset($conditions[$cond_all_key]['messages']['redirect']['delay']) && $conditions[$cond_all_key]['messages']['redirect']['delay'] != "" ? $conditions[$cond_all_key]['messages']['redirect']['delay'] : "";
							$cond_redirect_url    = isset($conditions[$cond_all_key]['messages']['redirect']['url']) && $conditions[$cond_all_key]['messages']['redirect']['url'] != "" ? $conditions[$cond_all_key]['messages']['redirect']['url'] : "";
							$cond_timer_countdown = Quiz_Maker_Data::secondsToWords( intval( $cond_redirect_delay ) );
						}
					}
				}

				$conditions_data = array(
					"pageMessage"       => $cond_page_message,
					"emailMessage"      => $cond_email_message,
					"email_file"   		=> $cond_email_file,
					"email_file_id"  	=> $cond_email_file_id,
					"redirectDelay"     => $cond_redirect_delay,
					"redirectUrl"       => $cond_redirect_url,
					"redirectCountDown" => $cond_timer_countdown
				);
			}
		}
		return $conditions_data;
	}

	public function ays_send_condition_email( $data ){
		$cond_user_email    = $data['cond_user_email'];
		$cond_user_name     =  $data['cond_user_name'];
		$cond_subject       =  $data['subject'];
		$cond_email_file_id = $data['cond_email_file_id'];
		$message_data		= $data['message_data'];
		$cond_email_message = $data['cond_email_message'];
		$cond_to = $cond_user_name . " <$cond_user_email>";

		$cond_headers = $nfrom."\r\n";
		if($nreply != ""){
			$cond_headers .= $nreply."\r\n";
		}
		
		$cond_headers .= "MIME-Version: 1.0\r\n";
		$cond_headers .= "Content-Type: text/html; charset=UTF-8\r\n";

		$cond_email_message = Quiz_Maker_Data::replace_message_variables($cond_email_message, $message_data);
		$cond_email_message = Quiz_Maker_Data::ays_autoembed( $cond_email_message );

		$attachment_path = false;
		$attachment_array = array();
		if($cond_email_file_id){
			$attachment_path = get_attached_file(intval($cond_email_file_id));
		}
		if($attachment_path){
			$attachment_array = array($attachment_path);
		}
		$quiz_send_cond_email = (wp_mail($cond_to, $cond_subject, $cond_email_message, $cond_headers, $attachment_array)) ? true : false;			
	}
}
