<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Conditional_Logic
 * @subpackage Quiz_Maker_Conditional_Logic/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Conditional_Logic_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-conditional-logic-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Conditional_Logic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Conditional_Logic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-conditional-logic-public.js', array( 'jquery' ), $this->version, false );

	}

	public function ays_quiz_detect_condition($conditions, $answered_questions, $options, $message_data) {

		// Condition calculation type
    	$quiz_condition_calculation_type = (isset($options->quiz_condition_calculation_type) && $options->quiz_condition_calculation_type != '') ? sanitize_text_field( $options->quiz_condition_calculation_type ) : 'default';

		$collected_conditions_all = array();

		if( $quiz_condition_calculation_type == "by_keyword" ){
			foreach($conditions as $condition_id => $condition_value){
				$collected_questions  = array();
				$collected_conditions = array();
				$condition_questions  = isset($condition_value['condition_question_add']) && !empty($condition_value['condition_question_add']) ? $condition_value['condition_question_add'] : array();
				foreach($condition_questions as $cond_question_id => $cond_question_value){
					$cond_question_id      = isset($cond_question_value['keyword_question_id']) && $cond_question_value['keyword_question_id'] != "" ? $cond_question_value['keyword_question_id'] : "";  
					$cond_question_type    = isset($cond_question_value['type']) && $cond_question_value['type'] != "" ? $cond_question_value['type'] : "keyword";  
					$cond_question_answer  = isset($cond_question_value['keyword_answer']) && $cond_question_value['keyword_answer'] != "" ? $cond_question_value['keyword_answer'] : "";  
					$cond_question_answer_points = isset($cond_question_value['keyword_answer_count']) && $cond_question_value['keyword_answer_count'] != '' ? $cond_question_value['keyword_answer_count'] : '';
					$cond_plus_condition   = isset($cond_question_value['plus_condition']) && $cond_question_value['plus_condition'] != "" ? $cond_question_value['plus_condition'] : "";
					$cond_question_equality = isset($cond_question_value['equality']) && $cond_question_value['equality'] != "" ? $cond_question_value['equality'] : "==";

					if($cond_plus_condition == 'and'){
						$cond_plus_condition_ready = "&&";
					}elseif($cond_plus_condition == 'or'){
						$cond_plus_condition_ready = "||";
					}else{
						$cond_plus_condition_ready = "";
					}

					if ($cond_question_answer == 'input') {
						if (array_key_exists("user_keyword_point_" . $cond_question_id , $message_data)) {
							$if_condition = false;
							if (isset($message_data["user_keyword_point_".$cond_question_id]) && $message_data["user_keyword_point_".$cond_question_id] != '' && $cond_question_type == 'keyword' && $cond_question_answer_points != '') {
								$if_condition = $this->ays_quiz_check_equality($cond_question_answer_points, $message_data["user_keyword_point_".$cond_question_id], $cond_question_equality);
							}

							if ($if_condition) {
								$collected_questions[] = 1;
							} else {
								$collected_questions[] = 0;
							}
							$collected_questions[] = $cond_plus_condition_ready;
						} else {
							$collected_questions[] = 0;
							$collected_questions[] = $cond_plus_condition_ready;
						}
					} else {
						if(array_key_exists("user_keyword_point_".$cond_question_id , $message_data)){
							$if_condition = false;
							if(isset($message_data["user_keyword_point_".$cond_question_id]) && isset($message_data["user_keyword_point_".$cond_question_answer]) ){
	
								if(is_array($message_data["user_keyword_point_".$cond_question_id])){
									if(in_array($cond_question_answer, $message_data["user_keyword_point_".$cond_question_id])){
										$if_condition = true;
									}
								}else{
									if( $message_data["user_keyword_point_".$cond_question_id] !== '' && $cond_question_type == 'keyword' ){
										$if_condition = $this->ays_quiz_check_equality(floatval( $message_data["user_keyword_point_".$cond_question_answer] ), $message_data["user_keyword_point_".$cond_question_id], $cond_question_equality);
									}
								}
							}
							if($if_condition){
								$collected_questions[] = 1;
							}else{
								$collected_questions[] = 0;
							}
							$collected_questions[] = $cond_plus_condition_ready;
						}
						else{
							$collected_questions[] = 0;
							$collected_questions[] = $cond_plus_condition_ready;
						}
					}
				}
				$if_condition_str   = implode("" , $collected_questions);
				$if_condition_ready = 0;
				try{
					$if_condition_ready = eval("return $if_condition_str;");
				}catch(Throwable $e){
					var_dump( "Captured Throwable: " . $e->getMessage());
				}

				if($if_condition_ready == 1){
					$if_condition_ready = true;
				}elseif($if_condition_ready == 0){
					$if_condition_ready = false;
				}
				$collected_conditions_all[$condition_id] = $if_condition_ready;
			}
		} else if ($quiz_condition_calculation_type == "by_category") {
			$score_by_categories = ( isset($message_data['score_by_cats_for_conditions']) && !empty($message_data['score_by_cats_for_conditions']) ) ? $message_data['score_by_cats_for_conditions'] : array();

			foreach($conditions as $condition_id => $condition_value){
				$collected_questions  = array();
				$collected_conditions = array();
				$condition_questions  = isset($condition_value['condition_question_add']) && !empty($condition_value['condition_question_add']) ? $condition_value['condition_question_add'] : array();
				foreach($condition_questions as $cond_question_id => $cond_question_value){
					$cond_question_id      = isset($cond_question_value['category_question_id']) && $cond_question_value['category_question_id'] != "" ? $cond_question_value['category_question_id'] : "";  
					$cond_question_type    = isset($cond_question_value['type']) && $cond_question_value['type'] != "" ? $cond_question_value['type'] : "category";  
					$cond_question_answer  = isset($cond_question_value['category_answer']) && $cond_question_value['category_answer'] != "" ? $cond_question_value['category_answer'] : "";  
					$cond_plus_condition   = isset($cond_question_value['plus_condition']) && $cond_question_value['plus_condition'] != "" ? $cond_question_value['plus_condition'] : "";  
					$cond_question_equality = isset($cond_question_value['equality']) && $cond_question_value['equality'] != "" ? $cond_question_value['equality'] : "==";
					if($cond_plus_condition == 'and'){
						$cond_plus_condition_ready = "&&";
					}elseif($cond_plus_condition == 'or'){
						$cond_plus_condition_ready = "||";
					}else{
						$cond_plus_condition_ready = "";
					}
					if(array_key_exists($cond_question_id, $score_by_categories)){
						$score = (int)$score_by_categories[$cond_question_id]['score'];
						$if_condition = $this->ays_quiz_check_equality(intval($cond_question_answer), $score, $cond_question_equality);
						if($if_condition){
							$collected_questions[] = 1;
						}else{
							$collected_questions[] = 0;
						}
						$collected_questions[] = $cond_plus_condition_ready;
					}
				}

				$if_condition_str   = implode("" , $collected_questions);
				$if_condition_ready = 0;
				try{
					$if_condition_ready = eval("return $if_condition_str;");
				}catch(Throwable $e){
					var_dump( "Captured Throwable: " . $e->getMessage());
				}
				if($if_condition_ready == 1){
					$if_condition_ready = true;
				}elseif($if_condition_ready == 0){
					$if_condition_ready = false;
				}
				$collected_conditions_all[$condition_id] = $if_condition_ready;
			}
		} else {
			foreach($conditions as $condition_id => $condition_value){
				$collected_questions  = array();
				$collected_conditions = array();
				$condition_questions  = isset($condition_value['condition_question_add']) && !empty($condition_value['condition_question_add']) ? $condition_value['condition_question_add'] : array();
				foreach($condition_questions as $cond_question_id => $cond_question_value){
					$cond_question_id      = isset($cond_question_value['question_id']) && $cond_question_value['question_id'] != "" ? $cond_question_value['question_id'] : "";  
					$cond_question_type    = isset($cond_question_value['type']) && $cond_question_value['type'] != "" ? $cond_question_value['type'] : "";  
					$cond_question_answer  = isset($cond_question_value['answer']) && $cond_question_value['answer'] != "" ? $cond_question_value['answer'] : "";  
					$cond_plus_condition   = isset($cond_question_value['plus_condition']) && $cond_question_value['plus_condition'] != "" ? $cond_question_value['plus_condition'] : "";  
					$cond_question_equality = isset($cond_question_value['equality']) && $cond_question_value['equality'] != "" ? $cond_question_value['equality'] : "==";
					
					if($cond_plus_condition == 'and'){
						$cond_plus_condition_ready = "&&";
					}elseif($cond_plus_condition == 'or'){
						$cond_plus_condition_ready = "||";
					}else{
						$cond_plus_condition_ready = "";
					}
					
					if(array_key_exists("ays-question-".$cond_question_id , $answered_questions)){
						$if_condition = false;
						if(isset($answered_questions["ays-question-".$cond_question_id])){
							
							if(is_array($answered_questions["ays-question-".$cond_question_id])){
								if(in_array($cond_question_answer, $answered_questions["ays-question-".$cond_question_id])){
									$if_condition = true;
								}
							}else{
								if( $answered_questions["ays-question-".$cond_question_id] != '' ){
									if($cond_question_type == 'number'){
											$if_condition = $this->ays_quiz_check_equality(intval($cond_question_answer), intval($answered_questions["ays-question-".$cond_question_id]), $cond_question_equality);
										}
									else{
										$if_condition = $this->ays_quiz_check_equality($cond_question_answer, $answered_questions["ays-question-".$cond_question_id], $cond_question_equality);
									}
								}
							}
						}


						if($if_condition){
							$collected_questions[] = 1;
						}else{
							$collected_questions[] = 0;
						}
						$collected_questions[] = $cond_plus_condition_ready;
					}
					else{
						$collected_questions[] = 0;
						$collected_questions[] = $cond_plus_condition_ready;
					}
				}
				$if_condition_str   = implode("" , $collected_questions);
				$if_condition_ready = 0;
				try{
					$if_condition_ready = eval("return $if_condition_str;");
				}catch(Throwable $e){
					var_dump( "Captured Throwable: " . $e->getMessage());
				}

				if($if_condition_ready == 1){
					$if_condition_ready = true;
				}elseif($if_condition_ready == 0){
					$if_condition_ready = false;
				}
				$collected_conditions_all[$condition_id] = $if_condition_ready;
			}
		}

		$true_conditions_count = false;
		if(array_sum($collected_conditions_all) > 1){
			$true_conditions_count = array_sum($collected_conditions_all);
		}

		$condition_messages = $this->ays_get_condition_messages($conditions, $collected_conditions_all, $options);
		return $condition_messages;
	}

	public function ays_quiz_check_equality( $condition_answer, $answered_answer, $sign = "==" ){
        switch($sign){
            case "==":
                if($answered_answer == $condition_answer){
                    return true;
                }
            break;
            case "!=":
                if($answered_answer != $condition_answer){
                    return true;
                }
            break;
            case "<":
                if($answered_answer < $condition_answer){
                    return true;
                }
            break;
            case "<=":
                if($answered_answer <= $condition_answer){
                    return true;
                }
            break;
            case ">":
                if($answered_answer > $condition_answer){
                    return true;
                }
            break;
            case ">=":
                if($answered_answer >= $condition_answer){
                    return true;
                }
            break;
            case "contains":
                if( strpos($answered_answer, $condition_answer) !== false ){
                    return true;
                }
            break;
            case "not_contain":
                if( strpos( $answered_answer, $condition_answer ) === false ){
                    return true;
                }
            break;
            default:
                if($condition_answer == $answered_answer){
                    return true;
                }
            break;
        }
        return false;
    }

	public function ays_get_condition_messages( $conditions, $collected_conditions, $options ){

		// Show all conditions results
        $options->quiz_condition_show_all_results = isset($options->quiz_condition_show_all_results) ? $options->quiz_condition_show_all_results : 'off';
        $quiz_condition_show_all_results = (isset($options->quiz_condition_show_all_results) && $options->quiz_condition_show_all_results == 'on') ? true : false;

		$cond_page_message    = $quiz_condition_show_all_results ? array() : '';

		$cond_email_message   = "";
		$cond_email_file      = "";
		$cond_redirect_delay  = "";
		$cond_redirect_url    = "";
		$cond_timer_countdown = "";
		$conditions_data      = array();
		foreach($collected_conditions as $cond_all_key => $cond_all_value){
			if($cond_all_value){
				if(array_key_exists($cond_all_key , $conditions)){
					if(isset($conditions[$cond_all_key]['messages'])){
						if(isset($conditions[$cond_all_key]['messages']['page'])){
							if(is_array($cond_page_message)){
	                            $cond_page_message[] = isset($conditions[$cond_all_key]['messages']['page']['message']) && $conditions[$cond_all_key]['messages']['page']['message'] != "" ? $conditions[$cond_all_key]['messages']['page']['message'] : "";
	                        }
	                        else{
	                            $cond_page_message = isset($conditions[$cond_all_key]['messages']['page']['message']) && $conditions[$cond_all_key]['messages']['page']['message'] != "" ? $conditions[$cond_all_key]['messages']['page']['message'] : "";
	                        }
						}
						if(isset($conditions[$cond_all_key]['messages']['email'])){
							$cond_email_message = isset($conditions[$cond_all_key]['messages']['email']['message']) && $conditions[$cond_all_key]['messages']['email']['message'] != "" ? $conditions[$cond_all_key]['messages']['email']['message'] : "";
							$cond_email_file    = isset($conditions[$cond_all_key]['messages']['email']['file']) && $conditions[$cond_all_key]['messages']['email']['file'] != "" ? $conditions[$cond_all_key]['messages']['email']['file'] : "";
							$cond_email_file_id = isset($conditions[$cond_all_key]['messages']['email']['file_id']) && $conditions[$cond_all_key]['messages']['email']['file_id'] != "" ? $conditions[$cond_all_key]['messages']['email']['file_id'] : "";
						}
						if(isset($conditions[$cond_all_key]['messages']['redirect'])){
							$cond_redirect_delay  = isset($conditions[$cond_all_key]['messages']['redirect']['delay']) && $conditions[$cond_all_key]['messages']['redirect']['delay'] != "" ? $conditions[$cond_all_key]['messages']['redirect']['delay'] : "";
							$cond_redirect_url    = isset($conditions[$cond_all_key]['messages']['redirect']['url']) && $conditions[$cond_all_key]['messages']['redirect']['url'] != "" ? $conditions[$cond_all_key]['messages']['redirect']['url'] : "";
							$cond_timer_countdown = Quiz_Maker_Data::secondsToWords( intval( $cond_redirect_delay ) );
						}
					}
				}

				$conditions_data = array(
					"pageMessage"       => $cond_page_message,
					"emailMessage"      => $cond_email_message,
					"email_file"   		=> $cond_email_file,
					"email_file_id"  	=> $cond_email_file_id,
					"redirectDelay"     => $cond_redirect_delay,
					"redirectUrl"       => $cond_redirect_url,
					"redirectCountDown" => $cond_timer_countdown
				);
			}
		}

		if(is_array($cond_page_message)){
            if(!empty($cond_page_message)){
                foreach($cond_page_message as $cond_page_message_key => &$cond_page_message_value){
                    $cond_page_message_value = Quiz_Maker_Data::replace_message_variables( $cond_page_message_value, $message_data );
                    $cond_page_message_value = Quiz_Maker_Data::ays_autoembed( $cond_page_message_value );
                }

                $cond_page_message = implode("", $cond_page_message);

                $conditions_data['pageMessage'] = $cond_page_message;
            }
        }
        else{
            if($cond_page_message != ""){
                $cond_page_message = Quiz_Maker_Data::replace_message_variables( $cond_page_message, $message_data );
                $cond_page_message = Quiz_Maker_Data::ays_autoembed( $cond_page_message );

                $conditions_data['pageMessage'] = $cond_page_message;
            }
        }

		return $conditions_data;
	}

	public function ays_send_condition_email( $data ){
		$cond_user_email    = $data['cond_user_email'];
		$cond_user_name     =  $data['cond_user_name'];
		$cond_subject       =  $data['subject'];
		$nfrom 				= $data['from'];
		$nreply 			= $data['reply_to'];
		$cond_email_file_id = $data['cond_email_file_id'];
		$message_data		= $data['message_data'];
		$cond_email_message = $data['cond_email_message'];
		$cond_to = $cond_user_name . " <$cond_user_email>";

		$cond_headers = $nfrom."\r\n";
		if($nreply != ""){
			$cond_headers .= $nreply."\r\n";
		}
		
		$cond_headers .= "MIME-Version: 1.0\r\n";
		$cond_headers .= "Content-Type: text/html; charset=UTF-8\r\n";

		$cond_email_message = Quiz_Maker_Data::replace_message_variables($cond_email_message, $message_data);
		$cond_email_message = Quiz_Maker_Data::ays_autoembed( $cond_email_message );

		$attachment_path = false;
		$attachment_array = array();
		if($cond_email_file_id){
			$attachment_path = get_attached_file(intval($cond_email_file_id));
		}
		if($attachment_path){
			$attachment_array = array($attachment_path);
		}

		if(!empty($attachment_array) && $cond_email_message == ""){
			$cond_email_message = ".";
		}

		$quiz_send_cond_email = (wp_mail($cond_to, $cond_subject, $cond_email_message, $cond_headers, $attachment_array)) ? true : false;			
	}
}
