<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Edd
 * @subpackage Quiz_Maker_Edd/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Edd
 * @subpackage Quiz_Maker_Edd/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Edd_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

    //Integrations quiz page content hook
    public function ays_quiz_page_edd_content($integrations, $args){
        $icon  = QUIZ_MAKER_EDD_ADMIN_URL .'/images/integration/logo-edd.png';
        $title = __('Easy Digital Downloads Settings',$this->plugin_name);

        if(isset($args)){
            $ays_quiz_edd_purchased_access = isset($args['ays_quiz_edd_purchased_access']) && $args['ays_quiz_edd_purchased_access'] != '' ? $args['ays_quiz_edd_purchased_access'] : '';
        }
        $checked = ($ays_quiz_edd_purchased_access == "on") ? "checked" : ''; 

        $content = '';

        if(in_array('easy-digital-downloads/easy-digital-downloads.php', apply_filters('active_plugins', get_option('active_plugins')))){
            $content .= '<div class="form-group row">
                  <div class="col-sm-5">
                      <label for="ays_quiz_edd_purchased_access">'. __('Give access to those quiz takers who have purchased the quiz',$this->plugin_name) .'</label>
                  </div>
                  <div class="col-sm-7">
                        <input type="checkbox" class="ays-enable-timer1" id="ays_quiz_edd_purchased_access"
                 name="ays_quiz_edd_purchased_access"
                 value="on"  '.$checked.' />';
              $content .= '
                  </div>
              </div>';
        }else{
            $content .= "<blockquote style='border-color:red;'>".__('To enable the integration, please install the Easy Digital Downloads plugin.' , $this->plugin_name)."</blockquote>";
        }   

        $integrations['edd'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );

        return $integrations;
    }

    // EDD integration in quiz page data options
    public function ays_quiz_page_edd_options( $args, $options ){

        $args['ays_quiz_edd_purchased_access'] = isset($options['ays_quiz_edd_purchased_access']) && $options['ays_quiz_edd_purchased_access'] == 'on' ? 'on' : 'off';  

        return $args;
    }

    // EDD integration in quiz page saver
    public function ays_quiz_page_edd_save( $options, $data ){
    	global $wpdb;
        // EDD
        $options['ays_quiz_edd_purchased_access'] = ( isset( $data['ays_quiz_edd_purchased_access'] ) && $data['ays_quiz_edd_purchased_access'] == 'on' ) ? 'on' : 'off';
        
        return $options;
    }

    // EDD integration in quiz page options
    public function ays_quiz_page_edd_after_save( $options, $quiz_id ){
        global $wpdb;
        // EDD
        $quiz_edd_purchased_access = ( isset( $_POST['ays_quiz_edd_purchased_access'] ) && $_POST['ays_quiz_edd_purchased_access'] == 'on' ) ? true : false;

        $title = ( isset( $_POST['ays_quiz_title'] ) && $_POST['ays_quiz_title'] != '' ) ? stripslashes(sanitize_text_field( $_POST['ays_quiz_title'] )) : '';

        $description = ( isset( $_POST['ays_quiz_description'] ) && $_POST['ays_quiz_description'] != '' ) ? stripslashes( $_POST['ays_quiz_description'] ) : '';

        $id = ( $_POST["id"] != NULL ) ? absint( intval( $_POST["id"] ) ) : null;
        $ays_edd_quiz_ids = self::ays_edd_quiz_ids();
        $ays_edd_ids_arr = array();

        foreach ($ays_edd_quiz_ids as $key => $value) {
            $ays_edd_ids_arr[] =  $value['meta_value'];
        }

        if( $id == null ){
            if($quiz_edd_purchased_access == true){
                if(in_array('easy-digital-downloads/easy-digital-downloads.php', apply_filters('active_plugins', get_option('active_plugins')))){ 
                    if(!in_array($quiz_id, $ays_edd_ids_arr)){
                        $new_download = new EDD_Dowlonad;
                        $download_args = array(
                            'post_title'    =>  $title,
                            'post_categoryntent'  =>  $description,
                            'post_status'   => 'publish',
                            'meta_input'    => array ('edd_ays_quiz_id'=> $quiz_id ),
                        );

                        $new_download->create( $download_args );
                    }
                }
            }
        }else{
            if($options['ays_quiz_edd_purchased_access'] == 'on'){
                if(in_array('easy-digital-downloads/easy-digital-downloads.php', apply_filters('active_plugins', get_option('active_plugins')))){ 
                    if(!in_array($id, $ays_edd_ids_arr)){
                        $new_download = new EDD_Download;
                        $download_args = array(
                            'post_title'    => $title,
                            'post_content'  => $description,
                            'post_status'   => 'publish',
                            'meta_input'    => array( 'edd_ays_quiz_id'=> $id ),
                        );

                        $new_download->create( $download_args );
                    }
                }
            }
        }

    }

   	public static function ays_edd_quiz_ids(){
        global $wpdb;
        $query = "SELECT * FROM `".$wpdb->prefix."postmeta` WHERE `meta_key` = 'edd_ays_quiz_id' ";
        $result_ids =  $wpdb->get_results( $query, "ARRAY_A" );

        return $result_ids;
    }

    public static function ays_edd_quiz_get_id($quiz_id){
        global $wpdb;
        $query = "SELECT post_id FROM `".$wpdb->prefix."postmeta` WHERE `meta_key` = 'edd_ays_quiz_id' AND `meta_value` = ".$quiz_id."  ";
        $result_id =  $wpdb->get_var( $query );

        return $result_id;
    }

}
