<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Edd
 * @subpackage Quiz_Maker_Edd/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Edd
 * @subpackage Quiz_Maker_Edd/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Edd_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


    public function ays_front_page_edd_pass_quiz_access($args, $quiz){
     	$id = ( $quiz["id"] != NULL ) ? absint( intval( $quiz["id"] ) ) : null;

     	if( $id === null ){
     		return $args;
     	}

        $options = ( json_decode($quiz['options'], true) != null ) ? json_decode($quiz['options'], true) : array();
     	$ays_quiz_edd_purchased_access = isset($options['ays_quiz_edd_purchased_access']) && $options['ays_quiz_edd_purchased_access'] == 'on' ? true : false;

     	if($ays_quiz_edd_purchased_access == 'on'){
            if(in_array('easy-digital-downloads/easy-digital-downloads.php', apply_filters('active_plugins', get_option('active_plugins')))){ 
                $ays_edd_post_id = Quiz_Maker_Edd_Admin::ays_edd_quiz_get_id($id);
                $edd_user_id = get_current_user_id();
                if($ays_edd_post_id !== null){
                    if( !edd_has_user_purchased( $edd_user_id, $ays_edd_post_id) ) {
                        $args['message'] = "<p style='text-align: center;font-style:italic;'>" . __( "You need to pay to pass this quiz.", $this->plugin_name ) . "</p>";
                        $args['status'] = false;
                    }
                }
            }
        }

        return $args;
    }

}
