<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Extra_Shortcodes
 * @subpackage Quiz_Maker_Extra_Shortcodes/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Extra_Shortcodes
 * @subpackage Quiz_Maker_Extra_Shortcodes/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Extra_Shortcodes_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Extra_Shortcodes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Extra_Shortcodes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-extra-shortcodes-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Extra_Shortcodes_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Extra_Shortcodes_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-extra-shortcodes-admin.js', array( 'jquery' ), $this->version, false );

	}

	public static function ays_get_setting( $meta_key ){
        global $wpdb;

        $settings_table  = esc_sql( $wpdb->prefix . "aysquiz_settings" );

        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
        $result = $wpdb->get_var($sql);

        if($result != ""){
            return $result;
        }
        return false;
    }

	////////////////////////////////////////////////////////////////////////////////////////
    //====================================================================================//
    ////////////////////////////////////////////////////////////////////////////////////////


	// Shorocde quiz page action hook
    public function ays_qm_settings_page_extra_shortcodes_content($args){

        $shortcodes_contents = apply_filters( 'ays_qm_settings_page_extra_shortcodes_contents', array(), $args );
        $shortcodes = array();

        foreach ($shortcodes_contents as $key => $shortcodes_content) {
            $content = '<fieldset>';
            if(isset($shortcodes_content['title'])){
                $content .= '<legend>';
                if(isset($shortcodes_content['icon'])){
                    $content .= '<strong style="font-size:30px;">'. $shortcodes_content['icon'] .'</strong>';
                }
                $content .= '<h5 style="margin: 0 4px;">'. $shortcodes_content['title'] .'</h5></legend>';
            }
            $content .= $shortcodes_content['content'];

            $content .= '</fieldset>';

            $shortcodes[] = $content;
        }

        echo implode('<hr/>', $shortcodes);
    }

    ////////////////////////////////////////////////////////////////////////////////////////
    //====================================================================================//
    ////////////////////////////////////////////////////////////////////////////////////////


    /*
    ==========================================
        User Progress shortcode | Start
    ==========================================
    */

    public function ays_settings_page_user_progres_content( $shortcodes, $args ){
    	$icon  = '[ ]';
        $title = __( 'User Progress Settings', $this->plugin_name );

        $shortcode_str = esc_attr( '[ays_user_progress id="Your_Quiz_ID" mode="score/points"]' );

        $content = array();

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_progress">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and insert it into any post. Put the ID of your preferred quiz and select one of the mode of calculation. It will show the progression of the current user in the form of chart.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_user_progress" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';


	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

	            		$content[] = '<li>';
	            			$content[] = sprintf(
                                            __( '%sID%s', $this->plugin_name ) . ' - ' . __( 'Enter the ID of the given quiz. Example: id="23".', $this->plugin_name ),
                                            '<b>',
                                            '</b>'
                                        );

	            		$content[] = '</li>';

	            		$content[] = '<li>';
	            			$content[] = sprintf(
                                            __( '%sMode%s', $this->plugin_name ) . ' - ' . __( 'Choose the way of displaying the result either via points or score.', $this->plugin_name ),
                                            '<b>',
                                            '</b>'
                                        );

	            		$content[] = '</li>';

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content = implode( '', $content );

        $shortcodes['user_progres'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}

	/*
    ==========================================
        User Progress shortcode | End
    ==========================================
    */


    /*
    ==========================================
        User History Quiz shortcode | Start
    ==========================================
    */

    public function ays_settings_page_user_history_quiz_content( $shortcodes, $args ){

    	// General Settings Options
    	$options = ($this->ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( $this->ays_get_setting('options') ), true);

    	$default_user_history_quiz_columns = array(
	        'quiz_name' 			=> 'quiz_name',
	        'start_date' 			=> 'start_date',
	        'end_date' 				=> 'end_date',
	        'duration' 				=> 'duration',
	        'score' 				=> 'score',
	        'points' 				=> '',
	        'download_certificate' 	=> '',
	        'details' 				=> 'details',
	    );
	    $options['user_history_quiz_columns'] = ! isset( $options['user_history_quiz_columns'] ) ? $default_user_history_quiz_columns : $options['user_history_quiz_columns'];
	    $user_history_quiz_columns = (isset( $options['user_history_quiz_columns'] ) && !empty($options['user_history_quiz_columns']) ) ? $options['user_history_quiz_columns'] : array();
	    $user_history_quiz_columns_order = (isset( $options['user_history_quiz_columns_order'] ) && !empty($options['user_history_quiz_columns_order']) ) ? $options['user_history_quiz_columns_order'] : $default_user_history_quiz_columns;

	    foreach( $default_user_history_quiz_columns as $key => $value ){
	        if( !isset( $user_history_quiz_columns[$key] ) ){
	            $user_history_quiz_columns[$key] = '';
	        }

	        if( !isset( $user_history_quiz_columns_order[$key] ) ){
	            $user_history_quiz_columns_order[$key] = $key;
	        }
	    }

	    foreach( $user_history_quiz_columns_order as $key => $value ){
	        if( !isset( $user_history_quiz_columns[$key] ) ){
	            if( isset( $user_history_quiz_columns[$value] ) ){
	                $user_history_quiz_columns_order[$value] = $value;
	            }
	            unset( $user_history_quiz_columns_order[$key] );
	        }
	    }

	    $default_user_history_quiz_column_names = array(
	        "quiz_name" 			=> __( 'Quiz name', $this->plugin_name ),
	        "start_date" 			=> __( 'Start date', $this->plugin_name ),
	        "end_date" 				=> __( 'End date', $this->plugin_name ),
	        "duration" 				=> __( 'Duration', $this->plugin_name ),
	        "score" 				=> __( 'Score', $this->plugin_name ),
	        "details" 				=> __( 'Details', $this->plugin_name ),
	        "download_certificate"  => __( 'Certificate', $this->plugin_name ),
	        "points" 				=> __( 'Points', $this->plugin_name ),
	    );

	    $hide_correct_answer = '';

	    // Hide correct answer
	    $options['quiz_hide_correct_answer_user_history_quiz'] = isset($options['quiz_hide_correct_answer_user_history_quiz']) ? sanitize_text_field( $options['quiz_hide_correct_answer_user_history_quiz'] ) : 'off';
	    $quiz_hide_correct_answer_user_history_quiz = (isset($options['quiz_hide_correct_answer_user_history_quiz']) && sanitize_text_field( $options['quiz_hide_correct_answer_user_history_quiz'] ) == "on") ? 'checked' : '';


	    /*
	    ==========================================
	    ==========================================
	    ==========================================
	    */


    	$icon  = '[ ]';
        $title = __( 'User History Quiz Settings', $this->plugin_name );

        $shortcode_str = esc_attr( '[ays_user_history_quiz id="Your_Quiz_ID"]' );

        $content = array();

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
            $content[] = '<div class="col-sm-12">';

				$content[] = '<div class="form-group row">';
		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_history_quiz">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Copy the shortcode and insert it into any post.  It shows the current user's history in the form of a list table. It includes all his previous results for a particular quiz. Put the corresponding quiz ID instead of Your_Quiz_ID part. Note that it works only for logged-in users.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_user_history_quiz" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
		            $content[] = '</div>';
	            $content[] = '</div>';

	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

	            		$content[] = '<li>';
	            			$content[] = sprintf(
                                            __( '%sID%s', $this->plugin_name ) . ' - ' . __( 'Enter the ID of the given quiz. Example: id="23".', $this->plugin_name ),
                                            '<b>',
                                            '</b>'
                                        );

	            		$content[] = '</li>';

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

	            $content[] = '<hr>';

				$content[] = '<div class="form-group row">';
		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_quiz_hide_correct_answer_user_history_quiz">';
		                    $content[] = __( "Hide correct answer", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Tick the checkbox if you want to hide the correct answers presented in the detailed report.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="checkbox" id="ays_quiz_hide_correct_answer_user_history_quiz" class="ays-checkbox-input" name="ays_quiz_hide_correct_answer_user_history_quiz" value="on" ' . $quiz_hide_correct_answer_user_history_quiz .'>';
		            $content[] = '</div>';
        		$content[] = '</div>';

	            $content[] = '<hr>';

				$content[] = '<div class="form-group row">';
           			$content[] = '<div class="col-sm-12">';

		                $content[] = '<label>';
		                    $content[] = __( "User history quiz results table columns", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("You can sort table columns and select which columns must display on the front-end.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';

			            $content[] = '<div class="ays-show-user-page-table-wrap">';
			                $content[] = '<ul class="ays-show-user-page-table">';
			                	foreach ($user_history_quiz_columns_order as $key => $val) :
			                		$checked = '';
			                        if(isset($user_history_quiz_columns[$key]) && $user_history_quiz_columns[$key] != ''){
			                            $checked = 'checked';
			                        }

			                		$content[] = '<li class="ays-user-page-option-row ui-state-default">';
			                			$content[] = '<input type="hidden" value="' . $key .'" name="ays_user_history_quiz_columns_order[' . $key .']"/>';
			                			$content[] = '<input type="checkbox" id="ays_user_history_quiz_columns_' . $key .'" value="' . $key .'" class="ays-checkbox-input" name="ays_user_history_quiz_columns[' . $key .']" '. $checked .' />';
			                			$content[] = '<label for="ays_user_history_quiz_columns_' . $key .'">';
			                				$content[] = $default_user_history_quiz_column_names[$key];
			                			$content[] = '</label>';
			                		$content[] = '</li>';

			                	endforeach;
			                $content[] = '</ul>';
			            $content[] = '</div>';

		            $content[] = '</div>';

        		$content[] = '</div>';
        	$content[] = '</div>';
        $content[] = '</div> <!-- User History Quiz Settings -->';

        $content = implode( '', $content );

        $shortcodes['user_history_quiz'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}


	// User History Quiz shortcode in General settings page data saver
    public function ays_settings_page_user_history_quiz_save( $fields, $data ){

    	// General Settings Options
    	$options = ($fields['options'] === false) ? array() : json_decode( stripcslashes( $fields['options'] ), true);

    	// columns | User History Quiz shortcode 
        $options['user_history_quiz_columns'] = (isset( $data['ays_user_history_quiz_columns'] ) && !empty($data['ays_user_history_quiz_columns'])) ? $data['ays_user_history_quiz_columns'] : array();
        $options['user_history_quiz_columns_order'] = (isset( $data['ays_user_history_quiz_columns_order'] ) && !empty($data['ays_user_history_quiz_columns_order'])) ? $data['ays_user_history_quiz_columns_order'] : array();

        // Hide correct answer | User History Quiz shortcode
        $options['quiz_hide_correct_answer_user_history_quiz'] = (isset( $data['ays_quiz_hide_correct_answer_user_history_quiz'] ) && $data['ays_quiz_hide_correct_answer_user_history_quiz'] == "on") ? "on" : "off";


        $fields['options'] = json_encode( $options );

        return $fields;
    }


	/*
    ==========================================
        User History Quiz shortcode | End
    ==========================================
    */


    /*
    ==========================================
        User Best Score shortcode | Start
    ==========================================
    */

    public function ays_settings_page_user_best_score_content( $shortcodes, $args ){

    	// General Settings Options
    	$options = ($this->ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( $this->ays_get_setting('options') ), true);

	    // User bestscore message from admin
	    $user_bestscore_message_admin = (isset($options['user_bestscore_message_admin']) && $options['user_bestscore_message_admin'] != '' ) ? stripslashes(esc_attr($options['user_bestscore_message_admin'])) : '';

	    // User bestscore message when not result yet
	    $user_bestscore_message = (isset($options['user_bestscore_message']) && $options['user_bestscore_message'] != '' ) ? stripslashes(esc_attr($options['user_bestscore_message'])) : '';


	    /*
	    ==========================================
	    ==========================================
	    ==========================================
	    */


    	$icon  = '[ ]';
        $title = __( 'User Best Score Settings', $this->plugin_name );

        $shortcode_str = esc_attr( '[ays_user_bestscore id="Your_Quiz_ID" mode="percentage/points"]' );

        $content = array();

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
            $content[] = '<div class="col-sm-12">';

				$content[] = '<div class="form-group row">';
		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_bestscore">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . esc_attr( __("Copy the shortcode, configure and paste it wherever you want, and it will display the user's best score. Put the corresponding quiz ID instead of Your_Quiz_ID part and select the preferred mode of the displaying of the score ( percentage or points ).",$this->plugin_name) ) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_user_bestscore" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
		            $content[] = '</div>';
	            $content[] = '</div>';

	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = __( "You can use the variable and paste it into the below message field." , $this->plugin_name );
	            	$content[] = '<hr/>';
	            	$content[] =  sprintf( __('%s%%%%best_points%%%%%s - The best point which got the user. The displaying method depends on the chosen mode of the shortcode. In the case of percentage it will display the score in percentage, in the case of points it will display it in points.',$this->plugin_name),
                            '<b>',
                            '</b>'
                        );
	            $content[] = '</blockquote>';
	            $content[] = '<hr>';

				$content[] = '<div class="form-group row">';
		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_bestscore_message_admin">';
		                    $content[] = __( "Message for the user who has passed", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Write the message which will be displayed when the user has passed the quiz.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<textarea class="ays-textarea" id="ays_user_bestscore_message_admin" name="ays_user_bestscore_message_admin" cols="30"
                                      rows="10" style="height: 80px;">' . $user_bestscore_message_admin . '</textarea>';
		            $content[] = '</div>';
        		$content[] = '</div>';

	            $content[] = '<hr>';

				$content[] = '<div class="form-group row">';
		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_bestscore_message">';
		                    $content[] = __( "Message for the user who has not passed yet", $this->plugin_name );
		                    $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("Write the message which will be displayed when the user has not passed the quiz yet and did not have any score yet.",$this->plugin_name) . ' "> ';
		                        $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		                    $content[] = '</a>';
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<textarea class="ays-textarea" id="ays_user_bestscore_message" name="ays_user_bestscore_message" cols="30"
                                      rows="10" style="height: 80px;">' . $user_bestscore_message . '</textarea>';
		            $content[] = '</div>';
        		$content[] = '</div>';

        	$content[] = '</div>';
        $content[] = '</div> <!-- User Best Score Settings -->';

        $content = implode( '', $content );

        $shortcodes['user_best_score'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );

        return $shortcodes;
	}

	// User Best Score shortcode in General settings page data saver
    public function ays_settings_page_user_best_score_save( $fields, $data ){

    	// General Settings Options
    	$options = ($fields['options'] === false) ? array() : json_decode( stripcslashes( $fields['options'] ), true);

    	// User bestscore message from admin | User Best Score shortcode
        $options['user_bestscore_message_admin'] = (isset( $data['ays_user_bestscore_message_admin'] ) && $data['ays_user_bestscore_message_admin'] != '' ) ? stripcslashes( sanitize_textarea_field( $data['ays_user_bestscore_message_admin'] ) ) : '';

        // User bestscore message when not result yet | User Best Score shortcode
	    $options['user_bestscore_message'] = (isset($data['ays_user_bestscore_message']) && $data['ays_user_bestscore_message'] != '' ) ? stripcslashes( sanitize_textarea_field($data['ays_user_bestscore_message']) ) : '';

        $fields['options'] = json_encode( $options );

        return $fields;
    }

    /*
    ==========================================
        User Best Score shortcode | End
    ==========================================
    */


    /*
    ==========================================
        User Activity Per day  | Start
    ==========================================
    */

    public function ays_settings_page_user_activity_per_day_content( $shortcodes, $args ){
    	$icon  = '[ ]';
        $title = __( 'User Activity Per Day Settings', $this->plugin_name );

        $shortcode_str = esc_attr( '[ays_user_activity_per_day]' );

        $content = array();

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_user_activity_per_day">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_user_activity_per_day" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';

	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

	            		$content[] = '<li>';
	            			$content[] = __( 'Copy the shortcode and insert it into any post. It shows the level of engagement for quizzes by quantifying the number of times the current user takes them daily. It displays the progress in the form of a chart. Note that it works only for logged-in users.', $this->plugin_name );
	            		$content[] = '</li>';

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content = implode( '', $content );

        $shortcodes['user_activity_per_day'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}

	/*
    ==========================================
        User Activity Per day | End
    ==========================================
    */

    /*
    ==========================================
        Quiz Activity Per day  | Start
    ==========================================
    */

    public function ays_settings_page_quiz_activity_per_day_content( $shortcodes, $args ){
    	$icon  = '[ ]';
        $title = __( 'Quiz Activity Per Day Settings', $this->plugin_name );

        $shortcode_str = esc_attr( '[ays_quiz_activity_per_day id="Your_Quiz_ID"]' );

        $content = array();

		$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
			$content[] = '<div class="col-sm-12" style="padding:20px;">';
				$content[] = '<div class="form-group row">';

		            $content[] = '<div class="col-sm-4">';
		                $content[] = '<label for="ays_quiz_activity_per_day">';
		                    $content[] = __( "Shortcode", $this->plugin_name );
		                $content[] = '</label>';
		            $content[] = '</div>';

		            $content[] = '<div class="col-sm-8">';
		                $content[] = '<input type="text" id="ays_quiz_activity_per_day" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
		            $content[] = '</div>';

	            $content[] = '</div>';

	            $content[] = '<hr>';

	            $content[] = '<blockquote>';
	            	$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

	            		$content[] = '<li>';
	            			$content[] = __( 'Copy the shortcode and insert it into any post. It shows the level of engagement for a particular quiz by quantifying the number of times all participants take the quiz daily. It displays the progress in the form of a chart. Put the corresponding quiz ID instead of Your_Quiz_ID part.', $this->plugin_name );
	            		$content[] = '</li>';

	            	$content[] = '</ul>';

	            $content[] = '</blockquote>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content = implode( '', $content );

        $shortcodes['quiz_activity_per_day'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $shortcodes;
	}

    /*
    ==========================================
        Quiz Activity Per day | End
    ==========================================
    */
}
