<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Extra_Shortcodes_User_Best_Score_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-extra-shortcodes-';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_user_bestscore', array($this, 'ays_generate_user_bestscore_method'));
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        
    }


    /*
    ==========================================
        User Best Score shortcode
    ==========================================
    */

    public function get_user_max_result( $attr, $mode = 'score' ){
        global $wpdb;

        $reports_table = esc_sql( $wpdb->prefix . "aysquiz_reports" );

        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;
        if($user_id == 0){
            return null;
        }

        $quiz_id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;
        $mode    = (isset($attr['mode']) && $attr['mode'] != '') ? sanitize_text_field( $attr['mode'] ) : 'percentage';

        if (is_null($quiz_id) || $quiz_id == 0 ) {
            return null;
        }

        if ($mode == 'points') {
            $quiz_mode = 'points';
        }else{
            $quiz_mode = 'score';
        }

        $sql = "SELECT MAX(CAST(".$quiz_mode." AS DECIMAL(10) )) AS avg_score
                FROM ". $reports_table ."
                WHERE user_id=". $user_id . " && quiz_id=".$quiz_id;

        $results = $wpdb->get_var($sql);

        return $results;

    }

    public function ays_quiz_replace_message_variables($content, $data){
        foreach($data as $variable => $value){
            $content = str_replace("%%".$variable."%%", $value, $content);
        }
        return $content;
    }

    public function ays_user_bestscore_html( $attr ){

        if(! is_user_logged_in() ){
            $user_bestscore_html = "<p style='text-align: center;font-style:italic;'>" . __( "You must log in to see your results.", $this->plugin_name ) . "</p>";
            return $user_bestscore_html;
        }

        $id   = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;
        $mode = (isset($attr['mode']) && $attr['mode'] != '') ? sanitize_text_field( $attr['mode'] ) : 'percentage';

        if (is_null( $id) ) {
            $content_html = "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return $content_html;
        }

        $quiz_settings_options = (Quiz_Maker_Extra_Shortcodes_Admin::ays_get_setting('options') === false) ? json_encode(array()) : Quiz_Maker_Extra_Shortcodes_Admin::ays_get_setting('options');
        $quiz_set_option = json_decode($quiz_settings_options, true);

        // User bestscore message from admin
        $user_bestscore_message_admin = (isset($quiz_set_option['user_bestscore_message_admin']) && $quiz_set_option['user_bestscore_message_admin'] != '' ) ? stripslashes(esc_attr($quiz_set_option['user_bestscore_message_admin'])) : __( "Your Best  Score is %%best_points%%" , $this->plugin_name);;

        // User bestscore message when not result yet
        $user_bestscore_message = (isset($quiz_set_option['user_bestscore_message']) && $quiz_set_option['user_bestscore_message'] != '' ) ? stripslashes(esc_attr($quiz_set_option['user_bestscore_message'])) : __( "There are no results yet" , $this->plugin_name);


        $best_score = $this->get_user_max_result($attr,$mode);
        
        $content_html = array();

        $content_html[] = "<div class='". $this->html_name_prefix ."user-bestscore-conteiner' id='". $this->html_name_prefix ."user-bestscore-conteiner-". $this->unique_id_in_class ."'>";

        if (is_null($best_score)) {
            $content_html[] = "<div class='". $this->html_name_prefix ."user-bestscore-text'>" . $user_bestscore_message . "</div>";
        }else{
            if ($mode == 'points') {
                if ( absint($best_score) === 1 || absint($best_score) === 0 ) {
                    $quiz_mode = __( 'point' , $this->plugin_name );
                }else{
                    $quiz_mode = __( 'points' , $this->plugin_name );
                }
            }else{
                $quiz_mode = '%';
            }

            $final_score_message = "<b class='". $this->html_name_prefix ."user-bestscore-text-bold'>". $best_score ." ". $quiz_mode ."</b>";

            $message_data = array(
                'best_points' => $final_score_message,
            );

            $message = $this->ays_quiz_replace_message_variables( $user_bestscore_message_admin , $message_data );

            
            $content_html[] = "<div class='". $this->html_name_prefix ."user-bestscore-text'>". $message ."</div>";
        }

        $content_html[] = $this->get_styles();
        $content_html[] = "</div>";

        $content_html = implode( '' , $content_html);

        return $content_html;
    }

    public function ays_generate_user_bestscore_method( $attr ){

        $id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;

        if (is_null($id) || $id == 0 ) {
            $content_html = "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return str_replace(array("\r\n", "\n", "\r"), "\n", $content_html);
        }

        $this->enqueue_styles();
        $this->enqueue_scripts();

        $unique_id = uniqid();
        $this->unique_id = $unique_id;
        $this->unique_id_in_class = $id . "-" . $unique_id;

        $content_html = $this->ays_user_bestscore_html( $attr );

        return str_replace(array("\r\n", "\n", "\r"), "\n", $content_html);
    }

    public function get_styles(){
        
        $content = array();
        $content[] = '<style type="text/css">';

        $content[] = "
            #". $this->html_name_prefix ."user-bestscore-conteiner-". $this->unique_id_in_class ." {
                margin: 20px auto;
            }

            #". $this->html_name_prefix ."user-bestscore-conteiner-". $this->unique_id_in_class ." .". $this->html_name_prefix ."user-bestscore-text {
                font-size: 32px;
                letter-spacing: normal;
                line-height: 1.3;
            }

            ";
        
        $content[] = "</style>";

        $content = implode( '', $content );

        return $content;
    }

}
