(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	function forRadioType( item, id, dataFlag ){
		var chartContent;
		if( dataFlag == 'quiz' ){
			chartContent = 'ays_quiz_quiz-question_frontend_statistics_chart_'+id;			
		}else if( dataFlag == 'question' ){
			chartContent = 'ays_quiz_question_frontend_statistics_chart_'+id;			
		}
		var dataTypes = [[ aysQuizFrontendStatisticsPublicChartLangObj.answers ,  aysQuizFrontendStatisticsPublicChartLangObj.percent ]];
		var answerName = item.answer_name;
		var answerCount = item.answer_count;
		var type = item.type;
		for (var key in answerCount) {
			if( answerName[key] == undefined ){
				answerName[key] = 'Not answered';
			}
			dataTypes.push([
				answerName[key] + '', answerCount[key]
			]);
		}
		google.charts.load('current', {'packages':['corechart']});
		google.charts.setOnLoadCallback(drawChart);
		
		function drawChart() {
	
			var data = google.visualization.arrayToDataTable(dataTypes);
			var options = {
				height: 250,
				fontSize: 16,
				chartArea: { 
					width: '80%',
					height: '80%'
				}
			};
	
			var chart = new google.visualization.PieChart( document.getElementById( chartContent ) );
	
			chart.draw(data, options);
	
			//create trigger to resizeEnd event     
			jQuery(window).resize(function() {
				if(this.resizeTO) clearTimeout(this.resizeTO);
				this.resizeTO = setTimeout(function() {
					jQuery(this).trigger('resizeEnd');
				}, 500);
			});
	
			//redraw graph when window resize is completed  
			jQuery(window).on('resizeEnd', function() {
				chart.draw(data, options);
			});
		}
	}

	function forCheckboxType( item, id, dataFlag ){
		var chartContent;
		var dataTypes = [[ aysQuizFrontendStatisticsPublicChartLangObj.answers ,  aysQuizFrontendStatisticsPublicChartLangObj.count ]];
		if( dataFlag == 'quiz' ){
			var answerName = item.answer_name;
			var answerCount = item.answer_count;
			if( ! jQuery.isEmptyObject( item ) ){
				for (var key in answerCount) {
					if( answerName[key] == undefined ){
						answerName[key] = 'Not answered';
					}
					dataTypes.push([
						answerName[key] + '', answerCount[key]
					]);
				}
			}else{
				dataTypes.push([
					'', 0
				]);
			}
			chartContent = 'ays_quiz_quiz-question_frontend_statistics_chart_'+id;			
		}else if( dataFlag == 'question' ){
			var answerName = item.answer_name;
			var answerCount = item.answer_count;
			var type = item.type;
			if( ! jQuery.isEmptyObject( item ) ){
				for (var key in answerCount) {
					if( answerName[key] == undefined ){
						answerName[key] = 'Not answered';
					}
					dataTypes.push([
						answerName[key] + '', answerCount[key]
					]);
				}
			}else{
				dataTypes.push([
					'', 0
				]);
			}
			chartContent = 'ays_quiz_question_frontend_statistics_chart_'+id;			
		}
	
		google.charts.load('current', {packages: ['corechart', 'bar']});
		google.charts.setOnLoadCallback(drawBasic);
	
		function drawBasic() {
	
			var data = google.visualization.arrayToDataTable(dataTypes);
			var groupData = google.visualization.data.group(
				data,
				[{column: 0, modifier: function () {return 'total'}, type:'string'}],
				[{column: 1, aggregation: google.visualization.data.sum, type: 'number'}]
			);
			
			var formatPercent = new google.visualization.NumberFormat({
				pattern: '#%'
			});
		
			var formatShort = new google.visualization.NumberFormat({
				pattern: 'short'
			});
		
			var view = new google.visualization.DataView(data);
			view.setColumns([0, 1, {
				calc: function (dt, row) {
					if( jQuery.isEmptyObject( item.answers ) ){
						return amount;
					}
					var amount =  formatShort.formatValue(dt.getValue(row, 1));
					var percent = formatPercent.formatValue(dt.getValue(row, 1) / groupData.getValue(0, 1));
					return amount + ' (' + percent + ')';
				},
				type: 'string',
				role: 'annotation'
			}]);
		
			var options = {
				height: 300,
				fontSize: 14,
				chartArea: { 
					width: '50%',
					height: '80%'
				},
				annotations: {
					alwaysOutside: true
				},
				bars: 'horizontal',
				bar: { groupWidth: "50%" },
			};
	
			var chart = new google.visualization.BarChart( document.getElementById( chartContent ) );

			chart.draw(view, options);
	
			//create trigger to resizeEnd event     
			jQuery(window).resize(function() {
				if(this.resizeTO) clearTimeout(this.resizeTO);
				this.resizeTO = setTimeout(function() {
					jQuery(this).trigger('resizeEnd');
				}, 500);
			});
	
			//redraw graph when window resize is completed  
			jQuery(window).on('resizeEnd', function() {
				chart.draw(view, options);
			});
		}
	}

	$(document).ready(function(){
		/**========================================
		* ========== Question chart start =========
		*==========================================*/
		var questionSummaryContainer = $(document).find('.ays-quiz-frontend-statistics-question-summary-container');
		var questionSummaryContainerLength = $(document).find('.ays-quiz-frontend-statistics-question-summary-container').length;
		for (var index = 0; index < questionSummaryContainerLength; index++) {
			var dataFlag = questionSummaryContainer.eq(index).data('flag');
			var uniqueId = questionSummaryContainer.eq(index).attr('data-unique-id');
			var id = questionSummaryContainer.eq(index).data('id');
			var aysQuizFrontendStatistics = JSON.parse( atob( window.aysQuizFrontendStatistics[ uniqueId ] ) );

			if(dataFlag == 'quiz'){
				for(var i in aysQuizFrontendStatistics){
					var questionType = aysQuizFrontendStatistics[i].type;
					switch ( questionType ) {
						case 'radio':
						case 'select':
						case 'true_or_false':
							forRadioType( aysQuizFrontendStatistics[i], i, dataFlag )
							break; 
						case 'checkbox':
							forCheckboxType( aysQuizFrontendStatistics[i], i, dataFlag )
							break;
						case 'text':
						case 'short_text':
						case 'number':
						case 'date':
							// forTextType( answerCount, questionType )
							break;		
						default:
							break;
					}	
				}
			}else if(dataFlag == 'question'){
				var questionType = aysQuizFrontendStatistics.type;
				switch ( questionType ) {
					case 'radio':
					case 'select':
					case 'true_or_false':
						forRadioType( aysQuizFrontendStatistics, id, dataFlag )
						break; 
					case 'checkbox':
						forCheckboxType( aysQuizFrontendStatistics, id, dataFlag )
						break;
					case 'text':
					case 'short_text':
					case 'number':
					case 'date':
						// forTextType( answerCount, questionType )
						break;		
					default:
						break;
				}			
			}
			// }
		}
		/**========================================
		* ========== Question chart end =========
		*==========================================*/
    });

})( jQuery );
