<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Frontend_Statistics_Question_Summary_Public{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-quiz-frontend-statistics';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_question_summary', array($this, 'ays_generate_question_summary_method'));
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->plugin_name, QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/css/quiz-maker-frontend-statistics-public.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        
        wp_enqueue_script( $this->plugin_name . '-google-chart-public', QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/js/google-chart.js', array('jquery'), $this->version, true);
        wp_enqueue_script( $this->plugin_name . '-public',QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/js/quiz-maker-frontend-statistics-public.js', array('jquery'), $this->version, true);
        wp_localize_script( $this->plugin_name . '-public', 'aysQuizFrontendStatisticsPublicChartLangObj', array(
            'answers' => __( 'Answers' , $this->plugin_name ),
            'percent' => __( 'Percent' , $this->plugin_name ),
            'count'   => __( 'Count' , $this->plugin_name ),
        ) );
    }


    /*
    ==========================================
        Quiz Summary shortcode
    ==========================================
    */
    
    public function ays_question_summary_html( $id ){
        $result = Quiz_Maker_Frontend_Statistics_Data::ays_get_question_summary_report( $id );
       
        //Question name
        $question_name = ( isset( $result['question'] ) && $result['question'] != '' ) ? sanitize_text_field( $result['question'] ) : '';

        //Answer name
        $answer_name = ( isset( $result['answers'] ) && !empty( $result['answers'] ) ) ? $result['answers'] : array();

        //Question type
        $question_type = ( isset( $result['type'] ) && $result['type'] != '' ) ? sanitize_text_field( $result['type'] ) : '';

        //User answer
        $user_answer = ( isset( $result['user_answered'] ) && !empty($result['user_answered'])  ) ? $result['user_answered'] : array();

        //Correct answer count 
        $correct_answer_count = ( isset( $result['correct_total_count'] ) && $result['correct_total_count'] != '' ) ? intval( $result['correct_total_count'] ) : '';

        //Total answer count 
        $total_answer_count = ( isset( $result['total_count'] ) && $result['total_count'] != '' ) ? intval( $result['total_count'] ) : '';
        $content = array();
        $answers = array();

        $answers['type']         = $question_type;
        $answers['answer_name']  = $answer_name;
        $answers['answer_count'] = $user_answer;

        $script = '<script type="text/javascript">';
        $script .= "
                if(typeof aysQuizFrontendStatistics === 'undefined'){
                    var aysQuizFrontendStatistics = [];
                }
                aysQuizFrontendStatistics['" . $this->unique_id . "']  = '" . base64_encode( json_encode( $answers ) ) . "';";
        $script .= '</script>';

        $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-container" data-unique-id="'. $this->unique_id .'" data-id="'.$id.'" data-flag="question">';

            $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-content">';

                $content[] = '<div class="'.$this->html_class_prefix.'-question-summary">';
                    //Question Name Content
                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-quest-name-content">';

                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-quest-name">';
                            $content[] = $question_name;
                        $content[] = '</p>';

                    $content[] = '</div>';

                    //Question Correct/Total Answer Content
                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-correct-total-ans-content">';

                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-total-answer">';
                            $content[] = '<span>' .__( 'Total answer', $this->plugin_name ). ' - '.$total_answer_count.'</span>';
                        $content[] = '</p>';

                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-correct-answer">';
                            $content[] = '<span>' .__( 'Correct answer', $this->plugin_name ). ' - '.$correct_answer_count.'</span>';
                        $content[] = '</p>';

                    $content[] = '</div>';

                    //Chart Content
                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-chart" id="'.$this->name_prefix.'question_frontend_statistics_chart_'.$id.'">';
                        if( $question_type == 'text' || $question_type == 'short_text' || $question_type == 'number' || $question_type == 'date' ){
                            foreach ($user_answer as $answer_name => $answer_count) {
                                $content[] = '<p>';
                                    $content[] = '<span>';
                                        $content[] = $answer_name;
                                    $content[] = '</span>';
                                    $content[] = '<span>';
                                        $content[] = $answer_count;
                                    $content[] = '</span>';
                                $content[] = '</p>';
                            }
                        }
                    $content[] = '</div>';

                $content[] = '</div>';
            $content[] = '</div>';

        $content[] = '</div>';

        $content[] = $script;

        $content = implode( '', $content );
        
        return $content;
    }

    public function ays_generate_question_summary_method( $attr ) {

        $id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;

        if (is_null($id) || $id == 0 ) {
            $question_summary_html = "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return str_replace(array("\r\n", "\n", "\r"), "\n", $question_summary_html);
        }

        $this->enqueue_styles();
        $this->enqueue_scripts();

        $unique_id = uniqid();
        $this->unique_id = $unique_id;
        $this->unique_id_in_class = $id . "-" . $unique_id;

        $content_html = $this->ays_question_summary_html( $id );
        
        return str_replace(array("\r\n", "\n", "\r"), "\n", $content_html);
    }

}
