<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker
 * @subpackage Quiz_Maker/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Quiz_Maker_Frontend_Statistics_Quiz_Summary_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    protected $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;


    protected $settings;

    private $html_class_prefix = 'ays-quiz-frontend-statistics';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'ays_quiz_';
    private $unique_id;
    private $unique_id_in_class;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version){

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_quiz_summary', array($this, 'ays_generate_quiz_summary_method'));
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->plugin_name, QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/css/quiz-maker-frontend-statistics-public.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(){

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Survey_Maker_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Survey_Maker_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        
        wp_enqueue_script( $this->plugin_name . '-google-chart-public', QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/js/google-chart.js', array('jquery'), $this->version, true);
        wp_enqueue_script( $this->plugin_name . '-public',QUIZ_MAKER_FRONTEND_STATISTICS_PUBLIC_URL . '/js/quiz-maker-frontend-statistics-public.js', array('jquery'), $this->version, true);
        wp_localize_script( $this->plugin_name . '-public', 'aysQuizFrontendStatisticsPublicChartLangObj', array(
            'answers' => __( 'Answers' , $this->plugin_name ),
            'percent' => __( 'Percent' , $this->plugin_name ),
            'count'   => __( 'Count' , $this->plugin_name ),
        ) );
    }


    /*
    ==========================================
        Quiz Summary shortcode
    ==========================================
    */

    public function get_quiz_summary( $id ){
        $report = Quiz_Maker_Frontend_Statistics_Data::ays_get_quiz_summary_report( $id );

        //Quiz results
        $results = ( isset( $report['results'] ) && !empty( $report['results'] ) ) ? $report['results'] : array();

        //Quiz Title
        $quiz_title = ( isset( $report['quiz_title'] ) && $report['quiz_title'] != '' ) ? $report['quiz_title'] : '';

        //Quiz Total Count
        $quiz_total_count = ( isset( $report['quiz_total_count'] ) && $report['quiz_total_count'] != '' ) ? intval($report['quiz_total_count']) : '';

        //Quiz Color
        $quiz_color = ( isset( $report['quiz_color'] ) && $report['quiz_color'] != '' ) ? sanitize_text_field( $report['quiz_color'] ) : '#e84706';

        $summary_results = array();
        $summary_res = array();

        $summary_results['quiz_title'] = $quiz_title;
        $summary_results['quiz_total_count'] = $quiz_total_count;
        $summary_results['quiz_color'] = $quiz_color;

        foreach ($results as $result_key => $result) {
            //Question id
            $question_id = ( isset( $result_key ) && $result_key != '' ) ? intval( $result_key ) : 0;

            //Question name
            $question_name = ( isset( $result['question'] ) && $result['question'] != '' ) ? sanitize_text_field( $result['question'] ) : '';

            //Answer name
            $answer_name = ( isset( $result['answers'] ) && !empty( $result['answers'] ) ) ? $result['answers'] : array();

            //Question type
            $question_type = ( isset( $result['type'] ) && $result['type'] != '' ) ? sanitize_text_field( $result['type'] ) : '';

            //User answer
            $user_answer = ( isset( $result['answered'] ) && !empty($result['answered'])  ) ? $result['answered'] : array();

            //Correct answer count 
            $correct_answer_count = ( isset( $result['correct'] ) && $result['correct'] != '' ) ? intval( $result['correct'] ) : '';

            //Total answer count 
            $total_answer_count = ( isset( $result['total'] ) && $result['total'] != '' ) ? intval( $result['total'] ) : '';   

            $total_count_each_answer = array();
            $answer = array();
            foreach ($user_answer as $user_answer_key => $user_answer_value) {
                if( is_array( $user_answer_value ) ){
                    foreach ($user_answer_value as $user_answer_value_k => $user_answer_value_v) {
                        $answer[] = $user_answer_value_v;
                    }
                    unset($user_answer[$user_answer_key]);
                }
            }
            foreach ($answer as $answer_key => $answer_value) {
                $user_answer[] = $answer_value;
            }
            switch ($question_type) {
                case 'radio':
                case 'select':
                case 'true_or_false':
                case 'checkbox':
                case 'text':
                case 'short_text':
                case 'number':
                case 'date':
                default:
                    $user_answer = array_replace($user_answer,array_fill_keys(array_keys($user_answer, null),''));
                    $total_count_each_answer = array_count_values($user_answer);
                break;
            }

            $summary_res[$question_id]['question']          = $question_name;
            $summary_res[$question_id]['answer_name']       = $answer_name;
            $summary_res[$question_id]['answer_count']      = $total_count_each_answer;
            $summary_res[$question_id]['correct_count']     = $correct_answer_count;
            $summary_res[$question_id]['total_count']       = $total_answer_count;
            $summary_res[$question_id]['type']              = $question_type;
        }

        $summary_results['results'] = $summary_res;

        return $summary_results;
    }

    public function ays_quiz_summary_html( $id ){
        $summary_results = $this->get_quiz_summary( $id ); 

        //Quiz results
        $results = ( isset( $summary_results['results'] ) && !empty( $summary_results['results'] ) ) ? $summary_results['results'] : array();

        //Quiz Title
        $quiz_title = ( isset( $summary_results['quiz_title'] ) && $summary_results['quiz_title']  != '' ) ? $summary_results['quiz_title'] : '';

        //Quiz Total Count
        $quiz_total_count = ( isset( $summary_results['quiz_total_count'] ) && $summary_results['quiz_total_count'] != '' ) ? intval($summary_results['quiz_total_count']) : '';

        //Quiz Color
        $quiz_color = ( isset( $summary_results['quiz_color'] ) && $summary_results['quiz_color'] != '' ) ? sanitize_text_field( $summary_results['quiz_color'] ) : '#e84706';

        $script = '<script type="text/javascript">';
        $script .= "
                if(typeof aysQuizFrontendStatistics === 'undefined'){
                    var aysQuizFrontendStatistics = [];
                }
                aysQuizFrontendStatistics['" . $this->unique_id . "']  = '" . base64_encode( json_encode( $results ) ) . "';";
        $script .= '</script>';

        $content = array();

        $content[] = '<div class="'.$this->html_class_prefix.'-quiz-summary-container" data-unique-id="'. $this->unique_id .'" data-flag="quiz">';
            $content[] = '<div class="'.$this->html_class_prefix.'-quiz-summary-content" >';

                $content[] = '<div class="'.$this->html_class_prefix.'-quiz-summary-quiz-passing-total-count-content" style="border-left:5px solid '.$quiz_color.'">';
                    $content[] = '<p class="'.$this->html_class_prefix.'-quiz-summary-quiz-passing-total-count" >';
                        $content[] = __( 'In total ' .$quiz_total_count. ' result(s)', $this->plugin_name );
                    $content[] = '</p>';
                $content[] = '</div>';

                $content[] = '<div class="'.$this->html_class_prefix.'-quiz-summary-quiz-name-content" style="border-top: 8px solid '.$quiz_color.'">';
                    $content[] = '<p class="'.$this->html_class_prefix.'-quiz-summary-quiz-name" >';
                        $content[] = $quiz_title;
                    $content[] = '</p>';
                $content[] = '</div>';

                $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-container '.$this->html_class_prefix.'-quiz-question-summary-content" data-unique-id="'. $this->unique_id .'" data-id="'.$id.'" data-flag="quiz" >';
                    foreach ($results as $result_key => $result) {
                        //Question id
                        $question_id = ( isset( $result_key ) && $result_key != '' ) ? intval( $result_key ) : 0;

                        //Question name
                        $question_name = ( isset( $result['question'] ) && $result['question'] != '' ) ? sanitize_text_field( $result['question'] ) : '';

                        //Question type
                        $question_type = ( isset( $result['type'] ) && $result['type'] != '' ) ? sanitize_text_field( $result['type'] ) : '';

                        //Correct answer count 
                        $correct_answer_count = ( isset( $result['correct_count'] ) && $result['correct_count'] != '' ) ? intval( $result['correct_count'] ) : '';

                        //Total answer count 
                        $total_answer_count = ( isset( $result['total_count'] ) && $result['total_count'] != '' ) ? intval( $result['total_count'] ) : '';

                        //Each answer count 
                        $each_answer_count_arr = ( isset( $result['answer_count'] ) && !empty($result['answer_count']) ) ? $result['answer_count'] : array();
                        
                            $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-content" style="border-left:5px solid '.$quiz_color.'">';

                                $content[] = '<div class="'.$this->html_class_prefix.'-question-summary">';
                                    //Question Name Content
                                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-quest-name-content">';

                                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-quest-name">';
                                            $content[] = $question_name;
                                        $content[] = '</p>';

                                    $content[] = '</div>';

                                    //Question Correct/Total Answer Content
                                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-correct-total-ans-content">';

                                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-total-answer">';
                                            $content[] = '<span>' .__( 'Total answer', $this->plugin_name ). ' - '.$total_answer_count.'</span>';
                                        $content[] = '</p>';

                                        $content[] = '<p class="'.$this->html_class_prefix.'-question-summary-correct-answer">';
                                            $content[] = '<span>' .__( 'Correct answer', $this->plugin_name ). ' - '.$correct_answer_count.'</span>';
                                        $content[] = '</p>';

                                    $content[] = '</div>';

                                    //Chart Content
                                    $content[] = '<div class="'.$this->html_class_prefix.'-question-summary-chart" id="'.$this->name_prefix.'quiz-question_frontend_statistics_chart_'.$question_id.'">';
                                        if( $question_type == 'text' || $question_type == 'short_text' || $question_type == 'number' || $question_type == 'date' ){
                                            foreach ($each_answer_count_arr as $each_answer_count_key => $each_answer_count) {
                                                if($each_answer_count_key == ''){
                                                    $each_answer_count_key = 'Not answered';
                                                }                                        
                                                $content[] = '<p>';
                                                    $content[] = '<span>';
                                                        $content[] = $each_answer_count_key;
                                                    $content[] = '</span>';
                                                    $content[] = '<span>';
                                                        $content[] = $each_answer_count;
                                                    $content[] = '</span>';
                                                $content[] = '</p>';
                                            }
                                        }
                                    $content[] = '</div>';

                                $content[] = '</div>';
                            $content[] = '</div>';
                    }
                $content[] = '</div>';

            $content[] = '</div>';
        $content[] = '</div>';

        $content[] = $script;

        $content = implode( '', $content );

        return $content;
    }

    public function ays_generate_quiz_summary_method( $attr ) {

        $id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;

        if (is_null($id) || $id == 0 ) {
            $quiz_summary_html = "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return str_replace(array("\r\n", "\n", "\r"), "\n", $quiz_summary_html);
        }

        $this->enqueue_styles();
        $this->enqueue_scripts();

        $unique_id = uniqid();
        $this->unique_id = $unique_id;
        $this->unique_id_in_class = $id . "-" . $unique_id;

        $content_html = $this->ays_quiz_summary_html( $id );
        
        return str_replace(array("\r\n", "\n", "\r"), "\n", $content_html);
    }
}
