<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Gamipress
 * @subpackage Quiz_Maker_Gamipress/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Gamipress
 * @subpackage Quiz_Maker_Gamipress/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Gamipress_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

     // GamiPress message content
    public function ays_gamipress_settings_page_content( $integrations, $args ){
        $icon  = QUIZ_MAKER_GAMIPRESS_ADMIN_URL . '/images/integrations/gamipress_logo.png';
        $title = __( 'GamiPress', $this->plugin_name );
        if(in_array('gamipress/gamipress.php', apply_filters('active_plugins', get_option('active_plugins')))){
        	$content = "<blockquote style='border-color:#78c0a8;'>".
        	__( "Configure the settings from the Automatic Points Awards section from the GamiPress plugin.", $this->plugin_name ) 
			. "<br>" .
			__( "After enabling the integration, the Quiz Maker will automatically be added to the event list.", $this->plugin_name )
			."</blockquote>";
		}else{
	        $content = "<blockquote style='border-color:red;'>".__('To enable the integration, please install the GamiPress plugin.' , $this->plugin_name)."</blockquote>";
		}

        $integrations['gamipress'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $integrations;
    }


    public function gamipress_ays_quiz_maker_activity_triggers( $triggers ) {

    	//GamiPress
        if(!in_array('quiz-maker/quiz-maker.php', apply_filters('active_plugins', get_option('active_plugins')))){ 
            return $triggers;
        }

        $triggers[__( 'Quiz Maker', 'gamipress-ays-quiz-maker-integration' )] = array(
            'gamipress_ays_quiz_maker_pass_quiz' => __( 'Finish a quiz', 'gamipress-ays-quiz-maker-integration' ),
            'gamipress_ays_quiz_maker_pass_specific_quiz' => __( 'Finish a specific quiz', 'gamipress-ays-quiz-maker-integration' ),
        );

        return $triggers;
    }

    public function gamipress_ays_quiz_maker_pass_quiz() {

        // Get the quiz ID
        $quiz_id = ( isset($_REQUEST['quiz_id'] ) ? (int) sanitize_key( $_REQUEST['quiz_id'] ) : 0 );
        
        if( $quiz_id === 0 ) return;

        $user_id = get_current_user_id();

        // Guests not allowed yet
        if( $user_id === 0 ) return;

        // Award user for pass a quiz
        do_action( 'gamipress_ays_quiz_maker_pass_quiz', $quiz_id, $user_id );

        // Award user for pass a specific quiz
        do_action( 'gamipress_ays_quiz_maker_pass_specific_quiz', $quiz_id, $user_id );

    }

    public function gamipress_ays_quiz_maker_pass_specific_activity_triggers( $specific_activity_triggers ) {
        $specific_activity_triggers['gamipress_ays_quiz_maker_pass_specific_quiz'] = array('ays_quiz_maker');
        
        return $specific_activity_triggers;
    }

    public function gamipress_ays_quiz_maker_trigger_get_user_id( $user_id, $trigger, $args ) {
          
        switch ( $trigger ) {
            case 'gamipress_ays_quiz_maker_pass_quiz':
            case 'gamipress_ays_quiz_maker_pass_specific_quiz':
                $user_id = $args[1];
                break;
        }

        return $user_id;

    }

    public  function gamipress_ays_quiz_maker_pass_specific_activity_trigger_title( $quiz_title, $quiz_id, $trigger_type ) {

        global $wpdb;
        switch( $trigger_type ) {
            case 'gamipress_ays_quiz_maker_pass_specific_quiz':
                if( absint( $quiz_id ) !== 0 ) {
                    $quiz_title = $this->gamipress_ays_quiz_maker_get_quiz_title( $quiz_id );
                }
                break;
        }

        return $quiz_title;

    }

    public function gamipress_ays_quiz_maker_pass_specific_trigger_get_id( $specific_id, $trigger = '', $args = array() ) {

        switch ( $trigger ) {
            case 'gamipress_ays_quiz_maker_pass_specific_quiz':
                $specific_id = $args[0];
                break;
        }

        return $specific_id;
    }

    public function gamipress_ays_quiz_maker_pass_specific_activity_trigger_label( $specific_activity_trigger_labels ) {

        $specific_activity_trigger_labels['gamipress_ays_quiz_maker_pass_specific_quiz'] = __( 'Pass on %s', 'gamipress-ays-quiz-maker-integration' );

        return $specific_activity_trigger_labels;
    }

    public function gamipress_ays_quiz_maker_ajax_get_posts() {

        global $wpdb;

         
        if( isset( $_REQUEST['post_type'] ) && in_array( 'ays_quiz_maker', $_REQUEST['post_type'] ) ) {

            $results = array();

            // Pull back the search string
            $search = isset( $_REQUEST['q'] ) ? $wpdb->esc_like( $_REQUEST['q'] ) : '';
            $sql = "SELECT id,title FROM {$wpdb->prefix}aysquiz_quizes WHERE title LIKE '%".$search."%' ";
            $quizzes = $wpdb->get_results( $sql, 'ARRAY_A');

            foreach ( $quizzes as $quiz ) {

                // Results should meet same structure like posts
                $results[] = array(
                    'ID' => $quiz['id'],
                    'post_title' => $quiz['title'],
                );

            }
            // Return our results
            wp_send_json_success( $results );
            die;
        }

    }

    public function gamipress_ays_quiz_maker_get_quiz_title( $quiz_id ) {

        global $wpdb;
        $sql = "SELECT title FROM {$wpdb->prefix}aysquiz_quizes WHERE id=".$quiz_id;

        return $wpdb->get_var( $sql);

    }
}
