<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Mycred
 * @subpackage Quiz_Maker_Mycred/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Mycred
 * @subpackage Quiz_Maker_Mycred/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Mycred_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		add_filter( 'mycred_setup_hooks',    array( $this, 'register_hook' ) );
        // add_action( 'mycred_init',           array( $this, 'load_textdomain' ) );
        add_action( 'mycred_all_references', array( $this, 'add_quiz_maker_log_support' ) );
        add_action( 'mycred_load_hooks',    'mycred_quiz_maker_load_hook' );

	}

	public static function ays_get_setting($meta_key){
        global $wpdb;
        $settings_table = $wpdb->prefix . "aysquiz_settings";

        if($wpdb->get_var("SHOW TABLES LIKE '$settings_table'") != $settings_table) {
            return false;
        }

        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
        $result = $wpdb->get_var($sql);
        if($result != ""){
            return $result;
        }
        return false;
    }

    public function ays_mycred_settings_page_content( $integrations, $args ){

        $icon  = QUIZ_MAKER_MYCRED_ADMIN_URL . '/images/mycred_icon.png';
        $title = __( 'MyCred', $this->plugin_name );
        
        if (is_multisite()) {
            $isPluginActive = is_plugin_active('mycred/mycred.php');
        } else {
            $isPluginActive = in_array( 'mycred/mycred.php', apply_filters( 'active_plugins', get_option('active_plugins') ) );
        }

        if($isPluginActive){

        	// MyCred Settings
            $options_res = (self::ays_get_setting('options') === false) ? json_encode(array()) : self::ays_get_setting('options');

            $options = json_decode(stripcslashes($options_res), true);

            $options['quiz_mycred_enable_pass_score'] = isset($options['quiz_mycred_enable_pass_score']) ? sanitize_text_field( $options['quiz_mycred_enable_pass_score'] ) : "off";
            $enable_pass_score = isset($options['quiz_mycred_enable_pass_score']) && $options['quiz_mycred_enable_pass_score'] == "on" ? true : false;

            $enable_pass_score_check = $enable_pass_score ? "checked" : "";

        	$content = "<blockquote style='border-color:#78c0a8;'>".
        	__( "Setup your first point type and go to the Hook page. Choose Quiz Maker from the Available Hooks list.", $this->plugin_name ) 
			. "<br>" .
			__( " Configure the settings and save the hook.", $this->plugin_name )
			."</blockquote>";

			$content .= '
            <hr>
            <div class="form-group row">
                <div class="col-sm-12">
                    <div class="form-group row">
                        <div class="col-sm-3">
                            <label for="ays_quiz_mycred_enable_pass_score">'. __('Enable Quiz Pass Score', $this->plugin_name) .'</label>
                            <a class="ays_help" data-toggle="tooltip" title="' . __("Quiz taker will get points only if he/she has reached the Pass Score set in the Results Settings tab of the Quiz Maker. For instance if the Pass Score is 70, and the user has got 70 or more for the quiz, he will get the points from MyCred.",$this->plugin_name) . '">
                                <i class="ays_fa ays_fa_info_circle"></i>
                            </a>
                        </div>
                        <div class="col-sm-9">
                            <input type="checkbox" id="ays_quiz_mycred_enable_pass_score" name="ays_quiz_mycred_enable_pass_score" value="on" '. $enable_pass_score_check .' />
                        </div>
                    </div>
                </div>
            </div>';
		}else{
	        $content = "<blockquote style='border-color:red;'>".__('To enable the integration, please install the MyCred plugin.' , $this->plugin_name)."</blockquote>";
		}

        $integrations['mycred'] = array(
            'content' => $content,
            'icon'    => $icon,
            'title'   => $title,
        );
        return $integrations;
    }

    // MyCred Settings integration in General settings page data saver
    public function ays_mycred_settings_page_save( $fields, $data ){

        $options = json_decode( $fields['options'], true );

        $options['quiz_mycred_enable_pass_score'] = isset($data['ays_quiz_mycred_enable_pass_score']) && $data['ays_quiz_mycred_enable_pass_score'] == "on" ? "on" : "off";

        $fields['options'] = json_encode( $options );

        return $fields;
    }


	public function register_hook( $installed ) {

        $installed['quizmaker'] = array(
            'title'       => __( 'Quiz Maker', 'mycred_quizmaker' ),
            'description' => __( 'Awards %_plural% for finishing a quiz.', 'mycred_quizmaker' ),
            'callback'    => array( 'myCRED_Hook_Quiz_Maker' )
        );

        return $installed;

    }

    public function add_quiz_maker_log_support( $references ) {

        $references['quiz_maker_finishing'] = __( 'Finishing a Quiz (QuizMaker)', 'mycred_quizmaker' );

        return $references;

    }


    public static function mycred_ays_finish_quiz(){
        if(!session_id()) {
            session_start();
        }
        $quiz_id = isset($_REQUEST['ays_quiz_id']) ? absint(intval($_REQUEST['ays_quiz_id'])) : 0;
        if($quiz_id === 0){

            $final_score = null;

            return $final_score;
        } else {
            global $wpdb;

            $limited_result_id = (isset($_REQUEST['ays_quiz_result_row_id']) && $_REQUEST['ays_quiz_result_row_id'] != '') ? absint(intval( $_REQUEST['ays_quiz_result_row_id'] )) : null;
            $questions_answers = (isset($_REQUEST["ays_questions"])) ? $_REQUEST['ays_questions'] : array();
            $questions_ids = preg_split('/,/', $_REQUEST['ays_quiz_questions']);
            $questions_answers = Quiz_Maker_Mycred_Data::sort_array_keys_by_array($questions_answers, $questions_ids);

            $quiz = Quiz_Maker_Mycred_Data::get_quiz_by_id($quiz_id);
            $quiz_intervals = isset($quiz['intervals']) && ($quiz['intervals']) != '' ? json_decode($quiz['intervals']) : null;
            $quiz_attributes = '';
            if (PARENT_QUIZ_MAKER_VERSION !== 'free') {
                $quiz_attributes = Quiz_Maker_Mycred_Data::get_quiz_attributes_by_id($quiz_id);
            }

            $options = json_decode($quiz['options']);
            if( is_array( $options ) ){
                $options = (object) $options;
            }

            $quiz_questions_count = Quiz_Maker_Mycred_Data::get_quiz_questions_count($quiz_id);
            //if (isset($options->enable_question_bank) && $options->enable_question_bank == "on" && isset($options->questions_count) && intval($options->questions_count) > 0 && count($quiz_questions_count) > intval($options->questions_count)) {
            $question_ids = preg_split('/,/', $_REQUEST['ays_quiz_questions']);
            //} else {
            //    $question_ids = Quiz_Maker_Mycred_Data::get_quiz_questions_count($quiz_id);
            //}
            // Strong calculation of checkbox answers
            // $options->checkbox_score_by = ! isset($options->checkbox_score_by) ? 'on' : $options->checkbox_score_by;
            // $strong_count_checkbox = (isset($options->checkbox_score_by) && $options->checkbox_score_by == "on") ? true : false;
            $calculate_score = 'by_correctness';
            if (PARENT_QUIZ_MAKER_VERSION !== 'free') {
                $calculate_score = isset($options->calculate_score) && $options->calculate_score != '' ? esc_attr($options->calculate_score) : '';
            }

            $questions_count = count($question_ids);
            $correctness = array();
            $user_answered = array();
            $correctness_results = array();
            $answer_max_weights = array();

            if (is_array($questions_answers)) {
                $quests = array();
                $questions_cats = array();
                $quiz_questions_ids = array();
                $question_bank_by_categories1 = array();

                foreach($questions_answers as $key => $val){
                    $question_id = explode('-', $key)[2];
                    $quiz_questions_ids[] = strval($question_id);
                }

                $questions_categories = Quiz_Maker_Mycred_Data::get_questions_categories( implode( ',', $quiz_questions_ids ) );
                $quest_s = Quiz_Maker_Mycred_Data::get_quiz_questions_by_ids($quiz_questions_ids);
                foreach($quest_s as $quest){
                    $quests[$quest['id']] = $quest;
                }

                foreach($quiz_questions_ids as $key => $question_id){
                    $questions_cats[$quests[$question_id]['category_id']][$question_id] = null;
                }

                $keywords_arr = array();
                $points_keywords_arr = array();
                foreach ($questions_answers as $key => $questions_answer) {
                    $continue = false;
                    $question_id = explode('-', $key)[2];
                    if(Quiz_Maker_Mycred_Data::is_question_not_influence($question_id)){
                        $questions_count--;
                        $continue = true;
                    }
                    $multiple_correctness = array();
                    $keyword_points_sum = array();
                    $has_multiple = Quiz_Maker_Mycred_Data::has_multiple_correct_answers($question_id);
                    $is_checkbox = Quiz_Maker_Mycred_Data::is_checkbox_answer($question_id);
                    $answer_max_weights[$question_id] = 0;
                    if (PARENT_QUIZ_MAKER_VERSION !== 'free') {
                        $answer_max_weights[$question_id] = Quiz_Maker_Mycred_Data::get_answers_max_weight($question_id, $is_checkbox);
                    }
                    
                    $user_answered["question_id_" . $question_id] = $questions_answer;

                    if($is_checkbox){
                       $has_multiple = true;
                    }

                    if ($has_multiple) {
                        if (is_array($questions_answer)) {
                            foreach ($questions_answer as $answer_id) {
                                $multiple_correctness[] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $answer_id, $calculate_score);
                                if (PARENT_QUIZ_MAKER_VERSION !== 'free') {
                                    $answer_keyword = Quiz_Maker_Mycred_Data::get_correct_answer_keyword($question_id, $answer_id);
                                    $keyword_points_sum[] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $answer_id, 'by_points');
                                    if(!is_null($answer_keyword) && $answer_keyword != false){
                                        $keywords_arr[] = $answer_keyword;
                                        $points_keywords_arr[$question_id][] = array(
                                            'keyword' => $answer_keyword,
                                            'point'   => Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $answer_id, 'by_points'),
                                        );
                                    }
                                }
                            }
                            if($calculate_score == 'by_points'){
                                if(!$continue){
                                    $correctness[$question_id] = array_sum($multiple_correctness);
                                }
                                $correctness_results["question_id_" . $question_id] = array_sum($multiple_correctness);
                                continue;
                            }
                            
                            // if($strong_count_checkbox === false){
                            //     if(!$continue){
                            //         $correctness[$question_id] = self::isHomogenousStrong($multiple_correctness, $question_id);
                            //     }
                            //     $correctness_results["question_id_" . $question_id] = self::isHomogenousStrong($multiple_correctness, $question_id);
                            // }
                            // else{
                            if (self::isHomogenous($multiple_correctness, $question_id)) {
                                if(!$continue){
                                    $correctness[$question_id] = true;
                                }
                                $correctness_results["question_id_" . $question_id] = true;
                            } else {
                                if(!$continue){
                                    $correctness[$question_id] = false;
                                }
                                $correctness_results["question_id_" . $question_id] = false;
                            }
                            // }
                        } else {
                            $questions_answer_keyword = $questions_answer;
                            if( intval( $questions_answer_keyword ) != 0 && PARENT_QUIZ_MAKER_VERSION !== 'free' ) {
                                $answer_keyword = Quiz_Maker_Mycred_Data::get_correct_answer_keyword($question_id, $questions_answer_keyword);
                                if(!is_null($answer_keyword) && $answer_keyword != false){
                                    $keywords_arr[] = $answer_keyword;
                                    $points_keywords_arr[$question_id] = array(
                                        'keyword' => $answer_keyword,
                                        'point'   => Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, 'by_points'),
                                    );
                                }
                            }
                            if($calculate_score == 'by_points'){
                                if(!$continue){
                                    $correctness[$question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                                }
                                $answer_keyword = Quiz_Maker_Mycred_Data::get_correct_answer_keyword($question_id, $questions_answer);
                                $points_keywords_arr[$question_id] = array(
                                    'keyword' => $answer_keyword,
                                    'point'   => Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, 'by_points'),
                                );
                                $correctness_results["question_id_" . $question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                                continue;
                            }
                            // if($strong_count_checkbox === false){
                            //     if(Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score)){
                            //         if(!$continue){
                            //             $correctness[$question_id] = 1 / intval(Quiz_Maker_Data::count_multiple_correct_answers($question_id));
                            //         }
                            //     }else{
                            //         if(!$continue){
                            //             $correctness[$question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                            //         }
                            //     }
                            //     $correctness_results["question_id_" . $question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                            // }else{
                                //if(!$continue){
                                //    $correctness[$question_id] = false;
                                //}
                                //$correctness_results["question_id_" . $question_id] = false;

                            $questions_answer = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                            if(!$continue){
                                $correctness[$question_id] = self::isHomogenous( array( $questions_answer ), $question_id );
                            }
                            $correctness_results["question_id_" . $question_id] = self::isHomogenous( array( $questions_answer ), $question_id );
                            // }
                        }
                    } elseif(Quiz_Maker_Mycred_Data::has_text_answer($question_id)) {
                        $quests_data = ( isset( $quests[$question_id] ) && ! empty( $quests[$question_id] ) ) ? $quests[$question_id] : array();
                        $quests_data_options = isset( $quests_data['options'] ) ? json_decode( $quests_data['options'], true ) : array();

                        if(!$continue){
                            $correctness[$question_id] = Quiz_Maker_Mycred_Data::check_text_answer_correctness($question_id, $questions_answer, $calculate_score, $quests_data_options);
                        }
                        $correctness_results["question_id_" . $question_id] = Quiz_Maker_Mycred_Data::check_text_answer_correctness($question_id, $questions_answer, $calculate_score, $quests_data_options);
                    } else {
                        if(!$continue){
                            $correctness[$question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                        }
                        $correctness_results["question_id_" . $question_id] = Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, $calculate_score);
                        if ( intval( $questions_answer ) != 0 && PARENT_QUIZ_MAKER_VERSION !== 'free' ) {
                            $answer_keyword = Quiz_Maker_Mycred_Data::get_correct_answer_keyword($question_id, $questions_answer);
                            if(!is_null($answer_keyword) && $answer_keyword != false){
                                $keywords_arr[] = $answer_keyword;
                                $points_keywords_arr[$question_id] = array(
                                    'keyword' => $answer_keyword,
                                    'point'   => Quiz_Maker_Mycred_Data::check_answer_correctness($question_id, $questions_answer, 'by_points'),
                                );
                            }
                        }
                    }
                }
                
                $new_correctness = array();
                $quiz_weight_correctness = array();
                $quiz_weight_points = array();
                $corrects_count = 0;
                $corrects_count_by_cats = array();
                foreach($questions_cats as $cat_id => &$q_ids){
                    $corrects_count_by_cats[$cat_id] = 0;
                    foreach($correctness as $question_id => $item){
                        if( array_key_exists( strval($question_id), $q_ids ) ){
                            switch($calculate_score){
                                case "by_correctness":
                                    if($item){
                                        $corrects_count_by_cats[$cat_id]++;
                                    }
                                break;
                                case "by_points":
                                    if($item == floatval($answer_max_weights[$question_id])){
                                        $corrects_count_by_cats[$cat_id]++;
                                    }
                                break;
                                default:
                                    if($item){
                                        $corrects_count_by_cats[$cat_id]++;
                                    }
                                break;
                            }
                        }
                    }
                }

                foreach($correctness as $question_id => $item){
                    $question_weight = 1;
                    if (PARENT_QUIZ_MAKER_VERSION != 'free') {
                        $question_weight = Quiz_Maker_Mycred_Data::get_question_weight($question_id);
                    }
                    $new_correctness[strval($question_id)] = $question_weight * floatval($item);
                    $quiz_weight_points[strval($question_id)] = $question_weight * floatval($answer_max_weights[$question_id]);
                    $quiz_weight_correctness[strval($question_id)] = $question_weight;
                    switch($calculate_score){
                        case "by_correctness":
                            if($item){
                                $corrects_count++;
                            }
                        break;
                        case "by_points":
                            if($item == floatval($answer_max_weights[$question_id])){
                                $corrects_count++;
                            }
                        break;
                        default:
                            if($item){
                                $corrects_count++;
                            }
                        break;
                    }
                }


                switch($calculate_score){
                    case "by_correctness":
                        $quiz_weight = array_sum($quiz_weight_correctness);
                    break;
                    case "by_points":
                        $quiz_weight = array_sum($quiz_weight_points);
                    break;
                    default:
                        $quiz_weight = array_sum($quiz_weight_correctness);
                    break;
                }
                $correct_answered_count = array_sum($new_correctness);
                
                if($quiz_weight == 0){
                    $final_score = floatval(0);
                }else{
                    $final_score = floatval( ( $correct_answered_count / $quiz_weight ) * 100 );
                    $final_score = round( $final_score, 2 );
                }

            } else {
                $final_score = null;
            }

            return $final_score;
        }
    }

    // public static function isHomogenousStrong($arr, $question_id){
    //     $arr_count = count( $arr );
    //     $arr_sum = array_sum( $arr );
    //     $count_correct = intval( Quiz_Maker_Data::count_multiple_correct_answers($question_id) );
    //     $a = $arr_count - $arr_sum;
    //     $b = $arr_sum - $a;
        
    //     return $b / $count_correct;
    // }
    
    public static function isHomogenous($arr, $question_id){
        $mustBe = true;
        $count = 0;
        foreach ($arr as $val) {
            if ($mustBe !== $val) {
                return false;
            }
            $count++;
        }
        $count_correct = intval( Quiz_Maker_Mycred_Data::count_multiple_correct_answers($question_id) );
        if($count !== $count_correct){
            return false;
        }
        return true;
    }

}
