<?php
    if ( ! function_exists( 'mycred_quiz_maker_load_hook' ) ) :
    function mycred_quiz_maker_load_hook() {

        if ( !class_exists( 'myCRED_Hook' ) ) return;
        if ( class_exists( 'myCRED_Hook_Quiz_Maker' ) ) return;

        class myCRED_Hook_Quiz_Maker extends myCRED_Hook {

            /**
             * Construct
             */
            function __construct( $hook_prefs, $type = MYCRED_DEFAULT_TYPE_KEY ) {

                parent::__construct( array(
                    'id'       => 'quizmaker',
                    'defaults' => array(
                        'creds'    => 1,
                        'log'      => '%plural% for finishing',
                        'limit'    => '0/x'
                    )
                ), $hook_prefs, $type );
            }

            /**
             * Run
             * This class method is fired of by myCRED when it's time to load all hooks.
             * It should be used to "hook" into the plugin we want to add support for or the
             * appropriate WordPress instances. Anything that must be loaded for this hook to work
             * needs to be called here.
             * @since 1.0
             * @version 1.0
             */
            public function run() {
                add_action( 'ays_quiz_maker_mycred', array( $this, 'finish_quiz' )); 
            }

            /**
             * Poll Voting
             * @since 1.0
             * @version 1.0
             */
            public function finish_quiz() {
                // $id = (isset($quiz['id'])) ? absint(intval($quiz['id'])) : null;
                
                // Get the quiz ID
                $quiz_id = ( isset($_REQUEST['quiz_id'] ) ? (int) sanitize_key( $_REQUEST['quiz_id'] ) : 0 );

                $user_id = get_current_user_id();
                if ( $user_id == 0 ) return;

                if ( $this->core->exclude_user( $user_id ) ) return;

                $mycred_flag = false;
                // MyCred Settings
                $options_res = (Quiz_Maker_Mycred_Admin::ays_get_setting('options') === false) ? json_encode(array()) : Quiz_Maker_Mycred_Admin::ays_get_setting('options');

                $options = json_decode( stripcslashes($options_res), true);

                $options['quiz_mycred_enable_pass_score'] = isset($options['quiz_mycred_enable_pass_score']) ? sanitize_text_field( $options['quiz_mycred_enable_pass_score'] ) : "off";
                $enable_pass_score = isset($options['quiz_mycred_enable_pass_score']) && $options['quiz_mycred_enable_pass_score'] == "on" ? true : false;

                if ( $enable_pass_score ) {
                    $user_score = Quiz_Maker_Mycred_Admin::mycred_ays_finish_quiz();

                    $quiz = Quiz_Maker_Mycred_Data::get_quiz_by_id($quiz_id);

                    $options = ( json_decode($quiz['options'], true) != null ) ? json_decode($quiz['options'], true) : array();

                    // Pass score of the quiz
                    $quiz_pass_score = (isset($options['pass_score']) && $options['pass_score'] != "") ? intval($options['pass_score']) : 0;

                    if ( $user_score >= $quiz_pass_score ) {
                        $mycred_flag = true;
                    } else {
                        $mycred_flag = false;
                    }
                } else {
                    $mycred_flag = true;
                }

                if ( $mycred_flag ) {
                    if ( ! $this->over_hook_limit( '', 'quiz_maker_finishing', $user_id ) ) {
                        $this->core->add_creds(
                            'quiz_maker_finishing',
                            $user_id,
                            $this->prefs['creds'],
                            $this->prefs['log'],
                            // $id,
                            array( 'ref_type' => 'post' ),
                            $this->mycred_type
                        );
                    }
                }
            }

            /**
             * Preferences
             * If the hook has settings, it has to be added in using this class method.
             * @since 1.0
             * @version 1.0
             */
            public function preferences() {

                $prefs = $this->prefs;
            ?>
            <label class="subheader"><?php _e( 'Earn:', 'mycred_quizmaker' ); ?></label>
            <ol>
                <li>
                    <div class="h2"><input type="text" name="<?php echo $this->field_name( 'creds' ); ?>" id="<?php echo $this->field_id( 'creds' ); ?>" value="<?php echo $this->core->number( $prefs['creds'] ); ?>" size="8" /></div>
                </li>
                <li>
                    <label for="<?php echo $this->field_id( array( 'giving' => 'limit' ) ); ?>"><?php _e( 'Limit:', 'mycred' ); ?></label>
                    <?php echo $this->hook_limit_setting( $this->field_name( 'limit' ), $this->field_id( 'limit' ), $prefs['limit'] ); ?>
                </li>
            </ol>
            <label class="subheader"><?php _e( 'Log Template:', 'mycred_quizmaker' ); ?></label>
            <ol>
                <li>
                    <div class="h2"><input type="text" name="<?php echo $this->field_name( 'log' ); ?>" id="<?php echo $this->field_id( 'log' ); ?>" value="<?php echo esc_attr( $prefs['log'] ); ?>" class="long" /></div>
                </li>
            </ol>
            <?php

            }

            /**
             * Sanitise Preferences
             * While myCRED does some basic sanitization of the data you submit in the settings,
             * we do need to handle our hook limits since 1.6. If your settings contain a checkbox (or multiple)
             * then you should also use this method to handle the submission making sure the checkbox values are
             * taken care of.
             * @since 1.0
             * @version 1.0
             */
            function sanitise_preferences( $data ) {

                if ( isset( $data['limit'] ) && isset( $data['limit_by'] ) ) {
                    $limit = sanitize_text_field( $data['limit'] );
                    if ( $limit == '' ) $limit = 0;
                    $data['limit'] = $limit . '/' . $data['limit_by'];
                    unset( $data['limit_by'] );
                }

                return $data;

            }
        }
    }
endif;