<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Popup_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The quiz popup list table object.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      object    $popup_quiz_obj    The quiz popup list table object.
	 */
    private $popup_quiz_obj;

    private $capability;
    private $current_user_can_edit;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		add_filter('set-screen-option', array(__CLASS__, 'set_screen'), 10, 3);

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Popup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Popup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (isset( $_GET['page'] ) && strpos( sanitize_text_field( $_GET['page'] ), QUIZ_MAKER_POPUP_NAME ) !== false) {
            wp_enqueue_style( $this->plugin_name . '-select2',  plugin_dir_url( __FILE__ ) .  'css/quiz-maker-select2.min.css', array(), $this->version, 'all');
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-popup-admin.css', array(), $this->version, 'all' );
        }

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Popup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Popup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (isset( $_GET['page'] ) && strpos( sanitize_text_field( $_GET['page'] ), QUIZ_MAKER_POPUP_NAME ) !== false) {
            wp_enqueue_script( $this->plugin_name . '-select2js', plugin_dir_url( __FILE__ ) . 'js/quiz-maker-select2.min.js', array('jquery'), $this->version, true);
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-popup-admin.js', array( 'jquery' ), $this->version, false );
            wp_localize_script( $this->plugin_name, 'PopupQuizMakerAdmin', array( 
                'ajaxUrl' 			=> admin_url( 'admin-ajax.php' ),
                'selectQuiz' 		=> __( 'Select Quiz' , $this->plugin_name ),
                'selectPage'        => __( 'Select page', $this->plugin_name ),
                'selectPostType'    => __( 'Select post type', $this->plugin_name ),
            ) );
        }

	}

	/**
	 * Get data from General Settings
	 *
	 * @since    1.0.0
	 */
	public static function ays_get_setting( $meta_key ){
        global $wpdb;

        $settings_table  = esc_sql( $wpdb->prefix . "aysquiz_settings" );

        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
        $result = $wpdb->get_var($sql);

        if($result != ""){
            return $result;
        }
        return false;
    }

    public function ays_quiz_popup_admin_ajax(){
		global $wpdb;

		$response = array(
			"status" => false
		);

		$function = isset($_REQUEST['function']) ? sanitize_text_field( $_REQUEST['function'] ) : null;

		if($function !== null){
			$response = array();
			if( is_callable( array( $this, $function ) ) ){
				$response = $this->$function();

	            ob_end_clean();
	            $ob_get_clean = ob_get_clean();
				echo json_encode( $response );
				wp_die();
			}
        }
        ob_end_clean();
        $ob_get_clean = ob_get_clean();
		echo json_encode( $response );
		wp_die();
	}

	////////////////////////////////////////////////////////////////////////////////////////
    //====================================================================================//
    ////////////////////////////////////////////////////////////////////////////////////////

	public function add_plugin_popup_quizzes_submenu() {

		$this->capability = $this->quiz_maker_popup_capabilities();
		$this->current_user_can_edit = self::quiz_maker_popup_capabilities_for_editing();
        $submenu_capability = PARENT_QUIZ_MAKER_VERSION !== 'free' ? $this->capability : 'manage_options';

        $hook_popup_quizzes = add_submenu_page(
            PARENT_QUIZ_MAKER_NAME,
            __('Popup Quiz', $this->plugin_name),
            __('Popup Quiz', $this->plugin_name),
            $submenu_capability,
            PARENT_QUIZ_MAKER_NAME . '-popup-quizzes',
            array($this, 'display_plugin_popup_quizzes_page')
        );

        add_action("load-$hook_popup_quizzes", array($this, 'screen_option_popup_quizzes'));
    }

    public static function set_screen($status, $option, $value){
        return $value;
    }

    public function display_plugin_popup_quizzes_page(){
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
            case 'add':
                include_once('partials/popups/actions/quiz-maker-popup-quizzes-actions.php');
                break;
            case 'edit':
                include_once('partials/popups/actions/quiz-maker-popup-quizzes-actions.php');
                break;
            default:
            include_once('partials/popups/quiz-maker-popups-display.php');
        }
    }

    public function screen_option_popup_quizzes(){
        $option = 'per_page';
        $args = array(
            'label' => __('Popup Quiz', $this->plugin_name),
            'default' => 20,
            'option' => 'popup_quiz_per_page'
        );

        if( ! ( isset( $_GET['action'] ) && ( $_GET['action'] == 'add' || $_GET['action'] == 'edit' ) ) ){
            add_screen_option( $option, $args );
        }

        $this->popup_quiz_obj = new Popup_Quiz_List_Table( $this->plugin_name );
    }

    /*
    ==========================================
        Quiz capabilities | Start
    ==========================================
    */

    protected function quiz_maker_popup_capabilities(){
        global $wpdb;

        $settings_table = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . 'settings' );

        $sql = "SELECT meta_value FROM {$settings_table} WHERE `meta_key` = 'user_roles'";
        $result = $wpdb->get_var($sql);
        
        $capability = 'ays_quiz_manage_options';
        if($result !== null){
            $ays_user_roles = json_decode($result, true);
            if(is_user_logged_in()){
                $current_user = wp_get_current_user();
                $current_user_roles = $current_user->roles;
                $ishmar = 0;
                foreach($current_user_roles as $r){
                    if(in_array($r, $ays_user_roles)){
                        $ishmar++;
                    }
                }
                if($ishmar > 0){
                    $capability = "read";
                }
            }
        }
        return $capability;
    }

    public static function quiz_maker_popup_capabilities_for_editing(){
        global $wpdb;

        $settings_table = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . 'settings' );

        $sql = "SELECT meta_value FROM {$settings_table} WHERE `meta_key` = 'options'";
        $result = $wpdb->get_var($sql);

        $capability = false;
        if($result !== null){
            $options = json_decode($result, true);

            // User roles to change quiz
            $ays_user_roles = (isset($options['user_roles_to_change_quiz']) && !empty( $options['user_roles_to_change_quiz'] ) ) ? $options['user_roles_to_change_quiz'] : array('administrator');
            if(is_user_logged_in()){
                $current_user = wp_get_current_user();
                $current_user_roles = $current_user->roles;
                $ishmar = 0;
                foreach($current_user_roles as $r){
                    if(in_array($r, $ays_user_roles)){
                        $ishmar++;
                    }
                }
                if($ishmar > 0){
                    $capability = true;
                }
            }
        }
        return $capability;
    }

    /*
    ==========================================
        Quiz capabilities | End
    ==========================================
    */

    public static function ays_restriction_string($type, $x, $length){
        $output = "";
        switch($type){
            case "char":                
                if(strlen($x)<=$length){
                    $output = $x;
                } else {
                    $output = substr($x,0,$length) . '...';
                }
                break;
            case "word":
                $res = explode(" ", $x);
                if(count($res)<=$length){
                    $output = implode(" ",$res);
                } else {
                    $res = array_slice($res,0,$length);
                    $output = implode(" ",$res) . '...';
                }
            break;
        }
        return $output;
    }

    public static function validateDate($date, $format = 'Y-m-d H:i:s'){
        $d = DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) == $date;
    }

    // Title change function in dashboard
    public function change_dashboard_title( $admin_title ) {
        
        global $current_screen;
        global $wpdb;

        if(strpos($current_screen->id, $this->plugin_name) === false){
            return $admin_title;
        }

        $quizzes_table          = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "quizes" );
        $popup_quizzes_table    = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "popup_quizzes" );

        $action = (isset($_GET['action'])) ? sanitize_text_field( $_GET['action'] ) : '';        
        $popup_quiz_id = ( isset( $_GET['id'] ) ) ? absint( sanitize_text_field( $_GET['id'] ) ) : null;
        
        if($popup_quiz_id !== null){
            $id = $popup_quiz_id;
        }else{
            $id = null;
        }

        $current = explode( PARENT_QUIZ_MAKER_NAME, $current_screen->id);
        $current = trim($current[count($current)-1], "-");

        $sql = '';
        switch($current){
            case "popup-quizzes":
                $page = __("Popup Quizzes", $this->plugin_name);
                if($id !== null){
                    $sql = "SELECT * FROM ". $popup_quizzes_table ." WHERE id=".$id;
                }
                break;
            default:
                $page = '';
                $sql = '';
                break;
        }
        $results = null;
        if($sql != ""){
            $results = $wpdb->get_row($sql, "ARRAY_A");
        }

        $change_title = null;
        switch($action){
            case "add":
                $change_title = __("Add New", $this->plugin_name) ." ‹ ".$page;
                break;
            case "edit":
                if($results !== null){
                    $title = "";
                    if($current == "popup-quizzes"){
                        if ( isset( $results['title'] ) && $results['title'] != '' ) {
                            $title = $results['title'];
                        }
                    }

                    $title = strip_tags($title);
                    $change_title = $this->ays_restriction_string("word", $title, 5) ." ‹ ". __("Edit", $this->plugin_name) . " ".$page;
                }
                break;
            default:
                $change_title = $admin_title;
                break;
        }

        if($change_title === null){
            $change_title = $admin_title;
        }
        
        return $change_title;

    }

    public function ays_quiz_popup_get_selected_posts() {
        $checked = isset( $_REQUEST['val'] ) && $_REQUEST['val'] !='' ? array_map( 'sanitize_text_field', $_REQUEST['val'] ) : null;
        $search = isset( $_REQUEST['q'] ) && $_REQUEST['q'] !='' ? sanitize_text_field( $_REQUEST['q'] ) : null;

        if($checked !== null){
	        $args = array(
				'post_type'   => $checked,
				'post_status' => 'publish',
				'numberposts' => -1
	        );
			if ($search !== null) {
				$args['s'] = $search;
			}

			$results = get_posts( $args );
		} else {
			$results = array();
		}

        $content_text = array(
            'results' => array()
        );

        foreach ($results as $value) {
            if ($checked !== null) {
                if (in_array($value->ID, $checked)) {
                    continue;
                }else{
                    $content_text['results'][] = array(
                        'id' => $value->ID,
                        'text' => $value->post_title,
                    );
                }
            }else{
             	$content_text['results'][] = array(
                    'id' => $value->ID,
                    'text' => $value->post_title,
                );
            }
        }
        return $content_text;
	}

    public function ays_quiz_popup_get_post_type(){
		global $wpdb;
        $checked = isset($_REQUEST['val']) && $_REQUEST['val'] !='' ? sanitize_text_field( $_REQUEST['val'] ) : null;
        $search = isset($_REQUEST['q']) && $_REQUEST['q'] !='' ? sanitize_text_field( $_REQUEST['q'] ) . '%' : null;
        $pref_posts = $wpdb->prefix . "posts";

        if($search !== null){
        	$search_query = "SELECT DISTINCT( post_type ) FROM ".$pref_posts." WHERE post_type LIKE '". $search ."' ";
			$results = $wpdb->get_results($search_query);
        }

        $content_text = array(
            'results' => array()
        );

        foreach ($results as $value) {
            if ($checked !== null) {
                if (in_array($value->post_type, $checked)) {
                    continue;
                }else{
        			$p_type = get_post_types( [ 'name'=>$value->post_type ], 'objects' );
                    $content_text['results'][] = array(
                        'id' => $value->post_type,
                        'text' => $p_type[$value->post_type]->label,
                    );
                }
            }else{
                $p_type = get_post_types( [ 'name'=>$value->post_type ], 'objects' );
                $content_text['results'][] = array(
                    'id' => $value->post_type,
                    'text' => $p_type[$value->post_type]->label,
                );
            }
        }
        return $content_text;
    }

}
