(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

 	$(document).ready(function () {

 		// ===============================================================
        // ========================= Prefixes ============================
		// ===============================================================

    	var $ays_prefix        = 'ays_';
	    var $name_prefix       = 'quiz_popup_';
	    var $html_name_prefix  = 'ays_quiz_popup_';
	    var $class_prefix      = '.ays-quiz-';
	    var $id_prefix         = '#ays-quiz-';

    	// ===============================================================
        // ========================= Prefixes ============================
		// ===============================================================

        $(document).find('#ays-quiz-popup-bg-color').wpColorPicker();

		$(document).find('table#ays-quiz-popup-position-table tr td').on('click', function(e){
            var val = $(this).data('value');
            $(document).find('.ays-popup-quiz-position-block '+ $html_name_prefix + 'position').val(val);
            aysQuizCheckPopupPosition( val );
        });

        function aysQuizCheckPopupPosition( hiddenVal ){
            var hiddeninput    = $(document).find('#'+ $html_name_prefix + 'position');

            var popupMarginBox = $(document).find("#popupMargin");
            var positionTable  = $(document).find('table#ays-quiz-popup-position-table');

            if (hiddenVal == "") {
                var $this = positionTable.find('tr td[data-value="center-center"');
            }else{
                var $this = positionTable.find('tr td[data-value='+ hiddenVal +']');
            }

            if (hiddenVal == 'center-center' || hiddenVal == ''){
                popupMarginBox.addClass('display_none');
                popupMarginBox.prev("hr").addClass('display_none');
            }else{
            	if ( popupMarginBox.hasClass('display_none') ) {
                	$(document).find("#popupMargin").removeClass('display_none');
            	}

            	if ( popupMarginBox.prev("hr").hasClass('display_none') ) {
                	popupMarginBox.prev("hr").removeClass('display_none');
            	}
            }

            positionTable.find('td').removeAttr('style');
            hiddeninput.val(hiddenVal);
            $this.css('background-color','#a2d6e7');
        }


        $(document).find(".ays-quiz-popup-show-where").on('change', function(){
            var checked   = $(this).val();
            var viewPlace = $(document).find('.ays_quiz_view_place_tr');
            if( checked == 'all' ){
                viewPlace.addClass('display_none');
            }else{
            	if ( viewPlace.hasClass('display_none') ) {
                	viewPlace.removeClass('display_none');
            	}
            }
        });

        $(document).find(".ays-quiz-popup-background-color").on('change', function(){
            var checked   = $(this).val();
            var viewPlace = $(document).find('.ays_quiz_popup_background_color');
            if( checked == 'quiz_bg_color' ){
                viewPlace.addClass('display_none');
            }else{
            	if ( viewPlace.hasClass('display_none') ) {
                	viewPlace.removeClass('display_none');
            	}
            }
        });

        $(document).find('#ays_quiz_popup_posts').select2({
            allowClear: true,
            placeholder: PopupQuizMakerAdmin.selectPage,
            minimumInputLength: 3,
            multiple: true,
            ajax: {
                url: PopupQuizMakerAdmin.ajaxUrl,
                dataType: 'json',
                data: function (params) {
                    var checkedUsers = $(document).find('#ays_quiz_popup_post_types').val();
                    return {
                    	action: 'ays_quiz_popup_admin_ajax',
                        function: 'ays_quiz_popup_get_selected_posts',
                        q: params.term,
                        val: checkedUsers,
                        page: params.page
                    };
                },
            }
        });   
    
        //Get Only selected post types(AV)
        $(document).find('#ays_quiz_popup_post_types').select2({
            placeholder: PopupQuizMakerAdmin.selectPostType,
            allowClear: true,
            minimumInputLength: 3,
            multiple: true,
            ajax: {
                url: PopupQuizMakerAdmin.ajaxUrl,
                dataType: 'json',
                data: function (params) {
                    var checkedUsers = $(document).find('#ays_quiz_popup_post_types').val();
                    return {
                    	action: 'ays_quiz_popup_admin_ajax',
                        function: 'ays_quiz_popup_get_post_type',
                        q: params.term,
                        val: checkedUsers,
                        page: params.page
                    };
                },
            }
        });

    });

})( jQuery );
