<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/includes
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @since      1.0.0
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/includes
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Popup_Data {

    public static function get_quiz_validated_data_from_array( $quiz, $attr ){
        global $wpdb;

        // Array for quiz validated options
        $settings = array();

        $ays_prefix   = 'ays_';
        $name_prefix  = 'quiz_popup_';
        $quiz_prefix  = 'quiz_';
        
        // ID
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
        $settings['id'] = $id;

        // Quiz options
        $options = array();
        $quiz_options = array();
        if( isset( $quiz['options'] ) && $quiz['options'] != '' ){
            $options = json_decode( $quiz['options'], true );
        }

        if ($quiz['q_options'] != '' || $quiz['q_options'] != null) {
            $quiz_options = json_decode( $quiz['q_options'], true );
        }

        $settings[ 'options' ]   = $options;
        // $settings[ 'q_options' ] = $quiz_options;

        // =======================  //  ======================= // ======================= // ======================= // ======================= //

        // =============================================================
        // ======================  Quiz Options  =======================
        // ========================    START    ========================

        // Quiz background color
        if (isset($options[ $name_prefix . 'bg_color_type' ]) && $options[ $name_prefix . 'bg_color_type' ] == 'custom_bg_color' ) {
            $settings[ $quiz_prefix . 'bg_color' ] = (isset( $options[ $name_prefix . 'bg_color' ] ) && $options[ $name_prefix . 'bg_color' ] != '') ? sanitize_text_field( $options[ $name_prefix . 'bg_color' ] ) : '#fff';
        } else {
            $settings[ $quiz_prefix . 'bg_color' ] = (isset( $quiz_options[ 'bg_color' ] ) && $quiz_options[ 'bg_color' ] != '') ? sanitize_text_field( $quiz_options[ 'bg_color' ] ) : '#fff';
        }
        // =============================================================
        // ======================  Quiz Options  =======================
        // ========================    END    ==========================

        // =======================  //  ======================= // ======================= // ======================= // ======================= //


        // =============================================================
        // ======================   General Tab   ======================
        // ========================    START    ========================

            // Quiz Status
            $settings[ 'quiz_status' ] = isset( $quiz[ 'quiz_status' ] ) && $quiz[ 'quiz_status' ] != '' ? absint( sanitize_text_field( $quiz[ 'quiz_status' ] ) ) : 0;

            // Enable popup quiz
            $options[ 'enable_quiz' ] = isset( $quiz[ 'enable_quiz' ] ) ? $quiz[ 'enable_quiz' ] : 'on';
            $settings[ $name_prefix . 'enable_quiz' ] = ( isset( $options[ 'enable_quiz' ] ) && $options[ 'enable_quiz' ] == 'on' ) ? true : false;

            // Title
            $settings[ $name_prefix . 'title' ] = ( isset( $quiz[ 'title' ] ) && $quiz[ 'title' ] != '' ) ? stripslashes( sanitize_text_field( $quiz[ 'title' ] ) ) : __( 'Quiz popup', QUIZ_MAKER_POPUP_NAME );

            // Status
            $settings[ $name_prefix . 'status' ] = isset( $quiz[ 'status' ] ) && $quiz[ 'status' ] != '' ? sanitize_text_field( $quiz[ 'status' ] ) : 'published';

            // Trash status
            $settings[ $name_prefix . 'trash_status' ] = '';
            
            // Date created
            $settings[ $name_prefix . 'date_created' ] = isset( $quiz[ 'date_created' ] ) && Quiz_Maker_Popup_Admin::validateDate( $quiz[ 'date_created' ] ) ? sanitize_text_field( $quiz[ 'date_created' ] ) : current_time( 'mysql' );
            
            // Date modified
            $settings[ $name_prefix . 'date_modified' ] = isset( $quiz[ 'date_modified' ] ) && Quiz_Maker_Popup_Admin::validateDate( $quiz[ 'date_modified' ] ) ? sanitize_text_field( $quiz[ 'date_modified' ] ) : current_time( 'mysql' );

            // Quiz_id
            $settings[ $name_prefix . 'quiz_id' ] = isset( $quiz[ 'quiz_id' ] ) && $quiz[ 'quiz_id' ] != '' ? absint( sanitize_text_field( $quiz[ 'quiz_id' ] ) ) : '';
            
            // Show All
            $settings[ $name_prefix . 'show_all' ] = isset( $quiz[ 'show_all' ] ) && $quiz[ 'show_all' ]  != '' ? sanitize_text_field( $quiz[ 'show_all' ] ) : 'all';
            
            // Width
            $settings[ $name_prefix . 'width' ] = (isset( $options[ $name_prefix . 'width' ] ) && $options[ $name_prefix . 'width' ] != '') ? absint( sanitize_text_field( $options[ $name_prefix . 'width' ] ) ) : 400;
            
            // Height
            $settings[ $name_prefix . 'height' ] = (isset( $options[ $name_prefix . 'height' ] ) && $options[ $name_prefix . 'height' ] != '') ? absint( sanitize_text_field( $options[ $name_prefix . 'height' ] ) ) : 500;
            
            // Border Radius
            $settings[ $name_prefix . 'border_radius' ] = (isset( $options[ $name_prefix . 'border_radius' ] ) && $options[ $name_prefix . 'border_radius' ] != '') ? absint( sanitize_text_field( $options[ $name_prefix . 'border_radius' ] ) ) : 0;

            // Popup position
            $settings[ $name_prefix . 'position' ] = (isset( $options[ $name_prefix . 'position' ] ) && $options[ $name_prefix . 'position' ] != 'center-center') ? sanitize_text_field( $options[ $name_prefix . 'position' ] ) : 'center-center';
            
            // Popup margin
            $settings[ $name_prefix . 'margin' ] = (isset( $options[ $name_prefix . 'margin' ] ) &&  $options[ $name_prefix . 'margin' ] != '') ? sanitize_text_field( $options[ $name_prefix . 'margin' ] ) : 0;
            
            // Posts
            $settings[ $name_prefix . 'post_types' ] = (isset( $options[ $name_prefix . 'post_types' ] ) && ! empty( $options[ $name_prefix . 'post_types' ] ) ) ? array_map( 'sanitize_text_field', $options[ $name_prefix . 'post_types' ] ) : array();
            $settings[ $name_prefix . 'posts' ] = (isset( $options[ $name_prefix . 'posts' ] ) && ! empty( $options[ $name_prefix . 'posts' ] ) ) ? array_map( 'sanitize_text_field', $options[ $name_prefix . 'posts' ] ) : array();
            $settings[ $name_prefix . 'all_posts' ] = (isset( $options[ $name_prefix . 'all_posts' ] ) && ! empty( $options[ $name_prefix . 'all_posts' ] ) ) ? array_map( 'sanitize_text_field', $options[ $name_prefix . 'all_posts' ] ) : array();

            // Show on Home page
            $options[ 'show_on_home_page' ] = isset( $options[ $name_prefix . 'show_on_home_page' ] ) ? $options[ $name_prefix . 'show_on_home_page' ] : 'on';
            $settings[ $name_prefix . 'show_on_home_page' ] = (isset( $options[ $name_prefix . 'show_on_home_page' ] ) && $options[ $name_prefix . 'show_on_home_page' ] == 'on') ? true : false;

            // Hide popup after one submission
            $options[ 'hide_popup' ] = isset( $options[ $name_prefix . 'hide_popup' ] ) ? $options[ $name_prefix . 'hide_popup' ] : 'off';
            $settings[ $name_prefix . 'hide_popup' ] = (isset( $options[ $name_prefix . 'hide_popup' ] ) && $options[ $name_prefix . 'hide_popup' ] == 'on') ? true : false;


        // =============================================================
        // ======================   General Tab   ======================
        // ========================     END     ========================


        // =======================  //  ======================= // ======================= // ======================= // ======================= //

        return $settings;
    }

    public static function get_popup_quiz_by_id( $id ){
        global $wpdb;
        $quizzes_table          = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "quizes" );
        $popup_quizzes_table    = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "popup_quizzes" );

        if ( is_null( $id ) || empty( $id ) ) {
            return null;
        }

        $sql = "SELECT p_q.*, q.options as q_options, q.published as quiz_status 
                FROM {$popup_quizzes_table} as p_q 
                LEFT JOIN {$quizzes_table} AS q 
                    ON p_q.quiz_id = q.id 
                WHERE p_q.id = {$id}";

        $popup_quiz = $wpdb->get_row( $sql, "ARRAY_A" );

        return $popup_quiz;
    }

    public static function ays_quiz_popup_set_cookie($attr){
        $cookie_name = $attr['name'].$attr['id'];
        $cookie_value = $attr['value'];

        $cookie_expiration =  current_time('timestamp') + (12 * 30 * 24 * 60 * 60);

        setcookie($cookie_name, $cookie_value, $cookie_expiration, '/');
    }

    public static function ays_quiz_popup_remove_cookie($attr){
        $cookie_name = $attr['name'].$attr['id'];
        if(isset($_COOKIE[$cookie_name])){

            unset($_COOKIE[$cookie_name]);
            
            $cookie_expiration =  current_time('timestamp') - 1;
            setcookie($cookie_name, null, $cookie_expiration, '/');

        }
    }

    public static function ays_quiz_popup_check_cookie($attr){
        $cookie_name = $attr['name'].$attr['id'];
        if(isset($_COOKIE[$cookie_name])){
            return true;
        }
        return false;
    }

    public static function get_setting_data( $meta_key = 'options' ){
        global $wpdb;

        $settings_table = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "settings" );

        $sql = "SELECT meta_value FROM " . $settings_table . " WHERE meta_key = '". $meta_key ."'";
        $result = $wpdb->get_var($sql);

        $options = ($result == "") ? array() : json_decode($result, true);

        return $options;
    }

}
