<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Popup
 * @subpackage Quiz_Maker_Popup/public
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Popup_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	private $html_class_prefix = 'ays-quiz-popup-';
    private $html_name_prefix = 'ays-quiz-';
    private $name_prefix = 'quiz_popup_';
    private $quiz_prefix = 'quiz_';
    private $options;
    private $unique_id;
    private $unique_id_in_class;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		add_shortcode('ays_quiz_popup', array($this, 'ays_generate_quiz_popup_method'));

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Popup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Popup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-popup-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Popup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Popup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script(  $this->plugin_name . '-popups', plugin_dir_url( __FILE__ ) . 'js/quiz-maker-popup-public.js', array( 'jquery' ), $this->version, false );
		wp_localize_script( $this->plugin_name . '-popups', 'aysQuizMakerPopupsAjaxPublic', array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
        ) );

	}

	public function ays_quiz_popup_public_ajax() {
		global $wpdb;

		$response = array(
			"status" => false
		);

		$function = isset($_REQUEST['function']) ? sanitize_text_field( $_REQUEST['function'] ) : null;

		if($function !== null){
			$response = array();
			if( is_callable( array( $this, $function ) ) ){
				$response = $this->$function();

	            ob_end_clean();
	            $ob_get_clean = ob_get_clean();
				echo json_encode( $response );
				wp_die();
			}
        }
        ob_end_clean();
        $ob_get_clean = ob_get_clean();
		echo json_encode( $response );
		wp_die();
	}

    public function ays_quiz_popup_set_cookie_after_submit() {

        if( isset( $_REQUEST['id'] ) && $_REQUEST['id'] != '' ){
            $id = absint( sanitize_text_field( $_REQUEST['id'] ) );
        }else{
            $id = null;
        }

        if( $id === null ){
            return array(
                'status' => false
            );
        }

        // Check user limitation
        $attr = array(
            'id'    => $id,
            'name'  => 'ays_quiz_popup_cookie_name_',
            'value' => 'ays_quiz_popup_cookie_value_',
        );

        $check_cookie = Quiz_Maker_Popup_Data::ays_quiz_popup_check_cookie( $attr );

        if ( ! $check_cookie ) {
            $set_cookie = Quiz_Maker_Popup_Data::ays_quiz_popup_set_cookie( $attr );
        }

        return array(
            'status' => true
        );
    }


	public function ays_generate_quiz_popup_method( $attr ){

        $id = (isset($attr['id']) && $attr['id'] != '') ? absint( sanitize_text_field($attr['id']) ) : null;

        if (is_null($id) || $id == 0 ) {
            return '';
        }
        
        $this->enqueue_styles();
        $this->enqueue_scripts();

        $unique_id = uniqid();
        $this->unique_id = $unique_id;
        $this->unique_id_in_class = $id . "-" . $unique_id;

        $content = $this->ays_popup_shortcode_content($id, $attr);
        return str_replace( array( "\r\n", "\n", "\r" ), "\n", $content );  
    }

    public function ays_quiz_popup_shortcodes_show_all(){
        global $wpdb;
        $popup_surveys_table = $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "popup_surveys";
        $surveys_table 		 = $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "quizes";

        $quizzes_table          = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "quizes" );
        $popup_quizzes_table    = esc_sql( $wpdb->prefix . QUIZ_MAKER_POPUP_DB_PREFIX . "popup_quizzes" );

        $sql = "SELECT p_q.*, q.options as s_options, q.published as quiz_status 
                FROM {$popup_quizzes_table} as p_q 
                LEFT JOIN {$quizzes_table} AS q 
                    ON p_q.quiz_id = q.id 
                WHERE p_q.status = 'published'";

        $result = $wpdb->get_results( $sql, "ARRAY_A" );

        foreach($result as $key => $value){

            if ( isset( $value['id'] ) && absint( $value['id'] ) > 0 ) {
                echo do_shortcode('[ays_quiz_popup id="'. $value['id'] .'"]');
            }

        }
    }

    public function ays_popup_shortcode_content( $id, $attr ){
        $content = array();
        
        $popup = Quiz_Maker_Popup_Data::get_popup_quiz_by_id( $id );

        if( is_null( $popup ) || empty( $popup ) ){
            return '';
        }

        $this->options = Quiz_Maker_Popup_Data::get_quiz_validated_data_from_array( $popup, $attr );

        if ( ! $this->options[ $this->name_prefix . 'enable_quiz' ]
                || $this->options[ $this->name_prefix . 'status' ] != 'published' ) {
            return '';
        }

        $quiz_status = $this->options[ 'quiz_status' ];

        if($quiz_status == 1){

            $quiz_id        = $this->options[ $this->name_prefix . 'quiz_id' ];

            $quiz_shortcode = '[ays_quiz id="'. $quiz_id .'"]';

            $show_popup = $this->check_quiz_popup();

            
            if( ! $this->options[ $this->name_prefix . 'hide_popup' ] ){
                $attr = array(
                    'id'    => $id,
                    'name'  => 'ays_quiz_popup_cookie_name_',
                    'value' => 'ays_quiz_popup_cookie_value_',
                );

                $check_cookie = Quiz_Maker_Popup_Data::ays_quiz_popup_check_cookie( $attr );

                if ( $check_cookie ) {
                    $remove_cookie = Quiz_Maker_Popup_Data::ays_quiz_popup_remove_cookie( $attr );
                }
            }

            if( ! isset( $_COOKIE[ 'ays_quiz_popup_cookie_name_' . $id ] ) ){
                if ($show_popup) {

                    $content[] = '<div class="' . $this->html_class_prefix . 'quiz-container" id="' . $this->html_class_prefix . 'quiz-container-' . $this->unique_id_in_class . '"  data-id="' . $id . '" data-uniqueid="' . $this->unique_id . '">';
                    
                        $content[] = '<div class="' . $this->html_class_prefix . 'btn-close">';                        
                            $content[] = '<img class="' . $this->html_class_prefix . 'btn-close-icon" src="'. QUIZ_MAKER_POPUP_PUBLIC_URL .'/images/close.svg">';
                        $content[] = '</div>';

                        $content[] = '<div class="' . $this->html_class_prefix . 'content">';

                            $content[] = '<div class="' . $this->html_class_prefix . 'main">';
                                $content[] = do_shortcode( $quiz_shortcode );
                            $content[] = '</div>';

                        $content[] = '</div>';
                    $content[] = '</div>';

                    $content[] = $this->get_styles();
                    $content[] = $this->get_encoded_options();

                }
            }
        }

        $content = implode( '', $content );

        return $content;
    }

    public function check_quiz_popup() {
        $post_id = get_the_ID();
        $show_popup = true;

        $show_all = $this->options[ $this->name_prefix . 'show_all' ];
        switch($show_all){
            case 'all':
                $show_popup = true;
            break;
            case 'selected':
                $show_popup = false;
            break;
            case 'except':
                $show_popup = true;
            break;
            default:
                $show_popup = true;
                $show_all = 'all';
            break;
        }

        $show = array('selected');

        if($show_all != 'all'){
            if($post_id != false){
                $post = get_post( $post_id );
                $this_post_title = strval( $post->ID );
                $except_posts = array();
                $except_post_types = array();
                $postType = $post->post_type;

                if ( ! empty( $this->options[ $this->name_prefix . 'posts' ] ) ) {
                    $except_posts = $this->options[ $this->name_prefix . 'posts' ];
                }

                if ( ! empty( $this->options[ $this->name_prefix . 'post_types' ] ) ) {
                    $except_post_types = $this->options[ $this->name_prefix . 'post_types' ];
                }

                $except_all_post_types = $this->options[ $this->name_prefix . 'all_posts' ];

                if ( is_front_page() ) {
                    if( $this->options[ $this->name_prefix . 'show_on_home_page' ] ){
                        $show_popup = true;
                    }else{
                        $show_popup = false;
                    }
                }
                
                if( in_array( $post_id . "", $except_posts ) ){
                    if( in_array( $show_all, $show ) ){
                        $show_popup = true;
                    }else{
                        $show_popup = false;
                    }
                }elseif( !in_array( $this_post_title, $except_posts ) && in_array( $postType, $except_all_post_types ) ) {
                    if( in_array( $show_all, $show ) ){
                        $show_popup = true;
                    }else{
                        $show_popup = false;
                    }
                }
            }
        }

        return $show_popup;

    }

    public function get_styles(){
        
        $content = array();
        $content[] = '<style type="text/css">';

        // Width
        $popup_quiz_width = $this->options[ $this->name_prefix . 'width' ];
        
        // Height
        $popup_quiz_height = $this->options[ $this->name_prefix . 'height' ];

        // Border Radius
        $popup_quiz_border_radius = $this->options[ $this->name_prefix . 'border_radius' ];

        // Popup Position
        $popup_position = $this->options[ $this->name_prefix . 'position' ];
        
        // Popup Margin
        $popup_margin = $this->options[ $this->name_prefix . 'margin' ];
        
        // Hide popup after one submission
        $hide_popup = $this->options[ $this->name_prefix . 'hide_popup' ];
        
        // Quiz background color
        $quiz_bg = $this->options[ $this->quiz_prefix . 'bg_color' ];


        $margin_right = '';
        if( absint( $popup_margin ) < 12 ){
            $margin_right = 'margin-right: 12px;';
        }

        $margin_right = '';
        $additional_css = '';
        switch ( $popup_position ){
            case "center-center":
                $popup_left_offset = $popup_quiz_width / 2;
                $popup_top_offset = $popup_quiz_height / 2; 
                $ays_quiz_popup_conteiner_pos_top = 'calc( 50% - ' . $popup_top_offset . 'px )';
                $ays_quiz_popup_conteiner_pos_left = 'calc( 50% - ' . $popup_left_offset . 'px )';
                $ays_quiz_popup_conteiner_pos_right = '0';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin = '0';

                break;
            case "left-top":

                $ays_quiz_popup_conteiner_pos_top = '0';
                $ays_quiz_popup_conteiner_pos_left = '0';
                $ays_quiz_popup_conteiner_pos_right = 'unset';
                $ays_quiz_popup_conteiner_pos_bottom = 'unset';
                $popup_margin .= 'px';

                if( absint( $popup_margin ) < 12 ){
                    $margin_right = 'margin-top: 12px;';
                }
                break;
            case "top-center":

                $ays_quiz_popup_conteiner_pos_top = '0';
                $ays_quiz_popup_conteiner_pos_left = '50%';
                $ays_quiz_popup_conteiner_pos_right = 'unset';
                $ays_quiz_popup_conteiner_pos_bottom = 'unset';
                $popup_margin .= 'px auto';
                $additional_css = 'transform: translateX(-50%);';

                if( absint( $popup_margin ) < 12 ){
                    $margin_right = 'margin-top: 12px;';
                }
                break;    
            case "right-top":

                $ays_quiz_popup_conteiner_pos_top = '0';
                $ays_quiz_popup_conteiner_pos_left = 'unset';
                $ays_quiz_popup_conteiner_pos_right = '0';
                $ays_quiz_popup_conteiner_pos_bottom = 'unset';
                $popup_margin .= 'px';
                if( absint( $popup_margin ) < 12 ){
                    $margin_right = 'margin-right: 12px;margin-top: 12px;';
                }

                break;
            case "left-center":

                $ays_quiz_popup_conteiner_pos_top = '0';
                $ays_quiz_popup_conteiner_pos_left = '0';
                $ays_quiz_popup_conteiner_pos_right = 'unset';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin = 'auto ' . $popup_margin . 'px';
                
                break; 
            case "right-center":
                
                $ays_quiz_popup_conteiner_pos_top = '0';
                $ays_quiz_popup_conteiner_pos_left = 'unset';
                $ays_quiz_popup_conteiner_pos_right = '0';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin = 'auto ' . $popup_margin . 'px';

                if( absint( $popup_margin ) < 12 ){
                    $margin_right = 'margin-right: 12px;';
                }
                break;       
            case "right-bottom":

                $ays_quiz_popup_conteiner_pos_top = 'unset';
                $ays_quiz_popup_conteiner_pos_left = 'unset';
                $ays_quiz_popup_conteiner_pos_right = '0';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin .= 'px';

                if( absint( $popup_margin ) < 12 ){
                    $margin_right = 'margin-right: 12px;';
                }
                break;
            case "center-bottom":

                $ays_quiz_popup_conteiner_pos_top = 'unset';
                $ays_quiz_popup_conteiner_pos_left = '50%';
                $ays_quiz_popup_conteiner_pos_right = 'unset';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin .= 'px auto';
                $additional_css = 'transform: translateX(-50%);';
                
                break;    
            case "left-bottom":

                $ays_quiz_popup_conteiner_pos_top = 'unset';
                $ays_quiz_popup_conteiner_pos_left = '0';
                $ays_quiz_popup_conteiner_pos_right = 'unset';
                $ays_quiz_popup_conteiner_pos_bottom = '0';
                $popup_margin .= 'px';
                
                break;
        }

        $content[] = '
            #' . $this->html_class_prefix . 'quiz-container-' . $this->unique_id_in_class . ' {
                width: ' . $popup_quiz_width . 'px;
                height: ' . $popup_quiz_height . 'px;
                border-radius: ' . $popup_quiz_border_radius . 'px;
                background-color: ' . $quiz_bg . ';
                top: ' . $ays_quiz_popup_conteiner_pos_top . ';
                left: ' . $ays_quiz_popup_conteiner_pos_left . ';
                right: ' . $ays_quiz_popup_conteiner_pos_right . ';
                bottom: ' . $ays_quiz_popup_conteiner_pos_bottom . ';
                margin: ' . $popup_margin . ';
                ' . $margin_right . '
                ' . $additional_css . '
            }

            ';
        
        $content[] = '</style>';

        $content = implode( '', $content );

        return $content;
    }

    public function get_encoded_options(){
        
        $content = array();

        $this->options['is_user_logged_in'] = is_user_logged_in();

        $options = array();
        foreach( $this->options as $k => $q ){
            if( strpos( $k, 'email' ) !== false ){
                unset( $this->options[ $k ] );
            }
        }
        $options = $this->options;

        $content[] = '<script type="text/javascript">';
    
        $content[] = "
                if(typeof aysQuizPopupsOptions === 'undefined'){
                    var aysQuizPopupsOptions = [];
                }
                aysQuizPopupsOptions['" . $this->unique_id . "']  = '" . base64_encode( json_encode( $options ) ) . "';";
        
        $content[] = '</script>';
    
        $content = implode( '', $content );

        return $content;
    }

}
