(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

    function AysQuizPopupsPlugin(element, options){
        this.el = element;
        this.$el = $(element);
        this.htmlClassPrefix = 'ays-quiz-';
        this.ajaxAction = 'ays_quiz_popup_public_ajax';
        this.dbOptions = undefined;
        this.popupId = undefined;
        this.uniqueId = undefined;
        this.confirmBeforeUnload = false;

        this.init();

        return this;
    }

    AysQuizPopupsPlugin.prototype.init = function() {
        var _this = this;

        _this.uniqueId = _this.$el.data('uniqueid');
        _this.popupId  = _this.$el.data('id');
        
        if( typeof window.aysQuizPopupsOptions != 'undefined' ){
            _this.dbOptions = JSON.parse( atob( window.aysQuizPopupsOptions[ _this.uniqueId ] ) );
        }

        _this.setEvents();
    };

    AysQuizPopupsPlugin.prototype.setEvents = function(e){
        var _this = this;

        _this.$el.on('click', '.' + _this.htmlClassPrefix + 'popup-btn-close', function(e){
            _this.$el.css('display', 'none');
        });

        _this.$el.on('click', 'input.ays_finish', function(){
            var hidePopupAfterSubmit = typeof _this.dbOptions.quiz_popup_hide_popup != 'undefined' && _this.dbOptions.quiz_popup_hide_popup == true ? true : false;
            if( hidePopupAfterSubmit ){
                $.ajax({
                    url: aysQuizMakerPopupsAjaxPublic.ajaxUrl,
                    method: 'post',
                    dataType: 'json',
                    data: {
                        action: _this.ajaxAction,
                        function: 'ays_quiz_popup_set_cookie_after_submit',
                        id: _this.popupId,
                    }
                });
            }
        });
    }
    
    /**
     * @return {string}
     */
    AysQuizPopupsPlugin.prototype.GetFullDateTime = function() {
        var now = new Date();
        var strDateTime = [[now.getFullYear(), AddZero(now.getMonth() + 1), AddZero(now.getDate())].join("-"), [AddZero(now.getHours()), AddZero(now.getMinutes()), AddZero(now.getSeconds())].join(":")].join(" ");
        return strDateTime;
    }

    /**
     * @return {string}
     */
    AysQuizPopupsPlugin.prototype.AddZero = function (num) {
        return (num >= 0 && num < 10) ? "0" + num : num + "";
    }

    /**
     * @return {string}
     */
    function AddZero(num) {
        return (num >= 0 && num < 10) ? "0" + num : num + "";
    }

    $.fn.AysQuizMakerPopups = function(options) {
        return this.each(function() {
            if (!$.data(this, 'AysQuizMakerPopups')) {
                $.data(this, 'AysQuizMakerPopups', new AysQuizPopupsPlugin(this, options));
            } else {
                try {
                    $(this).data('AysQuizMakerPopups').init();
                } catch (err) {
                    console.error('AysQuizMakerPopups has not initiated properly');
                }
            }
        });
    };
    
    $(document).find('.ays-quiz-popup-quiz-container').AysQuizMakerPopups();

})( jQuery );
