<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Razorpay
 * @subpackage Quiz_Maker_Razorpay/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Razorpay
 * @subpackage Quiz_Maker_Razorpay/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Razorpay_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

    private $blockquote_content;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

        $settings_url = sprintf(
            __( "For enabling this option, please go to %s page and fill all options.", $this->plugin_name ),
            "<a style='color:blue;text-decoration:underline;font-size:20px;' href='?page=".$this->plugin_name."-settings&ays_quiz_tab=tab2' target='_blank'>". __( "this", $this->plugin_name ) ."</a>"
        );
        $blockquote_content = '<blockquote class="error_message">'. $settings_url .'</blockquote>';
        $this->blockquote_content = $blockquote_content;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Razorpay_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Razorpay_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-razorpay-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Razorpay_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Razorpay_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-razorpay-admin.js', array( 'jquery' ), $this->version, false );

	}

    // Quiz add/edit integrations tab

        // Content
        public function ays_quiz_page_razorpay_content( $integrations, $args ){

            $quiz_settings = Quiz_Maker_Razorpay_Data::ays_get_setting('razorpay');
            $razorpay_res = ($quiz_settings === false) ? json_encode(array()) : $quiz_settings;
            $razorpay = json_decode($razorpay_res, true);

            $razorpay_key_id = isset($razorpay['key_id']) ? $razorpay['key_id'] : '';
            $razorpay_key_secret = isset($razorpay['key_secret']) ? $razorpay['key_secret'] : '';
            $razorpay_payment_terms = isset($razorpay['payment_terms']) ? $razorpay['payment_terms'] : 'lifetime';

            $enable_razorpay = (isset($args['enable_razorpay']) && $args['enable_razorpay'] == 'on') ? true : false;
            $razorpay_amount = (isset($args['razorpay_amount'])) ? $args['razorpay_amount'] : '';
            $razorpay_currency = (isset($args['razorpay_currency'])) ? $args['razorpay_currency'] : '';
            $razorpay_message = (isset($args['razorpay_message'])) ? stripslashes( $args['razorpay_message'] ) : __('You need to pay to pass this quiz.', $this->plugin_name);

            $razorpay_currencies = Quiz_Maker_Razorpay_Data::ays_get_razorpay_currencies();

            $icon = QUIZ_MAKER_RAZORPAY_ADMIN_URL .'/images/integrations/razorpay-logo.png';
            $title = __('Razorpay Settings',$this->plugin_name);

            $content = '';
            ob_start();
            if (count($razorpay) > 0) {
                if ($razorpay_key_id == "" || $razorpay_key_secret == "") {
                    $content .= $this->blockquote_content;
                } else { ?>
                    <div class="form-group row">
                        <div class="col-sm-4">
                            <label for="ays_enable_razorpay">
                                <?php echo __('Enable Razorpay',$this->plugin_name); ?>
                            </label>
                        </div>
                        <div class="col-sm-1">
                            <input type="checkbox" class="ays-enable-timer1" id="ays_enable_razorpay"
                                name="ays_enable_razorpay"
                                value="on"
                                <?php echo $enable_razorpay ? "checked" : ''; ?>
                            />
                        </div>
                    </div>
                    <hr>
                    <div class="form-group row">
                        <div class="col-sm-4">
                            <label for="ays_razorpay_amount">
                                <?php echo __('Amount',$this->plugin_name); ?>
                            </label>
                        </div>
                        <div class="col-sm-8">
                            <input type="text"
                                class="ays-text-input ays-text-input-short"
                                id="ays_razorpay_amount"
                                name="ays_razorpay_amount"
                                value="<?php echo $razorpay_amount; ?>"
                            />
                            <!-- <div class="ays_option_description">
                                <?php // echo __( "Specify the amount of the payment.", $this->plugin_name ); ?>
                                <ul style="list-style-position:inside;list-style-type:disc">
                                    <li><?php // echo __( "When selling a product for ₹ 1000 in the domestic market, you pass INR in the currency parameter and 100000 in the amount parameter (since the amount should be in paise).", $this->plugin_name ); ?></li>
                                    <li><?php // echo __( "When selling in the international market, you might want to charge $20 for the same product. In this case, you must pass USD in the currency parameter and 2000 in the amount parameter (since the amount should be in cents). For example: AED, AMD, INR and so on.", $this->plugin_name ); ?></li>
                                    <li><?php // echo __( "When selling in the international market with a three-decimal unit, you might want to charge 99.999 KD for the same product. In this case, you must pass KWD in the currency parameter and 99999 in the amount parameter.", $this->plugin_name ); ?></li>
                                </ul>
                            </div> -->
                        </div>
                    </div>
                    <hr>
                    <div class="form-group row">
                        <div class="col-sm-4">
                            <label for="ays_razorpay_currency">
                                <?php echo __('Currency',$this->plugin_name); ?>
                            </label>
                        </div>
                        <div class="col-sm-8">
                            <select name="ays_razorpay_currency" id="ays_razorpay_currency" class="ays-text-input ays-text-input-short">
                                <?php foreach ($razorpay_currencies as $key => $value): ?>
                                    <option value="<?= $key ?>" <?= $key == $razorpay_currency ? 'selected' : '' ?>><?= $value ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <hr>
                    <div class="form-group row">
                        <div class="col-sm-4">
                            <label for="ays_razorpay_currency">
                                <?php echo __('Payment details',$this->plugin_name); ?>
                            </label>
                        </div>
                        <div class="col-sm-8">
                            <?php $editor_id = "ays_razorpay_message";
                                $settings = array(
                                    "textarea_name" => "ays_razorpay_message",
                                    "editor_class" => "ays-textarea",
                                    "media_elements" => false
                                );
                                wp_editor($razorpay_message, $editor_id, $settings);
                            ?>
                        </div>
                    </div>
                                
                    <?php
                    $content = ob_get_clean();
                }
            } else {
                $content .= $this->blockquote_content;
            }

            $integrations['razorpay'] = array(
                'content' => $content,
                'icon' => $icon,
                'title' => $title,
            );

            return $integrations;
        }

        // Options get
        public function ays_quiz_page_razorpay_options( $args, $options ){

            $args['enable_razorpay'] = (isset($options['enable_razorpay']) && $options['enable_razorpay'] == 'on') ? true : false;
            $args['razorpay_amount'] = (isset($options['razorpay_amount'])) ? $options['razorpay_amount'] : '';
            $args['razorpay_currency'] = (isset($options['razorpay_currency'])) ? $options['razorpay_currency'] : '';
            $args['razorpay_message'] = (isset($options['razorpay_message'])) ? stripslashes( $options['razorpay_message'] ) : __('You need to pay to pass this quiz.', $this->plugin_name);

            return $args;
        }

        // Options save
        public function ays_quiz_page_razorpay_save( $options, $data ){

            $options['enable_razorpay'] = (isset($data['ays_enable_razorpay'])) && $data['ays_enable_razorpay'] == 'on' ? 'on' : 'off';
            $options['razorpay_amount'] = (isset($data['ays_razorpay_amount']) && intval($data['ays_razorpay_amount']) >= 1) ? $data['ays_razorpay_amount'] : '';
            $options['razorpay_currency'] = (isset($data['ays_razorpay_currency'])) ? $data['ays_razorpay_currency'] : '';
            $options['razorpay_message'] = (isset($data['ays_razorpay_message'])) ? $data['ays_razorpay_message'] : __('You need to pay to pass this quiz.', $this->plugin_name);
            
            return $options;
        }


    // General settings

        // Content
        public function ays_razorpay_settings_page_content( $integrations, $args ){

            $actions = Quiz_Maker_Razorpay_Data::ays_get_setting('razorpay');        
            $razorpay_res = ($actions === false) ? json_encode(array()) : $actions;
            $razorpay = json_decode($razorpay_res, true);

            $razorpay_key_id = isset($razorpay['key_id']) && $razorpay['key_id'] != "" ? esc_attr($razorpay['key_id']) : '';
            $razorpay_key_secret = isset($razorpay['key_secret']) && $razorpay['key_secret'] != "" ? esc_attr($razorpay['key_secret']) : '';
            $razorpay_payment_terms = isset($razorpay['payment_terms']) && $razorpay['payment_terms'] != "" ? esc_attr($razorpay['payment_terms']) : 'lifetime';

            $icon = QUIZ_MAKER_RAZORPAY_ADMIN_URL . '/images/integrations/razorpay-logo.png';
            $title = __( 'Razorpay', $this->plugin_name );

            $content = '';
            ob_start();
            ?>
                <div class="form-group row">
                    <div class="col-sm-12">
                        <div class="form-group row">
                            <div class="col-sm-3">
                                <label for="ays_razorpay_key_id">
                                    <?php echo __('Razorpay Key ID',$this->plugin_name); ?>
                                </label>
                            </div>
                            <div class="col-sm-9">
                                <input type="text" 
                                    class="ays-text-input" 
                                    id="ays_razorpay_key_id" 
                                    name="ays_razorpay_key_id"
                                    value="<?php echo $razorpay_key_id; ?>"
                                />
                            </div>
                        </div>
                        <hr/>
                        <div class="form-group row">
                            <div class="col-sm-3">
                                <label for="ays_razorpay_key_secret">
                                    <?php echo __('Razorpay Key Secret',$this->plugin_name); ?>
                                </label>
                            </div>
                            <div class="col-sm-9">
                                <input type="text" 
                                    class="ays-text-input" 
                                    id="ays_razorpay_key_secret" 
                                    name="ays_razorpay_key_secret"
                                    value="<?php echo $razorpay_key_secret; ?>"
                                />
                            </div>
                        </div>
                        <hr/>
                        <div class="form-group row">
                            <div class="col-sm-3">
                                <label>
                                    <?php echo __('Payment terms',$this->plugin_name); ?>
                                </label>
                            </div>
                            <div class="col-sm-9">
                                <label class="ays_quiz_loader" style="display:inline-block;">
                                    <input type="radio" name="ays_razorpay_payment_terms" class="ays_toggle_radio" data-flag="false" value="lifetime" <?php echo $razorpay_payment_terms == 'lifetime' ? 'checked' : ''; ?>/>
                                    <span><?php echo __('Lifetime payment',$this->plugin_name); ?></span>
                                </label>
                                <label class="ays_quiz_loader" style="display:inline-block">
                                    <input type="radio" name="ays_razorpay_payment_terms" class="ays_toggle_radio" data-flag="true" value="onetime" <?php echo $razorpay_payment_terms == 'onetime' ? 'checked' : ''; ?>/>
                                    <span><?php echo __('Onetime payment',$this->plugin_name); ?></span>
                                </label>
                                <a class="ays_help" style="font-size:15px;" data-toggle="tooltip" data-html="true" 
                                    title="<?php echo __('Choose your preferred method',$this->plugin_name).
                                        "<ul style='list-style-type: circle;padding-left: 20px;'>".
                                            "<li>".__('Lifetime  - By enabling this option, the user pays once at the beginning and gets access to the given quiz each time starting from that moment. It detects the user after the first attempt based on their WP user ID (designed for logged-in users).',$this->plugin_name). "</li>
                                            <li>".__('Onetime - By enabling this option, the user needs to pay each time separately for taking the quiz.',$this->plugin_name)."</li>
                                        </ul>";
                                    ?>">
                                    <i class="ays_fa ays_fa_info_circle"></i>
                                </a>
                            </div>
                        </div>
                        <blockquote>
                            <?php echo sprintf( __( "You can get your Razorpay Key ID and Razorpay Key Secret from your ", $this->plugin_name ) . "<a href='%s' target='_blank'> %s.</a>", "https://x.razorpay.com/settings/developer-controls", "Razorpay Account" ); ?>
                        </blockquote>
                    </div>
                </div>
            <?php
            $content = ob_get_clean();

            $integrations['razorpay'] = array(
                'content' => $content,
                'icon' => $icon,
                'title' => $title,
            );

            return $integrations;
        }

        // Options save
        public function ays_settings_page_razorpay_save( $fields, $data ){

            $razorpay_key_id = isset($data['ays_razorpay_key_id']) && $data['ays_razorpay_key_id'] != "" ? sanitize_text_field($data['ays_razorpay_key_id']) : '';
            $razorpay_key_secret = isset($data['ays_razorpay_key_secret']) && $data['ays_razorpay_key_secret'] != "" ? sanitize_text_field($data['ays_razorpay_key_secret']) : '';
            $razorpay_payment_terms = isset($data['ays_razorpay_payment_terms']) && $data['ays_razorpay_payment_terms'] != "" ? sanitize_text_field($data['ays_razorpay_payment_terms']) : '';

            $razorpay_options = array(
                "key_id"   => $razorpay_key_id,
                "key_secret"   => $razorpay_key_secret,
                "payment_terms"   => $razorpay_payment_terms
            );

            $fields['razorpay'] = json_encode($razorpay_options);
            return $fields;
        }
    
}
