(function($){
    'use strict';

    $(document).ready(function(){
        var containerWrap = $(document).find('.ays-quiz-container .ays_razorpay_wrap_div');
        containerWrap.each(function(){
            var quizID = $(this).parents('.ays-quiz-container').find('input[name="quiz_id"]').val();

            var quizMakerRazorpay = JSON.parse( window.atob( window.quizMakerRazorpay[ quizID ] ) );

            var wrap = $(document).find( quizMakerRazorpay.wrapClass );
            wrap.show();

			var options = quizMakerRazorpay.razorpayOptions;
			options['handler'] = function (response) {
                loading(true, wrap);
				handleCall(response, wrap, quizMakerRazorpay);
			};

            var rzp = new Razorpay(options);
			rzp.on('payment.failed', function (response) {
                loading(true, wrap);
				showError(response, wrap);
			});

			$(document).find(quizMakerRazorpay.buttonId).on('click', function (e) {
				rzp.open();
				e.preventDefault();
			})

        });

		function handleCall (response, wrap, options) {
            loading(false, wrap);
            wrap.find(".ays_quiz_razorpay_submit").prop( 'disabled', true );
            fetch( options.callbackUrl, {
                method: "post",
                headers: {
                    "Content-Type": "application/json"
                },
                body: JSON.stringify({
                    data: response,
                    options: options,
                }),
                credentials: "same-origin"
            }).then(
				response => response.json()
			).then(data => {
				Swal.fire({
                    title:"Your payment successfuly finished.",
                    type: "success",
                    showCancelButton: false,
                    allowOutsideClick: false,
                    allowEscapeKey: false,
                    allowEnterKey: false,
                    width: "450px",
                }).then((result) => {
                    var razorpayContainer = wrap.parents('.ays_razorpay_wrap_div');
                    if( razorpayContainer.attr('data-type') == 'postpay' ) {
                        var resId = razorpayContainer.attr("data-result");
                        $.ajax({
                            url: window.quiz_maker_ajax_public.ajax_url,
                            method: "post",
                            dataType: "json",
                            crossDomain: true,
                            data: {
                                action: "ays_store_result_payed",
                                res_id: resId
                            },
                            success: function (response) {

                            }
                        });
                        var data = razorpayContainer.parents(".ays-quiz-container").find("form").serializeFormJSON();
                        data.action = "ays_finish_quiz";
                        data.end_date = GetFullDateTime();
                        data.res_id = resId;
                        data["ays-paypal-paid"] = true;
                        data["ays-stripe-paid"] = true;

                        $.ajax({
                            url: window.quiz_maker_ajax_public.ajax_url,
                            method: "post",
                            dataType: "json",
                            crossDomain: true,
                            data: data,
                            success: function (response) {
                            }
                        });

                        razorpayContainer.hide(500);
                        razorpayContainer.parents(".step").find(".ays_paypal_wrap_div").hide(500);
                        razorpayContainer.parents(".step").find(".ays_stripe_wrap_div").hide(500);
                        razorpayContainer.parents(".step").find(".ays_quiz_results_page").html(window.aysResultsForQuiz);
                        razorpayContainer.parents(".step").find(".ays_quiz_results_page").css("display", "block");
                        razorpayContainer.parents(".step").find(".ays_quiz_results_page *").css("opacity", "1");
                        razorpayContainer.parents("form").find(".ays_quiz_results").slideDown(1000);
                        setTimeout(function () {
                            razorpayContainer.remove();
                        }, 1200);

                        var form = razorpayContainer.parents("form");
                        var resCont = razorpayContainer.parents(".step").find(".ays_quiz_results_page");
                        setTimeout(function () {
                            form.find("p.ays_score").addClass("tada");
                        }, 500);
                        var quizScore = form.find(".ays_score_percent").text();
                        quizScore = parseInt(quizScore);
                        var numberOfPercent = 0;
                        var percentAnimate = setInterval(function () {
                            form.find(".ays-progress-value").text(numberOfPercent + "%");
                            if (numberOfPercent == quizScore) {
                                clearInterval(percentAnimate);
                            }
                            numberOfPercent++;
                        }, 20);

                        var score = quizScore;
                        if (score > 0) {
                            form.find(".ays-progress-bar").css("padding-right", "7px");
                            var progressBarStyle = "first";
                            if (form.find(".ays-progress-bar").hasClass("second")) {
                                progressBarStyle = "second";
                            } else if (form.find(".ays-progress-bar").hasClass("third")) {
                                progressBarStyle = "third";
                            } else if (form.find(".ays-progress-bar").hasClass("fourth")) {
                                progressBarStyle = "fourth";
                            }
                            if (progressBarStyle == "first" || progressBarStyle == "second") {
                                form.find(".ays-progress-value").css("width", 0);
                                form.find(".ays-progress-value").css("transition", "width " + score * 25 + "ms linear");
                                setTimeout(function () {
                                    form.find(".ays-progress-value").css("width", score + "%");
                                }, 1);
                            }
                            form.find(".ays-progress-bar").css("transition", "width " + score * 25 + "ms linear");
                            setTimeout(function () {
                                form.find(".ays-progress-bar").css("width", score + "%");
                            }, 1);
                        }

                        form.find(".for_quiz_rate").rating({
                            onRate: function (res) {
                                $(this).rating("disable");
                                $(this).parent().find(".for_quiz_rate_reason").slideDown(500);
                                $(this).parents(".ays_quiz_rete").attr("data-rate_score", res);
                            }
                        });
                    }else{
                        location.reload();
                    }
                });
            }).catch(error => console.error(error));
		}

        function showError(errorMsgText, wrap) {
            loading(false, wrap);
            var errorMsg = wrap.find(".ays_quiz_razorpay_card_error");
            errorMsg.text( errorMsgText );
            setTimeout(function () {
                errorMsg.text( "" );
            }, 4000);
        };

        function loading(isLoading, wrap) {
            if (isLoading) {
                wrap.find(".ays_quiz_razorpay_submit").prop( 'disabled', true );
                wrap.find(".ays_quiz_razorpay_spinner").removeClass("ays_quiz_razorpay_hidden");
                wrap.find(".ays_quiz_razorpay_button_text").addClass("ays_quiz_razorpay_hidden");
            } else {
                wrap.find(".ays_quiz_razorpay_submit").prop( 'disabled', false );
                wrap.find(".ays_quiz_razorpay_spinner").addClass("ays_quiz_razorpay_hidden");
                wrap.find(".ays_quiz_razorpay_button_text").removeClass("ays_quiz_razorpay_hidden");
            }
        };
    });

})(jQuery);
