<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Summary_Emails
 * @subpackage Quiz_Maker_Summary_Emails/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Summary_Emails
 * @subpackage Quiz_Maker_Summary_Emails/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Summary_Emails_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	private $summary_emails_obj;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles( $hook_suffix ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Summary_Emails_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Summary_Emails_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if (false === strpos($hook_suffix, $this->plugin_name))
			return;

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-summary-emails-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts( $hook_suffix ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Summary_Emails_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Summary_Emails_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if (false === strpos($hook_suffix, $this->plugin_name))
		return;

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-summary-emails-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function add_plugin_admin_menu(){
    	
        $hook_quiz_maker_summary = add_submenu_page(
            PARENT_QUIZ_MAKER_NAME,
            __('Summary Emails', $this->plugin_name),
            __('Summary Emails', $this->plugin_name),
            'manage_options',
            PARENT_QUIZ_MAKER_NAME . "-summary-emails-admin",
            array($this, 'display_add_on_page')
		);
		add_action("load-$hook_quiz_maker_summary", array($this, 'screen_option_quiz_summary_emails'));
	}
	
	public function screen_option_quiz_summary_emails(){
        $option = 'per_page';
        $args = array(
            'label' => __('Quiz Summary', $this->plugin_name),
            'default' => 20,
            'option' => 'quiz_summary_per_page'
        );

		add_screen_option($option, $args);
		$this->summary_emails_obj = new Summary_Emails_List_Table($this->plugin_name);
    }

    public function display_add_on_page(){  
		$action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
            case 'add':
                include_once('partials/actions/quiz-maker-summary-emails-admin-actions.php');
                break;
            case 'edit':
                include_once('partials/actions/quiz-maker-summary-emails-admin-actions.php');
                break;
            default:
			include_once('partials/quiz-maker-summary-emails-admin-display.php');
        }  	
    }

	public function get_quiz_titles(){
		global $wpdb;
		
		$quiz_table = $wpdb->prefix . 'aysquiz_quizes';
		
		$sql = "SELECT id,title FROM {$quiz_table}";
		$result = $wpdb->get_results($sql,'ARRAY_A');
		return $result;
	}
	
	public function get_quiz_id(){
		global $wpdb;
		
		$quiz_table = $wpdb->prefix . 'aysquiz_quizes';
		
		$sql = "SELECT id FROM {$quiz_table}";
		$results = $wpdb->get_results($sql,'ARRAY_A');
		
		return $results;
	}

	public function get_users_emails($id){
		global $wpdb;

		$reports_teble = $wpdb->prefix.'aysquiz_reports';

		$summary_data = $this->get_summary_emails_by_id($id);

		switch ($summary_data['summary_type']) {
			case 'individual':
				$sql = "SELECT `user_email` FROM {$reports_teble} WHERE quiz_id=".$summary_data['summary_quiz_id'];
				$results = $wpdb->get_col($sql);
			break;
			case 'general':
			default:
				$sql = "SELECT `user_email` FROM {$reports_teble}";
				$results = $wpdb->get_col($sql);
			break;
		}
		
		return $results;
	}

	public function get_summary_emails_by_id($id){
		global $wpdb;

		$quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
		
		$sql = "SELECT * FROM {$quiz_summary_emails_table} WHERE `status`='on' AND id=".$id;
		$results = $wpdb->get_results($sql,'ARRAY_A');

		$summary_data = array();
		foreach($results as $key => $result){
			$summary_type     = (isset($result['type']) && $result['type'] != '') ? $result['type'] : 'general';
			$summary_schedule = (isset($result['sending_time']) && $result['sending_time'] != '') ? $result['sending_time'] : '';
			$summary_emails = (isset($result['emails']) && $result['emails'] != '') ? $result['emails'] : '';
			$summary_quiz_id  = (isset($result['quiz_id']) && $result['quiz_id'] != '') ? intval($result['quiz_id']) : null;	

			$options = (isset($result['options']) && !empty($result['options'])) ? json_decode($result['options'],true) : array();

			$options['summary_emails_email_to_users'] = (isset($options['summary_emails_email_to_users']) && $options['summary_emails_email_to_users'] == 'on' ) ? $options['summary_emails_email_to_users'] : 'off';
			$summary_emails_report_to_users = (isset($options['summary_emails_email_to_users']) && $options['summary_emails_email_to_users'] == 'on' ) ? true : false;
			
			$summary_data = array(
				'summary_type'      		=> $summary_type,
				'summary_schedule'  		=> $summary_schedule,
				'summary_emails'    		=> $summary_emails,
				'summary_quiz_id' 			=> $summary_quiz_id,
				'summary_report_to_users' 	=> $summary_emails_report_to_users,
			);
		}
		return $summary_data;
	}

	public function get_quiz_schedule($id){
		$summary_data = $this->get_summary_emails_by_id($id);
		
		$summary_schedule = (isset($summary_data['summary_schedule']) && $summary_data['summary_schedule'] != '') ? $summary_data['summary_schedule'] : 'hourly'; 
		
		$date_between = '';
		$date_last = '';
		$date_start = '';
		$date_end = '';
		$time_text = '';
		$date_time_name = '';

		switch($summary_schedule){
			case 'hourly':
				$date_start   	.= 'DATE_ADD(NOW(), INTERVAL -1 HOUR)';
				$date_end     	.= 'NOW()';
				$date_between	.= 'end_date BETWEEN DATE_ADD(NOW(), INTERVAL -1 HOUR) AND NOW() AND';
				$date_last	  	.= 'end_date BETWEEN DATE_ADD(NOW(),INTERVAL -2 HOUR) AND DATE_ADD(NOW(),INTERVAL -1 HOUR) AND';
				$time_text    	.= 'hourly';
				$date_time_name .= 'hour';
				break;
			case 'daily':
				$date_start   	.= 'DATE_ADD(NOW(), INTERVAL -1 DAY)';
				$date_end     	.= 'NOW()';
				$date_between 	.= 'end_date BETWEEN DATE_ADD(NOW(), INTERVAL -1 DAY) AND NOW() AND';
				$date_last	  	.= 'end_date BETWEEN DATE_SUB(NOW(),INTERVAL -2 DAY) AND DATE_SUB(NOW(),INTERVAL -1 DAY) AND';
				$time_text    	.= 'daily';
				$date_time_name .= 'day';
				break;
			case 'weekly':
				$date_start   	.= 'DATE_ADD(NOW(), INTERVAL -7 DAY)';
				$date_end     	.= 'NOW()';
				$date_between 	.= 'end_date BETWEEN DATE_ADD(NOW(), INTERVAL -7 DAY) AND NOW() AND';
				$date_last 	  	.= 'end_date BETWEEN DATE_ADD(NOW(),INTERVAL -14 DAY) AND DATE_ADD(NOW(),INTERVAL -7 DAY) AND';
				$time_text    	.= 'weekly';
				$date_time_name .= 'week';
				break;
			case 'monthly':
				$date_start   	.= 'DATE_ADD(NOW(), INTERVAL -30 DAY)';
				$date_end     	.= 'NOW()';
				$date_between 	.= 'end_date BETWEEN DATE_ADD(NOW(), INTERVAL -30 DAY) AND NOW() AND';
				$date_last	  	.= 'end_date BETWEEN DATE_ADD(NOW(),INTERVAL -60 DAY) AND DATE_ADD(NOW(),INTERVAL -30 DAY) AND';
				$time_text    	.= 'monthly';
				$date_time_name .= 'month';
				break;
			default:
				$date_start   	.= 'DATE_ADD(NOW(), INTERVAL -1 HOUR)';
				$date_end     	.= 'NOW()';
				break;
		}

		$summary_data_schedule = array(
			'date_start'    => $date_start,
			'date_end'      => $date_end,
			'date_between'  => $date_between,
			'date_last' 	=> $date_last,
			'time_text' 	=> $time_text,
			'date_time_name'=> $date_time_name,
		);

		return $summary_data_schedule;
	}

	public function get_quiz_summary_individual($id){
		global $wpdb;
		
		$quiz_table = $wpdb->prefix . 'aysquiz_quizes';
		

		$ays_quiz_report_table = $wpdb->prefix . 'aysquiz_reports';
		
		$summary_data = $this->get_summary_emails_by_id($id);
		$summary_data_scedule = $this->get_quiz_schedule($id);
		
		$summary_quiz_id = (isset($summary_data['summary_quiz_id']) && $summary_data['summary_quiz_id'] != '') ? intval($summary_data['summary_quiz_id']) : null; 
		if($summary_quiz_id == null)
			return;

		$date_between = (isset($summary_data_scedule['date_between']) && $summary_data_scedule['date_between'] != '') ? $summary_data_scedule['date_between'] : '';
		$date_last    = (isset($summary_data_scedule['date_last']) && $summary_data_scedule['date_last'] != '') ? $summary_data_scedule['date_last'] : '';

		$sql = "SELECT COUNT(quiz_id) AS quiz_count FROM {$ays_quiz_report_table} WHERE {$date_between} quiz_id = {$summary_quiz_id}";
		$results = $wpdb->get_results($sql,'ARRAY_A');
		
		$last_count =  "SELECT COUNT(id) AS quiz_last_count FROM  {$ays_quiz_report_table} WHERE {$date_last} quiz_id = {$summary_quiz_id}";
		$last_count_results = $wpdb->get_results($last_count,'ARRAY_A');
		
		$present_count = '';
		foreach($results as $key => $count){
			$summary_quiz_count = (isset($count['quiz_count']) && $count['quiz_count'] != '') ? intval($count['quiz_count']) : 0;
			$present_count = (isset($summary_quiz_count) && $summary_quiz_count != '') ? intval($summary_quiz_count ): 0;
		}
		
		$past_count = ''; 
		foreach($last_count_results as $key => $last_count_result){
			$summary_quiz_last_count = (isset($last_count_result['quiz_last_count']) && !empty($last_count_result['quiz_last_count']) ) ? intval($last_count_result['quiz_last_count']) : 0;
			$past_count = $summary_quiz_last_count;
		}

		$decrease_individual = 0;

		if($past_count == 0){
			$decrease_individual = 0;
			$difference_individual = 0;
			if($present_count != 0){	
				$decrease_individual = 100;
				$difference_individual = $present_count;
			}
		}else{
            if($present_count - $past_count == 0){
                $decrease_individual = 0;
                $difference_individual = 0;
            }else{
                $decrease_individual = round( ( ( $present_count - $past_count ) / $past_count ) * 100, 2 );
                $difference_individual = $present_count - $past_count;
            }
		}

		$total_count_sql = "SELECT COUNT(id) FROM {$ays_quiz_report_table} WHERE quiz_id=".$summary_quiz_id;
		$total_result = $wpdb->get_var($total_count_sql);

		$total_count_individual = (isset($total_result) && $total_result != '') ? intval($total_result) : 0;

		$title_sql = "SELECT title FROM {$quiz_table} WHERE id=".$summary_quiz_id;
		$title = $wpdb->get_var($title_sql);

		$decrease_difference_total_individual = array(
			'decrease_individual' => $decrease_individual,
			'difference_individual'=> $difference_individual,
			'total_count_individual'=> $total_count_individual,
			'present_count_individual'=> $present_count,
			'title_individual'=> $title,
		);

		return $decrease_difference_total_individual;
	}

	public function get_quiz_summary_general($id){
		global $wpdb;
		
		$ays_quiz_report_table = $wpdb->prefix . 'aysquiz_reports';
		
		$quiz_ids = $this->get_quiz_id();
		$summary_data_scedule = $this->get_quiz_schedule($id);
		$quizes = $this->get_quiz_titles();

		$date_between = (isset($summary_data_scedule['date_between']) && $summary_data_scedule['date_between'] != '') ? $summary_data_scedule['date_between'] : '';
		$date_last    = (isset($summary_data_scedule['date_last']) && $summary_data_scedule['date_last'] != '') ? $summary_data_scedule['date_last'] : '';
		
		$quiz_id = array();
		foreach($quiz_ids as $key => $value ){
			$quiz_id[] = (isset($value['id']) && $value['id'] != '') ? intval($value['id']) : 0;
		}

		$id = implode(',',array_map('intval',$quiz_id));

		$general_present_count = "SELECT quiz_id,COUNT(id) AS count_present FROM ".$ays_quiz_report_table." WHERE ".$date_between." quiz_id IN (".$id.") GROUP BY quiz_id";

		$general_present_results = $wpdb->get_results($general_present_count,"ARRAY_A");
		
		$general_past_count = "SELECT quiz_id,COUNT(id) AS count_past FROM ".$ays_quiz_report_table." WHERE {$date_last} quiz_id IN (".$id.") GROUP BY quiz_id";
		$general_past_results = $wpdb->get_results($general_past_count,"ARRAY_A");

		if(empty($general_past_results)){
			$general_past_results == array();
		}

		if(empty($general_present_results)){
			$general_present_results = array();
		}

		$per_quiz_result_present = array();
		foreach($general_present_results as $key => $value){
			$per_quiz_result_present[$value['quiz_id']] = intval($value['count_present']);
		}
		$per_quiz_result_past = array();
		foreach($general_past_results as $key => $value){
			$per_quiz_result_past[$value['quiz_id']] = intval($value['count_past']);
		}

		$total_count_sql = "SELECT quiz_id,COUNT(id) FROM ".$ays_quiz_report_table." WHERE quiz_id IN (".$id.") GROUP BY quiz_id";
		$total_results = $wpdb->get_results($total_count_sql,'ARRAY_A');

		$total_result_per_quiz = '';
		if(empty($total_results)){
			$total_results = array();
		}
		$all_summary = array();
		foreach($quizes as $key => $quiz){
			$quiz_id = (isset($quiz['id']) && $quiz['id'] != '') ? intval($quiz['id']) : '';
			$ays_summary = array();
			$per_quiz_id = array();
			$ays_summary['title'] = $quiz['title'];	
			foreach($total_results as $key => $total_result){
				$total_quiz_id = (isset($total_result['quiz_id']) && $total_result['quiz_id'] != '') ? intval($total_result['quiz_id']) : '';
				$total_quiz_quiz_count = (isset($total_result['COUNT(id)']) && $total_result['COUNT(id)'] != '') ? intval($total_result['COUNT(id)']) : '';
				$per_quiz_id[$total_quiz_id] = $total_quiz_quiz_count;
			}
			$ays_summary['total_count'] = $per_quiz_id[$quiz_id];

			$present_count = isset( $per_quiz_result_present[ $quiz['id'] ] ) ? $per_quiz_result_present[ $quiz['id'] ] : 0;
			$past_count = isset( $per_quiz_result_past[ $quiz['id'] ] ) ? $per_quiz_result_past[ $quiz['id'] ] : 0;
			
			if($past_count == 0){
				$decrease_general = 0;
				$difference_general = 0;
				if($present_count != 0){	
					$decrease_general = 100;
					$difference_general = $present_count;
				}
			}else{
				if($present_count - $past_count == 0){
					$decrease_general= 0;
					$difference_general = 0;
				}else{
					$decrease_general= round( ( ( $present_count - $past_count ) / $past_count ) * 100, 2 );
					$difference_general = $past_count - $past_count;
				}
			}
			$ays_summary['decrease'] = $decrease_general;
			$ays_summary['difference'] = $difference_general;
			$ays_summary['present_count'] = $present_count;
			$all_summary[] = $ays_summary;
		}
		
		return $all_summary;
	}

	public function total_summary($id){
		global $wpdb;
		
		$ays_quiz_report_table = $wpdb->prefix . 'aysquiz_reports';
		
		$quiz_ids = $this->get_quiz_id();
		$summary_data_scedule = $this->get_quiz_schedule($id);
		
		$date_between = (isset($summary_data_scedule['date_between']) && $summary_data_scedule['date_between'] != '') ? $summary_data_scedule['date_between'] : '';
		$date_last    = (isset($summary_data_scedule['date_last']) && $summary_data_scedule['date_last'] != '') ? $summary_data_scedule['date_last'] : '';

		$quiz_id = array();
		
		foreach($quiz_ids as $key => $value ){
			$quiz_id[] = (isset($value['id']) && $value['id'] != '') ? intval($value['id']) : 0;
		}

		$id = implode(',',array_map('intval',$quiz_id));

		$total_count_sql_present = "SELECT COUNT(id) FROM ".$ays_quiz_report_table." WHERE ".$date_between." quiz_id IN (".$id.")";
		$total_result_present = $wpdb->get_var($total_count_sql_present);
		
		$total_count_sql_past = "SELECT COUNT(id) FROM ".$ays_quiz_report_table." WHERE ".$date_last." quiz_id IN (".$id.")";
		$total_result_past = $wpdb->get_var($total_count_sql_past);
		
		$total_count_present = (isset($total_result_present) && $total_result_present != '') ? intval($total_result_present) : 0;
		$total_count_past = (isset($total_result_past) && $total_result_past != '') ? intval($total_result_past) : 0;

		$decrease_total = 0;

		if($total_count_past == 0){
			$decrease_total = 0;
			$difference_total = 0;
			if($total_count_present != 0){	
				$decrease_total = 100;
				$difference_total = $total_count_present;
			}
		}else{
            if($total_count_present - $total_count_past == 0){
                $decrease_total = 0;
                $difference_total = 0;
            }else{
                $decrease_total = round( ( ( $total_count_present - $total_count_past ) / $total_count_past ) * 100, 2 );
                $difference_total = $total_count_present - $total_count_past;
            }
		}
		
		$total_count_sql = "SELECT COUNT(id) FROM ".$ays_quiz_report_table." WHERE quiz_id IN (".$id.")";
		$total_result = $wpdb->get_var($total_count_sql);

		$total_count = (isset($total_result) && $total_result != '') ? intval($total_result) : 0;

		$total_summary = array(
			'total_decrease' => $decrease_total,
			'total_difference' => $difference_total,
			'total_present_count' => $total_count_present,
			'total_count' => $total_count,
		);

		return $total_summary;
	}
	
	public function get_scedule_days($id){
		global $wpdb;

		$summary_scedule = $this->get_quiz_schedule($id);
		$date_start = $summary_scedule['date_start'];
		$date_end   = $summary_scedule['date_end'];
		$ays_quiz_report_table = $wpdb->prefix . 'aysquiz_reports';
		
		$sql = "SELECT ".$date_start." AS past_time,".$date_end." AS present_time FROM ".$ays_quiz_report_table;
		$result = $wpdb->get_row($sql,'ARRAY_A');

		$summary_past_time 	  = (isset($result['past_time']) && $result['past_time'] != '') ? strtotime($result['past_time']) : '';
		$summary_present_time = (isset($result['present_time']) && $result['present_time'] != '') ? strtotime($result['present_time']) : '';
		
		$present_time = '';
		$past_time = '';
		if($summary_past_time == '' || $summary_present_time == ''){
			$present_time = '';
			$past_time = '';
		}else{
			$present_time  = date("F d,Y h:i:sa",$summary_present_time);
			$past_time  = date("F d,Y h:i:sa",$summary_past_time);
		}
		
		$summary_time = array(
			'present_time' => $present_time,
			'past_time' => $past_time,
		);

		return $summary_time;
	}

	public function get_sending_time_cron($schedules){
	
		if( !isset( $schedules['minutly'] ) ){
			$schedules['minutly'] = array(
				'interval' => 60,
				'display' => 'minutly'
			);
		}
		if( !isset( $schedules['weekly'] ) ){
			$schedules['weekly'] = array(
				'interval' => 60 * 60 * 24 * 7,
				'display' => 'weekly'
			);
		}
		if( !isset( $schedules['monthly'] ) ){
			$schedules['monthly'] = array(
				'interval' => 2629800,
				'display' => 'monthly'
			);
		}

		return $schedules;
	}
	
	public function get_content_data($id){

		$summary_data  = $this->get_summary_emails_by_id($id);
		$quizes_summary_individual = $this->get_quiz_summary_individual($id);
		$quizes_summary_schedule = $this->get_scedule_days($id);
		$quizes_summary_schedule_text = $this->get_quiz_schedule($id);
		$quizes_summary_total = $this->total_summary($id);
		$quizes_summary_general = $this->get_quiz_summary_general($id);

		$content = '';

		$summary_type = (isset($summary_data['summary_type']) && $summary_data['summary_type'] != '')? $summary_data['summary_type'] : 'general';
		
		//total summary
		$total_count = (isset($quizes_summary_total['total_count']) && $quizes_summary_total['total_count'] != '') ? intval($quizes_summary_total['total_count']) : 0;
		$total_present_count = (isset($quizes_summary_total['total_present_count']) && $quizes_summary_total['total_present_count'] != '') ? intval($quizes_summary_total['total_present_count']) : 0;
		$total_decrease = (isset($quizes_summary_total['total_decrease']) && $quizes_summary_total['total_decrease'] != '') ? intval($quizes_summary_total['total_decrease']) : 0;
		$total_difference = (isset($quizes_summary_total['total_difference']) && $quizes_summary_total['total_difference'] != '') ? intval($quizes_summary_total['total_difference']) : 0;

		//shcedule time
		$present_time = (isset($quizes_summary_schedule['present_time']) && $quizes_summary_schedule['present_time']) ? $quizes_summary_schedule['present_time'] : '';
		$past_time = (isset($quizes_summary_schedule['past_time']) && $quizes_summary_schedule['past_time']) ? $quizes_summary_schedule['past_time'] : '';
		$time_text = (isset($quizes_summary_schedule_text['time_text']) && $quizes_summary_schedule_text['time_text']) ? $quizes_summary_schedule_text['time_text'] : '';
		$date_time_name = (isset($quizes_summary_schedule_text['date_time_name']) && $quizes_summary_schedule_text['date_time_name']) ? $quizes_summary_schedule_text['date_time_name'] : '';

		$content .= '<table style="border-collapse: collapse;width: 100%;">';
				$content .= '<thead>';
					$content .=	'<tr>';
						$content .=	'<th colspan="4" style="text-transform:capitalize;text-align:center;">
										<h2>Your '.$time_text.' results of Quiz Maker</h2>';
						$content .=	'</th>';
					$content .=	'</tr>';
					$content .=	'<tr>';
						$content .=	'<th colspan="4" style="text-transform:capitalize;text-align:center;">
										<p>'.$past_time.' - '.$present_time.'</p>';
						$content .='</th>';
					$content .='</tr>';
					$content .=	'<tr>';
						$content .=	'<th colspan="4" style="text-align:center;">
									<p>Please find your '.$time_text.' results summary, as well as the percentage change compared your last '.$date_time_name.' performence below: </p>';
						$content .=	'</th>';
					$content .=	'</tr>';
					$content .= '<tr style="border: 1px solid #ddd;padding: 8px;">';
						$content .= '<th style="border: 1px solid #ddd;padding:12px;background-color: #2480B9;color: white;">Quiz Title</th>';
						$content .= '<th style="border: 1px solid #ddd;padding:12px;background-color: #2480B9;color: white;">Results count in the given period</th>';
						$content .= '<th style="border: 1px solid #ddd;padding:12px;background-color: #2480B9;color: white;">Results Growth</th>';
						$content .= '<th style="border: 1px solid #ddd;padding:12px;background-color: #2480B9;color: white;">Total results count </th>';
					$content .= '</tr>';
				$content .= '</thead>';
		
			if($summary_type == 'individual'){

				//individual summary
				$title_ind = (isset($quizes_summary_individual['title_individual']) && $quizes_summary_individual['title_individual'] != '') ? $quizes_summary_individual['title_individual'] : '';
				$decrease_ind = (isset($quizes_summary_individual['decrease_individual']) && $quizes_summary_individual['decrease_individual'] != '') ? intval($quizes_summary_individual['decrease_individual']) : 0;
				$difference_ind = (isset($quizes_summary_individual['difference_individual']) && $quizes_summary_individual['difference_individual']) ? intval($quizes_summary_individual['difference_individual']) : 0;
				$total_count_ind = (isset($quizes_summary_individual['total_count_individual']) && $quizes_summary_individual['total_count_individual']) ? $quizes_summary_individual['total_count_individual'] : '';
				$present_count_ind = (isset($quizes_summary_individual['present_count_individual']) && $quizes_summary_individual['present_count_individual']) ? $quizes_summary_individual['present_count_individual'] : 0;
				
				$decrease = '';

				if( $decrease_ind > 0 ){
					$decrease .= "<span style='color:green;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/up_green_arrow.png'> +" . $decrease_ind . "% ( +" . $difference_ind . " )</span>";
				}elseif( $decrease_ind < 0 ){
					$decrease .= "<span style='color:red;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/down_red_arrow.png'> " . $decrease_ind . "% ( " . $difference_ind . " )</span>";
				}else{
					$decrease .= "<span style='color:blue;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/equal.png'> " . $decrease_ind . "% ( " . $difference_ind . " )</span>";
				}

				$content .= '<tbody>';
					$content .= '<tr style="border: 1px solid #ddd;padding: 8px;">';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$title_ind.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$present_count_ind.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$decrease.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$total_count_ind.'</td>';
					$content .= '</tr>';
				$content .= '</tbody>';
			}

			if($summary_type == 'general'){
				
				$content .= '<tbody>';
				
				foreach($quizes_summary_general as $key => $quiz_summary_general){
					//general summary
					$title = (isset($quiz_summary_general['title']) && $quiz_summary_general['title'] != '') ? $quiz_summary_general['title'] : '';
					
					$decrease_general = (isset($quiz_summary_general['decrease']) && $quiz_summary_general['decrease'] != '') ? $quiz_summary_general['decrease'] : 0;
					
					$difference_general = (isset($quiz_summary_general['difference']) && $quiz_summary_general['difference']) ? $quiz_summary_general['difference'] : 0;
					
					$present_count_general = (isset($quiz_summary_general['present_count']) && $quiz_summary_general['present_count']) ? $quiz_summary_general['present_count'] : 0;
					
					$per_quiz_total = (isset($quiz_summary_general['total_count']) && $quiz_summary_general['total_count']) ? $quiz_summary_general['total_count'] : 0;

					$decrease_gen = '';
					if( $decrease_general > 0 ){
						$decrease_gen .= "<span style='color:green;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/up_green_arrow.png'> +" . $decrease_general . "% ( +" . $difference_general . " )</span>";
					}elseif( $decrease_general < 0 ){
						$decrease_gen .= "<span style='color:red;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/down_red_arrow.png'> " . $decrease_general . "% ( " . $difference_general . " )</span>";
					}else{
						$decrease_gen .= "<span style='color:blue;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/equal.png'> " . $decrease_general . "% ( " . $difference_general . " )</span>";
					}

					$content .= '<tr style="border: 1px solid #ddd;padding: 8px;">';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$title.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$present_count_general.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$decrease_gen.'</td>';
						$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$per_quiz_total.'</td>';
					$content .= '</tr>';
				}
				
				$decrease_total = '';
				if( $total_decrease > 0 ){
					$decrease_total .= "<span style='color:green;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/up_green_arrow.png'> +" . $total_decrease . "% ( +" . $total_difference . " )</span>";
				}elseif( $total_decrease < 0 ){
					$decrease_total .= "<span style='color:red;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/down_red_arrow.png'> " . $total_decrease . "% ( " . $total_difference . " )</span>";
				}else{
					$decrease_total .= "<span style='color:blue;'> <img src='". QUIZ_MAKER_SUMMARY_EMAILS_ADMIN_URL ."/images/statistics/equal.png'> " . $total_decrease . "% ( " . $total_difference . " )</span>";
				}
				
				$content .= '<tr style="border: 1px solid #ddd;padding: 8px;">';
					$content .= '<td style="border: 1px solid #ddd;padding: 8px;">Total</td>';
					$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$total_present_count.'</td>';
					$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$decrease_total.'</td>';
					$content .= '<td style="border: 1px solid #ddd;padding: 8px;">'.$total_count.'</td>';
				$content .= '</tr>';
				$content .= '</tbody>';
			}
		$content .= '</table>';

		return $content;
	}
	
	public function quiz_summary_send_mail_to_admins($id){
		$summary_id = (isset($id) && $id != '') ? intval($id) : null; 

		if($summary_id == null)
			return;

		$content_data = $this->get_content_data($id);
		$summary_data = $this->get_summary_emails_by_id($id);
		$users_emails = $this->get_users_emails($id);

		$users_email = array_unique($users_emails);
		$imploded_emails = implode( ',', $users_email );
		
		$emails = (isset($summary_data['summary_emails']) && $summary_data['summary_emails'] != '') ? $summary_data['summary_emails'] : '';

		if($summary_data['summary_report_to_users']){
			$all_emails = $emails.','.$imploded_emails;
		}else {
			$all_emails = $emails;
		}

		if($all_emails == '')											
			return;

		$nsite_url_base = get_site_url();
		$nsite_url_replaced = str_replace( array( 'http://', 'https://' ), '', $nsite_url_base );
		$nsite_url = trim( $nsite_url_replaced, '/' );
		$nno_reply = "noreply@".$nsite_url;
		$nfrom = "From:<quiz_maker@".$nsite_url.">";
		$headers = $nfrom."\r\n";
		$headers .= "MIME-Version: 1.0\r\n";
		$headers .= "Content-Type: text/html; charset=UTF-8\r\n";
		$subject = 'Quiz Summary';
		$message = $content_data;
		$to = $emails;
		
		wp_mail($all_emails, $subject, $message, $headers);
	}
}