<?php
ob_start();
class Summary_Emails_List_Table extends WP_List_Table{
    private $plugin_name;
    private $title_length;

    /** Class constructor */
    public function __construct($plugin_name) {
        global $status, $page;
        $this->plugin_name = $plugin_name;
        $this->title_length = Quiz_Maker_Data::get_listtables_title_length('');
        parent::__construct( array(
            'singular' => __( 'Summary Email', $this->plugin_name ), //singular name of the listed records
            'plural'   => __( 'Summary Emails', $this->plugin_name ), //plural name of the listed records
            'ajax'     => false //does this table support ajax?
        ) );
        add_action( 'admin_notices', array( $this, 'quiz_summary_emails_notices' ) );

    }

    /**
     * Override of table nav to avoid breaking with bulk actions & according nonce field
     */
    public function display_tablenav( $which ) {
        ?>
        <div class="tablenav <?php echo esc_attr( $which ); ?>">
            
            <div class="alignleft actions">
                <?php  $this->bulk_actions( $which ); ?>
            </div>
            <?php
            $this->extra_tablenav( $which );
            $this->pagination( $which );
            ?>
            <br class="clear" />
        </div>
        <?php
    }

    /**
     * Disables the views for 'side' context as there's not enough free space in the UI
     * Only displays them on screen/browser refresh. Else we'd have to do this via an AJAX DB update.
     *
     * @see WP_List_Table::extra_tablenav()
     */
    
    protected function get_views() {
        $published_count = $this->published_quiz_summary_emails_count();
        $unpublished_count = $this->unpublished_quiz_summary_emails_count();
        $all_count = $this->all_record_count();
        $selected_all = "";
        $selected_on = "";
        $selected_off = "";
        if(isset($_GET['fstatus'])){
            switch($_GET['fstatus']){
                case "on":
                    $selected_on = " style='font-weight:bold;' ";
                    break;
                case "off":
                    $selected_off = " style='font-weight:bold;' ";
                    break;
                default:
                    $selected_all = " style='font-weight:bold;' ";
                    break;
            }
        }else{
            $selected_all = " style='font-weight:bold;' ";
        }
        $status_links = array(
            "all" => "<a ".$selected_all." href='?page=".esc_attr( $_REQUEST['page'] )."'>". __( 'All', $this->plugin_name )." (".$all_count.")</a>",
            "on" => "<a ".$selected_on." href='?page=".esc_attr( $_REQUEST['page'] )."&fstatus=on'>". __( 'On', $this->plugin_name )." (".$published_count.")</a>",
            "off"   => "<a ".$selected_off." href='?page=".esc_attr( $_REQUEST['page'] )."&fstatus=off'>". __( 'Off', $this->plugin_name )." (".$unpublished_count.")</a>"
        );
        return $status_links;
    }

    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_quiz_summary_emails( $per_page = 20, $page_number = 1, $search = '' ) {
        global $wpdb;
        
        $sql = "SELECT * FROM {$wpdb->prefix}aysquiz_summary_emails";
        
        $where = array();

        if( $search != '' ){
            $where[] = $search;
        }

        if( isset( $_REQUEST['fstatus'] ) ){
            $fstatus = $_REQUEST['fstatus'];
            if($fstatus !== null){
                $where[] = " `status` = '".$fstatus."' ";
            }
        }

        if( ! empty($where) ){
            $sql .= " WHERE " . implode( " AND ", $where );
        }
        
        if ( ! empty( $_REQUEST['orderby'] ) ) {
            $sql .= ' ORDER BY ' . esc_sql( $_REQUEST['orderby'] );
            $sql .= ! empty( $_REQUEST['order'] ) ? ' ' . esc_sql( $_REQUEST['order'] ) : ' "DESC"';
        }else{
            $sql .= ' ORDER BY "DESC"';
        }
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;

        $result = $wpdb->get_results( $sql, 'ARRAY_A' );

        return $result;
    }

    public static function get_quiz_summary_emails_by_id( $id ){
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}aysquiz_summary_emails WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, 'ARRAY_A');
        return $result;
    }
    
    public function add_or_edit_quiz_summary_emails($data){
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $ays_summary_emails_change_type = (isset($data['ays_summary_emails_change_type'])) ? $data['ays_summary_emails_change_type'] : '';

        if( isset($data["quiz-maker-summary-emails_action"]) && wp_verify_nonce( $data["quiz-maker-summary-emails_action"],'quiz-maker-summary-emails_action' ) ){
            $id     = ( $data["id"] != NULL ) ? absint( intval( $data["id"] ) ) : null;
            $max_id = $this->get_max_id();
            
            //status
            $summary_emails_status  = (isset($data['ays_quiz_summary_emails_status']) && $data['ays_quiz_summary_emails_status'] != '') ? sanitize_text_field( $data['ays_quiz_summary_emails_status'] ) : 'on';

            //title
            $summary_emails_title  = (isset($data['ays_quiz_summary_emails_title']) && $data['ays_quiz_summary_emails_title']!= '') ?sanitize_text_field( $data['ays_quiz_summary_emails_title'] ) : 'Quiz Summary Email';
            
            //type
            $summary_emails_type   = (isset($data['ays_quiz_summary_emails_type']) && $data['ays_quiz_summary_emails_type'] != '') ? sanitize_text_field( $data['ays_quiz_summary_emails_type'] ) : '';
            
            // summary quiz_id
            $summary_quiz_id = '';
            if($summary_emails_type == 'general'){
                $summary_quiz_id = 0;
            }elseif ($summary_emails_type == 'individual') {
                $summary_quiz_id  = (isset($data['ays_quiz_summary_emails_quiz_id']) && $data['ays_quiz_summary_emails_quiz_id'] != null) ? absint(intval( $data['ays_quiz_summary_emails_quiz_id'] )) : '';
            }else {
                $summary_quiz_id = 0;
            }

            // summary sending time
            $summary_sending_time  = (isset($data['ays_quiz_summary_emails_sending_time']) && $data['ays_quiz_summary_emails_sending_time'] != '') ? stripslashes(sanitize_text_field( $data['ays_quiz_summary_emails_sending_time'] )) : 'hourly';

            //summary emails 
            $summary_admins_emails = (isset($data['ays_quiz_summary_emails_email']) && $data['ays_quiz_summary_emails_email'] != '') ? sanitize_text_field(implode(',',$data['ays_quiz_summary_emails_email'])) : '';

            //summary emails to users
            $summary_emails_email_to_users = (isset($data['ays_quiz_summary_emails_email_to_users']) && sanitize_text_field($data['ays_quiz_summary_emails_email_to_users'] == 'on')) ? 'on' : 'off';

            $options = array(
                'quiz_summary_emails_version'    => QUIZ_MAKER_SUMMARY_EMAILS_VERSION, 
                'summary_emails_email_to_users'  => $summary_emails_email_to_users, 
            );

            if($id == 0) {
                $quiz_summary_emails_result = $wpdb->insert(
                    $quiz_summary_emails_table,
                    array(
                        'title'        => $summary_emails_title,
                        'type'         => $summary_emails_type,
                        'quiz_id'      => $summary_quiz_id,
                        'sending_time' => $summary_sending_time,
                        'emails'       => $summary_admins_emails,
                        'status'       => $summary_emails_status,
                        'options'      => json_encode($options),
                    ),
                    array(
                        '%s', // title
                        '%s', // type
                        '%d', // quiz_id
                        '%s', // sending_time
                        '%s', // emails
                        '%s', // status
                        '%s', // options
                    )
                );
                $message = 'created';
              
                $quiz_summary_emails_insert_id = $wpdb->insert_id;

                $schedule_id = array(
                    'id' => $quiz_summary_emails_insert_id,
                );

                if ( ! wp_next_scheduled( 'ays_quiz_summary_mail_to_admins_'.$quiz_summary_emails_insert_id, $schedule_id) ) {
                    wp_schedule_event( current_time( 'timestamp' ),  $summary_sending_time , 'ays_quiz_summary_mail_to_admins_'.$quiz_summary_emails_insert_id, $schedule_id );
                }
                
            }else{
                $quiz_summary_emails_result = $wpdb->update(
                    $quiz_summary_emails_table,
                    array(
                        'title'          => $summary_emails_title,
                        'type'           => $summary_emails_type,
                        'quiz_id'        => $summary_quiz_id,
                        'sending_time'   => $summary_sending_time,
                        'emails'         => $summary_admins_emails,
                        'status'         => $summary_emails_status,
                        'options'        => json_encode($options),
                    ),
                    array( 'id' => $id ),
                    array(
                        '%s', // title
                        '%s', // type
                        '%d', // quiz_id
                        '%s', // sending_time
                        '%s', // emails
                        '%s', // status
                        '%s', // options
                    ),
                    array( '%d' )
                );
                $message = 'updated';

                $schedule_id = array(
                    'id' => $id,
                );
                
                wp_clear_scheduled_hook( 'ays_quiz_summary_mail_to_admins_'.$id, $schedule_id );
             
                if ( ! wp_next_scheduled( 'ays_quiz_summary_mail_to_admins_'.$id, $schedule_id) ) {
                    wp_schedule_event( current_time( 'timestamp' ),  $summary_sending_time , 'ays_quiz_summary_mail_to_admins_'.$id, $schedule_id );
                } 
            }

            if( $quiz_summary_emails_result >= 0 ){
                if($ays_summary_emails_change_type != ''){
                    if($id == null){
                        $url = esc_url_raw( add_query_arg( array(
                            "action"    => "edit",
                            "quiz_summary_emails"  => $quiz_summary_emails_insert_id,
                            "status"    => $message
                        ) ) );
                    }else{
                        $url = esc_url_raw( remove_query_arg(false) ).'&status=' . $message;
                    }
                    wp_redirect( $url );
                }else{
                    $url = esc_url_raw( remove_query_arg( array('action', 'quiz_summary_emails') ) ) . '&status=' . $message;
                    wp_redirect( $url );
                }
            }
        }
    }

    private function get_max_id() {
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';

        $sql = "SELECT max(id) FROM {$quiz_summary_emails_table}";

        $result = $wpdb->get_var($sql);

        return $result;
    }

    /**
     * Delete a customer record.
     *
     * @param int $id customer ID
     */
    public static function delete_quiz_summary_emails( $id ) {
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $wpdb->delete(
            "{$quiz_summary_emails_table}",
            array( 'id' => $id ),
            array( '%d' )
        );

        $schedule_id = array(
            'id' => $id,
        );
        
        wp_clear_scheduled_hook( 'ays_quiz_summary_mail_to_admins_'.$id, $schedule_id );
    }

    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count() {
        global $wpdb;
        $filter = array();
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $sql = "SELECT COUNT(*) FROM {$quiz_summary_emails_table}";

        return $wpdb->get_var( $sql );
    }
    
    public static function all_record_count() {
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $sql = "SELECT COUNT(*) FROM {$quiz_summary_emails_table} ";

        return $wpdb->get_var( $sql );
    }

    public static function published_quiz_summary_emails_count() {
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $sql = "SELECT COUNT(*) FROM {$quiz_summary_emails_table} WHERE status='on'";

        return $wpdb->get_var( $sql );
    }
    
    public static function unpublished_quiz_summary_emails_count() {
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $sql = "SELECT COUNT(*) FROM {$quiz_summary_emails_table} WHERE status='off'";

        return $wpdb->get_var( $sql );
    }

    public function duplicate_quizes_summary_emails( $id ){
        global $wpdb;
        $quiz_summary_emails_table = $wpdb->prefix . 'aysquiz_summary_emails';
        $quiz_summary_emails = $this->get_quiz_summary_emails_by_id($id);
        
        
        $max_id = $this->get_max_id();
        $ordering = ( $max_id != NULL ) ? ( $max_id + 1 ) : 1;
        
        $options = json_decode($quiz_summary_emails['options'], true);
        
        $result = $wpdb->insert(
            $quiz_summary_emails_table,            
            array(
                'title'          => "Copy - ".$quiz_summary_emails['title'],
                'type'           => $quiz_summary_emails['type'],
                'quiz_id'        => $quiz_summary_emails['quiz_id'],
                'sending_time'   => $quiz_summary_emails['sending_time'],
                'emails'         => $quiz_summary_emails['emails'],
                'status'         => $quiz_summary_emails['status'],
                'options'        => json_encode($options),
            ),
            array(
                '%s', // title
                '%s', // type
                '%d', // quiz_id
                '%s', // sending_time
                '%s', // emails
                '%s', // emails
                '%s', // options
            )
        );

        $schedule_id = array(
            'id' => $ordering,
        );

        if ( ! wp_next_scheduled( 'ays_quiz_summary_mail_to_admins_'.$ordering, $schedule_id) ) {
            wp_schedule_event( current_time( 'timestamp' ),  $quiz_summary_emails['sending_time'] , 'ays_quiz_summary_mail_to_admins_'.$ordering, $schedule_id );
        }

        if( $result >= 0 ){
            $message = "duplicated";
            $url = esc_url_raw( remove_query_arg(array('action', 'quiz_summary_emails')  ) ) . '&status=' . $message;
            wp_redirect( $url );
        }
        
    }


    /** Text displayed when no customer data is available */
    public function no_items() {
        echo __( 'There are no summary yet.', $this->plugin_name );
    }


    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default( $item, $column_name ) {
        switch ( $column_name ) {
            case 'title':
            case 'type':
            case 'sending_time':
            case 'id':
                return $item[ $column_name ];
                break;
            default:
                return print_r( $item, true ); //Show the whole array for troubleshooting purposes
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb( $item ) {
        return sprintf(
            '<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['id']
        );
    }


    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_title( $item ) {

        $delete_nonce = wp_create_nonce( $this->plugin_name . '-delete-quiz-summary-emails' );
        $quiz_summary_emails_title = stripcslashes($item['title']);

        $q = esc_attr( $quiz_summary_emails_title );
        $quiz_summary_emails_title_length = intval( $this->title_length );

        $restitle = Quiz_Maker_Admin::ays_restriction_string( "word", $q, $quiz_summary_emails_title_length );
        
        $title = sprintf( '<a href="?page=%s&action=%s&quiz_summary_emails=%d" title="%s">%s</a>', esc_attr( $_REQUEST['page'] ), 'edit', absint( $item['id'] ), $q, $restitle);

        $actions = array();
        
        $actions['edit'] = sprintf( '<a href="?page=%s&action=%s&quiz_summary_emails=%d">'. __('Edit', $this->plugin_name) .'</a>', esc_attr( $_REQUEST['page'] ), 'edit', absint( $item['id'] ) );

        $actions['duplicate'] = sprintf( '<a href="?page=%s&action=%s&quiz_summary_emails=%d">'. __('Duplicate', $this->plugin_name) .'</a>', esc_attr( $_REQUEST['page'] ), 'duplicate', absint( $item['id'] ) );
        
        $actions['delete'] = sprintf( '<a class="ays_confirm_del" data-message="%s" href="?page=%s&action=%s&quiz_summary_emails=%s&_wpnonce=%s">'. __('Delete', $this->plugin_name) .'</a>', $restitle, esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['id'] ), $delete_nonce );
        
        return $title . $this->row_actions( $actions );
    }

    function scolumn_published( $item ) {
        switch( $item['on'] ) {
            case "on":
                return '<span class="ays-publish-status"><i class="ays_fa ays_fa_check_square_o" aria-hidden="true"></i> '. __('On',$this->plugin_name) . '</span>';
                break;
            case "off":
                return '<span class="ays-publish-status"><i class="ays_fa ays_fa_square_o" aria-hidden="true"></i> '. __('Off',$this->plugin_name) . '</span>';
                break;
        }
    }

    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns() {
        $columns = array(
            'cb'                => '<input type="checkbox" />',
            'title'             => __( 'Title', $this->plugin_name ),
            'type'              => __( 'Type', $this->plugin_name ),
            'sending_time'      => __( 'Session Period', $this->plugin_name ),
            'id'                => __( 'ID', $this->plugin_name ),
        );

        return $columns;
    }


    /**
     * Columns to make sortable.
     *
     * @return array
     */
    public function get_sortable_columns() {
        $sortable_columns = array(
            'title'         => array( 'title', true ),
            'type'          => array( 'type', true ),
            'sending_time'  => array( 'sending_time', true ),
            'id'            => array( 'id', true ),
        );

        return $sortable_columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions() {
        $actions = array(
            'bulk-delete' => __('Delete', $this->plugin_name)
        );

        return $actions;
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items() {

        $this->_column_headers = $this->get_column_info();

        /** Process bulk action */
        $this->process_bulk_action();

        $per_page     = $this->get_items_per_page( 'quiz_summary_emails_per_page', 20 );
        $current_page = $this->get_pagenum();
        $total_items  = self::record_count();

        $this->set_pagination_args( array(
            'total_items' => $total_items, //WE have to calculate the total number of items
            'per_page'    => $per_page, //WE have to determine how many items to show on a page
            'total_pages' => ceil( $total_items / $per_page )
        ) );

        $search = ( isset( $_REQUEST['s'] ) ) ? $_REQUEST['s'] : false;

        $do_search = ( $search ) ? sprintf(" title LIKE '%%%s%%' ", $search ) : '';

        $this->items = self::get_quiz_summary_emails( $per_page, $current_page, $do_search );
    }

    public function process_bulk_action() {
        //Detect when a bulk action is being triggered...
        $message = 'deleted';
        if ( 'delete' === $this->current_action() ) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr( $_REQUEST['_wpnonce'] );

            if ( ! wp_verify_nonce( $nonce, $this->plugin_name . '-delete-quiz-summary-emails' ) ) {
                die( 'Go get a life script kiddies' );
            }
            else {
                self::delete_quiz_summary_emails( absint( $_GET['quiz_summary_emails'] ) );

                $url = esc_url_raw( remove_query_arg(array('action', 'quiz_summary_emails', '_wpnonce')  ) ) . '&status=' . $message;
                wp_redirect( $url );
            }

        }

        // If the delete bulk action is triggered
        if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' )
            || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' )
        ) {

            $delete_ids = esc_sql( $_POST['bulk-delete'] );

            // loop over the array of record IDs and delete them
            foreach ( $delete_ids as $id ) {
                self::delete_quiz_summary_emails( $id );

            }

            $url = esc_url_raw( remove_query_arg(array('action', 'quiz_summary_emails', '_wpnonce')  ) ) . '&status=' . $message;
            wp_redirect( $url );
        }
    }

    public function quiz_summary_emails_notices(){
        $status = (isset($_REQUEST['status'])) ? sanitize_text_field( $_REQUEST['status'] ) : '';

        if ( empty( $status ) )
            return;

        if ( 'created' == $status )
            $updated_message = esc_html( __( 'Summary created.', $this->plugin_name ) );
        elseif ( 'updated' == $status )
            $updated_message = esc_html( __( 'Summary saved.', $this->plugin_name ) );
        elseif ( 'duplicated' == $status )
            $updated_message = esc_html( __( 'Summary duplicated.', $this->plugin_name ) );
        elseif ( 'deleted' == $status )
            $updated_message = esc_html( __( 'Summary deleted.', $this->plugin_name ) );

        if ( empty( $updated_message ) )
            return;

        ?>
        <div class="notice notice-success is-dismissible">
            <p> <?php echo $updated_message; ?> </p>
        </div>
        <?php
    }
}
