<?php

/**
 * Fired during plugin activation
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Trainings
 * @subpackage Quiz_Maker_Trainings/includes
 */

use Quiz_Maker\Cookie\Cookie;

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Quiz_Maker_Trainings
 * @subpackage Quiz_Maker_Trainings/includes
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Trainings_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		global $wpdb;

		if( ! class_exists( 'Cookie' ) ){
			include_once( QUIZ_MAKER_TRAININGS_DIR .  '/includes/class-cookie.php');
		}

		$correct_cookie = new Cookie( QUIZ_MAKER_TRAININGS_COOKIE_KEY_CORRECT );
		$wrong_cookie = new Cookie( QUIZ_MAKER_TRAININGS_COOKIE_KEY_WRONG );

		if( ! Cookie::exists( QUIZ_MAKER_TRAININGS_COOKIE_KEY_CORRECT ) ||
		    ! Cookie::exists( QUIZ_MAKER_TRAININGS_COOKIE_KEY_WRONG ) ) {

			$sql     = "SELECT id FROM {$wpdb->prefix}aysquiz_quizes";
			$quizzes = $wpdb->get_results( $sql, ARRAY_A );

			$cookie_arr = array();
			foreach ( $quizzes as $quiz_id ) {
				$cookie_arr[ $quiz_id['id'] ] = array();
			}

			if ( ! $wrong_cookie->getValue() ) {
				$cookie_value = base64_encode( json_encode( $cookie_arr ) );
				$wrong_cookie->setValue( $cookie_value );
				$wrong_cookie->setMaxAge(60 * 60 * 24 * 30);
				$wrong_cookie->save();
			}

			if ( ! $correct_cookie->getValue() ) {
				$cookie_value = base64_encode( json_encode( $cookie_arr ) );
				$correct_cookie->setValue( $cookie_value );
				$correct_cookie->setMaxAge(60 * 60 * 24 * 30);
				$correct_cookie->save();
			}
		}
	}
}
