<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_User_Dashboard
 * @subpackage Quiz_Maker_User_Dashboard/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_User_Dashboard
 * @subpackage Quiz_Maker_User_Dashboard/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_User_Dashboard_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_User_Dashboard_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_User_Dashboard_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-user-dashboard-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_User_Dashboard_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_User_Dashboard_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-user-dashboard-admin.js', array( 'jquery' ), $this->version, false );

	}

		// Shorocde quiz page action hook
		public function ays_qm_settings_page_advanced_user_dashboard($args){

			$shortcodes_contents = apply_filters( 'ays_qm_settings_page_advanced_user_dashboard_contents', array(), $args );
			$shortcodes = array();

			foreach ($shortcodes_contents as $key => $shortcodes_content) {
				$content = '<fieldset>';
				if(isset($shortcodes_content['title'])){
					$content .= '<legend>';
					if(isset($shortcodes_content['icon'])){
						$content .= '<strong style="font-size:30px;">'. $shortcodes_content['icon'] .'</strong>';
					}
					$content .= '<h5 style="margin: 0 4px;">'. $shortcodes_content['title'] .'</h5></legend>';
				}
				$content .= $shortcodes_content['content'];
				
				$content .= '</fieldset>';
				
				$shortcodes[] = $content;
			}
			
			echo implode('<hr/>', $shortcodes);
		}
		
		////////////////////////////////////////////////////////////////////////////////////////
		//====================================================================================//
		////////////////////////////////////////////////////////////////////////////////////////
	
	
		/*
		==========================================
			Advanced User Dashboard | Start
		==========================================
		*/

		public static function ays_get_setting( $meta_key ){
			global $wpdb;
	
			$settings_table  = esc_sql( $wpdb->prefix . "aysquiz_settings" );
	
			$sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
			$result = $wpdb->get_var($sql);
	
			if($result != ""){
				return $result;
			}
			return false;
		}
	
		public function ays_settings_page_advanced_user_dashboard($shortcodes){
			// General Settings Options
			$options = ($this->ays_get_setting('options') === false) ? array() : json_decode( stripcslashes( $this->ays_get_setting('options') ), true);

			// results by quiz
			if (PARENT_QUIZ_MAKER_VERSION === 'free') {
				$default_user_dashboard_results_by_quiz_columns = array(
					'user_name' 			=> 'user_name',
					'start_date' 			=> 'start_date',
					'end_date' 				=> 'end_date',
					'duration' 				=> 'duration',
					'score' 				=> 'score',
					'details' 				=> 'details',
				);

				$default_user_dashboard_results_by_quiz_column_names = array(
					"user_name" 			=> __( 'Username', $this->plugin_name ),
					"start_date" 			=> __( 'Start date', $this->plugin_name ),
					"end_date" 				=> __( 'End date', $this->plugin_name ),
					"duration" 				=> __( 'Duration', $this->plugin_name ),
					"score" 				=> __( 'Score', $this->plugin_name ),
					"details" 				=> __( 'Details', $this->plugin_name ),
				);

				// results
				$default_user_dashboard_results_columns = array(
					'user_name' 			=> 'user_name',
					'quiz_name' 			=> 'quiz_name',
					'start_date' 			=> 'start_date',
					'end_date' 				=> 'end_date',
					'duration' 				=> 'duration',
					'score' 				=> 'score',
				);
				
				$default_user_dashboard_results_column_names = array(
					"user_name" 			=> __( 'User name', $this->plugin_name ),
					"quiz_name" 			=> __( 'Quiz name', $this->plugin_name ),
					"start_date" 			=> __( 'Start date', $this->plugin_name ),
					"end_date" 				=> __( 'End date', $this->plugin_name ),
					"duration" 				=> __( 'Duration', $this->plugin_name ),
					"score" 				=> __( 'Score', $this->plugin_name ),
				);
			} else {
				$default_user_dashboard_results_by_quiz_columns = array(
					'user_name' 			=> 'user_name',
					'start_date' 			=> 'start_date',
					'end_date' 				=> 'end_date',
					'duration' 				=> 'duration',
					'score' 				=> 'score',
					'certificate'       	=> 'certificate',
					'details' 				=> 'details',
					'points' 				=> 'points',
				);

				$default_user_dashboard_results_by_quiz_column_names = array(
					"user_name" 			=> __( 'Username', $this->plugin_name ),
					"start_date" 			=> __( 'Start date', $this->plugin_name ),
					"end_date" 				=> __( 'End date', $this->plugin_name ),
					"duration" 				=> __( 'Duration', $this->plugin_name ),
					"score" 				=> __( 'Score', $this->plugin_name ),
					"certificate"           => __( 'Certificate', $this->plugin_name ),
					"details" 				=> __( 'Details', $this->plugin_name ),
					"points" 				=> __( 'Points', $this->plugin_name ),
				);

				// results
				$default_user_dashboard_results_columns = array(
					'user_name' 			=> 'user_name',
					'quiz_name' 			=> 'quiz_name',
					'start_date' 			=> 'start_date',
					'end_date' 				=> 'end_date',
					'duration' 				=> 'duration',
					'score' 				=> 'score',
					'status' 				=> 'status',
				);

				$default_user_dashboard_results_column_names = array(
					"user_name" 			=> __( 'User name', $this->plugin_name ),
					"quiz_name" 			=> __( 'Quiz name', $this->plugin_name ),
					"start_date" 			=> __( 'Start date', $this->plugin_name ),
					"end_date" 				=> __( 'End date', $this->plugin_name ),
					"duration" 				=> __( 'Duration', $this->plugin_name ),
					"score" 				=> __( 'Score', $this->plugin_name ),
					"status" 				=> __( 'Status', $this->plugin_name ),
				);
			}

			$options['user_dashboard_results_by_quiz_columns'] = ! isset( $options['user_dashboard_results_by_quiz_columns'] ) ? $default_user_dashboard_results_by_quiz_columns : $options['user_dashboard_results_by_quiz_columns'];
			$user_dashboard_results_by_quiz_columns = (isset( $options['user_dashboard_results_by_quiz_columns'] ) && !empty($options['user_dashboard_results_by_quiz_columns']) ) ? $options['user_dashboard_results_by_quiz_columns'] : array();
			$user_dashboard_results_by_quiz_columns_order = (isset( $options['user_dashboard_results_by_quiz_columns_order'] ) && !empty($options['user_dashboard_results_by_quiz_columns_order']) ) ? $options['user_dashboard_results_by_quiz_columns_order'] : $default_user_dashboard_results_by_quiz_columns;
	
			foreach( $default_user_dashboard_results_by_quiz_columns as $key => $value ){
				if( !isset( $user_dashboard_results_by_quiz_columns[$key] ) ){
					$user_dashboard_results_by_quiz_columns[$key] = '';
				}
	
				if( !isset( $user_dashboard_results_by_quiz_columns_order[$key] ) ){
					$user_dashboard_results_by_quiz_columns_order[$key] = $key;
				}
			}
	
			foreach( $user_dashboard_results_by_quiz_columns_order as $key => $value ){
				if( !isset( $user_dashboard_results_by_quiz_columns[$key] ) ){
					if( isset( $user_dashboard_results_by_quiz_columns[$value] ) ){
						$user_dashboard_results_by_quiz_columns_order[$value] = $value;
					}
					unset( $user_dashboard_results_by_quiz_columns_order[$key] );
				}
			}

			$options['user_dashboard_results_columns'] = ! isset( $options['user_dashboard_results_columns'] ) ? $default_user_dashboard_results_columns : $options['user_dashboard_results_columns'];
			$user_dashboard_results_columns = (isset( $options['user_dashboard_results_columns'] ) && !empty($options['user_dashboard_results_columns']) ) ? $options['user_dashboard_results_columns'] : array();
			$user_dashboard_results_columns_order = (isset( $options['user_dashboard_results_columns_order'] ) && !empty($options['user_dashboard_results_columns_order']) ) ? $options['user_dashboard_results_columns_order'] : $default_user_dashboard_results_columns;
	
			foreach( $default_user_dashboard_results_columns as $key => $value ){
				if( !isset( $user_dashboard_results_columns[$key] ) ){
					$user_dashboard_results_columns[$key] = '';
				}
	
				if( !isset( $user_dashboard_results_columns_order[$key] ) ){
					$user_dashboard_results_columns_order[$key] = $key;
				}
			}
	
			foreach( $user_dashboard_results_columns_order as $key => $value ){
				if( !isset( $user_dashboard_results_columns[$key] ) ){
					if( isset( $user_dashboard_results_columns[$value] ) ){
						$user_dashboard_results_columns_order[$value] = $value;
					}
					unset( $user_dashboard_results_columns_order[$key] );
				}
			}

			$icon  = '[ ]';
			$title = __( 'Advanced User Dashboard Settings', $this->plugin_name );
	
			$shortcode_str = esc_attr( '[ays_quiz_advanced_user_dashboard]' );
	
			$content = array();
	
			$content[] = '<div class="form-group row" style="padding:0px;margin:0;">';
				$content[] = '<div class="col-sm-12" style="padding:20px;">';
					$content[] = '<div class="form-group row">';
	
						$content[] = '<div class="col-sm-4">';
							$content[] = '<label for="ays_advanced_user_dashboard">';
								$content[] = __( "Shortcode", $this->plugin_name );
							$content[] = '</label>';
						$content[] = '</div>';
	
						$content[] = '<div class="col-sm-8">';
							$content[] = '<input type="text" id="ays_advanced_user_dashboard" class="ays-text-input" onclick="this.setSelectionRange(0, this.value.length)" readonly="" value="'. $shortcode_str .'">';
						$content[] = '</div>';

					$content[] = '</div>';

					$content[] = '<hr>';

					$content[] = '<div class="form-group row">';
           				$content[] = '<div class="col-sm-12">';

		        	        $content[] = '<label>';
		        	            $content[] = __( "Results section table columns", $this->plugin_name );
		        	            $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("You can sort table columns and select which columns must display in the Results section on the front-end.",$this->plugin_name) . ' "> ';
		        	                $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		        	            $content[] = '</a>';
		        	        $content[] = '</label>';

			    	        $content[] = '<div class="ays-show-user-page-table-wrap">';
			    	            $content[] = '<ul class="ays-show-user-page-table">';
			    	            	foreach ($user_dashboard_results_columns_order as $key => $val) :
			    	            		$checked = '';
			    	                    if(isset($user_dashboard_results_columns[$key]) && $user_dashboard_results_columns[$key] != ''){
			    	                        $checked = 'checked';
			    	                    }

			    	            		$content[] = '<li class="ays-user-page-option-row ui-state-default">';
			    	            			$content[] = '<input type="hidden" value="' . $key .'" name="ays_user_dashboard_results_columns_order[' . $key .']"/>';
			    	            			$content[] = '<input type="checkbox" id="ays_user_dashboard_results_columns_' . $key .'" value="' . $key .'" class="ays-checkbox-input" name="ays_user_dashboard_results_columns[' . $key .']" '. $checked .' />';
			    	            			$content[] = '<label for="ays_user_dashboard_results_columns_' . $key .'">';
			    	            				$content[] = $default_user_dashboard_results_column_names[$key];
			    	            			$content[] = '</label>';
			    	            		$content[] = '</li>';

			    	            	endforeach;
			    	            $content[] = '</ul>';
			    	        $content[] = '</div>';

		        	    $content[] = '</div>';
        			$content[] = '</div>';

					$content[] = '<hr>';

					$content[] = '<div class="form-group row">';
           				$content[] = '<div class="col-sm-12">';

		        	        $content[] = '<label>';
		        	            $content[] = __( "Results by Quiz section table columns", $this->plugin_name );
		        	            $content[] = '<a class="ays_help" data-toggle="tooltip" title="' . __("You can sort table columns and select which columns must display in the Results by Quiz section on the front-end.",$this->plugin_name) . ' "> ';
		        	                $content[] = '<i class="ays_fa ays_fa_info_circle"></i>';
		        	            $content[] = '</a>';
		        	        $content[] = '</label>';

			    	        $content[] = '<div class="ays-show-user-page-table-wrap">';
			    	            $content[] = '<ul class="ays-show-user-page-table">';
			    	            	foreach ($user_dashboard_results_by_quiz_columns_order as $key => $val) :
			    	            		$checked = '';
			    	                    if(isset($user_dashboard_results_by_quiz_columns[$key]) && $user_dashboard_results_by_quiz_columns[$key] != ''){
			    	                        $checked = 'checked';
			    	                    }

			    	            		$content[] = '<li class="ays-user-page-option-row ui-state-default">';
			    	            			$content[] = '<input type="hidden" value="' . $key .'" name="ays_user_dashboard_results_by_quiz_columns_order[' . $key .']"/>';
			    	            			$content[] = '<input type="checkbox" id="ays_user_dashboard_results_by_quiz_columns_' . $key .'" value="' . $key .'" class="ays-checkbox-input" name="ays_user_dashboard_results_by_quiz_columns[' . $key .']" '. $checked .' />';
			    	            			$content[] = '<label for="ays_user_dashboard_results_by_quiz_columns_' . $key .'">';
			    	            				$content[] = $default_user_dashboard_results_by_quiz_column_names[$key];
			    	            			$content[] = '</label>';
			    	            		$content[] = '</li>';

			    	            	endforeach;
			    	            $content[] = '</ul>';
			    	        $content[] = '</div>';

		        	    $content[] = '</div>';
        			$content[] = '</div>';

					$content[] = '<hr>';

					$content[] = '<blockquote>';
						$content[] = '<ul class="ays-quiz-general-settings-blockquote-ul">';

							$content[] = '<li>';
								$content[] = __( 'Copy the shortcode and insert it into any post. It will show all the activities of the user (Activity per Day, User Results, The Results by the quiz, Best Score, User Progress).', $this->plugin_name );
							$content[] = '</li>';

						$content[] = '</ul>';

	            	$content[] = '</blockquote>';
				$content[] = '</div>';
			$content[] = '</div>';
	
			$content = implode( '', $content );
	
			$shortcodes['advanced_user_dashboard'] = array(
				'content' => $content,
				'icon'    => $icon,
				'title'   => $title,
			);
			return $shortcodes;
		}

		public function ays_settings_page_user_dashboard_quiz_save( $fields, $data ){

			// General Settings Options
			$options = ($fields['options'] === false) ? array() : json_decode( stripcslashes( $fields['options'] ), true);

			// columns | Results by quiz section
			$options['user_dashboard_results_by_quiz_columns'] = (isset( $data['ays_user_dashboard_results_by_quiz_columns'] ) && !empty($data['ays_user_dashboard_results_by_quiz_columns'])) ? $data['ays_user_dashboard_results_by_quiz_columns'] : array();
			$options['user_dashboard_results_by_quiz_columns_order'] = (isset( $data['ays_user_dashboard_results_by_quiz_columns_order'] ) && !empty($data['ays_user_dashboard_results_by_quiz_columns_order'])) ? $data['ays_user_dashboard_results_by_quiz_columns_order'] : array();

			// columns | Results section
			$options['user_dashboard_results_columns'] = (isset( $data['ays_user_dashboard_results_columns'] ) && !empty($data['ays_user_dashboard_results_columns'])) ? $data['ays_user_dashboard_results_columns'] : array();
			$options['user_dashboard_results_columns_order'] = (isset( $data['ays_user_dashboard_results_columns_order'] ) && !empty($data['ays_user_dashboard_results_columns_order'])) ? $data['ays_user_dashboard_results_columns_order'] : array();

			$fields['options'] = json_encode( $options );
	
			return $fields;
		}
}
