<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Quiz_Maker_Woocommerce
 * @subpackage Quiz_Maker_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Quiz_Maker_Woocommerce
 * @subpackage Quiz_Maker_Woocommerce/admin
 * @author     Quiz Maker team <info@ays-pro.com>
 */
class Quiz_Maker_Woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */

	private $blockquote_content;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$settings_url = sprintf(
            __( "For enabling this option, please go to %s page and fill all options.", $this->plugin_name ),
            "<a style='color:blue;text-decoration:underline;font-size:20px;' href='?page=".$this->plugin_name."-settings&ays_quiz_tab=tab2' target='_blank'>". __( "this", $this->plugin_name ) ."</a>"
        );
        $blockquote_content = '<blockquote class="error_message">'. $settings_url .'</blockquote>';
        $this->blockquote_content = $blockquote_content;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style($this->plugin_name . '-sweetalert-css', plugin_dir_url( __FILE__ ) . 'css/quiz-maker-sweetalert2.min.css', array(), $this->version, 'all');
		wp_enqueue_style($this->plugin_name . '-select2', plugin_dir_url( __FILE__ ) .  'css/quiz-maker-select2.min.css', array(), $this->version, 'all');

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/quiz-maker-woocommerce-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Quiz_Maker_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Quiz_Maker_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script($this->plugin_name . '-sweetalert-js', plugin_dir_url( __FILE__ ) . 'js/quiz-maker-sweetalert2.all.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script( $this->plugin_name.'-select2js', plugin_dir_url( __FILE__ ) . 'js/quiz-maker-select2.min.js', array('jquery'), $this->version, true);

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/quiz-maker-woocommerce-admin.js', array( 'jquery' ), $this->version, true );
		wp_localize_script( $this->plugin_name, 'quiz_maker_woocommerce_ajax', array(
			'ajax_url' 			   => admin_url('admin-ajax.php'),

            'loadResource'          => __( "Can't load resource.", $this->plugin_name ),
            'somethingWentWrong'    => __( "Maybe something went wrong.", $this->plugin_name ),
		));

	}

	public static function ays_autoembed( $content ) {
        global $wp_embed;
        $content = stripslashes( wpautop( $content ) );
        $content = $wp_embed->autoembed( $content );
        if ( strpos( $content, '[embed]' ) !== false ) {
            $content = $wp_embed->run_shortcode( $content );
        }
        $content = do_shortcode( $content );
        return $content;
    }

	public static function ays_get_setting($meta_key){
        global $wpdb;
        $settings_table = $wpdb->prefix . "aysquiz_settings";

        if($wpdb->get_var("SHOW TABLES LIKE '$settings_table'") != $settings_table) {
            return false;
        }

        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
        $result = $wpdb->get_var($sql);
        if($result != ""){
            return $result;
        }
        return false;
    }

	public static function get_quiz_by_id( $id ){
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}aysquiz_quizes WHERE id=" . absint( sanitize_text_field( $id ) );

        $result = $wpdb->get_row($sql, 'ARRAY_A');

        return $result;
    }

    public static function ays_get_woocommerce_product( $prod_id ){
        $product_post_ids = array();

        if ( ! empty( $prod_id ) ) {
            $product_post_ids[] = get_post( absint($prod_id) );
        }

        return $product_post_ids;
    }

    public static function ays_get_woocommerce_product_categories(){
        $taxonomy     = 'product_cat';
		$orderby      = 'name';  
		$show_count   = 0;      // 1 for yes, 0 for no
		$pad_counts   = 0;      // 1 for yes, 0 for no
		$hierarchical = 1;      // 1 for yes, 0 for no  
		$title        = '';  
		$empty        = 0;

		$args = array(
			'taxonomy'     => $taxonomy,
			'orderby'      => $orderby,
			'show_count'   => $show_count,
			'pad_counts'   => $pad_counts,
			'hierarchical' => $hierarchical,
			'title_li'     => $title,
			'hide_empty'   => $empty
		);
		$all_categories = get_categories( $args );

		$sub_category_name_arr = array();
		foreach ($all_categories as $cat) {

			if($cat->category_parent == 0) {
			    $category_id   = $cat->term_id;       
			    $category_name = $cat->name;  

			    $sub_category_name_arr[] = array(
	            	"id" 	=> $category_id,
	            	"name" 	=> $category_name,
	            );
			}       
		}

		return $sub_category_name_arr;
    }

    public function ays_quiz_woocommerce_get_woocommerce_products(){
        global $wpdb;

        $search = isset($_REQUEST['q']) && $_REQUEST['q'] != '' ? $_REQUEST['q'] : null;

        $results = array(
            'results' => array()
        );

        $sql = "SELECT t.*
                FROM {$wpdb->prefix}posts AS t
                WHERE t.post_type IN ('product')
                    AND t.post_status = 'publish' ";

        if($search !== null){
            $sql .= " AND t.post_title LIKE '%{$search}%' ";
        }else{

        }

        $sql .= " ORDER BY t.post_title ASC";
        $products = $wpdb->get_results( $sql );

        foreach ($products as $key => $value) {
            $results['results'][] = array(
                'id' => $value->ID,
                'text' => $value->post_title,
            );
        }

        ob_end_clean();
        $ob_get_clean = ob_get_clean();
        echo json_encode( $results );
        wp_die();
    }


    public function ays_quiz_woocommerce_create_item( $data ) {

    	$results = array(
            'status' 		=> false,
            'message' 		=> 'aaa',
            'product_id' 	=> 0,
        );

		// Quiz ID
		$quiz_id = (isset( $_REQUEST['quiz_id'] ) && $_REQUEST['quiz_id'] != '') ? absint( sanitize_text_field( $_REQUEST['quiz_id'] ) ) : null;

		if ( ! is_null( $quiz_id ) || $quiz_id > 0 ) {

    		if ( class_exists( "WC_Product" ) ) {

	    		// Product title
	    		$product_title = (isset( $_REQUEST['title'] ) && $_REQUEST['title'] != '') ? stripcslashes( sanitize_text_field( $_REQUEST['title'] ) ) : "";

	    		// Product Price
	    		$product_price = (isset( $_REQUEST['price'] ) && $_REQUEST['price'] != '') ? absint( sanitize_text_field( $_REQUEST['price'] ) ) : 0;

	    		// Product Category
	    		$product_category 	  = (isset( $_REQUEST['category'] ) && $_REQUEST['category'] != '') ? absint( sanitize_text_field( $_REQUEST['category'] ) ) : 0;
	    		$product_category_arr = array( $product_category );

	    		$product_description = "[ays_quiz id='". $quiz_id ."']";

		    	$objProduct = new WC_Product();
			    
			    $objProduct->set_name( $product_title );
				$objProduct->set_status("publish");
				$objProduct->set_catalog_visibility('visible');
				$objProduct->set_description( $product_description );
				// $objProduct->set_sku("product-sku");
				$objProduct->set_price( $product_price );
				$objProduct->set_regular_price( $product_price );
				$objProduct->set_manage_stock(false);
				// $objProduct->set_stock_quantity();
				$objProduct->set_stock_status('instock');
				$objProduct->set_backorders('no');
				$objProduct->set_reviews_allowed(false);
				$objProduct->set_sold_individually(false);
				$objProduct->set_category_ids( $product_category_arr );

				$product_id = $objProduct->save();

				$results = array(
		            'status' 		=> true,
		            'message' 		=> 'BBB',
		            'product_id' 	=> $product_id,
		        );
    		}

    	}

    	ob_end_clean();
        $ob_get_clean = ob_get_clean();
        echo json_encode( $results );
        wp_die();
	}

	////////////////////////////////////////////////////////////////////////////////////////
    //====================================================================================//
    ////////////////////////////////////////////////////////////////////////////////////////

    // ===== Woocommerce start =====

        // Woocommerce integration

        // Woocommerce integration in quiz page content
        public function ays_quiz_page_woocommerce_content( $integrations, $args ){

        	$quiz_id = (isset( $_REQUEST['quiz'] ) && $_REQUEST['quiz'] != '') ? absint( sanitize_text_field( $_REQUEST['quiz'] ) ) : '';

        	$settings_options = $this->ays_get_setting('options');
			if($settings_options){
			    $settings_options = json_decode(stripcslashes($settings_options), true);
			}else{
			    $settings_options = array();
			}

    		$create_product_btn_class 		= "disabled";
    		$create_product_btn_attr  		= "disabled";
			$create_product_btn_error_msg   = '<hr><blockquote class="error_message">'. __( "Please save the quiz.", $this->plugin_name ) .'</blockquote>';

        	if ( $quiz_id != '' && $quiz_id > 0 ) {
        		$create_product_btn_class = "ays_quiz_woocommerce_create_product_btn";
    			$create_product_btn_attr  = "";
    			$create_product_btn_error_msg  	= "";
        	}

            $enable_woocommerce 	= $args['enable_woocommerce'];
            $woocommerce_method 	= $args['woocommerce_method'];
            $woocommerce_title 		= $args['woocommerce_title'];
            $woocommerce_price 		= $args['woocommerce_price'];
            $woocommerce_category 	= $args['woocommerce_category'];
            $woocommerce_product 	= $args['woocommerce_product'];
            $woocommerce_message 	= $args['woocommerce_message'];


            $woocommerce_method_create 			= '';
            $woocommerce_method_existed_product = '';
            $woocommerce_method_existed_product_class = '';
            $woocommerce_method_create_class = '';
            switch ( $woocommerce_method ) {
            	case 'existed_product':
            		$woocommerce_method_existed_product = "checked";
            		$woocommerce_method_create_class = "display_none";
            		break;
            	case 'create':
            	default:
            		$woocommerce_method_create = "checked";
            		$woocommerce_method_existed_product_class = "display_none";
            		break;
            }

            $selected_product = "";
            if( ! empty( $woocommerce_product ) ){

            	$product = $this->ays_get_woocommerce_product( $woocommerce_product );

                if(! empty( $product ) ){
                    foreach($product as $_key => $_value){
                        $selected_product .= "<option selected data-nkar='". $_value->image ."' value='". $_value->ID ."'>". $_value->post_title ."</option>";
                    }
                }
            }

            $woocommerce_category_list = $this->ays_get_woocommerce_product_categories();
            $woocommerce_category_html = "";
            if( ! empty( $woocommerce_category_list ) ){

                foreach($woocommerce_category_list as $_key => $_value){

                	$selected = "";
                	if ( $woocommerce_category == $_value['id'] ) {
                		$selected = "selected";
                	}

                    $woocommerce_category_html .= "<option ". $selected ." value='". $_value['id'] ."'>". $_value['name'] ."</option>";
                }
            }


			// WP Editor height
			$quiz_wp_editor_height = (isset($settings_options['quiz_wp_editor_height']) && $settings_options['quiz_wp_editor_height'] != '') ? absint( sanitize_text_field($settings_options['quiz_wp_editor_height']) ) : 100;

            $editor_id = 'ays_quiz_woocommerce_message';
            $woocommerce_wp_editor_settings = array('editor_height' => $quiz_wp_editor_height, 'textarea_name' => 'ays_quiz_woocommerce_message', 'editor_class' => 'ays-textarea', 'media_elements' => false);


            $icon = QUIZ_MAKER_WOOCOMMERCE_ADMIN_URL .'/images/integrations/woocommerce-logo.png';
            $title = __('WooCommerce Settings',$this->plugin_name);

            $content = '';
            if( ! in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) ){
                $content .= $this->blockquote_content;
            }else{
                $checked = ($enable_woocommerce == true) ? "checked" : '';

                $checked = "";
            	$hide_woocommerce = "display_none";
                if ( $enable_woocommerce ) {
                	$checked = "checked";
                	$hide_woocommerce = "";
                }

            	ob_start();
            	wp_editor( $woocommerce_message, $editor_id, $woocommerce_wp_editor_settings );
                $content .= '
                <div class="form-group row ays_toggle_parent">
                    <div class="col-sm-4">
                        <label for="ays_quiz_enable_woocommerce">'. __('Enable WooCommerce', $this->plugin_name) .'</label>
                    </div>
                    <div class="col-sm-1">
                        <input type="checkbox" class="ays-enable-timer1 ays_toggle_checkbox" id="ays_quiz_enable_woocommerce" name="ays_quiz_enable_woocommerce" value="on" '.$checked.' />
                    </div>
                    <div class="col-sm-7 ays_toggle_target ays_divider_left '. $hide_woocommerce .'">
                    	<div class="form-group row">
		                	<div class="col-sm-3">
		                		<label for="ays_quiz_woocommerce_message">'. __('Message', $this->plugin_name) .'</label>
		                        <a class="ays_help" data-toggle="tooltip" title="' . __('Provide the message text that will be displayed on the front page of your WooCommerce product.',$this->plugin_name) .'">
		                            <i class="ays_fa ays_fa_info_circle"></i>
		                        </a>
		                	</div>
		                	<div class="col-sm-9">
		                	';

            	$ob_get_clean = ob_get_clean();
            	$content .= $ob_get_clean;

	           	$content .= '
		                	</div>
		                </div>
		                <hr>
                    	<div class="form-group row">
		                    <div class="col-sm-3">
		                        <label>'. __('Select method', $this->plugin_name) .'</label>
		                        <a class="ays_help" data-toggle="tooltip" data-html="true" data-placement="top" title="'. esc_attr( '<p style="margin-bottom:3px;">'. __( "Please, choose between the two methods of selecting the product available." , $this->plugin_name ) .'
		                            <p style="padding-left:10px;margin-bottom:3px;"><strong>'. __( "Create product", $this->plugin_name ) .'</strong>  '. __( "- If you select this method, you need to configure the product details in the fields below, and the new WooCommerce product will automatically be added to your WooCommerce products page. The shortcode of this quiz will be added as the description of the product." , $this->plugin_name ) .'</p>
		                            <p style="padding-left:10px;margin-bottom:3px;"><strong>'. __( "Connect existing product", $this->plugin_name ) .'</strong>  '. __( "- If you choose this method, you will have to select an existing WooCommerce product from your products." , $this->plugin_name ) .'</p>' ) .'"
		                            >
		                            <i class="ays_fa ays_fa_info_circle"></i>
		                        </a>
		                    </div>
		                    <div class="col-sm-9">
		                    	<div class="form-check form-check-inline checkbox_ays">
			                    	<input type="radio" id="ays_quiz_woocommerce_method_create" class="form-check-input ays_quiz_woocommerce_method" name="ays_quiz_woocommerce_method" value="create" '. $woocommerce_method_create .'/>
				                    <label class="form-check-label" for="ays_quiz_woocommerce_method_create">' . __("Create product",$this->plugin_name) . '</label>
				                </div>
			                	<div class="form-check form-check-inline checkbox_ays">
		                            <input type="radio" id="ays_quiz_woocommerce_method_existed_product" class="form-check-input ays_quiz_woocommerce_method" name="ays_quiz_woocommerce_method" value="existed_product" '. $woocommerce_method_existed_product . '/>
		                            <label class="form-check-label" for="ays_quiz_woocommerce_method_existed_product">' . __("Connect existing product",$this->plugin_name) . '</label>
		                        </div>
		                    </div>
		                </div>
		                <hr>
		                <div class="form-group row ays_quiz_woocommerce_create '. $woocommerce_method_create_class .'">
		                    <div class="col-sm-12">
		                    	<div class="form-group row">
			                    	<div class="col-sm-3">
				                        <label for="ays_quiz_woocommerce_title">'. __('Product title', $this->plugin_name) .'</label>
				                        <a class="ays_help" data-toggle="tooltip" title="' . esc_attr( __("Define the title of the new product. If you don't change this field, your product will get the quiz name as default.",$this->plugin_name) ) .'">
				                            <i class="ays_fa ays_fa_info_circle"></i>
				                        </a>
				                    </div>
				                    <div class="col-sm-9">
				                    	<input type="text" class="ays-text-input" id="ays_quiz_woocommerce_title" name="ays_quiz_woocommerce_title" value="'. $woocommerce_title . '"/>
				                    </div>
			                    </div>
			                    <hr>
		                		<div class="form-group row">
			                    	<div class="col-sm-3">
				                        <label for="ays_quiz_woocommerce_price">'. __('Price', $this->plugin_name) .'</label>
				                        <a class="ays_help" data-toggle="tooltip" title="' . __('Specify the price of the product.',$this->plugin_name) .'">
				                            <i class="ays_fa ays_fa_info_circle"></i>
				                        </a>
				                    </div>
				                    <div class="col-sm-9">
				                    	<input type="number" class="ays-text-input" id="ays_quiz_woocommerce_price" name="ays_quiz_woocommerce_price" step="any" value="'. $woocommerce_price . '"/>
				                    </div>
			                    </div>
			                    <hr>
			                    <div class="form-group row">
			                    	<div class="col-sm-3">
				                        <label for="ays_quiz_woocommerce_category">'. __('Category', $this->plugin_name) .'</label>
				                        <a class="ays_help" data-toggle="tooltip" title="' . __('Choose the product category from your existing WooCommerce categories.',$this->plugin_name) .'">
				                            <i class="ays_fa ays_fa_info_circle"></i>
				                        </a>
				                    </div>
				                    <div class="col-sm-9">
				                    	<select class="ays-text-input ays-text-input-long" name="ays_quiz_woocommerce_category" id="ays_quiz_woocommerce_category">
				                    		<option>'. __( "Select category", $this->plugin_name ) .'</option>
				                    		'. $woocommerce_category_html .'
				                    	</select>
				                    </div>
			                    </div>
			                    <hr>
			                    <div class="form-group row">
				                    <div class="col-sm-12">
				                    	<a href="javascript:void(0)" class="'. $create_product_btn_class .' button button-primary" data-id="'. $quiz_id .'" '. $create_product_btn_attr .'>'. __( "Create product", $this->plugin_name ) .'</a>
				                    	<img class="ays_quiz_woocommerce_loader" src="'. QUIZ_MAKER_WOOCOMMERCE_ADMIN_URL . "/images/loaders/tail-spin.svg" .'" style="display: none;">
                        				<span id="ays_quiz_woocommerce_successful_message" style="display: none;"></span>
                        				'. $create_product_btn_error_msg .'
				                    </div> 
			                    </div>
		                    </div>
		                </div>
		                <div class="form-group row ays_quiz_woocommerce_existed_product '. $woocommerce_method_existed_product_class .'">
		                    <div class="col-sm-12">
				                <div class="form-group row">
				                    <div class="col-sm-3">
				                        <label for="ays_quiz_woocommerce_product">'. __('Select Product', $this->plugin_name) .'</label>
				                        <a class="ays_help" data-toggle="tooltip" title="' . __('Select an already existing product from your WooCommerce products.',$this->plugin_name) .'">
				                            <i class="ays_fa ays_fa_info_circle"></i>
				                        </a>
				                    </div>
				                    <div class="col-sm-9">
				                    	<select class="ays-text-input ays-text-input-long ays_quiz_woocommerce_interval_wproduct" name="ays_quiz_woocommerce_product" id="ays_quiz_woocommerce_product">
				                    		<option></option>
				                    		'. $selected_product .'
				                    	</select>
				                    </div>
				                </div>
			                </div>
		                </div>
                    </div>
                </div>';
            }

            $integrations['woocommerce'] = array(
                'content' => $content,
                'icon' => $icon,
                'title' => $title,
            );

            return $integrations;
        }

        // Woocommerce integration in quiz page options
        public function ays_quiz_page_woocommerce_options( $args, $options ){

        	$quiz_id = (isset( $_REQUEST['quiz'] ) && $_REQUEST['quiz'] != '') ? absint( sanitize_text_field( $_REQUEST['quiz'] ) ) : '';

        	$quiz_title = "";
        	if ( $quiz_id != "" && $quiz_id > 0 ) {
        		$quiz = $this->get_quiz_by_id($quiz_id);

        		$quiz_title = (isset( $quiz['title'] ) && $quiz['title'] != "") ? esc_attr( sanitize_text_field( $quiz['title'] ) ) : "";
        	}

            // Enable Woocommerce
            $options['enable_woocommerce'] = isset( $options['enable_woocommerce'] ) ? sanitize_text_field( $options['enable_woocommerce'] ) : 'off';
            $args['enable_woocommerce'] = ( isset( $options['enable_woocommerce'] ) && $options['enable_woocommerce'] == 'on' ) ? true : false;

            // Select Method
            $args['woocommerce_method'] = ( isset($options['woocommerce_method']) && $options['woocommerce_method'] != '' ) ? esc_attr( sanitize_text_field( $options['woocommerce_method'] ) ) : 'create';

            // Woocommerce Title
            $args['woocommerce_title'] = ( isset($options['woocommerce_title']) && $options['woocommerce_title'] != '' ) ? esc_attr( sanitize_text_field( $options['woocommerce_title'] ) ) : $quiz_title;

            // Woocommerce Price
            $args['woocommerce_price'] = ( isset($options['woocommerce_price']) && $options['woocommerce_price'] != '' ) ? floatval( sanitize_text_field( $options['woocommerce_price'] ) ) : '';

            // Woocommerce Category
            $args['woocommerce_category'] = ( isset($options['woocommerce_category']) && $options['woocommerce_category'] != '' ) ? absint( sanitize_text_field( $options['woocommerce_category'] ) ) : '';

            // Woocommerce Category
            $args['woocommerce_product'] = ( isset($options['woocommerce_product']) && $options['woocommerce_product'] != '' ) ? absint( sanitize_text_field( $options['woocommerce_product'] ) ) : '';

            // Woocommerce Category
            $args['woocommerce_message'] = ( isset($options['woocommerce_message']) && $options['woocommerce_message'] != '' ) ? stripslashes( $options['woocommerce_message'] ) : '';


            return $args;
        }

        // Woocommerce integration in quiz page data saver
        public function ays_quiz_page_woocommerce_save( $options, $data ){

        	// Enable Woocommerce
            $options['enable_woocommerce'] = ( isset( $_POST['ays_quiz_enable_woocommerce'] ) && $_POST['ays_quiz_enable_woocommerce'] == 'on' ) ? 'on' : 'off';

            // Select Method
            $options['woocommerce_method'] = ( isset( $_POST['ays_quiz_woocommerce_method'] ) && $_POST['ays_quiz_woocommerce_method'] != '' ) ? sanitize_text_field( $_POST['ays_quiz_woocommerce_method'] ) : 'create';

            // Woocommerce Title
            $options['woocommerce_title'] = ( isset( $_POST['ays_quiz_woocommerce_title'] ) && $_POST['ays_quiz_woocommerce_title'] != '' ) ? sanitize_text_field( $_POST['ays_quiz_woocommerce_title'] ) : '';

            // Woocommerce Price
            $options['woocommerce_price'] = ( isset( $_POST['ays_quiz_woocommerce_price'] ) && $_POST['ays_quiz_woocommerce_price'] != '' ) ? floatval( sanitize_text_field( $_POST['ays_quiz_woocommerce_price'] ) ) : '';

            // Woocommerce Category
            $options['woocommerce_category'] = ( isset( $_POST['ays_quiz_woocommerce_category'] ) && $_POST['ays_quiz_woocommerce_category'] != '' ) ? sanitize_text_field( $_POST['ays_quiz_woocommerce_category'] ) : '';

            // Woocommerce Product
            $options['woocommerce_product'] = ( isset( $_POST['ays_quiz_woocommerce_product'] ) && $_POST['ays_quiz_woocommerce_product'] != '' ) ? sanitize_text_field( $_POST['ays_quiz_woocommerce_product'] ) : '';

            // Woocommerce Message
            $options['woocommerce_message'] = ( isset( $_POST['ays_quiz_woocommerce_message'] ) && $_POST['ays_quiz_woocommerce_message'] != '' ) ? wp_kses_post( $_POST['ays_quiz_woocommerce_message'] ) : '';

            return $options;
        }

        // Woocommerce integration / settings page

        // Woocommerce integration in General settings page content
    	public function ays_woocommerce_settings_page_content( $integrations, $args ){
	        $icon  = QUIZ_MAKER_WOOCOMMERCE_ADMIN_URL . '/images/integrations/woocommerce-logo.png';
	        $title = __( 'WooCommerce', $this->plugin_name );

	        if(in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))){
	        	$content = "<blockquote style='border-color:#78c0a8;'>".
	        	__( "You are connected to WooCommerce.", $this->plugin_name ) 
				. "<br>" .
				__( "Please, go to the Integration tab of your quiz to configure the settings.", $this->plugin_name )
				."</blockquote>";
			}else{
		        $content = "<blockquote style='border-color:red;'>".__('To enable the integration, please install the WooCommerce plugin.' , $this->plugin_name)."</blockquote>";
			}

	        $integrations['woocommerce'] = array(
	            'content' => $content,
	            'icon'    => $icon,
	            'title'   => $title,
	        );
	        return $integrations;
	    }


        // Woocommerce integration / front-end

        // Woocommerce integration in front-end functional
        public function ays_front_end_woocommerce_functional( $options ){

        	$woo = in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')));
            $product = array();
            $woocommerce_data = array();

            $product_id = ( isset($options['woocommerce_product']) && $options['woocommerce_product'] != '' ) ? absint( sanitize_text_field( $options['woocommerce_product'] ) ) : '';

            $product_message = ( isset($options['woocommerce_message']) && $options['woocommerce_message'] != '' ) ? $options['woocommerce_message'] : '';

            if ( $product_id > 0 && $product_id != "" ) {

            	$check_if_user_has_bought_items = $this->ays_quiz_woocommerce_check_if_user_has_bought_items( $product_id );

            	if ( $check_if_user_has_bought_items ) {
            		$woocommerce_data = array();
            	} else {
	            	if ( class_exists( "WC_Product_Factory" ) ) {
		                $wpf = new WC_Product_Factory();
		                $cart_text = __('Add to cart', 'woocommerce');
		                $product_id = explode(',', $product_id);

		                $woocommerce_html = array();
		                $woocommerce_html[] = '<div class="ays-woo-block-message">';
	                		$woocommerce_html[] = $this->ays_autoembed( $product_message );
            			$woocommerce_html[] = '</div>';

		                $woocommerce_html[] = '<div class="ays-woo-block-main">';

		                foreach($product_id as $_key => $_value){
		                	$product_url  	= get_permalink(intval($_value));
		                	$product_name 	= $wpf->get_product($_value)->get_data()['name'];
		                	$product_image 	= "";
		                	if( wp_get_attachment_image_src(get_post_thumbnail_id($_value), 'single-post-thumbnail') ){
		                	    $product_image 	= wp_get_attachment_image_src(get_post_thumbnail_id($_value), 'single-post-thumbnail')[0];
		                	}
		                	$product_link 	= "<a href=\"?add-to-cart=$_value\" data-quantity=\"1\" class=\"action-button product_type_simple add_to_cart_button ajax_add_to_cart\" data-product_id=\"$_value\" data-product_sku=\"\" aria-label=\"$cart_text\" rel=\"nofollow\">$cart_text</a><br>";

		                	$woocommerce_html[] = '<div class="ays-quiz-woo-addon-block" style="flex-wrap: wrap;">';
		                		$woocommerce_html[] = '<div class="ays-woo-product-block">';
		                			$woocommerce_html[] = '<h4 class="ays-woo-product-title"><a href="' . $product_url . '" target="_blank">'. $product_name .'</a></h4>';

		                			if ( is_null( $product_image ) && !empty( $product_image ) ) {
		                				$woocommerce_html[] = '<div class="product-image"><img src="' . $product_image . '" alt="'. __( "WooCommerce Product" , 'woocommerce' ) .'"></div>';
		                			}
	                				$woocommerce_html[] = '<div class="ays-quiz-woo-product-link-box">';
		                				$woocommerce_html[] = $product_link;
		                			$woocommerce_html[] = '</div>';
		                		$woocommerce_html[] = '</div>';
		                	$woocommerce_html[] = '</div>';

		                }
		                $woocommerce_html[] = '</div>';

		                $woocommerce_html = implode('', $woocommerce_html);

		                $woocommerce_data = array(
		                	'woocommerce_html' => $woocommerce_html
		                );
	            	}
            	}

            } else {
            	$woocommerce_data = array();
            }

            return $woocommerce_data;
        }

        // Woocommerce integration in front-end options
        public function ays_front_end_woocommerce_options( $args, $options ){

            // Woocommerce
            $args['enable_woocommerce'] = ( isset($options['enable_woocommerce'] ) && $options['enable_woocommerce'] == 'on') ? true : false;
            $args['woocommerce_list'] = (isset($options['woocommerce_list'])) ? $options['woocommerce_list'] : '';

            return $args;
        }

        public function ays_quiz_woocommerce_check_if_user_has_bought_items( $product_ids ) {
		    $bought = false;

		    // Set HERE ine the array your specific target product IDs
		    $prod_arr = array();
		    if ( is_array( $product_ids ) ) {
		    	$prod_arr = $product_ids;
		    } else {
		    	$prod_arr[] = $product_ids."";
		    }

		    // Get all customer orders
		    $customer_orders = get_posts( array(
		        'numberposts' => -1,
		        'meta_key'    => '_customer_user',
		        'meta_value'  => get_current_user_id(),
		        'post_type'   => 'shop_order', // WC orders post type
		        'post_status' => 'wc-completed' // Only orders with status "completed"
		    ) );
		    foreach ( $customer_orders as $customer_order ) {

		        // Updated compatibility with WooCommerce 3+
		        $order = wc_get_order( $customer_order );
		        $order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;

		        // Iterating through each current customer products bought in the order
		        foreach ($order->get_items() as $item) {
		            // WC 3+ compatibility
		            if ( version_compare( WC_VERSION, '3.0', '<' ) ) {
		                $product_id = $item['product_id'];
		            }
		            else {
		                $product_id = $item->get_product_id();
		            }

		            // Your condition related to your 2 specific products Ids
		            if ( in_array( $product_id, $prod_arr ) ) {
		                $bought = true;
		            }
		        }
		    }

		    // return "true" if one the specifics products have been bought before by customer
		    return $bought;
		}

    // ===== Woocommerce end =====

    ////////////////////////////////////////////////////////////////////////////////////////
    //====================================================================================//
    ////////////////////////////////////////////////////////////////////////////////////////


}
