(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	$(document).ready(function () {
    	$(document).on('change', '.ays_quiz_woocommerce_method', function (e) {
            var _this = $(this);

            var val    = _this.val();
            var parent = _this.parents('.ays_toggle_target');

	        switch( val ) {
	            case 'existed_product':
	                parent.find(".ays_quiz_woocommerce_existed_product").show(250);
	                parent.find(".ays_quiz_woocommerce_create").hide(250);
	            break;
	            case 'create':
	            default:
	                parent.find(".ays_quiz_woocommerce_existed_product").hide(250);
	                parent.find(".ays_quiz_woocommerce_create").show(250);
	            break;
	        }
        });
    });

    //Access Only selected users (AV)
    $(document).find('select.ays_quiz_woocommerce_interval_wproduct').select2({
        allowClear: false,
        placeholder: 'Select product',
        minimumInputLength: 1,
        ajax: {
            url: quiz_maker_woocommerce_ajax.ajax_url,
            dataType: 'json',
            delay: 250,
            data: function (params) {
                var checkedProducts = $(document).find('#ays_woo_selected_prods').val();
                var checkedArray = [];
                if(checkedProducts != ""){
                    checkedArray = checkedProducts.split(',');
                }
                return {
                    action: 'ays_get_woocommerce_products',
                    q: params.term,
                    prods: checkedArray,
                    page: params.page
                };
            },
        }
    });

    $(document).find('.ays_quiz_woocommerce_create_product_btn').on('click', function(e) {
    	var $this = $(this);
    	var parent = $this.parents('.ays_toggle_target');

    	var selectedProduct = parent.find('select.ays_quiz_woocommerce_interval_wproduct');

        $this.prop('disabled', true);
        $this.addClass('disabled');

    	parent.find('.ays_quiz_woocommerce_loader').css({'display': 'inline'});

        var action  = 'ays_quiz_woocommerce_create_item';
        var quiz_id = $this.attr('data-id');

        var product_title 	 = parent.find('#ays_quiz_woocommerce_title').val();
        var product_price 	 = parent.find('#ays_quiz_woocommerce_price').val();
        var product_category = parent.find('#ays_quiz_woocommerce_category').val();

        $.ajax({
            url: quiz_maker_woocommerce_ajax.ajax_url,
            method: 'post',
            dataType: 'json',
            data: {
                action: action,
                quiz_id: quiz_id,
                title: product_title,
                price: product_price,
                category: product_category,
            },
            success: function (response) {

                if (response.status) {
                	parent.find("#ays_quiz_woocommerce_method_existed_product").trigger('click');

                	var selectData = {
					    id: response.product_id,
					    text: product_title
					};

					var newOption = new Option(selectData.text, selectData.id, false, true);
					selectedProduct.append(newOption).trigger('change');

                }else{
                    swal.fire({
                        type: 'info',
                        html: "<h2>"+ quiz_maker_woocommerce_ajax.loadResource +"</h2><br><h4>"+ quiz_maker_woocommerce_ajax.somethingWentWrong +"</h4>"
                    });
                }

                $this.prop('disabled', false);
        		$this.removeClass('disabled');

        		parent.find('.ays_quiz_woocommerce_loader').css({'display': 'none'});
            }
        });
        e.preventDefault();
    });


})( jQuery );
